""" Cisco_IOS_XR_pmengine_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR pmengine package operational data.

This module contains definitions
for the following management objects\:
  performance\-management\: performace data
  performance\-management\-history\: performance management history

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class PmPrbsPatternEt(Enum):
    """
    PmPrbsPatternEt

    PM PRBS Pattern Mode Enum

    .. data:: prbs_none = 0

    	pn none

    .. data:: pn31 = 1

    	pn31

    .. data:: pn23 = 2

    	pn23

    .. data:: pn11 = 4

    	pn11

    .. data:: inv_pn31 = 8

    	inv pn31

    .. data:: inv_pn11 = 16

    	inv pn11

    """

    prbs_none = Enum.YLeaf(0, "prbs-none")

    pn31 = Enum.YLeaf(1, "pn31")

    pn23 = Enum.YLeaf(2, "pn23")

    pn11 = Enum.YLeaf(4, "pn11")

    inv_pn31 = Enum.YLeaf(8, "inv-pn31")

    inv_pn11 = Enum.YLeaf(16, "inv-pn11")


class PmSonetPathWidthEnum(Enum):
    """
    PmSonetPathWidthEnum

    Sonet Path Width Enum

    .. data:: none = 0

    	Sonet Path Width NONE 

    .. data:: sts1 = 1

    	Sonet Path Width STS1 

    .. data:: sts3c_stm1 = 2

    	Sonet Path Width sts3cSTM1 

    .. data:: sts12c_stm4 = 3

    	Sonet Path Width sts12cSTM4 

    .. data:: sts24c = 4

    	Sonet Path Width sts24 

    .. data:: sts48c_stm16 = 5

    	Sonet Path Width sts48cSTM16 

    .. data:: sts192c_stm64 = 6

    	Sonet Path Width sts192cSTM64 

    .. data:: sts768c_stm256 = 7

    	Sonet Path Width sts768cSTM256 

    """

    none = Enum.YLeaf(0, "none")

    sts1 = Enum.YLeaf(1, "sts1")

    sts3c_stm1 = Enum.YLeaf(2, "sts3c-stm1")

    sts12c_stm4 = Enum.YLeaf(3, "sts12c-stm4")

    sts24c = Enum.YLeaf(4, "sts24c")

    sts48c_stm16 = Enum.YLeaf(5, "sts48c-stm16")

    sts192c_stm64 = Enum.YLeaf(6, "sts192c-stm64")

    sts768c_stm256 = Enum.YLeaf(7, "sts768c-stm256")



class PerformanceManagement(Entity):
    """
    performace data
    
    .. attribute:: dwdm
    
    	DWDM controller performance data
    	**type**\:   :py:class:`Dwdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm>`
    
    .. attribute:: ethernet
    
    	EHERNET controller performance data
    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet>`
    
    .. attribute:: ho_vc
    
    	HO\_VC controller performance data
    	**type**\:   :py:class:`HoVc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc>`
    
    .. attribute:: oc
    
    	OC controller performance data
    	**type**\:   :py:class:`Oc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc>`
    
    .. attribute:: odu
    
    	ODU controller performance data
    	**type**\:   :py:class:`Odu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu>`
    
    .. attribute:: optics
    
    	OPTICS controller performance data
    	**type**\:   :py:class:`Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics>`
    
    .. attribute:: otu
    
    	OTU controller performance data
    	**type**\:   :py:class:`Otu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu>`
    
    .. attribute:: sonet
    
    	SONET controller performance data
    	**type**\:   :py:class:`Sonet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet>`
    
    .. attribute:: stm
    
    	STM controller performance data
    	**type**\:   :py:class:`Stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm>`
    
    .. attribute:: sts
    
    	STS controller performance data
    	**type**\:   :py:class:`Sts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts>`
    
    

    """

    _prefix = 'pmengine-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(PerformanceManagement, self).__init__()
        self._top_entity = None

        self.yang_name = "performance-management"
        self.yang_parent_name = "Cisco-IOS-XR-pmengine-oper"

        self.dwdm = PerformanceManagement.Dwdm()
        self.dwdm.parent = self
        self._children_name_map["dwdm"] = "dwdm"
        self._children_yang_names.add("dwdm")

        self.ethernet = PerformanceManagement.Ethernet()
        self.ethernet.parent = self
        self._children_name_map["ethernet"] = "ethernet"
        self._children_yang_names.add("ethernet")

        self.ho_vc = PerformanceManagement.HoVc()
        self.ho_vc.parent = self
        self._children_name_map["ho_vc"] = "ho-vc"
        self._children_yang_names.add("ho-vc")

        self.oc = PerformanceManagement.Oc()
        self.oc.parent = self
        self._children_name_map["oc"] = "oc"
        self._children_yang_names.add("oc")

        self.odu = PerformanceManagement.Odu()
        self.odu.parent = self
        self._children_name_map["odu"] = "odu"
        self._children_yang_names.add("odu")

        self.optics = PerformanceManagement.Optics()
        self.optics.parent = self
        self._children_name_map["optics"] = "optics"
        self._children_yang_names.add("optics")

        self.otu = PerformanceManagement.Otu()
        self.otu.parent = self
        self._children_name_map["otu"] = "otu"
        self._children_yang_names.add("otu")

        self.sonet = PerformanceManagement.Sonet()
        self.sonet.parent = self
        self._children_name_map["sonet"] = "sonet"
        self._children_yang_names.add("sonet")

        self.stm = PerformanceManagement.Stm()
        self.stm.parent = self
        self._children_name_map["stm"] = "stm"
        self._children_yang_names.add("stm")

        self.sts = PerformanceManagement.Sts()
        self.sts.parent = self
        self._children_name_map["sts"] = "sts"
        self._children_yang_names.add("sts")


    class HoVc(Entity):
        """
        HO\_VC controller performance data
        
        .. attribute:: ho_vc_ports
        
        	Port performance data
        	**type**\:   :py:class:`HoVcPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PerformanceManagement.HoVc, self).__init__()

            self.yang_name = "ho-vc"
            self.yang_parent_name = "performance-management"

            self.ho_vc_ports = PerformanceManagement.HoVc.HoVcPorts()
            self.ho_vc_ports.parent = self
            self._children_name_map["ho_vc_ports"] = "ho-vc-ports"
            self._children_yang_names.add("ho-vc-ports")


        class HoVcPorts(Entity):
            """
            Port performance data
            
            .. attribute:: ho_vc_port
            
            	Port performance data
            	**type**\: list of    :py:class:`HoVcPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PerformanceManagement.HoVc.HoVcPorts, self).__init__()

                self.yang_name = "ho-vc-ports"
                self.yang_parent_name = "ho-vc"

                self.ho_vc_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(PerformanceManagement.HoVc.HoVcPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(PerformanceManagement.HoVc.HoVcPorts, self).__setattr__(name, value)


            class HoVcPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ho_vc_current
                
                	port current performance data
                	**type**\:   :py:class:`HoVcCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort, self).__init__()

                    self.yang_name = "ho-vc-port"
                    self.yang_parent_name = "ho-vc-ports"

                    self.name = YLeaf(YType.str, "name")

                    self.ho_vc_current = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent()
                    self.ho_vc_current.parent = self
                    self._children_name_map["ho_vc_current"] = "ho-vc-current"
                    self._children_yang_names.add("ho-vc-current")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort, self).__setattr__(name, value)


                class HoVcCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: ho_vc_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`HoVcHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24>`
                    
                    .. attribute:: ho_vc_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`HoVcMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent, self).__init__()

                        self.yang_name = "ho-vc-current"
                        self.yang_parent_name = "ho-vc-port"

                        self.ho_vc_hour24 = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24()
                        self.ho_vc_hour24.parent = self
                        self._children_name_map["ho_vc_hour24"] = "ho-vc-hour24"
                        self._children_yang_names.add("ho-vc-hour24")

                        self.ho_vc_minute15 = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15()
                        self.ho_vc_minute15.parent = self
                        self._children_name_map["ho_vc_minute15"] = "ho-vc-minute15"
                        self._children_yang_names.add("ho-vc-minute15")


                    class HoVcHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: ho_vc_hour24_paths
                        
                        	port current performance data
                        	**type**\:   :py:class:`HoVcHour24Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24, self).__init__()

                            self.yang_name = "ho-vc-hour24"
                            self.yang_parent_name = "ho-vc-current"

                            self.ho_vc_hour24_paths = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths()
                            self.ho_vc_hour24_paths.parent = self
                            self._children_name_map["ho_vc_hour24_paths"] = "ho-vc-hour24-paths"
                            self._children_yang_names.add("ho-vc-hour24-paths")


                        class HoVcHour24Paths(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: ho_vc_hour24_path
                            
                            	port 24 hour Path performance data
                            	**type**\: list of    :py:class:`HoVcHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths, self).__init__()

                                self.yang_name = "ho-vc-hour24-paths"
                                self.yang_parent_name = "ho-vc-hour24"

                                self.ho_vc_hour24_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths, self).__setattr__(name, value)


                            class HoVcHour24Path(Entity):
                                """
                                port 24 hour Path performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path, self).__init__()

                                    self.yang_name = "ho-vc-hour24-path"
                                    self.yang_parent_name = "ho-vc-hour24-paths"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.fe_path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath()
                                    self.fe_path.parent = self
                                    self._children_name_map["fe_path"] = "fe-path"
                                    self._children_yang_names.add("fe-path")

                                    self.path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path()
                                    self.path.parent = self
                                    self._children_name_map["path"] = "path"
                                    self._children_yang_names.add("path")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path, self).__setattr__(name, value)


                                class Path(Entity):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_bb_es
                                    
                                    	The number of background block errors
                                    	**type**\:   :py:class:`PathBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs>`
                                    
                                    .. attribute:: path_bbe_rs
                                    
                                    	The number of background block errors
                                    	**type**\:   :py:class:`PathBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs>`
                                    
                                    .. attribute:: path_e_bs
                                    
                                    	The number of Errored blocks
                                    	**type**\:   :py:class:`PathEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs>`
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs>`
                                    
                                    .. attribute:: path_es_rs
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_ses_rs
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "ho-vc-hour24-path"

                                        self.path_status = YLeaf(YType.int32, "path-status")

                                        self.path_bb_es = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs()
                                        self.path_bb_es.parent = self
                                        self._children_name_map["path_bb_es"] = "path-bb-es"
                                        self._children_yang_names.add("path-bb-es")

                                        self.path_bbe_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs()
                                        self.path_bbe_rs.parent = self
                                        self._children_name_map["path_bbe_rs"] = "path-bbe-rs"
                                        self._children_yang_names.add("path-bbe-rs")

                                        self.path_e_bs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs()
                                        self.path_e_bs.parent = self
                                        self._children_name_map["path_e_bs"] = "path-e-bs"
                                        self._children_yang_names.add("path-e-bs")

                                        self.path_e_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self._children_name_map["path_e_ss"] = "path-e-ss"
                                        self._children_yang_names.add("path-e-ss")

                                        self.path_es_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs()
                                        self.path_es_rs.parent = self
                                        self._children_name_map["path_es_rs"] = "path-es-rs"
                                        self._children_yang_names.add("path-es-rs")

                                        self.path_se_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self._children_name_map["path_se_ss"] = "path-se-ss"
                                        self._children_yang_names.add("path-se-ss")

                                        self.path_ses_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs()
                                        self.path_ses_rs.parent = self
                                        self._children_name_map["path_ses_rs"] = "path-ses-rs"
                                        self._children_yang_names.add("path-ses-rs")

                                        self.path_ua_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                        self._children_yang_names.add("path-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path, self).__setattr__(name, value)


                                    class PathESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs, self).__init__()

                                            self.yang_name = "path-e-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathEsRs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs, self).__init__()

                                            self.yang_name = "path-es-rs"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-es-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs, self).__init__()

                                            self.yang_name = "path-se-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathSesRs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs, self).__init__()

                                            self.yang_name = "path-ses-rs"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-ses-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathEBs(Entity):
                                        """
                                        The number of Errored blocks
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs, self).__init__()

                                            self.yang_name = "path-e-bs"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-e-bs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs, self).__init__()

                                            self.yang_name = "path-ua-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathBbEs(Entity):
                                        """
                                        The number of background block errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs, self).__init__()

                                            self.yang_name = "path-bb-es"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-bb-es" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathBbeRs(Entity):
                                        """
                                        The number of background block errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs, self).__init__()

                                            self.yang_name = "path-bbe-rs"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-bbe-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_status.is_set or
                                            (self.path_bb_es is not None and self.path_bb_es.has_data()) or
                                            (self.path_bbe_rs is not None and self.path_bbe_rs.has_data()) or
                                            (self.path_e_bs is not None and self.path_e_bs.has_data()) or
                                            (self.path_e_ss is not None and self.path_e_ss.has_data()) or
                                            (self.path_es_rs is not None and self.path_es_rs.has_data()) or
                                            (self.path_se_ss is not None and self.path_se_ss.has_data()) or
                                            (self.path_ses_rs is not None and self.path_ses_rs.has_data()) or
                                            (self.path_ua_ss is not None and self.path_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_status.yfilter != YFilter.not_set or
                                            (self.path_bb_es is not None and self.path_bb_es.has_operation()) or
                                            (self.path_bbe_rs is not None and self.path_bbe_rs.has_operation()) or
                                            (self.path_e_bs is not None and self.path_e_bs.has_operation()) or
                                            (self.path_e_ss is not None and self.path_e_ss.has_operation()) or
                                            (self.path_es_rs is not None and self.path_es_rs.has_operation()) or
                                            (self.path_se_ss is not None and self.path_se_ss.has_operation()) or
                                            (self.path_ses_rs is not None and self.path_ses_rs.has_operation()) or
                                            (self.path_ua_ss is not None and self.path_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "path-bb-es"):
                                            if (self.path_bb_es is None):
                                                self.path_bb_es = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbEs()
                                                self.path_bb_es.parent = self
                                                self._children_name_map["path_bb_es"] = "path-bb-es"
                                            return self.path_bb_es

                                        if (child_yang_name == "path-bbe-rs"):
                                            if (self.path_bbe_rs is None):
                                                self.path_bbe_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathBbeRs()
                                                self.path_bbe_rs.parent = self
                                                self._children_name_map["path_bbe_rs"] = "path-bbe-rs"
                                            return self.path_bbe_rs

                                        if (child_yang_name == "path-e-bs"):
                                            if (self.path_e_bs is None):
                                                self.path_e_bs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEBs()
                                                self.path_e_bs.parent = self
                                                self._children_name_map["path_e_bs"] = "path-e-bs"
                                            return self.path_e_bs

                                        if (child_yang_name == "path-e-ss"):
                                            if (self.path_e_ss is None):
                                                self.path_e_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathESs()
                                                self.path_e_ss.parent = self
                                                self._children_name_map["path_e_ss"] = "path-e-ss"
                                            return self.path_e_ss

                                        if (child_yang_name == "path-es-rs"):
                                            if (self.path_es_rs is None):
                                                self.path_es_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathEsRs()
                                                self.path_es_rs.parent = self
                                                self._children_name_map["path_es_rs"] = "path-es-rs"
                                            return self.path_es_rs

                                        if (child_yang_name == "path-se-ss"):
                                            if (self.path_se_ss is None):
                                                self.path_se_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSeSs()
                                                self.path_se_ss.parent = self
                                                self._children_name_map["path_se_ss"] = "path-se-ss"
                                            return self.path_se_ss

                                        if (child_yang_name == "path-ses-rs"):
                                            if (self.path_ses_rs is None):
                                                self.path_ses_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathSesRs()
                                                self.path_ses_rs.parent = self
                                                self._children_name_map["path_ses_rs"] = "path-ses-rs"
                                            return self.path_ses_rs

                                        if (child_yang_name == "path-ua-ss"):
                                            if (self.path_ua_ss is None):
                                                self.path_ua_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path.PathUaSs()
                                                self.path_ua_ss.parent = self
                                                self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                            return self.path_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "path-bb-es" or name == "path-bbe-rs" or name == "path-e-bs" or name == "path-e-ss" or name == "path-es-rs" or name == "path-se-ss" or name == "path-ses-rs" or name == "path-ua-ss" or name == "path-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-status"):
                                            self.path_status = value
                                            self.path_status.value_namespace = name_space
                                            self.path_status.value_namespace_prefix = name_space_prefix


                                class FePath(Entity):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath, self).__init__()

                                        self.yang_name = "fe-path"
                                        self.yang_parent_name = "ho-vc-hour24-path"

                                        self.far_end_path_c_vs = YLeaf(YType.uint32, "far-end-path-c-vs")

                                        self.far_end_path_e_ss = YLeaf(YType.uint32, "far-end-path-e-ss")

                                        self.far_end_path_se_ss = YLeaf(YType.uint32, "far-end-path-se-ss")

                                        self.far_end_path_ua_ss = YLeaf(YType.uint32, "far-end-path-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("far_end_path_c_vs",
                                                        "far_end_path_e_ss",
                                                        "far_end_path_se_ss",
                                                        "far_end_path_ua_ss") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.far_end_path_c_vs.is_set or
                                            self.far_end_path_e_ss.is_set or
                                            self.far_end_path_se_ss.is_set or
                                            self.far_end_path_ua_ss.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.far_end_path_c_vs.yfilter != YFilter.not_set or
                                            self.far_end_path_e_ss.yfilter != YFilter.not_set or
                                            self.far_end_path_se_ss.yfilter != YFilter.not_set or
                                            self.far_end_path_ua_ss.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fe-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.far_end_path_c_vs.is_set or self.far_end_path_c_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_c_vs.get_name_leafdata())
                                        if (self.far_end_path_e_ss.is_set or self.far_end_path_e_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_e_ss.get_name_leafdata())
                                        if (self.far_end_path_se_ss.is_set or self.far_end_path_se_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_se_ss.get_name_leafdata())
                                        if (self.far_end_path_ua_ss.is_set or self.far_end_path_ua_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_ua_ss.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "far-end-path-c-vs" or name == "far-end-path-e-ss" or name == "far-end-path-se-ss" or name == "far-end-path-ua-ss"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "far-end-path-c-vs"):
                                            self.far_end_path_c_vs = value
                                            self.far_end_path_c_vs.value_namespace = name_space
                                            self.far_end_path_c_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-e-ss"):
                                            self.far_end_path_e_ss = value
                                            self.far_end_path_e_ss.value_namespace = name_space
                                            self.far_end_path_e_ss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-se-ss"):
                                            self.far_end_path_se_ss = value
                                            self.far_end_path_se_ss.value_namespace = name_space
                                            self.far_end_path_se_ss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-ua-ss"):
                                            self.far_end_path_ua_ss = value
                                            self.far_end_path_ua_ss.value_namespace = name_space
                                            self.far_end_path_ua_ss.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.fe_path is not None and self.fe_path.has_data()) or
                                        (self.path is not None and self.path.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.fe_path is not None and self.fe_path.has_operation()) or
                                        (self.path is not None and self.path.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ho-vc-hour24-path" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "fe-path"):
                                        if (self.fe_path is None):
                                            self.fe_path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.FePath()
                                            self.fe_path.parent = self
                                            self._children_name_map["fe_path"] = "fe-path"
                                        return self.fe_path

                                    if (child_yang_name == "path"):
                                        if (self.path is None):
                                            self.path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path.Path()
                                            self.path.parent = self
                                            self._children_name_map["path"] = "path"
                                        return self.path

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fe-path" or name == "path" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.ho_vc_hour24_path:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.ho_vc_hour24_path:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ho-vc-hour24-paths" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ho-vc-hour24-path"):
                                    for c in self.ho_vc_hour24_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths.HoVcHour24Path()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.ho_vc_hour24_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ho-vc-hour24-path"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.ho_vc_hour24_paths is not None and self.ho_vc_hour24_paths.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.ho_vc_hour24_paths is not None and self.ho_vc_hour24_paths.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ho-vc-hour24" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ho-vc-hour24-paths"):
                                if (self.ho_vc_hour24_paths is None):
                                    self.ho_vc_hour24_paths = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24.HoVcHour24Paths()
                                    self.ho_vc_hour24_paths.parent = self
                                    self._children_name_map["ho_vc_hour24_paths"] = "ho-vc-hour24-paths"
                                return self.ho_vc_hour24_paths

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ho-vc-hour24-paths"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class HoVcMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: ho_vc_minute15_paths
                        
                        	port current performance data
                        	**type**\:   :py:class:`HoVcMinute15Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15, self).__init__()

                            self.yang_name = "ho-vc-minute15"
                            self.yang_parent_name = "ho-vc-current"

                            self.ho_vc_minute15_paths = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths()
                            self.ho_vc_minute15_paths.parent = self
                            self._children_name_map["ho_vc_minute15_paths"] = "ho-vc-minute15-paths"
                            self._children_yang_names.add("ho-vc-minute15-paths")


                        class HoVcMinute15Paths(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: ho_vc_minute15_path
                            
                            	port 15\-minute Path performance data
                            	**type**\: list of    :py:class:`HoVcMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths, self).__init__()

                                self.yang_name = "ho-vc-minute15-paths"
                                self.yang_parent_name = "ho-vc-minute15"

                                self.ho_vc_minute15_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths, self).__setattr__(name, value)


                            class HoVcMinute15Path(Entity):
                                """
                                port 15\-minute Path performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path, self).__init__()

                                    self.yang_name = "ho-vc-minute15-path"
                                    self.yang_parent_name = "ho-vc-minute15-paths"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.fe_path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath()
                                    self.fe_path.parent = self
                                    self._children_name_map["fe_path"] = "fe-path"
                                    self._children_yang_names.add("fe-path")

                                    self.path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path()
                                    self.path.parent = self
                                    self._children_name_map["path"] = "path"
                                    self._children_yang_names.add("path")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path, self).__setattr__(name, value)


                                class Path(Entity):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_bb_es
                                    
                                    	The number of background block errors
                                    	**type**\:   :py:class:`PathBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs>`
                                    
                                    .. attribute:: path_bbe_rs
                                    
                                    	The number of background block errors
                                    	**type**\:   :py:class:`PathBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs>`
                                    
                                    .. attribute:: path_e_bs
                                    
                                    	The number of Errored blocks
                                    	**type**\:   :py:class:`PathEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs>`
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs>`
                                    
                                    .. attribute:: path_es_rs
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_ses_rs
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "ho-vc-minute15-path"

                                        self.path_status = YLeaf(YType.int32, "path-status")

                                        self.path_bb_es = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs()
                                        self.path_bb_es.parent = self
                                        self._children_name_map["path_bb_es"] = "path-bb-es"
                                        self._children_yang_names.add("path-bb-es")

                                        self.path_bbe_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs()
                                        self.path_bbe_rs.parent = self
                                        self._children_name_map["path_bbe_rs"] = "path-bbe-rs"
                                        self._children_yang_names.add("path-bbe-rs")

                                        self.path_e_bs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs()
                                        self.path_e_bs.parent = self
                                        self._children_name_map["path_e_bs"] = "path-e-bs"
                                        self._children_yang_names.add("path-e-bs")

                                        self.path_e_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self._children_name_map["path_e_ss"] = "path-e-ss"
                                        self._children_yang_names.add("path-e-ss")

                                        self.path_es_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs()
                                        self.path_es_rs.parent = self
                                        self._children_name_map["path_es_rs"] = "path-es-rs"
                                        self._children_yang_names.add("path-es-rs")

                                        self.path_se_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self._children_name_map["path_se_ss"] = "path-se-ss"
                                        self._children_yang_names.add("path-se-ss")

                                        self.path_ses_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs()
                                        self.path_ses_rs.parent = self
                                        self._children_name_map["path_ses_rs"] = "path-ses-rs"
                                        self._children_yang_names.add("path-ses-rs")

                                        self.path_ua_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                        self._children_yang_names.add("path-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path, self).__setattr__(name, value)


                                    class PathESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs, self).__init__()

                                            self.yang_name = "path-e-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathEsRs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs, self).__init__()

                                            self.yang_name = "path-es-rs"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-es-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs, self).__init__()

                                            self.yang_name = "path-se-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathSesRs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs, self).__init__()

                                            self.yang_name = "path-ses-rs"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-ses-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathEBs(Entity):
                                        """
                                        The number of Errored blocks
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs, self).__init__()

                                            self.yang_name = "path-e-bs"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-e-bs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs, self).__init__()

                                            self.yang_name = "path-ua-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathBbEs(Entity):
                                        """
                                        The number of background block errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs, self).__init__()

                                            self.yang_name = "path-bb-es"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-bb-es" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathBbeRs(Entity):
                                        """
                                        The number of background block errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs, self).__init__()

                                            self.yang_name = "path-bbe-rs"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-bbe-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_status.is_set or
                                            (self.path_bb_es is not None and self.path_bb_es.has_data()) or
                                            (self.path_bbe_rs is not None and self.path_bbe_rs.has_data()) or
                                            (self.path_e_bs is not None and self.path_e_bs.has_data()) or
                                            (self.path_e_ss is not None and self.path_e_ss.has_data()) or
                                            (self.path_es_rs is not None and self.path_es_rs.has_data()) or
                                            (self.path_se_ss is not None and self.path_se_ss.has_data()) or
                                            (self.path_ses_rs is not None and self.path_ses_rs.has_data()) or
                                            (self.path_ua_ss is not None and self.path_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_status.yfilter != YFilter.not_set or
                                            (self.path_bb_es is not None and self.path_bb_es.has_operation()) or
                                            (self.path_bbe_rs is not None and self.path_bbe_rs.has_operation()) or
                                            (self.path_e_bs is not None and self.path_e_bs.has_operation()) or
                                            (self.path_e_ss is not None and self.path_e_ss.has_operation()) or
                                            (self.path_es_rs is not None and self.path_es_rs.has_operation()) or
                                            (self.path_se_ss is not None and self.path_se_ss.has_operation()) or
                                            (self.path_ses_rs is not None and self.path_ses_rs.has_operation()) or
                                            (self.path_ua_ss is not None and self.path_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "path-bb-es"):
                                            if (self.path_bb_es is None):
                                                self.path_bb_es = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbEs()
                                                self.path_bb_es.parent = self
                                                self._children_name_map["path_bb_es"] = "path-bb-es"
                                            return self.path_bb_es

                                        if (child_yang_name == "path-bbe-rs"):
                                            if (self.path_bbe_rs is None):
                                                self.path_bbe_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathBbeRs()
                                                self.path_bbe_rs.parent = self
                                                self._children_name_map["path_bbe_rs"] = "path-bbe-rs"
                                            return self.path_bbe_rs

                                        if (child_yang_name == "path-e-bs"):
                                            if (self.path_e_bs is None):
                                                self.path_e_bs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEBs()
                                                self.path_e_bs.parent = self
                                                self._children_name_map["path_e_bs"] = "path-e-bs"
                                            return self.path_e_bs

                                        if (child_yang_name == "path-e-ss"):
                                            if (self.path_e_ss is None):
                                                self.path_e_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathESs()
                                                self.path_e_ss.parent = self
                                                self._children_name_map["path_e_ss"] = "path-e-ss"
                                            return self.path_e_ss

                                        if (child_yang_name == "path-es-rs"):
                                            if (self.path_es_rs is None):
                                                self.path_es_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathEsRs()
                                                self.path_es_rs.parent = self
                                                self._children_name_map["path_es_rs"] = "path-es-rs"
                                            return self.path_es_rs

                                        if (child_yang_name == "path-se-ss"):
                                            if (self.path_se_ss is None):
                                                self.path_se_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSeSs()
                                                self.path_se_ss.parent = self
                                                self._children_name_map["path_se_ss"] = "path-se-ss"
                                            return self.path_se_ss

                                        if (child_yang_name == "path-ses-rs"):
                                            if (self.path_ses_rs is None):
                                                self.path_ses_rs = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathSesRs()
                                                self.path_ses_rs.parent = self
                                                self._children_name_map["path_ses_rs"] = "path-ses-rs"
                                            return self.path_ses_rs

                                        if (child_yang_name == "path-ua-ss"):
                                            if (self.path_ua_ss is None):
                                                self.path_ua_ss = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path.PathUaSs()
                                                self.path_ua_ss.parent = self
                                                self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                            return self.path_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "path-bb-es" or name == "path-bbe-rs" or name == "path-e-bs" or name == "path-e-ss" or name == "path-es-rs" or name == "path-se-ss" or name == "path-ses-rs" or name == "path-ua-ss" or name == "path-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-status"):
                                            self.path_status = value
                                            self.path_status.value_namespace = name_space
                                            self.path_status.value_namespace_prefix = name_space_prefix


                                class FePath(Entity):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath, self).__init__()

                                        self.yang_name = "fe-path"
                                        self.yang_parent_name = "ho-vc-minute15-path"

                                        self.far_end_path_c_vs = YLeaf(YType.uint32, "far-end-path-c-vs")

                                        self.far_end_path_e_ss = YLeaf(YType.uint32, "far-end-path-e-ss")

                                        self.far_end_path_se_ss = YLeaf(YType.uint32, "far-end-path-se-ss")

                                        self.far_end_path_ua_ss = YLeaf(YType.uint32, "far-end-path-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("far_end_path_c_vs",
                                                        "far_end_path_e_ss",
                                                        "far_end_path_se_ss",
                                                        "far_end_path_ua_ss") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.far_end_path_c_vs.is_set or
                                            self.far_end_path_e_ss.is_set or
                                            self.far_end_path_se_ss.is_set or
                                            self.far_end_path_ua_ss.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.far_end_path_c_vs.yfilter != YFilter.not_set or
                                            self.far_end_path_e_ss.yfilter != YFilter.not_set or
                                            self.far_end_path_se_ss.yfilter != YFilter.not_set or
                                            self.far_end_path_ua_ss.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fe-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.far_end_path_c_vs.is_set or self.far_end_path_c_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_c_vs.get_name_leafdata())
                                        if (self.far_end_path_e_ss.is_set or self.far_end_path_e_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_e_ss.get_name_leafdata())
                                        if (self.far_end_path_se_ss.is_set or self.far_end_path_se_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_se_ss.get_name_leafdata())
                                        if (self.far_end_path_ua_ss.is_set or self.far_end_path_ua_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_ua_ss.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "far-end-path-c-vs" or name == "far-end-path-e-ss" or name == "far-end-path-se-ss" or name == "far-end-path-ua-ss"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "far-end-path-c-vs"):
                                            self.far_end_path_c_vs = value
                                            self.far_end_path_c_vs.value_namespace = name_space
                                            self.far_end_path_c_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-e-ss"):
                                            self.far_end_path_e_ss = value
                                            self.far_end_path_e_ss.value_namespace = name_space
                                            self.far_end_path_e_ss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-se-ss"):
                                            self.far_end_path_se_ss = value
                                            self.far_end_path_se_ss.value_namespace = name_space
                                            self.far_end_path_se_ss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-ua-ss"):
                                            self.far_end_path_ua_ss = value
                                            self.far_end_path_ua_ss.value_namespace = name_space
                                            self.far_end_path_ua_ss.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.fe_path is not None and self.fe_path.has_data()) or
                                        (self.path is not None and self.path.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.fe_path is not None and self.fe_path.has_operation()) or
                                        (self.path is not None and self.path.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ho-vc-minute15-path" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "fe-path"):
                                        if (self.fe_path is None):
                                            self.fe_path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.FePath()
                                            self.fe_path.parent = self
                                            self._children_name_map["fe_path"] = "fe-path"
                                        return self.fe_path

                                    if (child_yang_name == "path"):
                                        if (self.path is None):
                                            self.path = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path.Path()
                                            self.path.parent = self
                                            self._children_name_map["path"] = "path"
                                        return self.path

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fe-path" or name == "path" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.ho_vc_minute15_path:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.ho_vc_minute15_path:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ho-vc-minute15-paths" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ho-vc-minute15-path"):
                                    for c in self.ho_vc_minute15_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths.HoVcMinute15Path()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.ho_vc_minute15_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ho-vc-minute15-path"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.ho_vc_minute15_paths is not None and self.ho_vc_minute15_paths.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.ho_vc_minute15_paths is not None and self.ho_vc_minute15_paths.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ho-vc-minute15" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ho-vc-minute15-paths"):
                                if (self.ho_vc_minute15_paths is None):
                                    self.ho_vc_minute15_paths = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15.HoVcMinute15Paths()
                                    self.ho_vc_minute15_paths.parent = self
                                    self._children_name_map["ho_vc_minute15_paths"] = "ho-vc-minute15-paths"
                                return self.ho_vc_minute15_paths

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ho-vc-minute15-paths"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.ho_vc_hour24 is not None and self.ho_vc_hour24.has_data()) or
                            (self.ho_vc_minute15 is not None and self.ho_vc_minute15.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.ho_vc_hour24 is not None and self.ho_vc_hour24.has_operation()) or
                            (self.ho_vc_minute15 is not None and self.ho_vc_minute15.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ho-vc-current" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ho-vc-hour24"):
                            if (self.ho_vc_hour24 is None):
                                self.ho_vc_hour24 = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcHour24()
                                self.ho_vc_hour24.parent = self
                                self._children_name_map["ho_vc_hour24"] = "ho-vc-hour24"
                            return self.ho_vc_hour24

                        if (child_yang_name == "ho-vc-minute15"):
                            if (self.ho_vc_minute15 is None):
                                self.ho_vc_minute15 = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent.HoVcMinute15()
                                self.ho_vc_minute15.parent = self
                                self._children_name_map["ho_vc_minute15"] = "ho-vc-minute15"
                            return self.ho_vc_minute15

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ho-vc-hour24" or name == "ho-vc-minute15"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.name.is_set or
                        (self.ho_vc_current is not None and self.ho_vc_current.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        (self.ho_vc_current is not None and self.ho_vc_current.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ho-vc-port" + "[name='" + self.name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/ho-vc/ho-vc-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ho-vc-current"):
                        if (self.ho_vc_current is None):
                            self.ho_vc_current = PerformanceManagement.HoVc.HoVcPorts.HoVcPort.HoVcCurrent()
                            self.ho_vc_current.parent = self
                            self._children_name_map["ho_vc_current"] = "ho-vc-current"
                        return self.ho_vc_current

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ho-vc-current" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.ho_vc_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.ho_vc_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "ho-vc-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/ho-vc/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "ho-vc-port"):
                    for c in self.ho_vc_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = PerformanceManagement.HoVc.HoVcPorts.HoVcPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.ho_vc_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "ho-vc-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.ho_vc_ports is not None and self.ho_vc_ports.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.ho_vc_ports is not None and self.ho_vc_ports.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "ho-vc" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "ho-vc-ports"):
                if (self.ho_vc_ports is None):
                    self.ho_vc_ports = PerformanceManagement.HoVc.HoVcPorts()
                    self.ho_vc_ports.parent = self
                    self._children_name_map["ho_vc_ports"] = "ho-vc-ports"
                return self.ho_vc_ports

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "ho-vc-ports"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Odu(Entity):
        """
        ODU controller performance data
        
        .. attribute:: odu_ports
        
        	Port performance data
        	**type**\:   :py:class:`OduPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PerformanceManagement.Odu, self).__init__()

            self.yang_name = "odu"
            self.yang_parent_name = "performance-management"

            self.odu_ports = PerformanceManagement.Odu.OduPorts()
            self.odu_ports.parent = self
            self._children_name_map["odu_ports"] = "odu-ports"
            self._children_yang_names.add("odu-ports")


        class OduPorts(Entity):
            """
            Port performance data
            
            .. attribute:: odu_port
            
            	Port performance data
            	**type**\: list of    :py:class:`OduPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PerformanceManagement.Odu.OduPorts, self).__init__()

                self.yang_name = "odu-ports"
                self.yang_parent_name = "odu"

                self.odu_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(PerformanceManagement.Odu.OduPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(PerformanceManagement.Odu.OduPorts, self).__setattr__(name, value)


            class OduPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: odu_current
                
                	port current performance data
                	**type**\:   :py:class:`OduCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagement.Odu.OduPorts.OduPort, self).__init__()

                    self.yang_name = "odu-port"
                    self.yang_parent_name = "odu-ports"

                    self.name = YLeaf(YType.str, "name")

                    self.odu_current = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent()
                    self.odu_current.parent = self
                    self._children_name_map["odu_current"] = "odu-current"
                    self._children_yang_names.add("odu-current")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PerformanceManagement.Odu.OduPorts.OduPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PerformanceManagement.Odu.OduPorts.OduPort, self).__setattr__(name, value)


                class OduCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: odu_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`OduHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24>`
                    
                    .. attribute:: odu_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`OduMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent, self).__init__()

                        self.yang_name = "odu-current"
                        self.yang_parent_name = "odu-port"

                        self.odu_hour24 = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24()
                        self.odu_hour24.parent = self
                        self._children_name_map["odu_hour24"] = "odu-hour24"
                        self._children_yang_names.add("odu-hour24")

                        self.odu_minute15 = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15()
                        self.odu_minute15.parent = self
                        self._children_name_map["odu_minute15"] = "odu-minute15"
                        self._children_yang_names.add("odu-minute15")


                    class OduMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: odu_minute15gfps
                        
                        	port current performance data
                        	**type**\:   :py:class:`OduMinute15Gfps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps>`
                        
                        .. attribute:: odu_minute15otns
                        
                        	port current performance data
                        	**type**\:   :py:class:`OduMinute15Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns>`
                        
                        .. attribute:: odu_minute15prbses
                        
                        	port current performance data
                        	**type**\:   :py:class:`OduMinute15Prbses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15, self).__init__()

                            self.yang_name = "odu-minute15"
                            self.yang_parent_name = "odu-current"

                            self.odu_minute15gfps = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps()
                            self.odu_minute15gfps.parent = self
                            self._children_name_map["odu_minute15gfps"] = "odu-minute15gfps"
                            self._children_yang_names.add("odu-minute15gfps")

                            self.odu_minute15otns = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns()
                            self.odu_minute15otns.parent = self
                            self._children_name_map["odu_minute15otns"] = "odu-minute15otns"
                            self._children_yang_names.add("odu-minute15otns")

                            self.odu_minute15prbses = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses()
                            self.odu_minute15prbses.parent = self
                            self._children_name_map["odu_minute15prbses"] = "odu-minute15prbses"
                            self._children_yang_names.add("odu-minute15prbses")


                        class OduMinute15Gfps(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: odu_minute15gfp
                            
                            	port 15\-minute otn performance data
                            	**type**\: list of    :py:class:`OduMinute15Gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps, self).__init__()

                                self.yang_name = "odu-minute15gfps"
                                self.yang_parent_name = "odu-minute15"

                                self.odu_minute15gfp = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps, self).__setattr__(name, value)


                            class OduMinute15Gfp(Entity):
                                """
                                port 15\-minute otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: rx_bit_err
                                
                                	RX BIT ERR
                                	**type**\:   :py:class:`RxBitErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxBitErr>`
                                
                                .. attribute:: rx_crc
                                
                                	RX CRC
                                	**type**\:   :py:class:`RxCrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCrc>`
                                
                                .. attribute:: rx_csf
                                
                                	RX CSF
                                	**type**\:   :py:class:`RxCsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCsf>`
                                
                                .. attribute:: rx_inv_typ
                                
                                	RX INV TYP
                                	**type**\:   :py:class:`RxInvTyp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxInvTyp>`
                                
                                .. attribute:: rx_lfd
                                
                                	RX LFD
                                	**type**\:   :py:class:`RxLfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxLfd>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp, self).__init__()

                                    self.yang_name = "odu-minute15gfp"
                                    self.yang_parent_name = "odu-minute15gfps"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.rx_bit_err = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxBitErr()
                                    self.rx_bit_err.parent = self
                                    self._children_name_map["rx_bit_err"] = "rx-bit-err"
                                    self._children_yang_names.add("rx-bit-err")

                                    self.rx_crc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCrc()
                                    self.rx_crc.parent = self
                                    self._children_name_map["rx_crc"] = "rx-crc"
                                    self._children_yang_names.add("rx-crc")

                                    self.rx_csf = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCsf()
                                    self.rx_csf.parent = self
                                    self._children_name_map["rx_csf"] = "rx-csf"
                                    self._children_yang_names.add("rx-csf")

                                    self.rx_inv_typ = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxInvTyp()
                                    self.rx_inv_typ.parent = self
                                    self._children_name_map["rx_inv_typ"] = "rx-inv-typ"
                                    self._children_yang_names.add("rx-inv-typ")

                                    self.rx_lfd = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxLfd()
                                    self.rx_lfd.parent = self
                                    self._children_name_map["rx_lfd"] = "rx-lfd"
                                    self._children_yang_names.add("rx-lfd")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp, self).__setattr__(name, value)


                                class RxBitErr(Entity):
                                    """
                                    RX BIT ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxBitErr, self).__init__()

                                        self.yang_name = "rx-bit-err"
                                        self.yang_parent_name = "odu-minute15gfp"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxBitErr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxBitErr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-bit-err" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class RxInvTyp(Entity):
                                    """
                                    RX INV TYP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxInvTyp, self).__init__()

                                        self.yang_name = "rx-inv-typ"
                                        self.yang_parent_name = "odu-minute15gfp"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxInvTyp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxInvTyp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-inv-typ" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class RxCrc(Entity):
                                    """
                                    RX CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCrc, self).__init__()

                                        self.yang_name = "rx-crc"
                                        self.yang_parent_name = "odu-minute15gfp"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCrc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCrc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-crc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class RxLfd(Entity):
                                    """
                                    RX LFD
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxLfd, self).__init__()

                                        self.yang_name = "rx-lfd"
                                        self.yang_parent_name = "odu-minute15gfp"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxLfd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxLfd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-lfd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class RxCsf(Entity):
                                    """
                                    RX CSF
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCsf, self).__init__()

                                        self.yang_name = "rx-csf"
                                        self.yang_parent_name = "odu-minute15gfp"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCsf, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCsf, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-csf" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.rx_bit_err is not None and self.rx_bit_err.has_data()) or
                                        (self.rx_crc is not None and self.rx_crc.has_data()) or
                                        (self.rx_csf is not None and self.rx_csf.has_data()) or
                                        (self.rx_inv_typ is not None and self.rx_inv_typ.has_data()) or
                                        (self.rx_lfd is not None and self.rx_lfd.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.rx_bit_err is not None and self.rx_bit_err.has_operation()) or
                                        (self.rx_crc is not None and self.rx_crc.has_operation()) or
                                        (self.rx_csf is not None and self.rx_csf.has_operation()) or
                                        (self.rx_inv_typ is not None and self.rx_inv_typ.has_operation()) or
                                        (self.rx_lfd is not None and self.rx_lfd.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "odu-minute15gfp" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rx-bit-err"):
                                        if (self.rx_bit_err is None):
                                            self.rx_bit_err = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxBitErr()
                                            self.rx_bit_err.parent = self
                                            self._children_name_map["rx_bit_err"] = "rx-bit-err"
                                        return self.rx_bit_err

                                    if (child_yang_name == "rx-crc"):
                                        if (self.rx_crc is None):
                                            self.rx_crc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCrc()
                                            self.rx_crc.parent = self
                                            self._children_name_map["rx_crc"] = "rx-crc"
                                        return self.rx_crc

                                    if (child_yang_name == "rx-csf"):
                                        if (self.rx_csf is None):
                                            self.rx_csf = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxCsf()
                                            self.rx_csf.parent = self
                                            self._children_name_map["rx_csf"] = "rx-csf"
                                        return self.rx_csf

                                    if (child_yang_name == "rx-inv-typ"):
                                        if (self.rx_inv_typ is None):
                                            self.rx_inv_typ = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxInvTyp()
                                            self.rx_inv_typ.parent = self
                                            self._children_name_map["rx_inv_typ"] = "rx-inv-typ"
                                        return self.rx_inv_typ

                                    if (child_yang_name == "rx-lfd"):
                                        if (self.rx_lfd is None):
                                            self.rx_lfd = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp.RxLfd()
                                            self.rx_lfd.parent = self
                                            self._children_name_map["rx_lfd"] = "rx-lfd"
                                        return self.rx_lfd

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rx-bit-err" or name == "rx-crc" or name == "rx-csf" or name == "rx-inv-typ" or name == "rx-lfd" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.odu_minute15gfp:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.odu_minute15gfp:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "odu-minute15gfps" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "odu-minute15gfp"):
                                    for c in self.odu_minute15gfp:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps.OduMinute15Gfp()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.odu_minute15gfp.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "odu-minute15gfp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OduMinute15Prbses(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: odu_minute15prbs
                            
                            	port 15\-minute prbs performance data
                            	**type**\: list of    :py:class:`OduMinute15Prbs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses, self).__init__()

                                self.yang_name = "odu-minute15prbses"
                                self.yang_parent_name = "odu-minute15"

                                self.odu_minute15prbs = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses, self).__setattr__(name, value)


                            class OduMinute15Prbs(Entity):
                                """
                                port 15\-minute prbs performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: conf_patt
                                
                                	CONFIG PTRN
                                	**type**\:   :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                
                                .. attribute:: ebc
                                
                                	EBC
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: found_at_time
                                
                                	FOUND AT TS
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: found_count
                                
                                	FOUND COUNT
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: lost_at_time
                                
                                	LOST AT TS
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: lost_count
                                
                                	LOST COUNT
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rcv_patt
                                
                                	RCVD PTRN
                                	**type**\:   :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs.RcvPatt>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs, self).__init__()

                                    self.yang_name = "odu-minute15prbs"
                                    self.yang_parent_name = "odu-minute15prbses"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.conf_patt = YLeaf(YType.enumeration, "conf-patt")

                                    self.ebc = YLeaf(YType.uint64, "ebc")

                                    self.found_at_time = YLeaf(YType.str, "found-at-time")

                                    self.found_count = YLeaf(YType.uint32, "found-count")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.lost_at_time = YLeaf(YType.str, "lost-at-time")

                                    self.lost_count = YLeaf(YType.uint32, "lost-count")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.rcv_patt = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs.RcvPatt()
                                    self.rcv_patt.parent = self
                                    self._children_name_map["rcv_patt"] = "rcv-patt"
                                    self._children_yang_names.add("rcv-patt")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "conf_patt",
                                                    "ebc",
                                                    "found_at_time",
                                                    "found_count",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "lost_at_time",
                                                    "lost_count",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs, self).__setattr__(name, value)


                                class RcvPatt(Entity):
                                    """
                                    RCVD PTRN
                                    
                                    .. attribute:: rcv_patt
                                    
                                    	RCVD PTRN
                                    	**type**\:   :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs.RcvPatt, self).__init__()

                                        self.yang_name = "rcv-patt"
                                        self.yang_parent_name = "odu-minute15prbs"

                                        self.rcv_patt = YLeaf(YType.enumeration, "rcv-patt")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("rcv_patt",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs.RcvPatt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs.RcvPatt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.rcv_patt.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.rcv_patt.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rcv-patt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.rcv_patt.is_set or self.rcv_patt.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rcv_patt.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "rcv-patt" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "rcv-patt"):
                                            self.rcv_patt = value
                                            self.rcv_patt.value_namespace = name_space
                                            self.rcv_patt.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.conf_patt.is_set or
                                        self.ebc.is_set or
                                        self.found_at_time.is_set or
                                        self.found_count.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.lost_at_time.is_set or
                                        self.lost_count.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.rcv_patt is not None and self.rcv_patt.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.conf_patt.yfilter != YFilter.not_set or
                                        self.ebc.yfilter != YFilter.not_set or
                                        self.found_at_time.yfilter != YFilter.not_set or
                                        self.found_count.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.lost_at_time.yfilter != YFilter.not_set or
                                        self.lost_count.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.rcv_patt is not None and self.rcv_patt.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "odu-minute15prbs" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.conf_patt.is_set or self.conf_patt.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.conf_patt.get_name_leafdata())
                                    if (self.ebc.is_set or self.ebc.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebc.get_name_leafdata())
                                    if (self.found_at_time.is_set or self.found_at_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.found_at_time.get_name_leafdata())
                                    if (self.found_count.is_set or self.found_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.found_count.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.lost_at_time.is_set or self.lost_at_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lost_at_time.get_name_leafdata())
                                    if (self.lost_count.is_set or self.lost_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lost_count.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rcv-patt"):
                                        if (self.rcv_patt is None):
                                            self.rcv_patt = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs.RcvPatt()
                                            self.rcv_patt.parent = self
                                            self._children_name_map["rcv_patt"] = "rcv-patt"
                                        return self.rcv_patt

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rcv-patt" or name == "number" or name == "conf-patt" or name == "ebc" or name == "found-at-time" or name == "found-count" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "lost-at-time" or name == "lost-count" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "conf-patt"):
                                        self.conf_patt = value
                                        self.conf_patt.value_namespace = name_space
                                        self.conf_patt.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebc"):
                                        self.ebc = value
                                        self.ebc.value_namespace = name_space
                                        self.ebc.value_namespace_prefix = name_space_prefix
                                    if(value_path == "found-at-time"):
                                        self.found_at_time = value
                                        self.found_at_time.value_namespace = name_space
                                        self.found_at_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "found-count"):
                                        self.found_count = value
                                        self.found_count.value_namespace = name_space
                                        self.found_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lost-at-time"):
                                        self.lost_at_time = value
                                        self.lost_at_time.value_namespace = name_space
                                        self.lost_at_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lost-count"):
                                        self.lost_count = value
                                        self.lost_count.value_namespace = name_space
                                        self.lost_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.odu_minute15prbs:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.odu_minute15prbs:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "odu-minute15prbses" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "odu-minute15prbs"):
                                    for c in self.odu_minute15prbs:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses.OduMinute15Prbs()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.odu_minute15prbs.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "odu-minute15prbs"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OduMinute15Otns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: odu_minute15otn
                            
                            	port 15\-minute otn performance data
                            	**type**\: list of    :py:class:`OduMinute15Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns, self).__init__()

                                self.yang_name = "odu-minute15otns"
                                self.yang_parent_name = "odu-minute15"

                                self.odu_minute15otn = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns, self).__setattr__(name, value)


                            class OduMinute15Otn(Entity):
                                """
                                port 15\-minute otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn, self).__init__()

                                    self.yang_name = "odu-minute15otn"
                                    self.yang_parent_name = "odu-minute15otns"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.bbe_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"
                                    self._children_yang_names.add("bbe-fe")

                                    self.bbe_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"
                                    self._children_yang_names.add("bbe-ne")

                                    self.bber_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"
                                    self._children_yang_names.add("bber-fe")

                                    self.bber_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"
                                    self._children_yang_names.add("bber-ne")

                                    self.es_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"
                                    self._children_yang_names.add("es-fe")

                                    self.es_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"
                                    self._children_yang_names.add("es-ne")

                                    self.esr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"
                                    self._children_yang_names.add("esr-fe")

                                    self.esr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"
                                    self._children_yang_names.add("esr-ne")

                                    self.fc_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._children_yang_names.add("fc-fe")

                                    self.fc_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"
                                    self._children_yang_names.add("fc-ne")

                                    self.lbc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"
                                    self._children_yang_names.add("lbc")

                                    self.ses_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"
                                    self._children_yang_names.add("ses-fe")

                                    self.ses_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"
                                    self._children_yang_names.add("ses-ne")

                                    self.sesr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"
                                    self._children_yang_names.add("sesr-fe")

                                    self.sesr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"
                                    self._children_yang_names.add("sesr-ne")

                                    self.uas_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"
                                    self._children_yang_names.add("uas-fe")

                                    self.uas_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"
                                    self._children_yang_names.add("uas-ne")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn, self).__setattr__(name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.Lbc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.Lbc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "odu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                        (self.bber_fe is not None and self.bber_fe.has_data()) or
                                        (self.bber_ne is not None and self.bber_ne.has_data()) or
                                        (self.es_fe is not None and self.es_fe.has_data()) or
                                        (self.es_ne is not None and self.es_ne.has_data()) or
                                        (self.esr_fe is not None and self.esr_fe.has_data()) or
                                        (self.esr_ne is not None and self.esr_ne.has_data()) or
                                        (self.fc_fe is not None and self.fc_fe.has_data()) or
                                        (self.fc_ne is not None and self.fc_ne.has_data()) or
                                        (self.lbc is not None and self.lbc.has_data()) or
                                        (self.ses_fe is not None and self.ses_fe.has_data()) or
                                        (self.ses_ne is not None and self.ses_ne.has_data()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                        (self.uas_fe is not None and self.uas_fe.has_data()) or
                                        (self.uas_ne is not None and self.uas_ne.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                        (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                        (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                        (self.es_fe is not None and self.es_fe.has_operation()) or
                                        (self.es_ne is not None and self.es_ne.has_operation()) or
                                        (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                        (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                        (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                        (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                        (self.lbc is not None and self.lbc.has_operation()) or
                                        (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                        (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                        (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                        (self.uas_ne is not None and self.uas_ne.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "odu-minute15otn" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "bbe-fe"):
                                        if (self.bbe_fe is None):
                                            self.bbe_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeFe()
                                            self.bbe_fe.parent = self
                                            self._children_name_map["bbe_fe"] = "bbe-fe"
                                        return self.bbe_fe

                                    if (child_yang_name == "bbe-ne"):
                                        if (self.bbe_ne is None):
                                            self.bbe_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BbeNe()
                                            self.bbe_ne.parent = self
                                            self._children_name_map["bbe_ne"] = "bbe-ne"
                                        return self.bbe_ne

                                    if (child_yang_name == "bber-fe"):
                                        if (self.bber_fe is None):
                                            self.bber_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberFe()
                                            self.bber_fe.parent = self
                                            self._children_name_map["bber_fe"] = "bber-fe"
                                        return self.bber_fe

                                    if (child_yang_name == "bber-ne"):
                                        if (self.bber_ne is None):
                                            self.bber_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.BberNe()
                                            self.bber_ne.parent = self
                                            self._children_name_map["bber_ne"] = "bber-ne"
                                        return self.bber_ne

                                    if (child_yang_name == "es-fe"):
                                        if (self.es_fe is None):
                                            self.es_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsFe()
                                            self.es_fe.parent = self
                                            self._children_name_map["es_fe"] = "es-fe"
                                        return self.es_fe

                                    if (child_yang_name == "es-ne"):
                                        if (self.es_ne is None):
                                            self.es_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsNe()
                                            self.es_ne.parent = self
                                            self._children_name_map["es_ne"] = "es-ne"
                                        return self.es_ne

                                    if (child_yang_name == "esr-fe"):
                                        if (self.esr_fe is None):
                                            self.esr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrFe()
                                            self.esr_fe.parent = self
                                            self._children_name_map["esr_fe"] = "esr-fe"
                                        return self.esr_fe

                                    if (child_yang_name == "esr-ne"):
                                        if (self.esr_ne is None):
                                            self.esr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.EsrNe()
                                            self.esr_ne.parent = self
                                            self._children_name_map["esr_ne"] = "esr-ne"
                                        return self.esr_ne

                                    if (child_yang_name == "fc-fe"):
                                        if (self.fc_fe is None):
                                            self.fc_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcFe()
                                            self.fc_fe.parent = self
                                            self._children_name_map["fc_fe"] = "fc-fe"
                                        return self.fc_fe

                                    if (child_yang_name == "fc-ne"):
                                        if (self.fc_ne is None):
                                            self.fc_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.FcNe()
                                            self.fc_ne.parent = self
                                            self._children_name_map["fc_ne"] = "fc-ne"
                                        return self.fc_ne

                                    if (child_yang_name == "lbc"):
                                        if (self.lbc is None):
                                            self.lbc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.Lbc()
                                            self.lbc.parent = self
                                            self._children_name_map["lbc"] = "lbc"
                                        return self.lbc

                                    if (child_yang_name == "ses-fe"):
                                        if (self.ses_fe is None):
                                            self.ses_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesFe()
                                            self.ses_fe.parent = self
                                            self._children_name_map["ses_fe"] = "ses-fe"
                                        return self.ses_fe

                                    if (child_yang_name == "ses-ne"):
                                        if (self.ses_ne is None):
                                            self.ses_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesNe()
                                            self.ses_ne.parent = self
                                            self._children_name_map["ses_ne"] = "ses-ne"
                                        return self.ses_ne

                                    if (child_yang_name == "sesr-fe"):
                                        if (self.sesr_fe is None):
                                            self.sesr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrFe()
                                            self.sesr_fe.parent = self
                                            self._children_name_map["sesr_fe"] = "sesr-fe"
                                        return self.sesr_fe

                                    if (child_yang_name == "sesr-ne"):
                                        if (self.sesr_ne is None):
                                            self.sesr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.SesrNe()
                                            self.sesr_ne.parent = self
                                            self._children_name_map["sesr_ne"] = "sesr-ne"
                                        return self.sesr_ne

                                    if (child_yang_name == "uas-fe"):
                                        if (self.uas_fe is None):
                                            self.uas_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasFe()
                                            self.uas_fe.parent = self
                                            self._children_name_map["uas_fe"] = "uas-fe"
                                        return self.uas_fe

                                    if (child_yang_name == "uas-ne"):
                                        if (self.uas_ne is None):
                                            self.uas_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn.UasNe()
                                            self.uas_ne.parent = self
                                            self._children_name_map["uas_ne"] = "uas-ne"
                                        return self.uas_ne

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.odu_minute15otn:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.odu_minute15otn:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "odu-minute15otns" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "odu-minute15otn"):
                                    for c in self.odu_minute15otn:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns.OduMinute15Otn()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.odu_minute15otn.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "odu-minute15otn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.odu_minute15gfps is not None and self.odu_minute15gfps.has_data()) or
                                (self.odu_minute15otns is not None and self.odu_minute15otns.has_data()) or
                                (self.odu_minute15prbses is not None and self.odu_minute15prbses.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.odu_minute15gfps is not None and self.odu_minute15gfps.has_operation()) or
                                (self.odu_minute15otns is not None and self.odu_minute15otns.has_operation()) or
                                (self.odu_minute15prbses is not None and self.odu_minute15prbses.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "odu-minute15" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "odu-minute15gfps"):
                                if (self.odu_minute15gfps is None):
                                    self.odu_minute15gfps = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Gfps()
                                    self.odu_minute15gfps.parent = self
                                    self._children_name_map["odu_minute15gfps"] = "odu-minute15gfps"
                                return self.odu_minute15gfps

                            if (child_yang_name == "odu-minute15otns"):
                                if (self.odu_minute15otns is None):
                                    self.odu_minute15otns = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Otns()
                                    self.odu_minute15otns.parent = self
                                    self._children_name_map["odu_minute15otns"] = "odu-minute15otns"
                                return self.odu_minute15otns

                            if (child_yang_name == "odu-minute15prbses"):
                                if (self.odu_minute15prbses is None):
                                    self.odu_minute15prbses = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15.OduMinute15Prbses()
                                    self.odu_minute15prbses.parent = self
                                    self._children_name_map["odu_minute15prbses"] = "odu-minute15prbses"
                                return self.odu_minute15prbses

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "odu-minute15gfps" or name == "odu-minute15otns" or name == "odu-minute15prbses"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OduHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: odu_hour24gfps
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`OduHour24Gfps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps>`
                        
                        .. attribute:: odu_hour24otns
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`OduHour24Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns>`
                        
                        .. attribute:: odu_hour24prbses
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`OduHour24Prbses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24, self).__init__()

                            self.yang_name = "odu-hour24"
                            self.yang_parent_name = "odu-current"

                            self.odu_hour24gfps = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps()
                            self.odu_hour24gfps.parent = self
                            self._children_name_map["odu_hour24gfps"] = "odu-hour24gfps"
                            self._children_yang_names.add("odu-hour24gfps")

                            self.odu_hour24otns = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns()
                            self.odu_hour24otns.parent = self
                            self._children_name_map["odu_hour24otns"] = "odu-hour24otns"
                            self._children_yang_names.add("odu-hour24otns")

                            self.odu_hour24prbses = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses()
                            self.odu_hour24prbses.parent = self
                            self._children_name_map["odu_hour24prbses"] = "odu-hour24prbses"
                            self._children_yang_names.add("odu-hour24prbses")


                        class OduHour24Prbses(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: odu_hour24prbs
                            
                            	port 24 hour otn performance data
                            	**type**\: list of    :py:class:`OduHour24Prbs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses, self).__init__()

                                self.yang_name = "odu-hour24prbses"
                                self.yang_parent_name = "odu-hour24"

                                self.odu_hour24prbs = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses, self).__setattr__(name, value)


                            class OduHour24Prbs(Entity):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: conf_patt
                                
                                	CONFIG PTRN
                                	**type**\:   :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                
                                .. attribute:: ebc
                                
                                	EBC
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: found_at_time
                                
                                	FOUND AT TS
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: found_count
                                
                                	FOUND COUNT
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: lost_at_time
                                
                                	LOST AT TS
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: lost_count
                                
                                	LOST COUNT
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rcv_patt
                                
                                	RCVD PTRN
                                	**type**\:   :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs.RcvPatt>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs, self).__init__()

                                    self.yang_name = "odu-hour24prbs"
                                    self.yang_parent_name = "odu-hour24prbses"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.conf_patt = YLeaf(YType.enumeration, "conf-patt")

                                    self.ebc = YLeaf(YType.uint64, "ebc")

                                    self.found_at_time = YLeaf(YType.str, "found-at-time")

                                    self.found_count = YLeaf(YType.uint32, "found-count")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.lost_at_time = YLeaf(YType.str, "lost-at-time")

                                    self.lost_count = YLeaf(YType.uint32, "lost-count")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.rcv_patt = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs.RcvPatt()
                                    self.rcv_patt.parent = self
                                    self._children_name_map["rcv_patt"] = "rcv-patt"
                                    self._children_yang_names.add("rcv-patt")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "conf_patt",
                                                    "ebc",
                                                    "found_at_time",
                                                    "found_count",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "lost_at_time",
                                                    "lost_count",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs, self).__setattr__(name, value)


                                class RcvPatt(Entity):
                                    """
                                    RCVD PTRN
                                    
                                    .. attribute:: rcv_patt
                                    
                                    	RCVD PTRN
                                    	**type**\:   :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs.RcvPatt, self).__init__()

                                        self.yang_name = "rcv-patt"
                                        self.yang_parent_name = "odu-hour24prbs"

                                        self.rcv_patt = YLeaf(YType.enumeration, "rcv-patt")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("rcv_patt",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs.RcvPatt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs.RcvPatt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.rcv_patt.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.rcv_patt.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rcv-patt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.rcv_patt.is_set or self.rcv_patt.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rcv_patt.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "rcv-patt" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "rcv-patt"):
                                            self.rcv_patt = value
                                            self.rcv_patt.value_namespace = name_space
                                            self.rcv_patt.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.conf_patt.is_set or
                                        self.ebc.is_set or
                                        self.found_at_time.is_set or
                                        self.found_count.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.lost_at_time.is_set or
                                        self.lost_count.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.rcv_patt is not None and self.rcv_patt.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.conf_patt.yfilter != YFilter.not_set or
                                        self.ebc.yfilter != YFilter.not_set or
                                        self.found_at_time.yfilter != YFilter.not_set or
                                        self.found_count.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.lost_at_time.yfilter != YFilter.not_set or
                                        self.lost_count.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.rcv_patt is not None and self.rcv_patt.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "odu-hour24prbs" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.conf_patt.is_set or self.conf_patt.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.conf_patt.get_name_leafdata())
                                    if (self.ebc.is_set or self.ebc.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ebc.get_name_leafdata())
                                    if (self.found_at_time.is_set or self.found_at_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.found_at_time.get_name_leafdata())
                                    if (self.found_count.is_set or self.found_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.found_count.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.lost_at_time.is_set or self.lost_at_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lost_at_time.get_name_leafdata())
                                    if (self.lost_count.is_set or self.lost_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lost_count.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rcv-patt"):
                                        if (self.rcv_patt is None):
                                            self.rcv_patt = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs.RcvPatt()
                                            self.rcv_patt.parent = self
                                            self._children_name_map["rcv_patt"] = "rcv-patt"
                                        return self.rcv_patt

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rcv-patt" or name == "number" or name == "conf-patt" or name == "ebc" or name == "found-at-time" or name == "found-count" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "lost-at-time" or name == "lost-count" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "conf-patt"):
                                        self.conf_patt = value
                                        self.conf_patt.value_namespace = name_space
                                        self.conf_patt.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ebc"):
                                        self.ebc = value
                                        self.ebc.value_namespace = name_space
                                        self.ebc.value_namespace_prefix = name_space_prefix
                                    if(value_path == "found-at-time"):
                                        self.found_at_time = value
                                        self.found_at_time.value_namespace = name_space
                                        self.found_at_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "found-count"):
                                        self.found_count = value
                                        self.found_count.value_namespace = name_space
                                        self.found_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lost-at-time"):
                                        self.lost_at_time = value
                                        self.lost_at_time.value_namespace = name_space
                                        self.lost_at_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lost-count"):
                                        self.lost_count = value
                                        self.lost_count.value_namespace = name_space
                                        self.lost_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.odu_hour24prbs:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.odu_hour24prbs:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "odu-hour24prbses" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "odu-hour24prbs"):
                                    for c in self.odu_hour24prbs:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses.OduHour24Prbs()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.odu_hour24prbs.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "odu-hour24prbs"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OduHour24Gfps(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: odu_hour24gfp
                            
                            	port 24 hour otn performance data
                            	**type**\: list of    :py:class:`OduHour24Gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps, self).__init__()

                                self.yang_name = "odu-hour24gfps"
                                self.yang_parent_name = "odu-hour24"

                                self.odu_hour24gfp = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps, self).__setattr__(name, value)


                            class OduHour24Gfp(Entity):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: rx_bit_err
                                
                                	RX BIT ERR
                                	**type**\:   :py:class:`RxBitErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxBitErr>`
                                
                                .. attribute:: rx_crc
                                
                                	RX CRC
                                	**type**\:   :py:class:`RxCrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCrc>`
                                
                                .. attribute:: rx_csf
                                
                                	RX CSF
                                	**type**\:   :py:class:`RxCsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCsf>`
                                
                                .. attribute:: rx_inv_typ
                                
                                	RX INV TYP
                                	**type**\:   :py:class:`RxInvTyp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxInvTyp>`
                                
                                .. attribute:: rx_lfd
                                
                                	RX LFD
                                	**type**\:   :py:class:`RxLfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxLfd>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp, self).__init__()

                                    self.yang_name = "odu-hour24gfp"
                                    self.yang_parent_name = "odu-hour24gfps"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.rx_bit_err = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxBitErr()
                                    self.rx_bit_err.parent = self
                                    self._children_name_map["rx_bit_err"] = "rx-bit-err"
                                    self._children_yang_names.add("rx-bit-err")

                                    self.rx_crc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCrc()
                                    self.rx_crc.parent = self
                                    self._children_name_map["rx_crc"] = "rx-crc"
                                    self._children_yang_names.add("rx-crc")

                                    self.rx_csf = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCsf()
                                    self.rx_csf.parent = self
                                    self._children_name_map["rx_csf"] = "rx-csf"
                                    self._children_yang_names.add("rx-csf")

                                    self.rx_inv_typ = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxInvTyp()
                                    self.rx_inv_typ.parent = self
                                    self._children_name_map["rx_inv_typ"] = "rx-inv-typ"
                                    self._children_yang_names.add("rx-inv-typ")

                                    self.rx_lfd = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxLfd()
                                    self.rx_lfd.parent = self
                                    self._children_name_map["rx_lfd"] = "rx-lfd"
                                    self._children_yang_names.add("rx-lfd")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp, self).__setattr__(name, value)


                                class RxBitErr(Entity):
                                    """
                                    RX BIT ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxBitErr, self).__init__()

                                        self.yang_name = "rx-bit-err"
                                        self.yang_parent_name = "odu-hour24gfp"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxBitErr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxBitErr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-bit-err" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class RxInvTyp(Entity):
                                    """
                                    RX INV TYP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxInvTyp, self).__init__()

                                        self.yang_name = "rx-inv-typ"
                                        self.yang_parent_name = "odu-hour24gfp"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxInvTyp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxInvTyp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-inv-typ" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class RxCrc(Entity):
                                    """
                                    RX CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCrc, self).__init__()

                                        self.yang_name = "rx-crc"
                                        self.yang_parent_name = "odu-hour24gfp"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCrc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCrc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-crc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class RxLfd(Entity):
                                    """
                                    RX LFD
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxLfd, self).__init__()

                                        self.yang_name = "rx-lfd"
                                        self.yang_parent_name = "odu-hour24gfp"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxLfd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxLfd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-lfd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class RxCsf(Entity):
                                    """
                                    RX CSF
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCsf, self).__init__()

                                        self.yang_name = "rx-csf"
                                        self.yang_parent_name = "odu-hour24gfp"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCsf, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCsf, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-csf" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.rx_bit_err is not None and self.rx_bit_err.has_data()) or
                                        (self.rx_crc is not None and self.rx_crc.has_data()) or
                                        (self.rx_csf is not None and self.rx_csf.has_data()) or
                                        (self.rx_inv_typ is not None and self.rx_inv_typ.has_data()) or
                                        (self.rx_lfd is not None and self.rx_lfd.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.rx_bit_err is not None and self.rx_bit_err.has_operation()) or
                                        (self.rx_crc is not None and self.rx_crc.has_operation()) or
                                        (self.rx_csf is not None and self.rx_csf.has_operation()) or
                                        (self.rx_inv_typ is not None and self.rx_inv_typ.has_operation()) or
                                        (self.rx_lfd is not None and self.rx_lfd.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "odu-hour24gfp" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rx-bit-err"):
                                        if (self.rx_bit_err is None):
                                            self.rx_bit_err = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxBitErr()
                                            self.rx_bit_err.parent = self
                                            self._children_name_map["rx_bit_err"] = "rx-bit-err"
                                        return self.rx_bit_err

                                    if (child_yang_name == "rx-crc"):
                                        if (self.rx_crc is None):
                                            self.rx_crc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCrc()
                                            self.rx_crc.parent = self
                                            self._children_name_map["rx_crc"] = "rx-crc"
                                        return self.rx_crc

                                    if (child_yang_name == "rx-csf"):
                                        if (self.rx_csf is None):
                                            self.rx_csf = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxCsf()
                                            self.rx_csf.parent = self
                                            self._children_name_map["rx_csf"] = "rx-csf"
                                        return self.rx_csf

                                    if (child_yang_name == "rx-inv-typ"):
                                        if (self.rx_inv_typ is None):
                                            self.rx_inv_typ = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxInvTyp()
                                            self.rx_inv_typ.parent = self
                                            self._children_name_map["rx_inv_typ"] = "rx-inv-typ"
                                        return self.rx_inv_typ

                                    if (child_yang_name == "rx-lfd"):
                                        if (self.rx_lfd is None):
                                            self.rx_lfd = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp.RxLfd()
                                            self.rx_lfd.parent = self
                                            self._children_name_map["rx_lfd"] = "rx-lfd"
                                        return self.rx_lfd

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rx-bit-err" or name == "rx-crc" or name == "rx-csf" or name == "rx-inv-typ" or name == "rx-lfd" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.odu_hour24gfp:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.odu_hour24gfp:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "odu-hour24gfps" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "odu-hour24gfp"):
                                    for c in self.odu_hour24gfp:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps.OduHour24Gfp()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.odu_hour24gfp.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "odu-hour24gfp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OduHour24Otns(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: odu_hour24otn
                            
                            	port 24 hour otn performance data
                            	**type**\: list of    :py:class:`OduHour24Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns, self).__init__()

                                self.yang_name = "odu-hour24otns"
                                self.yang_parent_name = "odu-hour24"

                                self.odu_hour24otn = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns, self).__setattr__(name, value)


                            class OduHour24Otn(Entity):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn, self).__init__()

                                    self.yang_name = "odu-hour24otn"
                                    self.yang_parent_name = "odu-hour24otns"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.bbe_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"
                                    self._children_yang_names.add("bbe-fe")

                                    self.bbe_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"
                                    self._children_yang_names.add("bbe-ne")

                                    self.bber_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"
                                    self._children_yang_names.add("bber-fe")

                                    self.bber_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"
                                    self._children_yang_names.add("bber-ne")

                                    self.es_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"
                                    self._children_yang_names.add("es-fe")

                                    self.es_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"
                                    self._children_yang_names.add("es-ne")

                                    self.esr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"
                                    self._children_yang_names.add("esr-fe")

                                    self.esr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"
                                    self._children_yang_names.add("esr-ne")

                                    self.fc_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._children_yang_names.add("fc-fe")

                                    self.fc_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"
                                    self._children_yang_names.add("fc-ne")

                                    self.lbc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"
                                    self._children_yang_names.add("lbc")

                                    self.ses_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"
                                    self._children_yang_names.add("ses-fe")

                                    self.ses_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"
                                    self._children_yang_names.add("ses-ne")

                                    self.sesr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"
                                    self._children_yang_names.add("sesr-fe")

                                    self.sesr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"
                                    self._children_yang_names.add("sesr-ne")

                                    self.uas_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"
                                    self._children_yang_names.add("uas-fe")

                                    self.uas_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"
                                    self._children_yang_names.add("uas-ne")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn, self).__setattr__(name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.Lbc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.Lbc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "odu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                        (self.bber_fe is not None and self.bber_fe.has_data()) or
                                        (self.bber_ne is not None and self.bber_ne.has_data()) or
                                        (self.es_fe is not None and self.es_fe.has_data()) or
                                        (self.es_ne is not None and self.es_ne.has_data()) or
                                        (self.esr_fe is not None and self.esr_fe.has_data()) or
                                        (self.esr_ne is not None and self.esr_ne.has_data()) or
                                        (self.fc_fe is not None and self.fc_fe.has_data()) or
                                        (self.fc_ne is not None and self.fc_ne.has_data()) or
                                        (self.lbc is not None and self.lbc.has_data()) or
                                        (self.ses_fe is not None and self.ses_fe.has_data()) or
                                        (self.ses_ne is not None and self.ses_ne.has_data()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                        (self.uas_fe is not None and self.uas_fe.has_data()) or
                                        (self.uas_ne is not None and self.uas_ne.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                        (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                        (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                        (self.es_fe is not None and self.es_fe.has_operation()) or
                                        (self.es_ne is not None and self.es_ne.has_operation()) or
                                        (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                        (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                        (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                        (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                        (self.lbc is not None and self.lbc.has_operation()) or
                                        (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                        (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                        (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                        (self.uas_ne is not None and self.uas_ne.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "odu-hour24otn" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "bbe-fe"):
                                        if (self.bbe_fe is None):
                                            self.bbe_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeFe()
                                            self.bbe_fe.parent = self
                                            self._children_name_map["bbe_fe"] = "bbe-fe"
                                        return self.bbe_fe

                                    if (child_yang_name == "bbe-ne"):
                                        if (self.bbe_ne is None):
                                            self.bbe_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BbeNe()
                                            self.bbe_ne.parent = self
                                            self._children_name_map["bbe_ne"] = "bbe-ne"
                                        return self.bbe_ne

                                    if (child_yang_name == "bber-fe"):
                                        if (self.bber_fe is None):
                                            self.bber_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberFe()
                                            self.bber_fe.parent = self
                                            self._children_name_map["bber_fe"] = "bber-fe"
                                        return self.bber_fe

                                    if (child_yang_name == "bber-ne"):
                                        if (self.bber_ne is None):
                                            self.bber_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.BberNe()
                                            self.bber_ne.parent = self
                                            self._children_name_map["bber_ne"] = "bber-ne"
                                        return self.bber_ne

                                    if (child_yang_name == "es-fe"):
                                        if (self.es_fe is None):
                                            self.es_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsFe()
                                            self.es_fe.parent = self
                                            self._children_name_map["es_fe"] = "es-fe"
                                        return self.es_fe

                                    if (child_yang_name == "es-ne"):
                                        if (self.es_ne is None):
                                            self.es_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsNe()
                                            self.es_ne.parent = self
                                            self._children_name_map["es_ne"] = "es-ne"
                                        return self.es_ne

                                    if (child_yang_name == "esr-fe"):
                                        if (self.esr_fe is None):
                                            self.esr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrFe()
                                            self.esr_fe.parent = self
                                            self._children_name_map["esr_fe"] = "esr-fe"
                                        return self.esr_fe

                                    if (child_yang_name == "esr-ne"):
                                        if (self.esr_ne is None):
                                            self.esr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.EsrNe()
                                            self.esr_ne.parent = self
                                            self._children_name_map["esr_ne"] = "esr-ne"
                                        return self.esr_ne

                                    if (child_yang_name == "fc-fe"):
                                        if (self.fc_fe is None):
                                            self.fc_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcFe()
                                            self.fc_fe.parent = self
                                            self._children_name_map["fc_fe"] = "fc-fe"
                                        return self.fc_fe

                                    if (child_yang_name == "fc-ne"):
                                        if (self.fc_ne is None):
                                            self.fc_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.FcNe()
                                            self.fc_ne.parent = self
                                            self._children_name_map["fc_ne"] = "fc-ne"
                                        return self.fc_ne

                                    if (child_yang_name == "lbc"):
                                        if (self.lbc is None):
                                            self.lbc = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.Lbc()
                                            self.lbc.parent = self
                                            self._children_name_map["lbc"] = "lbc"
                                        return self.lbc

                                    if (child_yang_name == "ses-fe"):
                                        if (self.ses_fe is None):
                                            self.ses_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesFe()
                                            self.ses_fe.parent = self
                                            self._children_name_map["ses_fe"] = "ses-fe"
                                        return self.ses_fe

                                    if (child_yang_name == "ses-ne"):
                                        if (self.ses_ne is None):
                                            self.ses_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesNe()
                                            self.ses_ne.parent = self
                                            self._children_name_map["ses_ne"] = "ses-ne"
                                        return self.ses_ne

                                    if (child_yang_name == "sesr-fe"):
                                        if (self.sesr_fe is None):
                                            self.sesr_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrFe()
                                            self.sesr_fe.parent = self
                                            self._children_name_map["sesr_fe"] = "sesr-fe"
                                        return self.sesr_fe

                                    if (child_yang_name == "sesr-ne"):
                                        if (self.sesr_ne is None):
                                            self.sesr_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.SesrNe()
                                            self.sesr_ne.parent = self
                                            self._children_name_map["sesr_ne"] = "sesr-ne"
                                        return self.sesr_ne

                                    if (child_yang_name == "uas-fe"):
                                        if (self.uas_fe is None):
                                            self.uas_fe = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasFe()
                                            self.uas_fe.parent = self
                                            self._children_name_map["uas_fe"] = "uas-fe"
                                        return self.uas_fe

                                    if (child_yang_name == "uas-ne"):
                                        if (self.uas_ne is None):
                                            self.uas_ne = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn.UasNe()
                                            self.uas_ne.parent = self
                                            self._children_name_map["uas_ne"] = "uas-ne"
                                        return self.uas_ne

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.odu_hour24otn:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.odu_hour24otn:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "odu-hour24otns" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "odu-hour24otn"):
                                    for c in self.odu_hour24otn:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns.OduHour24Otn()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.odu_hour24otn.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "odu-hour24otn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.odu_hour24gfps is not None and self.odu_hour24gfps.has_data()) or
                                (self.odu_hour24otns is not None and self.odu_hour24otns.has_data()) or
                                (self.odu_hour24prbses is not None and self.odu_hour24prbses.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.odu_hour24gfps is not None and self.odu_hour24gfps.has_operation()) or
                                (self.odu_hour24otns is not None and self.odu_hour24otns.has_operation()) or
                                (self.odu_hour24prbses is not None and self.odu_hour24prbses.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "odu-hour24" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "odu-hour24gfps"):
                                if (self.odu_hour24gfps is None):
                                    self.odu_hour24gfps = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Gfps()
                                    self.odu_hour24gfps.parent = self
                                    self._children_name_map["odu_hour24gfps"] = "odu-hour24gfps"
                                return self.odu_hour24gfps

                            if (child_yang_name == "odu-hour24otns"):
                                if (self.odu_hour24otns is None):
                                    self.odu_hour24otns = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Otns()
                                    self.odu_hour24otns.parent = self
                                    self._children_name_map["odu_hour24otns"] = "odu-hour24otns"
                                return self.odu_hour24otns

                            if (child_yang_name == "odu-hour24prbses"):
                                if (self.odu_hour24prbses is None):
                                    self.odu_hour24prbses = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24.OduHour24Prbses()
                                    self.odu_hour24prbses.parent = self
                                    self._children_name_map["odu_hour24prbses"] = "odu-hour24prbses"
                                return self.odu_hour24prbses

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "odu-hour24gfps" or name == "odu-hour24otns" or name == "odu-hour24prbses"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.odu_hour24 is not None and self.odu_hour24.has_data()) or
                            (self.odu_minute15 is not None and self.odu_minute15.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.odu_hour24 is not None and self.odu_hour24.has_operation()) or
                            (self.odu_minute15 is not None and self.odu_minute15.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "odu-current" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "odu-hour24"):
                            if (self.odu_hour24 is None):
                                self.odu_hour24 = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduHour24()
                                self.odu_hour24.parent = self
                                self._children_name_map["odu_hour24"] = "odu-hour24"
                            return self.odu_hour24

                        if (child_yang_name == "odu-minute15"):
                            if (self.odu_minute15 is None):
                                self.odu_minute15 = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent.OduMinute15()
                                self.odu_minute15.parent = self
                                self._children_name_map["odu_minute15"] = "odu-minute15"
                            return self.odu_minute15

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "odu-hour24" or name == "odu-minute15"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.name.is_set or
                        (self.odu_current is not None and self.odu_current.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        (self.odu_current is not None and self.odu_current.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "odu-port" + "[name='" + self.name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/odu/odu-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "odu-current"):
                        if (self.odu_current is None):
                            self.odu_current = PerformanceManagement.Odu.OduPorts.OduPort.OduCurrent()
                            self.odu_current.parent = self
                            self._children_name_map["odu_current"] = "odu-current"
                        return self.odu_current

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "odu-current" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.odu_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.odu_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "odu-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/odu/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "odu-port"):
                    for c in self.odu_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = PerformanceManagement.Odu.OduPorts.OduPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.odu_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "odu-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.odu_ports is not None and self.odu_ports.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.odu_ports is not None and self.odu_ports.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "odu" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "odu-ports"):
                if (self.odu_ports is None):
                    self.odu_ports = PerformanceManagement.Odu.OduPorts()
                    self.odu_ports.parent = self
                    self._children_name_map["odu_ports"] = "odu-ports"
                return self.odu_ports

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "odu-ports"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Otu(Entity):
        """
        OTU controller performance data
        
        .. attribute:: otu_ports
        
        	Port performance data
        	**type**\:   :py:class:`OtuPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PerformanceManagement.Otu, self).__init__()

            self.yang_name = "otu"
            self.yang_parent_name = "performance-management"

            self.otu_ports = PerformanceManagement.Otu.OtuPorts()
            self.otu_ports.parent = self
            self._children_name_map["otu_ports"] = "otu-ports"
            self._children_yang_names.add("otu-ports")


        class OtuPorts(Entity):
            """
            Port performance data
            
            .. attribute:: otu_port
            
            	Port performance data
            	**type**\: list of    :py:class:`OtuPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PerformanceManagement.Otu.OtuPorts, self).__init__()

                self.yang_name = "otu-ports"
                self.yang_parent_name = "otu"

                self.otu_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(PerformanceManagement.Otu.OtuPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(PerformanceManagement.Otu.OtuPorts, self).__setattr__(name, value)


            class OtuPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: otu_current
                
                	port current performance data
                	**type**\:   :py:class:`OtuCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagement.Otu.OtuPorts.OtuPort, self).__init__()

                    self.yang_name = "otu-port"
                    self.yang_parent_name = "otu-ports"

                    self.name = YLeaf(YType.str, "name")

                    self.otu_current = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent()
                    self.otu_current.parent = self
                    self._children_name_map["otu_current"] = "otu-current"
                    self._children_yang_names.add("otu-current")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PerformanceManagement.Otu.OtuPorts.OtuPort, self).__setattr__(name, value)


                class OtuCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: otu_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`OtuHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24>`
                    
                    .. attribute:: otu_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`OtuMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15>`
                    
                    .. attribute:: otu_second30
                    
                    	port current performance data
                    	**type**\:   :py:class:`OtuSecond30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent, self).__init__()

                        self.yang_name = "otu-current"
                        self.yang_parent_name = "otu-port"

                        self.otu_hour24 = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24()
                        self.otu_hour24.parent = self
                        self._children_name_map["otu_hour24"] = "otu-hour24"
                        self._children_yang_names.add("otu-hour24")

                        self.otu_minute15 = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15()
                        self.otu_minute15.parent = self
                        self._children_name_map["otu_minute15"] = "otu-minute15"
                        self._children_yang_names.add("otu-minute15")

                        self.otu_second30 = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30()
                        self.otu_second30.parent = self
                        self._children_name_map["otu_second30"] = "otu-second30"
                        self._children_yang_names.add("otu-second30")


                    class OtuMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: otu_minute15fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuMinute15Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs>`
                        
                        .. attribute:: otu_minute15otns
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuMinute15Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15, self).__init__()

                            self.yang_name = "otu-minute15"
                            self.yang_parent_name = "otu-current"

                            self.otu_minute15fecs = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs()
                            self.otu_minute15fecs.parent = self
                            self._children_name_map["otu_minute15fecs"] = "otu-minute15fecs"
                            self._children_yang_names.add("otu-minute15fecs")

                            self.otu_minute15otns = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns()
                            self.otu_minute15otns.parent = self
                            self._children_name_map["otu_minute15otns"] = "otu-minute15otns"
                            self._children_yang_names.add("otu-minute15otns")


                        class OtuMinute15Fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_minute15fec
                            
                            	port 15\-minute fec performance data
                            	**type**\: list of    :py:class:`OtuMinute15Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs, self).__init__()

                                self.yang_name = "otu-minute15fecs"
                                self.yang_parent_name = "otu-minute15"

                                self.otu_minute15fec = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs, self).__setattr__(name, value)


                            class OtuMinute15Fec(Entity):
                                """
                                port 15\-minute fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec, self).__init__()

                                    self.yang_name = "otu-minute15fec"
                                    self.yang_parent_name = "otu-minute15fecs"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.ec_bits = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"
                                    self._children_yang_names.add("ec-bits")

                                    self.post_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                    self._children_yang_names.add("post-fec-ber")

                                    self.pre_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                    self._children_yang_names.add("pre-fec-ber")

                                    self.q = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"
                                    self._children_yang_names.add("q")

                                    self.qmargin = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._children_yang_names.add("qmargin")

                                    self.uc_words = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"
                                    self._children_yang_names.add("uc-words")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec, self).__setattr__(name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "otu-minute15fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.EcBits, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.EcBits, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ec-bits" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "otu-minute15fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.UcWords, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.UcWords, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uc-words" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "otu-minute15fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PreFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PreFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pre-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "otu-minute15fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PostFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PostFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "post-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "otu-minute15fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Q, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Q, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "q" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "otu-minute15fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Qmargin, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Qmargin, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "qmargin" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.ec_bits is not None and self.ec_bits.has_data()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                        (self.q is not None and self.q.has_data()) or
                                        (self.qmargin is not None and self.qmargin.has_data()) or
                                        (self.uc_words is not None and self.uc_words.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                        (self.q is not None and self.q.has_operation()) or
                                        (self.qmargin is not None and self.qmargin.has_operation()) or
                                        (self.uc_words is not None and self.uc_words.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "otu-minute15fec" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ec-bits"):
                                        if (self.ec_bits is None):
                                            self.ec_bits = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.EcBits()
                                            self.ec_bits.parent = self
                                            self._children_name_map["ec_bits"] = "ec-bits"
                                        return self.ec_bits

                                    if (child_yang_name == "post-fec-ber"):
                                        if (self.post_fec_ber is None):
                                            self.post_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PostFecBer()
                                            self.post_fec_ber.parent = self
                                            self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                        return self.post_fec_ber

                                    if (child_yang_name == "pre-fec-ber"):
                                        if (self.pre_fec_ber is None):
                                            self.pre_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.PreFecBer()
                                            self.pre_fec_ber.parent = self
                                            self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                        return self.pre_fec_ber

                                    if (child_yang_name == "q"):
                                        if (self.q is None):
                                            self.q = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Q()
                                            self.q.parent = self
                                            self._children_name_map["q"] = "q"
                                        return self.q

                                    if (child_yang_name == "qmargin"):
                                        if (self.qmargin is None):
                                            self.qmargin = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.Qmargin()
                                            self.qmargin.parent = self
                                            self._children_name_map["qmargin"] = "qmargin"
                                        return self.qmargin

                                    if (child_yang_name == "uc-words"):
                                        if (self.uc_words is None):
                                            self.uc_words = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec.UcWords()
                                            self.uc_words.parent = self
                                            self._children_name_map["uc_words"] = "uc-words"
                                        return self.uc_words

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.otu_minute15fec:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.otu_minute15fec:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "otu-minute15fecs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "otu-minute15fec"):
                                    for c in self.otu_minute15fec:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs.OtuMinute15Fec()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.otu_minute15fec.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otu-minute15fec"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OtuMinute15Otns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_minute15otn
                            
                            	port 15\-minute otn performance data
                            	**type**\: list of    :py:class:`OtuMinute15Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns, self).__init__()

                                self.yang_name = "otu-minute15otns"
                                self.yang_parent_name = "otu-minute15"

                                self.otu_minute15otn = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns, self).__setattr__(name, value)


                            class OtuMinute15Otn(Entity):
                                """
                                port 15\-minute otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn, self).__init__()

                                    self.yang_name = "otu-minute15otn"
                                    self.yang_parent_name = "otu-minute15otns"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.bbe_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"
                                    self._children_yang_names.add("bbe-fe")

                                    self.bbe_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"
                                    self._children_yang_names.add("bbe-ne")

                                    self.bber_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"
                                    self._children_yang_names.add("bber-fe")

                                    self.bber_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"
                                    self._children_yang_names.add("bber-ne")

                                    self.es_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"
                                    self._children_yang_names.add("es-fe")

                                    self.es_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"
                                    self._children_yang_names.add("es-ne")

                                    self.esr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"
                                    self._children_yang_names.add("esr-fe")

                                    self.esr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"
                                    self._children_yang_names.add("esr-ne")

                                    self.fc_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._children_yang_names.add("fc-fe")

                                    self.fc_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"
                                    self._children_yang_names.add("fc-ne")

                                    self.lbc = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"
                                    self._children_yang_names.add("lbc")

                                    self.ses_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"
                                    self._children_yang_names.add("ses-fe")

                                    self.ses_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"
                                    self._children_yang_names.add("ses-ne")

                                    self.sesr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"
                                    self._children_yang_names.add("sesr-fe")

                                    self.sesr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"
                                    self._children_yang_names.add("sesr-ne")

                                    self.uas_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"
                                    self._children_yang_names.add("uas-fe")

                                    self.uas_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"
                                    self._children_yang_names.add("uas-ne")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn, self).__setattr__(name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.Lbc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.Lbc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "otu-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                        (self.bber_fe is not None and self.bber_fe.has_data()) or
                                        (self.bber_ne is not None and self.bber_ne.has_data()) or
                                        (self.es_fe is not None and self.es_fe.has_data()) or
                                        (self.es_ne is not None and self.es_ne.has_data()) or
                                        (self.esr_fe is not None and self.esr_fe.has_data()) or
                                        (self.esr_ne is not None and self.esr_ne.has_data()) or
                                        (self.fc_fe is not None and self.fc_fe.has_data()) or
                                        (self.fc_ne is not None and self.fc_ne.has_data()) or
                                        (self.lbc is not None and self.lbc.has_data()) or
                                        (self.ses_fe is not None and self.ses_fe.has_data()) or
                                        (self.ses_ne is not None and self.ses_ne.has_data()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                        (self.uas_fe is not None and self.uas_fe.has_data()) or
                                        (self.uas_ne is not None and self.uas_ne.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                        (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                        (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                        (self.es_fe is not None and self.es_fe.has_operation()) or
                                        (self.es_ne is not None and self.es_ne.has_operation()) or
                                        (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                        (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                        (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                        (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                        (self.lbc is not None and self.lbc.has_operation()) or
                                        (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                        (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                        (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                        (self.uas_ne is not None and self.uas_ne.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "otu-minute15otn" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "bbe-fe"):
                                        if (self.bbe_fe is None):
                                            self.bbe_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeFe()
                                            self.bbe_fe.parent = self
                                            self._children_name_map["bbe_fe"] = "bbe-fe"
                                        return self.bbe_fe

                                    if (child_yang_name == "bbe-ne"):
                                        if (self.bbe_ne is None):
                                            self.bbe_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BbeNe()
                                            self.bbe_ne.parent = self
                                            self._children_name_map["bbe_ne"] = "bbe-ne"
                                        return self.bbe_ne

                                    if (child_yang_name == "bber-fe"):
                                        if (self.bber_fe is None):
                                            self.bber_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberFe()
                                            self.bber_fe.parent = self
                                            self._children_name_map["bber_fe"] = "bber-fe"
                                        return self.bber_fe

                                    if (child_yang_name == "bber-ne"):
                                        if (self.bber_ne is None):
                                            self.bber_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.BberNe()
                                            self.bber_ne.parent = self
                                            self._children_name_map["bber_ne"] = "bber-ne"
                                        return self.bber_ne

                                    if (child_yang_name == "es-fe"):
                                        if (self.es_fe is None):
                                            self.es_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsFe()
                                            self.es_fe.parent = self
                                            self._children_name_map["es_fe"] = "es-fe"
                                        return self.es_fe

                                    if (child_yang_name == "es-ne"):
                                        if (self.es_ne is None):
                                            self.es_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsNe()
                                            self.es_ne.parent = self
                                            self._children_name_map["es_ne"] = "es-ne"
                                        return self.es_ne

                                    if (child_yang_name == "esr-fe"):
                                        if (self.esr_fe is None):
                                            self.esr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrFe()
                                            self.esr_fe.parent = self
                                            self._children_name_map["esr_fe"] = "esr-fe"
                                        return self.esr_fe

                                    if (child_yang_name == "esr-ne"):
                                        if (self.esr_ne is None):
                                            self.esr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.EsrNe()
                                            self.esr_ne.parent = self
                                            self._children_name_map["esr_ne"] = "esr-ne"
                                        return self.esr_ne

                                    if (child_yang_name == "fc-fe"):
                                        if (self.fc_fe is None):
                                            self.fc_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcFe()
                                            self.fc_fe.parent = self
                                            self._children_name_map["fc_fe"] = "fc-fe"
                                        return self.fc_fe

                                    if (child_yang_name == "fc-ne"):
                                        if (self.fc_ne is None):
                                            self.fc_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.FcNe()
                                            self.fc_ne.parent = self
                                            self._children_name_map["fc_ne"] = "fc-ne"
                                        return self.fc_ne

                                    if (child_yang_name == "lbc"):
                                        if (self.lbc is None):
                                            self.lbc = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.Lbc()
                                            self.lbc.parent = self
                                            self._children_name_map["lbc"] = "lbc"
                                        return self.lbc

                                    if (child_yang_name == "ses-fe"):
                                        if (self.ses_fe is None):
                                            self.ses_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesFe()
                                            self.ses_fe.parent = self
                                            self._children_name_map["ses_fe"] = "ses-fe"
                                        return self.ses_fe

                                    if (child_yang_name == "ses-ne"):
                                        if (self.ses_ne is None):
                                            self.ses_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesNe()
                                            self.ses_ne.parent = self
                                            self._children_name_map["ses_ne"] = "ses-ne"
                                        return self.ses_ne

                                    if (child_yang_name == "sesr-fe"):
                                        if (self.sesr_fe is None):
                                            self.sesr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrFe()
                                            self.sesr_fe.parent = self
                                            self._children_name_map["sesr_fe"] = "sesr-fe"
                                        return self.sesr_fe

                                    if (child_yang_name == "sesr-ne"):
                                        if (self.sesr_ne is None):
                                            self.sesr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.SesrNe()
                                            self.sesr_ne.parent = self
                                            self._children_name_map["sesr_ne"] = "sesr-ne"
                                        return self.sesr_ne

                                    if (child_yang_name == "uas-fe"):
                                        if (self.uas_fe is None):
                                            self.uas_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasFe()
                                            self.uas_fe.parent = self
                                            self._children_name_map["uas_fe"] = "uas-fe"
                                        return self.uas_fe

                                    if (child_yang_name == "uas-ne"):
                                        if (self.uas_ne is None):
                                            self.uas_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn.UasNe()
                                            self.uas_ne.parent = self
                                            self._children_name_map["uas_ne"] = "uas-ne"
                                        return self.uas_ne

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.otu_minute15otn:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.otu_minute15otn:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "otu-minute15otns" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "otu-minute15otn"):
                                    for c in self.otu_minute15otn:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns.OtuMinute15Otn()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.otu_minute15otn.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otu-minute15otn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.otu_minute15fecs is not None and self.otu_minute15fecs.has_data()) or
                                (self.otu_minute15otns is not None and self.otu_minute15otns.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.otu_minute15fecs is not None and self.otu_minute15fecs.has_operation()) or
                                (self.otu_minute15otns is not None and self.otu_minute15otns.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "otu-minute15" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "otu-minute15fecs"):
                                if (self.otu_minute15fecs is None):
                                    self.otu_minute15fecs = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Fecs()
                                    self.otu_minute15fecs.parent = self
                                    self._children_name_map["otu_minute15fecs"] = "otu-minute15fecs"
                                return self.otu_minute15fecs

                            if (child_yang_name == "otu-minute15otns"):
                                if (self.otu_minute15otns is None):
                                    self.otu_minute15otns = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15.OtuMinute15Otns()
                                    self.otu_minute15otns.parent = self
                                    self._children_name_map["otu_minute15otns"] = "otu-minute15otns"
                                return self.otu_minute15otns

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "otu-minute15fecs" or name == "otu-minute15otns"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OtuSecond30(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: otu_second30fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuSecond30Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs>`
                        
                        .. attribute:: otu_second30otns
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuSecond30Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30, self).__init__()

                            self.yang_name = "otu-second30"
                            self.yang_parent_name = "otu-current"

                            self.otu_second30fecs = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs()
                            self.otu_second30fecs.parent = self
                            self._children_name_map["otu_second30fecs"] = "otu-second30fecs"
                            self._children_yang_names.add("otu-second30fecs")

                            self.otu_second30otns = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns()
                            self.otu_second30otns.parent = self
                            self._children_name_map["otu_second30otns"] = "otu-second30otns"
                            self._children_yang_names.add("otu-second30otns")


                        class OtuSecond30Fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_second30fec
                            
                            	port 30\-sec fec performance data
                            	**type**\: list of    :py:class:`OtuSecond30Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs, self).__init__()

                                self.yang_name = "otu-second30fecs"
                                self.yang_parent_name = "otu-second30"

                                self.otu_second30fec = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs, self).__setattr__(name, value)


                            class OtuSecond30Fec(Entity):
                                """
                                port 30\-sec fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec, self).__init__()

                                    self.yang_name = "otu-second30fec"
                                    self.yang_parent_name = "otu-second30fecs"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.ec_bits = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"
                                    self._children_yang_names.add("ec-bits")

                                    self.post_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                    self._children_yang_names.add("post-fec-ber")

                                    self.pre_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                    self._children_yang_names.add("pre-fec-ber")

                                    self.q = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"
                                    self._children_yang_names.add("q")

                                    self.qmargin = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._children_yang_names.add("qmargin")

                                    self.uc_words = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"
                                    self._children_yang_names.add("uc-words")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec, self).__setattr__(name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "otu-second30fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.EcBits, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.EcBits, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ec-bits" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "otu-second30fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.UcWords, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.UcWords, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uc-words" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "otu-second30fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PreFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PreFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pre-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "otu-second30fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PostFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PostFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "post-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "otu-second30fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Q, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Q, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "q" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "otu-second30fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Qmargin, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Qmargin, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "qmargin" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.ec_bits is not None and self.ec_bits.has_data()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                        (self.q is not None and self.q.has_data()) or
                                        (self.qmargin is not None and self.qmargin.has_data()) or
                                        (self.uc_words is not None and self.uc_words.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                        (self.q is not None and self.q.has_operation()) or
                                        (self.qmargin is not None and self.qmargin.has_operation()) or
                                        (self.uc_words is not None and self.uc_words.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "otu-second30fec" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ec-bits"):
                                        if (self.ec_bits is None):
                                            self.ec_bits = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.EcBits()
                                            self.ec_bits.parent = self
                                            self._children_name_map["ec_bits"] = "ec-bits"
                                        return self.ec_bits

                                    if (child_yang_name == "post-fec-ber"):
                                        if (self.post_fec_ber is None):
                                            self.post_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PostFecBer()
                                            self.post_fec_ber.parent = self
                                            self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                        return self.post_fec_ber

                                    if (child_yang_name == "pre-fec-ber"):
                                        if (self.pre_fec_ber is None):
                                            self.pre_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.PreFecBer()
                                            self.pre_fec_ber.parent = self
                                            self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                        return self.pre_fec_ber

                                    if (child_yang_name == "q"):
                                        if (self.q is None):
                                            self.q = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Q()
                                            self.q.parent = self
                                            self._children_name_map["q"] = "q"
                                        return self.q

                                    if (child_yang_name == "qmargin"):
                                        if (self.qmargin is None):
                                            self.qmargin = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.Qmargin()
                                            self.qmargin.parent = self
                                            self._children_name_map["qmargin"] = "qmargin"
                                        return self.qmargin

                                    if (child_yang_name == "uc-words"):
                                        if (self.uc_words is None):
                                            self.uc_words = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec.UcWords()
                                            self.uc_words.parent = self
                                            self._children_name_map["uc_words"] = "uc-words"
                                        return self.uc_words

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.otu_second30fec:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.otu_second30fec:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "otu-second30fecs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "otu-second30fec"):
                                    for c in self.otu_second30fec:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs.OtuSecond30Fec()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.otu_second30fec.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otu-second30fec"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OtuSecond30Otns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_second30otn
                            
                            	port 30\-sec otn performance data
                            	**type**\: list of    :py:class:`OtuSecond30Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns, self).__init__()

                                self.yang_name = "otu-second30otns"
                                self.yang_parent_name = "otu-second30"

                                self.otu_second30otn = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns, self).__setattr__(name, value)


                            class OtuSecond30Otn(Entity):
                                """
                                port 30\-sec otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn, self).__init__()

                                    self.yang_name = "otu-second30otn"
                                    self.yang_parent_name = "otu-second30otns"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.bbe_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"
                                    self._children_yang_names.add("bbe-fe")

                                    self.bbe_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"
                                    self._children_yang_names.add("bbe-ne")

                                    self.bber_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"
                                    self._children_yang_names.add("bber-fe")

                                    self.bber_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"
                                    self._children_yang_names.add("bber-ne")

                                    self.es_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"
                                    self._children_yang_names.add("es-fe")

                                    self.es_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"
                                    self._children_yang_names.add("es-ne")

                                    self.esr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"
                                    self._children_yang_names.add("esr-fe")

                                    self.esr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"
                                    self._children_yang_names.add("esr-ne")

                                    self.fc_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._children_yang_names.add("fc-fe")

                                    self.fc_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"
                                    self._children_yang_names.add("fc-ne")

                                    self.lbc = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"
                                    self._children_yang_names.add("lbc")

                                    self.ses_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"
                                    self._children_yang_names.add("ses-fe")

                                    self.ses_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"
                                    self._children_yang_names.add("ses-ne")

                                    self.sesr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"
                                    self._children_yang_names.add("sesr-fe")

                                    self.sesr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"
                                    self._children_yang_names.add("sesr-ne")

                                    self.uas_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"
                                    self._children_yang_names.add("uas-fe")

                                    self.uas_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"
                                    self._children_yang_names.add("uas-ne")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn, self).__setattr__(name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.Lbc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.Lbc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "otu-second30otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                        (self.bber_fe is not None and self.bber_fe.has_data()) or
                                        (self.bber_ne is not None and self.bber_ne.has_data()) or
                                        (self.es_fe is not None and self.es_fe.has_data()) or
                                        (self.es_ne is not None and self.es_ne.has_data()) or
                                        (self.esr_fe is not None and self.esr_fe.has_data()) or
                                        (self.esr_ne is not None and self.esr_ne.has_data()) or
                                        (self.fc_fe is not None and self.fc_fe.has_data()) or
                                        (self.fc_ne is not None and self.fc_ne.has_data()) or
                                        (self.lbc is not None and self.lbc.has_data()) or
                                        (self.ses_fe is not None and self.ses_fe.has_data()) or
                                        (self.ses_ne is not None and self.ses_ne.has_data()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                        (self.uas_fe is not None and self.uas_fe.has_data()) or
                                        (self.uas_ne is not None and self.uas_ne.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                        (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                        (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                        (self.es_fe is not None and self.es_fe.has_operation()) or
                                        (self.es_ne is not None and self.es_ne.has_operation()) or
                                        (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                        (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                        (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                        (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                        (self.lbc is not None and self.lbc.has_operation()) or
                                        (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                        (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                        (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                        (self.uas_ne is not None and self.uas_ne.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "otu-second30otn" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "bbe-fe"):
                                        if (self.bbe_fe is None):
                                            self.bbe_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeFe()
                                            self.bbe_fe.parent = self
                                            self._children_name_map["bbe_fe"] = "bbe-fe"
                                        return self.bbe_fe

                                    if (child_yang_name == "bbe-ne"):
                                        if (self.bbe_ne is None):
                                            self.bbe_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BbeNe()
                                            self.bbe_ne.parent = self
                                            self._children_name_map["bbe_ne"] = "bbe-ne"
                                        return self.bbe_ne

                                    if (child_yang_name == "bber-fe"):
                                        if (self.bber_fe is None):
                                            self.bber_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberFe()
                                            self.bber_fe.parent = self
                                            self._children_name_map["bber_fe"] = "bber-fe"
                                        return self.bber_fe

                                    if (child_yang_name == "bber-ne"):
                                        if (self.bber_ne is None):
                                            self.bber_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.BberNe()
                                            self.bber_ne.parent = self
                                            self._children_name_map["bber_ne"] = "bber-ne"
                                        return self.bber_ne

                                    if (child_yang_name == "es-fe"):
                                        if (self.es_fe is None):
                                            self.es_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsFe()
                                            self.es_fe.parent = self
                                            self._children_name_map["es_fe"] = "es-fe"
                                        return self.es_fe

                                    if (child_yang_name == "es-ne"):
                                        if (self.es_ne is None):
                                            self.es_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsNe()
                                            self.es_ne.parent = self
                                            self._children_name_map["es_ne"] = "es-ne"
                                        return self.es_ne

                                    if (child_yang_name == "esr-fe"):
                                        if (self.esr_fe is None):
                                            self.esr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrFe()
                                            self.esr_fe.parent = self
                                            self._children_name_map["esr_fe"] = "esr-fe"
                                        return self.esr_fe

                                    if (child_yang_name == "esr-ne"):
                                        if (self.esr_ne is None):
                                            self.esr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.EsrNe()
                                            self.esr_ne.parent = self
                                            self._children_name_map["esr_ne"] = "esr-ne"
                                        return self.esr_ne

                                    if (child_yang_name == "fc-fe"):
                                        if (self.fc_fe is None):
                                            self.fc_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcFe()
                                            self.fc_fe.parent = self
                                            self._children_name_map["fc_fe"] = "fc-fe"
                                        return self.fc_fe

                                    if (child_yang_name == "fc-ne"):
                                        if (self.fc_ne is None):
                                            self.fc_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.FcNe()
                                            self.fc_ne.parent = self
                                            self._children_name_map["fc_ne"] = "fc-ne"
                                        return self.fc_ne

                                    if (child_yang_name == "lbc"):
                                        if (self.lbc is None):
                                            self.lbc = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.Lbc()
                                            self.lbc.parent = self
                                            self._children_name_map["lbc"] = "lbc"
                                        return self.lbc

                                    if (child_yang_name == "ses-fe"):
                                        if (self.ses_fe is None):
                                            self.ses_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesFe()
                                            self.ses_fe.parent = self
                                            self._children_name_map["ses_fe"] = "ses-fe"
                                        return self.ses_fe

                                    if (child_yang_name == "ses-ne"):
                                        if (self.ses_ne is None):
                                            self.ses_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesNe()
                                            self.ses_ne.parent = self
                                            self._children_name_map["ses_ne"] = "ses-ne"
                                        return self.ses_ne

                                    if (child_yang_name == "sesr-fe"):
                                        if (self.sesr_fe is None):
                                            self.sesr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrFe()
                                            self.sesr_fe.parent = self
                                            self._children_name_map["sesr_fe"] = "sesr-fe"
                                        return self.sesr_fe

                                    if (child_yang_name == "sesr-ne"):
                                        if (self.sesr_ne is None):
                                            self.sesr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.SesrNe()
                                            self.sesr_ne.parent = self
                                            self._children_name_map["sesr_ne"] = "sesr-ne"
                                        return self.sesr_ne

                                    if (child_yang_name == "uas-fe"):
                                        if (self.uas_fe is None):
                                            self.uas_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasFe()
                                            self.uas_fe.parent = self
                                            self._children_name_map["uas_fe"] = "uas-fe"
                                        return self.uas_fe

                                    if (child_yang_name == "uas-ne"):
                                        if (self.uas_ne is None):
                                            self.uas_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn.UasNe()
                                            self.uas_ne.parent = self
                                            self._children_name_map["uas_ne"] = "uas-ne"
                                        return self.uas_ne

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.otu_second30otn:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.otu_second30otn:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "otu-second30otns" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "otu-second30otn"):
                                    for c in self.otu_second30otn:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns.OtuSecond30Otn()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.otu_second30otn.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otu-second30otn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.otu_second30fecs is not None and self.otu_second30fecs.has_data()) or
                                (self.otu_second30otns is not None and self.otu_second30otns.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.otu_second30fecs is not None and self.otu_second30fecs.has_operation()) or
                                (self.otu_second30otns is not None and self.otu_second30otns.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "otu-second30" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "otu-second30fecs"):
                                if (self.otu_second30fecs is None):
                                    self.otu_second30fecs = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Fecs()
                                    self.otu_second30fecs.parent = self
                                    self._children_name_map["otu_second30fecs"] = "otu-second30fecs"
                                return self.otu_second30fecs

                            if (child_yang_name == "otu-second30otns"):
                                if (self.otu_second30otns is None):
                                    self.otu_second30otns = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30.OtuSecond30Otns()
                                    self.otu_second30otns.parent = self
                                    self._children_name_map["otu_second30otns"] = "otu-second30otns"
                                return self.otu_second30otns

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "otu-second30fecs" or name == "otu-second30otns"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OtuHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: otu_hour24fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuHour24Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs>`
                        
                        .. attribute:: otu_hour24otns
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`OtuHour24Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24, self).__init__()

                            self.yang_name = "otu-hour24"
                            self.yang_parent_name = "otu-current"

                            self.otu_hour24fecs = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs()
                            self.otu_hour24fecs.parent = self
                            self._children_name_map["otu_hour24fecs"] = "otu-hour24fecs"
                            self._children_yang_names.add("otu-hour24fecs")

                            self.otu_hour24otns = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns()
                            self.otu_hour24otns.parent = self
                            self._children_name_map["otu_hour24otns"] = "otu-hour24otns"
                            self._children_yang_names.add("otu-hour24otns")


                        class OtuHour24Fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_hour24fec
                            
                            	port 24 hour fec performance data
                            	**type**\: list of    :py:class:`OtuHour24Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs, self).__init__()

                                self.yang_name = "otu-hour24fecs"
                                self.yang_parent_name = "otu-hour24"

                                self.otu_hour24fec = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs, self).__setattr__(name, value)


                            class OtuHour24Fec(Entity):
                                """
                                port 24 hour fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec, self).__init__()

                                    self.yang_name = "otu-hour24fec"
                                    self.yang_parent_name = "otu-hour24fecs"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.ec_bits = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"
                                    self._children_yang_names.add("ec-bits")

                                    self.post_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                    self._children_yang_names.add("post-fec-ber")

                                    self.pre_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                    self._children_yang_names.add("pre-fec-ber")

                                    self.q = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"
                                    self._children_yang_names.add("q")

                                    self.qmargin = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._children_yang_names.add("qmargin")

                                    self.uc_words = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"
                                    self._children_yang_names.add("uc-words")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec, self).__setattr__(name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "otu-hour24fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.EcBits, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.EcBits, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ec-bits" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "otu-hour24fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.UcWords, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.UcWords, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uc-words" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "otu-hour24fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PreFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PreFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pre-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "otu-hour24fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PostFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PostFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "post-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "otu-hour24fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Q, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Q, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "q" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "otu-hour24fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Qmargin, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Qmargin, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "qmargin" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.ec_bits is not None and self.ec_bits.has_data()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                        (self.q is not None and self.q.has_data()) or
                                        (self.qmargin is not None and self.qmargin.has_data()) or
                                        (self.uc_words is not None and self.uc_words.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                        (self.q is not None and self.q.has_operation()) or
                                        (self.qmargin is not None and self.qmargin.has_operation()) or
                                        (self.uc_words is not None and self.uc_words.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "otu-hour24fec" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ec-bits"):
                                        if (self.ec_bits is None):
                                            self.ec_bits = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.EcBits()
                                            self.ec_bits.parent = self
                                            self._children_name_map["ec_bits"] = "ec-bits"
                                        return self.ec_bits

                                    if (child_yang_name == "post-fec-ber"):
                                        if (self.post_fec_ber is None):
                                            self.post_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PostFecBer()
                                            self.post_fec_ber.parent = self
                                            self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                        return self.post_fec_ber

                                    if (child_yang_name == "pre-fec-ber"):
                                        if (self.pre_fec_ber is None):
                                            self.pre_fec_ber = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.PreFecBer()
                                            self.pre_fec_ber.parent = self
                                            self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                        return self.pre_fec_ber

                                    if (child_yang_name == "q"):
                                        if (self.q is None):
                                            self.q = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Q()
                                            self.q.parent = self
                                            self._children_name_map["q"] = "q"
                                        return self.q

                                    if (child_yang_name == "qmargin"):
                                        if (self.qmargin is None):
                                            self.qmargin = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.Qmargin()
                                            self.qmargin.parent = self
                                            self._children_name_map["qmargin"] = "qmargin"
                                        return self.qmargin

                                    if (child_yang_name == "uc-words"):
                                        if (self.uc_words is None):
                                            self.uc_words = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec.UcWords()
                                            self.uc_words.parent = self
                                            self._children_name_map["uc_words"] = "uc-words"
                                        return self.uc_words

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.otu_hour24fec:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.otu_hour24fec:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "otu-hour24fecs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "otu-hour24fec"):
                                    for c in self.otu_hour24fec:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs.OtuHour24Fec()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.otu_hour24fec.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otu-hour24fec"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OtuHour24Otns(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: otu_hour24otn
                            
                            	port 24 hour otn performance data
                            	**type**\: list of    :py:class:`OtuHour24Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns, self).__init__()

                                self.yang_name = "otu-hour24otns"
                                self.yang_parent_name = "otu-hour24"

                                self.otu_hour24otn = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns, self).__setattr__(name, value)


                            class OtuHour24Otn(Entity):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn, self).__init__()

                                    self.yang_name = "otu-hour24otn"
                                    self.yang_parent_name = "otu-hour24otns"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.bbe_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"
                                    self._children_yang_names.add("bbe-fe")

                                    self.bbe_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"
                                    self._children_yang_names.add("bbe-ne")

                                    self.bber_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"
                                    self._children_yang_names.add("bber-fe")

                                    self.bber_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"
                                    self._children_yang_names.add("bber-ne")

                                    self.es_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"
                                    self._children_yang_names.add("es-fe")

                                    self.es_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"
                                    self._children_yang_names.add("es-ne")

                                    self.esr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"
                                    self._children_yang_names.add("esr-fe")

                                    self.esr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"
                                    self._children_yang_names.add("esr-ne")

                                    self.fc_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._children_yang_names.add("fc-fe")

                                    self.fc_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"
                                    self._children_yang_names.add("fc-ne")

                                    self.lbc = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"
                                    self._children_yang_names.add("lbc")

                                    self.ses_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"
                                    self._children_yang_names.add("ses-fe")

                                    self.ses_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"
                                    self._children_yang_names.add("ses-ne")

                                    self.sesr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"
                                    self._children_yang_names.add("sesr-fe")

                                    self.sesr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"
                                    self._children_yang_names.add("sesr-ne")

                                    self.uas_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"
                                    self._children_yang_names.add("uas-fe")

                                    self.uas_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"
                                    self._children_yang_names.add("uas-ne")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn, self).__setattr__(name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.Lbc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.Lbc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "otu-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                        (self.bber_fe is not None and self.bber_fe.has_data()) or
                                        (self.bber_ne is not None and self.bber_ne.has_data()) or
                                        (self.es_fe is not None and self.es_fe.has_data()) or
                                        (self.es_ne is not None and self.es_ne.has_data()) or
                                        (self.esr_fe is not None and self.esr_fe.has_data()) or
                                        (self.esr_ne is not None and self.esr_ne.has_data()) or
                                        (self.fc_fe is not None and self.fc_fe.has_data()) or
                                        (self.fc_ne is not None and self.fc_ne.has_data()) or
                                        (self.lbc is not None and self.lbc.has_data()) or
                                        (self.ses_fe is not None and self.ses_fe.has_data()) or
                                        (self.ses_ne is not None and self.ses_ne.has_data()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                        (self.uas_fe is not None and self.uas_fe.has_data()) or
                                        (self.uas_ne is not None and self.uas_ne.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                        (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                        (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                        (self.es_fe is not None and self.es_fe.has_operation()) or
                                        (self.es_ne is not None and self.es_ne.has_operation()) or
                                        (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                        (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                        (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                        (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                        (self.lbc is not None and self.lbc.has_operation()) or
                                        (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                        (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                        (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                        (self.uas_ne is not None and self.uas_ne.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "otu-hour24otn" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "bbe-fe"):
                                        if (self.bbe_fe is None):
                                            self.bbe_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeFe()
                                            self.bbe_fe.parent = self
                                            self._children_name_map["bbe_fe"] = "bbe-fe"
                                        return self.bbe_fe

                                    if (child_yang_name == "bbe-ne"):
                                        if (self.bbe_ne is None):
                                            self.bbe_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BbeNe()
                                            self.bbe_ne.parent = self
                                            self._children_name_map["bbe_ne"] = "bbe-ne"
                                        return self.bbe_ne

                                    if (child_yang_name == "bber-fe"):
                                        if (self.bber_fe is None):
                                            self.bber_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberFe()
                                            self.bber_fe.parent = self
                                            self._children_name_map["bber_fe"] = "bber-fe"
                                        return self.bber_fe

                                    if (child_yang_name == "bber-ne"):
                                        if (self.bber_ne is None):
                                            self.bber_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.BberNe()
                                            self.bber_ne.parent = self
                                            self._children_name_map["bber_ne"] = "bber-ne"
                                        return self.bber_ne

                                    if (child_yang_name == "es-fe"):
                                        if (self.es_fe is None):
                                            self.es_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsFe()
                                            self.es_fe.parent = self
                                            self._children_name_map["es_fe"] = "es-fe"
                                        return self.es_fe

                                    if (child_yang_name == "es-ne"):
                                        if (self.es_ne is None):
                                            self.es_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsNe()
                                            self.es_ne.parent = self
                                            self._children_name_map["es_ne"] = "es-ne"
                                        return self.es_ne

                                    if (child_yang_name == "esr-fe"):
                                        if (self.esr_fe is None):
                                            self.esr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrFe()
                                            self.esr_fe.parent = self
                                            self._children_name_map["esr_fe"] = "esr-fe"
                                        return self.esr_fe

                                    if (child_yang_name == "esr-ne"):
                                        if (self.esr_ne is None):
                                            self.esr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.EsrNe()
                                            self.esr_ne.parent = self
                                            self._children_name_map["esr_ne"] = "esr-ne"
                                        return self.esr_ne

                                    if (child_yang_name == "fc-fe"):
                                        if (self.fc_fe is None):
                                            self.fc_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcFe()
                                            self.fc_fe.parent = self
                                            self._children_name_map["fc_fe"] = "fc-fe"
                                        return self.fc_fe

                                    if (child_yang_name == "fc-ne"):
                                        if (self.fc_ne is None):
                                            self.fc_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.FcNe()
                                            self.fc_ne.parent = self
                                            self._children_name_map["fc_ne"] = "fc-ne"
                                        return self.fc_ne

                                    if (child_yang_name == "lbc"):
                                        if (self.lbc is None):
                                            self.lbc = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.Lbc()
                                            self.lbc.parent = self
                                            self._children_name_map["lbc"] = "lbc"
                                        return self.lbc

                                    if (child_yang_name == "ses-fe"):
                                        if (self.ses_fe is None):
                                            self.ses_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesFe()
                                            self.ses_fe.parent = self
                                            self._children_name_map["ses_fe"] = "ses-fe"
                                        return self.ses_fe

                                    if (child_yang_name == "ses-ne"):
                                        if (self.ses_ne is None):
                                            self.ses_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesNe()
                                            self.ses_ne.parent = self
                                            self._children_name_map["ses_ne"] = "ses-ne"
                                        return self.ses_ne

                                    if (child_yang_name == "sesr-fe"):
                                        if (self.sesr_fe is None):
                                            self.sesr_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrFe()
                                            self.sesr_fe.parent = self
                                            self._children_name_map["sesr_fe"] = "sesr-fe"
                                        return self.sesr_fe

                                    if (child_yang_name == "sesr-ne"):
                                        if (self.sesr_ne is None):
                                            self.sesr_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.SesrNe()
                                            self.sesr_ne.parent = self
                                            self._children_name_map["sesr_ne"] = "sesr-ne"
                                        return self.sesr_ne

                                    if (child_yang_name == "uas-fe"):
                                        if (self.uas_fe is None):
                                            self.uas_fe = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasFe()
                                            self.uas_fe.parent = self
                                            self._children_name_map["uas_fe"] = "uas-fe"
                                        return self.uas_fe

                                    if (child_yang_name == "uas-ne"):
                                        if (self.uas_ne is None):
                                            self.uas_ne = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn.UasNe()
                                            self.uas_ne.parent = self
                                            self._children_name_map["uas_ne"] = "uas-ne"
                                        return self.uas_ne

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.otu_hour24otn:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.otu_hour24otn:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "otu-hour24otns" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "otu-hour24otn"):
                                    for c in self.otu_hour24otn:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns.OtuHour24Otn()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.otu_hour24otn.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otu-hour24otn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.otu_hour24fecs is not None and self.otu_hour24fecs.has_data()) or
                                (self.otu_hour24otns is not None and self.otu_hour24otns.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.otu_hour24fecs is not None and self.otu_hour24fecs.has_operation()) or
                                (self.otu_hour24otns is not None and self.otu_hour24otns.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "otu-hour24" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "otu-hour24fecs"):
                                if (self.otu_hour24fecs is None):
                                    self.otu_hour24fecs = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Fecs()
                                    self.otu_hour24fecs.parent = self
                                    self._children_name_map["otu_hour24fecs"] = "otu-hour24fecs"
                                return self.otu_hour24fecs

                            if (child_yang_name == "otu-hour24otns"):
                                if (self.otu_hour24otns is None):
                                    self.otu_hour24otns = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24.OtuHour24Otns()
                                    self.otu_hour24otns.parent = self
                                    self._children_name_map["otu_hour24otns"] = "otu-hour24otns"
                                return self.otu_hour24otns

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "otu-hour24fecs" or name == "otu-hour24otns"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.otu_hour24 is not None and self.otu_hour24.has_data()) or
                            (self.otu_minute15 is not None and self.otu_minute15.has_data()) or
                            (self.otu_second30 is not None and self.otu_second30.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.otu_hour24 is not None and self.otu_hour24.has_operation()) or
                            (self.otu_minute15 is not None and self.otu_minute15.has_operation()) or
                            (self.otu_second30 is not None and self.otu_second30.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "otu-current" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "otu-hour24"):
                            if (self.otu_hour24 is None):
                                self.otu_hour24 = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuHour24()
                                self.otu_hour24.parent = self
                                self._children_name_map["otu_hour24"] = "otu-hour24"
                            return self.otu_hour24

                        if (child_yang_name == "otu-minute15"):
                            if (self.otu_minute15 is None):
                                self.otu_minute15 = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuMinute15()
                                self.otu_minute15.parent = self
                                self._children_name_map["otu_minute15"] = "otu-minute15"
                            return self.otu_minute15

                        if (child_yang_name == "otu-second30"):
                            if (self.otu_second30 is None):
                                self.otu_second30 = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent.OtuSecond30()
                                self.otu_second30.parent = self
                                self._children_name_map["otu_second30"] = "otu-second30"
                            return self.otu_second30

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "otu-hour24" or name == "otu-minute15" or name == "otu-second30"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.name.is_set or
                        (self.otu_current is not None and self.otu_current.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        (self.otu_current is not None and self.otu_current.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "otu-port" + "[name='" + self.name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/otu/otu-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "otu-current"):
                        if (self.otu_current is None):
                            self.otu_current = PerformanceManagement.Otu.OtuPorts.OtuPort.OtuCurrent()
                            self.otu_current.parent = self
                            self._children_name_map["otu_current"] = "otu-current"
                        return self.otu_current

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "otu-current" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.otu_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.otu_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "otu-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/otu/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "otu-port"):
                    for c in self.otu_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = PerformanceManagement.Otu.OtuPorts.OtuPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.otu_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "otu-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.otu_ports is not None and self.otu_ports.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.otu_ports is not None and self.otu_ports.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "otu" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "otu-ports"):
                if (self.otu_ports is None):
                    self.otu_ports = PerformanceManagement.Otu.OtuPorts()
                    self.otu_ports.parent = self
                    self._children_name_map["otu_ports"] = "otu-ports"
                return self.otu_ports

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "otu-ports"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Stm(Entity):
        """
        STM controller performance data
        
        .. attribute:: stm_ports
        
        	Port performance data
        	**type**\:   :py:class:`StmPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PerformanceManagement.Stm, self).__init__()

            self.yang_name = "stm"
            self.yang_parent_name = "performance-management"

            self.stm_ports = PerformanceManagement.Stm.StmPorts()
            self.stm_ports.parent = self
            self._children_name_map["stm_ports"] = "stm-ports"
            self._children_yang_names.add("stm-ports")


        class StmPorts(Entity):
            """
            Port performance data
            
            .. attribute:: stm_port
            
            	Port performance data
            	**type**\: list of    :py:class:`StmPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PerformanceManagement.Stm.StmPorts, self).__init__()

                self.yang_name = "stm-ports"
                self.yang_parent_name = "stm"

                self.stm_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(PerformanceManagement.Stm.StmPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(PerformanceManagement.Stm.StmPorts, self).__setattr__(name, value)


            class StmPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: stm_current
                
                	port current performance data
                	**type**\:   :py:class:`StmCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagement.Stm.StmPorts.StmPort, self).__init__()

                    self.yang_name = "stm-port"
                    self.yang_parent_name = "stm-ports"

                    self.name = YLeaf(YType.str, "name")

                    self.stm_current = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent()
                    self.stm_current.parent = self
                    self._children_name_map["stm_current"] = "stm-current"
                    self._children_yang_names.add("stm-current")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PerformanceManagement.Stm.StmPorts.StmPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PerformanceManagement.Stm.StmPorts.StmPort, self).__setattr__(name, value)


                class StmCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: stm_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`StmHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24>`
                    
                    .. attribute:: stm_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`StmMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent, self).__init__()

                        self.yang_name = "stm-current"
                        self.yang_parent_name = "stm-port"

                        self.stm_hour24 = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24()
                        self.stm_hour24.parent = self
                        self._children_name_map["stm_hour24"] = "stm-hour24"
                        self._children_yang_names.add("stm-hour24")

                        self.stm_minute15 = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15()
                        self.stm_minute15.parent = self
                        self._children_name_map["stm_minute15"] = "stm-minute15"
                        self._children_yang_names.add("stm-minute15")


                    class StmHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: stm_hour24stms
                        
                        	port current performance data
                        	**type**\:   :py:class:`StmHour24Stms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24, self).__init__()

                            self.yang_name = "stm-hour24"
                            self.yang_parent_name = "stm-current"

                            self.stm_hour24stms = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms()
                            self.stm_hour24stms.parent = self
                            self._children_name_map["stm_hour24stms"] = "stm-hour24stms"
                            self._children_yang_names.add("stm-hour24stms")


                        class StmHour24Stms(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: stm_hour24stm
                            
                            	port 24 hour stm performance data
                            	**type**\: list of    :py:class:`StmHour24Stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms, self).__init__()

                                self.yang_name = "stm-hour24stms"
                                self.yang_parent_name = "stm-hour24"

                                self.stm_hour24stm = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms, self).__setattr__(name, value)


                            class StmHour24Stm(Entity):
                                """
                                port 24 hour stm performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line>`
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm, self).__init__()

                                    self.yang_name = "stm-hour24stm"
                                    self.yang_parent_name = "stm-hour24stms"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.fe_line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine()
                                    self.fe_line.parent = self
                                    self._children_name_map["fe_line"] = "fe-line"
                                    self._children_yang_names.add("fe-line")

                                    self.line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line()
                                    self.line.parent = self
                                    self._children_name_map["line"] = "line"
                                    self._children_yang_names.add("line")

                                    self.section = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section()
                                    self.section.parent = self
                                    self._children_name_map["section"] = "section"
                                    self._children_yang_names.add("section")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm, self).__setattr__(name, value)


                                class Section(Entity):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_bb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`SectionBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbEs>`
                                    
                                    .. attribute:: section_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`SectionBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbeRs>`
                                    
                                    .. attribute:: section_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:   :py:class:`SectionEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEBs>`
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionESs>`
                                    
                                    .. attribute:: section_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:   :py:class:`SectionEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEsRs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:   :py:class:`SectionSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSesRs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: section_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:   :py:class:`SectionUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section, self).__init__()

                                        self.yang_name = "section"
                                        self.yang_parent_name = "stm-hour24stm"

                                        self.section_status = YLeaf(YType.int32, "section-status")

                                        self.section_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbEs()
                                        self.section_bb_es.parent = self
                                        self._children_name_map["section_bb_es"] = "section-bb-es"
                                        self._children_yang_names.add("section-bb-es")

                                        self.section_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbeRs()
                                        self.section_bbe_rs.parent = self
                                        self._children_name_map["section_bbe_rs"] = "section-bbe-rs"
                                        self._children_yang_names.add("section-bbe-rs")

                                        self.section_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEBs()
                                        self.section_e_bs.parent = self
                                        self._children_name_map["section_e_bs"] = "section-e-bs"
                                        self._children_yang_names.add("section-e-bs")

                                        self.section_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self._children_name_map["section_e_ss"] = "section-e-ss"
                                        self._children_yang_names.add("section-e-ss")

                                        self.section_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEsRs()
                                        self.section_es_rs.parent = self
                                        self._children_name_map["section_es_rs"] = "section-es-rs"
                                        self._children_yang_names.add("section-es-rs")

                                        self.section_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self._children_name_map["section_se_ss"] = "section-se-ss"
                                        self._children_yang_names.add("section-se-ss")

                                        self.section_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSesRs()
                                        self.section_ses_rs.parent = self
                                        self._children_name_map["section_ses_rs"] = "section-ses-rs"
                                        self._children_yang_names.add("section-ses-rs")

                                        self.section_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionUaSs()
                                        self.section_ua_ss.parent = self
                                        self._children_name_map["section_ua_ss"] = "section-ua-ss"
                                        self._children_yang_names.add("section-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("section_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section, self).__setattr__(name, value)


                                    class SectionESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionESs, self).__init__()

                                            self.yang_name = "section-e-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionEsRs(Entity):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEsRs, self).__init__()

                                            self.yang_name = "section-es-rs"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEsRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEsRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-es-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionBbEs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbEs, self).__init__()

                                            self.yang_name = "section-bb-es"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbEs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbEs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-bb-es" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionBbeRs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbeRs, self).__init__()

                                            self.yang_name = "section-bbe-rs"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbeRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbeRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-bbe-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionSeSs(Entity):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSeSs, self).__init__()

                                            self.yang_name = "section-se-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionSesRs(Entity):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSesRs, self).__init__()

                                            self.yang_name = "section-ses-rs"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSesRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSesRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-ses-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionUaSs(Entity):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionUaSs, self).__init__()

                                            self.yang_name = "section-ua-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionEBs(Entity):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEBs, self).__init__()

                                            self.yang_name = "section-e-bs"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEBs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEBs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-e-bs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.section_status.is_set or
                                            (self.section_bb_es is not None and self.section_bb_es.has_data()) or
                                            (self.section_bbe_rs is not None and self.section_bbe_rs.has_data()) or
                                            (self.section_e_bs is not None and self.section_e_bs.has_data()) or
                                            (self.section_e_ss is not None and self.section_e_ss.has_data()) or
                                            (self.section_es_rs is not None and self.section_es_rs.has_data()) or
                                            (self.section_se_ss is not None and self.section_se_ss.has_data()) or
                                            (self.section_ses_rs is not None and self.section_ses_rs.has_data()) or
                                            (self.section_ua_ss is not None and self.section_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.section_status.yfilter != YFilter.not_set or
                                            (self.section_bb_es is not None and self.section_bb_es.has_operation()) or
                                            (self.section_bbe_rs is not None and self.section_bbe_rs.has_operation()) or
                                            (self.section_e_bs is not None and self.section_e_bs.has_operation()) or
                                            (self.section_e_ss is not None and self.section_e_ss.has_operation()) or
                                            (self.section_es_rs is not None and self.section_es_rs.has_operation()) or
                                            (self.section_se_ss is not None and self.section_se_ss.has_operation()) or
                                            (self.section_ses_rs is not None and self.section_ses_rs.has_operation()) or
                                            (self.section_ua_ss is not None and self.section_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "section" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.section_status.is_set or self.section_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.section_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "section-bb-es"):
                                            if (self.section_bb_es is None):
                                                self.section_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbEs()
                                                self.section_bb_es.parent = self
                                                self._children_name_map["section_bb_es"] = "section-bb-es"
                                            return self.section_bb_es

                                        if (child_yang_name == "section-bbe-rs"):
                                            if (self.section_bbe_rs is None):
                                                self.section_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionBbeRs()
                                                self.section_bbe_rs.parent = self
                                                self._children_name_map["section_bbe_rs"] = "section-bbe-rs"
                                            return self.section_bbe_rs

                                        if (child_yang_name == "section-e-bs"):
                                            if (self.section_e_bs is None):
                                                self.section_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEBs()
                                                self.section_e_bs.parent = self
                                                self._children_name_map["section_e_bs"] = "section-e-bs"
                                            return self.section_e_bs

                                        if (child_yang_name == "section-e-ss"):
                                            if (self.section_e_ss is None):
                                                self.section_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionESs()
                                                self.section_e_ss.parent = self
                                                self._children_name_map["section_e_ss"] = "section-e-ss"
                                            return self.section_e_ss

                                        if (child_yang_name == "section-es-rs"):
                                            if (self.section_es_rs is None):
                                                self.section_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionEsRs()
                                                self.section_es_rs.parent = self
                                                self._children_name_map["section_es_rs"] = "section-es-rs"
                                            return self.section_es_rs

                                        if (child_yang_name == "section-se-ss"):
                                            if (self.section_se_ss is None):
                                                self.section_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSeSs()
                                                self.section_se_ss.parent = self
                                                self._children_name_map["section_se_ss"] = "section-se-ss"
                                            return self.section_se_ss

                                        if (child_yang_name == "section-ses-rs"):
                                            if (self.section_ses_rs is None):
                                                self.section_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionSesRs()
                                                self.section_ses_rs.parent = self
                                                self._children_name_map["section_ses_rs"] = "section-ses-rs"
                                            return self.section_ses_rs

                                        if (child_yang_name == "section-ua-ss"):
                                            if (self.section_ua_ss is None):
                                                self.section_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section.SectionUaSs()
                                                self.section_ua_ss.parent = self
                                                self._children_name_map["section_ua_ss"] = "section-ua-ss"
                                            return self.section_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "section-bb-es" or name == "section-bbe-rs" or name == "section-e-bs" or name == "section-e-ss" or name == "section-es-rs" or name == "section-se-ss" or name == "section-ses-rs" or name == "section-ua-ss" or name == "section-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "section-status"):
                                            self.section_status = value
                                            self.section_status.value_namespace = name_space
                                            self.section_status.value_namespace_prefix = name_space_prefix


                                class Line(Entity):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_bb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`LineBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbEs>`
                                    
                                    .. attribute:: line_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`LineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbeRs>`
                                    
                                    .. attribute:: line_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:   :py:class:`LineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEBs>`
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineESs>`
                                    
                                    .. attribute:: line_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:   :py:class:`LineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEsRs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSeSs>`
                                    
                                    .. attribute:: line_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:   :py:class:`LineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSesRs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line, self).__init__()

                                        self.yang_name = "line"
                                        self.yang_parent_name = "stm-hour24stm"

                                        self.line_status = YLeaf(YType.int32, "line-status")

                                        self.line_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbEs()
                                        self.line_bb_es.parent = self
                                        self._children_name_map["line_bb_es"] = "line-bb-es"
                                        self._children_yang_names.add("line-bb-es")

                                        self.line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbeRs()
                                        self.line_bbe_rs.parent = self
                                        self._children_name_map["line_bbe_rs"] = "line-bbe-rs"
                                        self._children_yang_names.add("line-bbe-rs")

                                        self.line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEBs()
                                        self.line_e_bs.parent = self
                                        self._children_name_map["line_e_bs"] = "line-e-bs"
                                        self._children_yang_names.add("line-e-bs")

                                        self.line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self._children_name_map["line_e_ss"] = "line-e-ss"
                                        self._children_yang_names.add("line-e-ss")

                                        self.line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEsRs()
                                        self.line_es_rs.parent = self
                                        self._children_name_map["line_es_rs"] = "line-es-rs"
                                        self._children_yang_names.add("line-es-rs")

                                        self.line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self._children_name_map["line_se_ss"] = "line-se-ss"
                                        self._children_yang_names.add("line-se-ss")

                                        self.line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSesRs()
                                        self.line_ses_rs.parent = self
                                        self._children_name_map["line_ses_rs"] = "line-ses-rs"
                                        self._children_yang_names.add("line-ses-rs")

                                        self.line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineUaSs()
                                        self.line_ua_ss.parent = self
                                        self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                        self._children_yang_names.add("line-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("line_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line, self).__setattr__(name, value)


                                    class LineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineESs, self).__init__()

                                            self.yang_name = "line-e-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineEsRs(Entity):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEsRs, self).__init__()

                                            self.yang_name = "line-es-rs"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEsRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEsRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-es-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineBbEs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbEs, self).__init__()

                                            self.yang_name = "line-bb-es"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbEs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbEs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-bb-es" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineBbeRs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbeRs, self).__init__()

                                            self.yang_name = "line-bbe-rs"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbeRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbeRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-bbe-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineSeSs(Entity):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSeSs, self).__init__()

                                            self.yang_name = "line-se-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineSesRs(Entity):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSesRs, self).__init__()

                                            self.yang_name = "line-ses-rs"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSesRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSesRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-ses-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineUaSs(Entity):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineUaSs, self).__init__()

                                            self.yang_name = "line-ua-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineEBs(Entity):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEBs, self).__init__()

                                            self.yang_name = "line-e-bs"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEBs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEBs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-e-bs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.line_status.is_set or
                                            (self.line_bb_es is not None and self.line_bb_es.has_data()) or
                                            (self.line_bbe_rs is not None and self.line_bbe_rs.has_data()) or
                                            (self.line_e_bs is not None and self.line_e_bs.has_data()) or
                                            (self.line_e_ss is not None and self.line_e_ss.has_data()) or
                                            (self.line_es_rs is not None and self.line_es_rs.has_data()) or
                                            (self.line_se_ss is not None and self.line_se_ss.has_data()) or
                                            (self.line_ses_rs is not None and self.line_ses_rs.has_data()) or
                                            (self.line_ua_ss is not None and self.line_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.line_status.yfilter != YFilter.not_set or
                                            (self.line_bb_es is not None and self.line_bb_es.has_operation()) or
                                            (self.line_bbe_rs is not None and self.line_bbe_rs.has_operation()) or
                                            (self.line_e_bs is not None and self.line_e_bs.has_operation()) or
                                            (self.line_e_ss is not None and self.line_e_ss.has_operation()) or
                                            (self.line_es_rs is not None and self.line_es_rs.has_operation()) or
                                            (self.line_se_ss is not None and self.line_se_ss.has_operation()) or
                                            (self.line_ses_rs is not None and self.line_ses_rs.has_operation()) or
                                            (self.line_ua_ss is not None and self.line_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "line" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.line_status.is_set or self.line_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.line_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "line-bb-es"):
                                            if (self.line_bb_es is None):
                                                self.line_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbEs()
                                                self.line_bb_es.parent = self
                                                self._children_name_map["line_bb_es"] = "line-bb-es"
                                            return self.line_bb_es

                                        if (child_yang_name == "line-bbe-rs"):
                                            if (self.line_bbe_rs is None):
                                                self.line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineBbeRs()
                                                self.line_bbe_rs.parent = self
                                                self._children_name_map["line_bbe_rs"] = "line-bbe-rs"
                                            return self.line_bbe_rs

                                        if (child_yang_name == "line-e-bs"):
                                            if (self.line_e_bs is None):
                                                self.line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEBs()
                                                self.line_e_bs.parent = self
                                                self._children_name_map["line_e_bs"] = "line-e-bs"
                                            return self.line_e_bs

                                        if (child_yang_name == "line-e-ss"):
                                            if (self.line_e_ss is None):
                                                self.line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineESs()
                                                self.line_e_ss.parent = self
                                                self._children_name_map["line_e_ss"] = "line-e-ss"
                                            return self.line_e_ss

                                        if (child_yang_name == "line-es-rs"):
                                            if (self.line_es_rs is None):
                                                self.line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineEsRs()
                                                self.line_es_rs.parent = self
                                                self._children_name_map["line_es_rs"] = "line-es-rs"
                                            return self.line_es_rs

                                        if (child_yang_name == "line-se-ss"):
                                            if (self.line_se_ss is None):
                                                self.line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSeSs()
                                                self.line_se_ss.parent = self
                                                self._children_name_map["line_se_ss"] = "line-se-ss"
                                            return self.line_se_ss

                                        if (child_yang_name == "line-ses-rs"):
                                            if (self.line_ses_rs is None):
                                                self.line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineSesRs()
                                                self.line_ses_rs.parent = self
                                                self._children_name_map["line_ses_rs"] = "line-ses-rs"
                                            return self.line_ses_rs

                                        if (child_yang_name == "line-ua-ss"):
                                            if (self.line_ua_ss is None):
                                                self.line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line.LineUaSs()
                                                self.line_ua_ss.parent = self
                                                self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                            return self.line_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "line-bb-es" or name == "line-bbe-rs" or name == "line-e-bs" or name == "line-e-ss" or name == "line-es-rs" or name == "line-se-ss" or name == "line-ses-rs" or name == "line-ua-ss" or name == "line-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "line-status"):
                                            self.line_status = value
                                            self.line_status.value_namespace = name_space
                                            self.line_status.value_namespace_prefix = name_space_prefix


                                class FeLine(Entity):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`FarEndLineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineBbeRs>`
                                    
                                    .. attribute:: far_end_line_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:   :py:class:`FarEndLineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEBs>`
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_ebb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`FarEndLineEbbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEbbEs>`
                                    
                                    .. attribute:: far_end_line_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:   :py:class:`FarEndLineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEsRs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:   :py:class:`FarEndLineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSesRs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine, self).__init__()

                                        self.yang_name = "fe-line"
                                        self.yang_parent_name = "stm-hour24stm"

                                        self.far_end_line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineBbeRs()
                                        self.far_end_line_bbe_rs.parent = self
                                        self._children_name_map["far_end_line_bbe_rs"] = "far-end-line-bbe-rs"
                                        self._children_yang_names.add("far-end-line-bbe-rs")

                                        self.far_end_line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEBs()
                                        self.far_end_line_e_bs.parent = self
                                        self._children_name_map["far_end_line_e_bs"] = "far-end-line-e-bs"
                                        self._children_yang_names.add("far-end-line-e-bs")

                                        self.far_end_line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                        self._children_yang_names.add("far-end-line-e-ss")

                                        self.far_end_line_ebb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEbbEs()
                                        self.far_end_line_ebb_es.parent = self
                                        self._children_name_map["far_end_line_ebb_es"] = "far-end-line-ebb-es"
                                        self._children_yang_names.add("far-end-line-ebb-es")

                                        self.far_end_line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEsRs()
                                        self.far_end_line_es_rs.parent = self
                                        self._children_name_map["far_end_line_es_rs"] = "far-end-line-es-rs"
                                        self._children_yang_names.add("far-end-line-es-rs")

                                        self.far_end_line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                        self._children_yang_names.add("far-end-line-se-ss")

                                        self.far_end_line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSesRs()
                                        self.far_end_line_ses_rs.parent = self
                                        self._children_name_map["far_end_line_ses_rs"] = "far-end-line-ses-rs"
                                        self._children_yang_names.add("far-end-line-ses-rs")

                                        self.far_end_line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self
                                        self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                        self._children_yang_names.add("far-end-line-ua-ss")


                                    class FarEndLineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineESs, self).__init__()

                                            self.yang_name = "far-end-line-e-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineEsRs(Entity):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEsRs, self).__init__()

                                            self.yang_name = "far-end-line-es-rs"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEsRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEsRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-es-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineEbbEs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEbbEs, self).__init__()

                                            self.yang_name = "far-end-line-ebb-es"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEbbEs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEbbEs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-ebb-es" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineBbeRs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineBbeRs, self).__init__()

                                            self.yang_name = "far-end-line-bbe-rs"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineBbeRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineBbeRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-bbe-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineSeSs(Entity):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSeSs, self).__init__()

                                            self.yang_name = "far-end-line-se-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineSesRs(Entity):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSesRs, self).__init__()

                                            self.yang_name = "far-end-line-ses-rs"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSesRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSesRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-ses-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineUaSs(Entity):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineUaSs, self).__init__()

                                            self.yang_name = "far-end-line-ua-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineEBs(Entity):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEBs, self).__init__()

                                            self.yang_name = "far-end-line-e-bs"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEBs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEBs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-e-bs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.far_end_line_bbe_rs is not None and self.far_end_line_bbe_rs.has_data()) or
                                            (self.far_end_line_e_bs is not None and self.far_end_line_e_bs.has_data()) or
                                            (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_data()) or
                                            (self.far_end_line_ebb_es is not None and self.far_end_line_ebb_es.has_data()) or
                                            (self.far_end_line_es_rs is not None and self.far_end_line_es_rs.has_data()) or
                                            (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_data()) or
                                            (self.far_end_line_ses_rs is not None and self.far_end_line_ses_rs.has_data()) or
                                            (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.far_end_line_bbe_rs is not None and self.far_end_line_bbe_rs.has_operation()) or
                                            (self.far_end_line_e_bs is not None and self.far_end_line_e_bs.has_operation()) or
                                            (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_operation()) or
                                            (self.far_end_line_ebb_es is not None and self.far_end_line_ebb_es.has_operation()) or
                                            (self.far_end_line_es_rs is not None and self.far_end_line_es_rs.has_operation()) or
                                            (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_operation()) or
                                            (self.far_end_line_ses_rs is not None and self.far_end_line_ses_rs.has_operation()) or
                                            (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fe-line" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "far-end-line-bbe-rs"):
                                            if (self.far_end_line_bbe_rs is None):
                                                self.far_end_line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineBbeRs()
                                                self.far_end_line_bbe_rs.parent = self
                                                self._children_name_map["far_end_line_bbe_rs"] = "far-end-line-bbe-rs"
                                            return self.far_end_line_bbe_rs

                                        if (child_yang_name == "far-end-line-e-bs"):
                                            if (self.far_end_line_e_bs is None):
                                                self.far_end_line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEBs()
                                                self.far_end_line_e_bs.parent = self
                                                self._children_name_map["far_end_line_e_bs"] = "far-end-line-e-bs"
                                            return self.far_end_line_e_bs

                                        if (child_yang_name == "far-end-line-e-ss"):
                                            if (self.far_end_line_e_ss is None):
                                                self.far_end_line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineESs()
                                                self.far_end_line_e_ss.parent = self
                                                self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                            return self.far_end_line_e_ss

                                        if (child_yang_name == "far-end-line-ebb-es"):
                                            if (self.far_end_line_ebb_es is None):
                                                self.far_end_line_ebb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEbbEs()
                                                self.far_end_line_ebb_es.parent = self
                                                self._children_name_map["far_end_line_ebb_es"] = "far-end-line-ebb-es"
                                            return self.far_end_line_ebb_es

                                        if (child_yang_name == "far-end-line-es-rs"):
                                            if (self.far_end_line_es_rs is None):
                                                self.far_end_line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineEsRs()
                                                self.far_end_line_es_rs.parent = self
                                                self._children_name_map["far_end_line_es_rs"] = "far-end-line-es-rs"
                                            return self.far_end_line_es_rs

                                        if (child_yang_name == "far-end-line-se-ss"):
                                            if (self.far_end_line_se_ss is None):
                                                self.far_end_line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSeSs()
                                                self.far_end_line_se_ss.parent = self
                                                self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                            return self.far_end_line_se_ss

                                        if (child_yang_name == "far-end-line-ses-rs"):
                                            if (self.far_end_line_ses_rs is None):
                                                self.far_end_line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineSesRs()
                                                self.far_end_line_ses_rs.parent = self
                                                self._children_name_map["far_end_line_ses_rs"] = "far-end-line-ses-rs"
                                            return self.far_end_line_ses_rs

                                        if (child_yang_name == "far-end-line-ua-ss"):
                                            if (self.far_end_line_ua_ss is None):
                                                self.far_end_line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine.FarEndLineUaSs()
                                                self.far_end_line_ua_ss.parent = self
                                                self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                            return self.far_end_line_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "far-end-line-bbe-rs" or name == "far-end-line-e-bs" or name == "far-end-line-e-ss" or name == "far-end-line-ebb-es" or name == "far-end-line-es-rs" or name == "far-end-line-se-ss" or name == "far-end-line-ses-rs" or name == "far-end-line-ua-ss"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.fe_line is not None and self.fe_line.has_data()) or
                                        (self.line is not None and self.line.has_data()) or
                                        (self.section is not None and self.section.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.fe_line is not None and self.fe_line.has_operation()) or
                                        (self.line is not None and self.line.has_operation()) or
                                        (self.section is not None and self.section.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "stm-hour24stm" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "fe-line"):
                                        if (self.fe_line is None):
                                            self.fe_line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.FeLine()
                                            self.fe_line.parent = self
                                            self._children_name_map["fe_line"] = "fe-line"
                                        return self.fe_line

                                    if (child_yang_name == "line"):
                                        if (self.line is None):
                                            self.line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Line()
                                            self.line.parent = self
                                            self._children_name_map["line"] = "line"
                                        return self.line

                                    if (child_yang_name == "section"):
                                        if (self.section is None):
                                            self.section = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm.Section()
                                            self.section.parent = self
                                            self._children_name_map["section"] = "section"
                                        return self.section

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fe-line" or name == "line" or name == "section" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.stm_hour24stm:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.stm_hour24stm:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "stm-hour24stms" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "stm-hour24stm"):
                                    for c in self.stm_hour24stm:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms.StmHour24Stm()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.stm_hour24stm.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "stm-hour24stm"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.stm_hour24stms is not None and self.stm_hour24stms.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.stm_hour24stms is not None and self.stm_hour24stms.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "stm-hour24" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "stm-hour24stms"):
                                if (self.stm_hour24stms is None):
                                    self.stm_hour24stms = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24.StmHour24Stms()
                                    self.stm_hour24stms.parent = self
                                    self._children_name_map["stm_hour24stms"] = "stm-hour24stms"
                                return self.stm_hour24stms

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "stm-hour24stms"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class StmMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: stm_minute15stms
                        
                        	port current performance data
                        	**type**\:   :py:class:`StmMinute15Stms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15, self).__init__()

                            self.yang_name = "stm-minute15"
                            self.yang_parent_name = "stm-current"

                            self.stm_minute15stms = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms()
                            self.stm_minute15stms.parent = self
                            self._children_name_map["stm_minute15stms"] = "stm-minute15stms"
                            self._children_yang_names.add("stm-minute15stms")


                        class StmMinute15Stms(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: stm_minute15stm
                            
                            	port 15\-minute stm performance data
                            	**type**\: list of    :py:class:`StmMinute15Stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms, self).__init__()

                                self.yang_name = "stm-minute15stms"
                                self.yang_parent_name = "stm-minute15"

                                self.stm_minute15stm = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms, self).__setattr__(name, value)


                            class StmMinute15Stm(Entity):
                                """
                                port 15\-minute stm performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line>`
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm, self).__init__()

                                    self.yang_name = "stm-minute15stm"
                                    self.yang_parent_name = "stm-minute15stms"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.fe_line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine()
                                    self.fe_line.parent = self
                                    self._children_name_map["fe_line"] = "fe-line"
                                    self._children_yang_names.add("fe-line")

                                    self.line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line()
                                    self.line.parent = self
                                    self._children_name_map["line"] = "line"
                                    self._children_yang_names.add("line")

                                    self.section = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section()
                                    self.section.parent = self
                                    self._children_name_map["section"] = "section"
                                    self._children_yang_names.add("section")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm, self).__setattr__(name, value)


                                class Section(Entity):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_bb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`SectionBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbEs>`
                                    
                                    .. attribute:: section_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`SectionBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbeRs>`
                                    
                                    .. attribute:: section_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:   :py:class:`SectionEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEBs>`
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionESs>`
                                    
                                    .. attribute:: section_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:   :py:class:`SectionEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEsRs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:   :py:class:`SectionSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSesRs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: section_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:   :py:class:`SectionUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section, self).__init__()

                                        self.yang_name = "section"
                                        self.yang_parent_name = "stm-minute15stm"

                                        self.section_status = YLeaf(YType.int32, "section-status")

                                        self.section_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbEs()
                                        self.section_bb_es.parent = self
                                        self._children_name_map["section_bb_es"] = "section-bb-es"
                                        self._children_yang_names.add("section-bb-es")

                                        self.section_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbeRs()
                                        self.section_bbe_rs.parent = self
                                        self._children_name_map["section_bbe_rs"] = "section-bbe-rs"
                                        self._children_yang_names.add("section-bbe-rs")

                                        self.section_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEBs()
                                        self.section_e_bs.parent = self
                                        self._children_name_map["section_e_bs"] = "section-e-bs"
                                        self._children_yang_names.add("section-e-bs")

                                        self.section_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self._children_name_map["section_e_ss"] = "section-e-ss"
                                        self._children_yang_names.add("section-e-ss")

                                        self.section_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEsRs()
                                        self.section_es_rs.parent = self
                                        self._children_name_map["section_es_rs"] = "section-es-rs"
                                        self._children_yang_names.add("section-es-rs")

                                        self.section_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self._children_name_map["section_se_ss"] = "section-se-ss"
                                        self._children_yang_names.add("section-se-ss")

                                        self.section_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSesRs()
                                        self.section_ses_rs.parent = self
                                        self._children_name_map["section_ses_rs"] = "section-ses-rs"
                                        self._children_yang_names.add("section-ses-rs")

                                        self.section_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionUaSs()
                                        self.section_ua_ss.parent = self
                                        self._children_name_map["section_ua_ss"] = "section-ua-ss"
                                        self._children_yang_names.add("section-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("section_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section, self).__setattr__(name, value)


                                    class SectionESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionESs, self).__init__()

                                            self.yang_name = "section-e-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionEsRs(Entity):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEsRs, self).__init__()

                                            self.yang_name = "section-es-rs"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEsRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEsRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-es-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionBbEs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbEs, self).__init__()

                                            self.yang_name = "section-bb-es"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbEs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbEs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-bb-es" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionBbeRs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbeRs, self).__init__()

                                            self.yang_name = "section-bbe-rs"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbeRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbeRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-bbe-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionSeSs(Entity):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSeSs, self).__init__()

                                            self.yang_name = "section-se-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionSesRs(Entity):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSesRs, self).__init__()

                                            self.yang_name = "section-ses-rs"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSesRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSesRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-ses-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionUaSs(Entity):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionUaSs, self).__init__()

                                            self.yang_name = "section-ua-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionEBs(Entity):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEBs, self).__init__()

                                            self.yang_name = "section-e-bs"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEBs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEBs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-e-bs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.section_status.is_set or
                                            (self.section_bb_es is not None and self.section_bb_es.has_data()) or
                                            (self.section_bbe_rs is not None and self.section_bbe_rs.has_data()) or
                                            (self.section_e_bs is not None and self.section_e_bs.has_data()) or
                                            (self.section_e_ss is not None and self.section_e_ss.has_data()) or
                                            (self.section_es_rs is not None and self.section_es_rs.has_data()) or
                                            (self.section_se_ss is not None and self.section_se_ss.has_data()) or
                                            (self.section_ses_rs is not None and self.section_ses_rs.has_data()) or
                                            (self.section_ua_ss is not None and self.section_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.section_status.yfilter != YFilter.not_set or
                                            (self.section_bb_es is not None and self.section_bb_es.has_operation()) or
                                            (self.section_bbe_rs is not None and self.section_bbe_rs.has_operation()) or
                                            (self.section_e_bs is not None and self.section_e_bs.has_operation()) or
                                            (self.section_e_ss is not None and self.section_e_ss.has_operation()) or
                                            (self.section_es_rs is not None and self.section_es_rs.has_operation()) or
                                            (self.section_se_ss is not None and self.section_se_ss.has_operation()) or
                                            (self.section_ses_rs is not None and self.section_ses_rs.has_operation()) or
                                            (self.section_ua_ss is not None and self.section_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "section" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.section_status.is_set or self.section_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.section_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "section-bb-es"):
                                            if (self.section_bb_es is None):
                                                self.section_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbEs()
                                                self.section_bb_es.parent = self
                                                self._children_name_map["section_bb_es"] = "section-bb-es"
                                            return self.section_bb_es

                                        if (child_yang_name == "section-bbe-rs"):
                                            if (self.section_bbe_rs is None):
                                                self.section_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionBbeRs()
                                                self.section_bbe_rs.parent = self
                                                self._children_name_map["section_bbe_rs"] = "section-bbe-rs"
                                            return self.section_bbe_rs

                                        if (child_yang_name == "section-e-bs"):
                                            if (self.section_e_bs is None):
                                                self.section_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEBs()
                                                self.section_e_bs.parent = self
                                                self._children_name_map["section_e_bs"] = "section-e-bs"
                                            return self.section_e_bs

                                        if (child_yang_name == "section-e-ss"):
                                            if (self.section_e_ss is None):
                                                self.section_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionESs()
                                                self.section_e_ss.parent = self
                                                self._children_name_map["section_e_ss"] = "section-e-ss"
                                            return self.section_e_ss

                                        if (child_yang_name == "section-es-rs"):
                                            if (self.section_es_rs is None):
                                                self.section_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionEsRs()
                                                self.section_es_rs.parent = self
                                                self._children_name_map["section_es_rs"] = "section-es-rs"
                                            return self.section_es_rs

                                        if (child_yang_name == "section-se-ss"):
                                            if (self.section_se_ss is None):
                                                self.section_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSeSs()
                                                self.section_se_ss.parent = self
                                                self._children_name_map["section_se_ss"] = "section-se-ss"
                                            return self.section_se_ss

                                        if (child_yang_name == "section-ses-rs"):
                                            if (self.section_ses_rs is None):
                                                self.section_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionSesRs()
                                                self.section_ses_rs.parent = self
                                                self._children_name_map["section_ses_rs"] = "section-ses-rs"
                                            return self.section_ses_rs

                                        if (child_yang_name == "section-ua-ss"):
                                            if (self.section_ua_ss is None):
                                                self.section_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section.SectionUaSs()
                                                self.section_ua_ss.parent = self
                                                self._children_name_map["section_ua_ss"] = "section-ua-ss"
                                            return self.section_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "section-bb-es" or name == "section-bbe-rs" or name == "section-e-bs" or name == "section-e-ss" or name == "section-es-rs" or name == "section-se-ss" or name == "section-ses-rs" or name == "section-ua-ss" or name == "section-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "section-status"):
                                            self.section_status = value
                                            self.section_status.value_namespace = name_space
                                            self.section_status.value_namespace_prefix = name_space_prefix


                                class Line(Entity):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_bb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`LineBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbEs>`
                                    
                                    .. attribute:: line_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`LineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbeRs>`
                                    
                                    .. attribute:: line_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:   :py:class:`LineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEBs>`
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineESs>`
                                    
                                    .. attribute:: line_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:   :py:class:`LineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEsRs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSeSs>`
                                    
                                    .. attribute:: line_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:   :py:class:`LineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSesRs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line, self).__init__()

                                        self.yang_name = "line"
                                        self.yang_parent_name = "stm-minute15stm"

                                        self.line_status = YLeaf(YType.int32, "line-status")

                                        self.line_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbEs()
                                        self.line_bb_es.parent = self
                                        self._children_name_map["line_bb_es"] = "line-bb-es"
                                        self._children_yang_names.add("line-bb-es")

                                        self.line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbeRs()
                                        self.line_bbe_rs.parent = self
                                        self._children_name_map["line_bbe_rs"] = "line-bbe-rs"
                                        self._children_yang_names.add("line-bbe-rs")

                                        self.line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEBs()
                                        self.line_e_bs.parent = self
                                        self._children_name_map["line_e_bs"] = "line-e-bs"
                                        self._children_yang_names.add("line-e-bs")

                                        self.line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self._children_name_map["line_e_ss"] = "line-e-ss"
                                        self._children_yang_names.add("line-e-ss")

                                        self.line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEsRs()
                                        self.line_es_rs.parent = self
                                        self._children_name_map["line_es_rs"] = "line-es-rs"
                                        self._children_yang_names.add("line-es-rs")

                                        self.line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self._children_name_map["line_se_ss"] = "line-se-ss"
                                        self._children_yang_names.add("line-se-ss")

                                        self.line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSesRs()
                                        self.line_ses_rs.parent = self
                                        self._children_name_map["line_ses_rs"] = "line-ses-rs"
                                        self._children_yang_names.add("line-ses-rs")

                                        self.line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineUaSs()
                                        self.line_ua_ss.parent = self
                                        self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                        self._children_yang_names.add("line-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("line_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line, self).__setattr__(name, value)


                                    class LineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineESs, self).__init__()

                                            self.yang_name = "line-e-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineEsRs(Entity):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEsRs, self).__init__()

                                            self.yang_name = "line-es-rs"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEsRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEsRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-es-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineBbEs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbEs, self).__init__()

                                            self.yang_name = "line-bb-es"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbEs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbEs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-bb-es" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineBbeRs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbeRs, self).__init__()

                                            self.yang_name = "line-bbe-rs"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbeRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbeRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-bbe-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineSeSs(Entity):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSeSs, self).__init__()

                                            self.yang_name = "line-se-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineSesRs(Entity):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSesRs, self).__init__()

                                            self.yang_name = "line-ses-rs"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSesRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSesRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-ses-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineUaSs(Entity):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineUaSs, self).__init__()

                                            self.yang_name = "line-ua-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineEBs(Entity):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEBs, self).__init__()

                                            self.yang_name = "line-e-bs"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEBs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEBs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-e-bs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.line_status.is_set or
                                            (self.line_bb_es is not None and self.line_bb_es.has_data()) or
                                            (self.line_bbe_rs is not None and self.line_bbe_rs.has_data()) or
                                            (self.line_e_bs is not None and self.line_e_bs.has_data()) or
                                            (self.line_e_ss is not None and self.line_e_ss.has_data()) or
                                            (self.line_es_rs is not None and self.line_es_rs.has_data()) or
                                            (self.line_se_ss is not None and self.line_se_ss.has_data()) or
                                            (self.line_ses_rs is not None and self.line_ses_rs.has_data()) or
                                            (self.line_ua_ss is not None and self.line_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.line_status.yfilter != YFilter.not_set or
                                            (self.line_bb_es is not None and self.line_bb_es.has_operation()) or
                                            (self.line_bbe_rs is not None and self.line_bbe_rs.has_operation()) or
                                            (self.line_e_bs is not None and self.line_e_bs.has_operation()) or
                                            (self.line_e_ss is not None and self.line_e_ss.has_operation()) or
                                            (self.line_es_rs is not None and self.line_es_rs.has_operation()) or
                                            (self.line_se_ss is not None and self.line_se_ss.has_operation()) or
                                            (self.line_ses_rs is not None and self.line_ses_rs.has_operation()) or
                                            (self.line_ua_ss is not None and self.line_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "line" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.line_status.is_set or self.line_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.line_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "line-bb-es"):
                                            if (self.line_bb_es is None):
                                                self.line_bb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbEs()
                                                self.line_bb_es.parent = self
                                                self._children_name_map["line_bb_es"] = "line-bb-es"
                                            return self.line_bb_es

                                        if (child_yang_name == "line-bbe-rs"):
                                            if (self.line_bbe_rs is None):
                                                self.line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineBbeRs()
                                                self.line_bbe_rs.parent = self
                                                self._children_name_map["line_bbe_rs"] = "line-bbe-rs"
                                            return self.line_bbe_rs

                                        if (child_yang_name == "line-e-bs"):
                                            if (self.line_e_bs is None):
                                                self.line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEBs()
                                                self.line_e_bs.parent = self
                                                self._children_name_map["line_e_bs"] = "line-e-bs"
                                            return self.line_e_bs

                                        if (child_yang_name == "line-e-ss"):
                                            if (self.line_e_ss is None):
                                                self.line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineESs()
                                                self.line_e_ss.parent = self
                                                self._children_name_map["line_e_ss"] = "line-e-ss"
                                            return self.line_e_ss

                                        if (child_yang_name == "line-es-rs"):
                                            if (self.line_es_rs is None):
                                                self.line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineEsRs()
                                                self.line_es_rs.parent = self
                                                self._children_name_map["line_es_rs"] = "line-es-rs"
                                            return self.line_es_rs

                                        if (child_yang_name == "line-se-ss"):
                                            if (self.line_se_ss is None):
                                                self.line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSeSs()
                                                self.line_se_ss.parent = self
                                                self._children_name_map["line_se_ss"] = "line-se-ss"
                                            return self.line_se_ss

                                        if (child_yang_name == "line-ses-rs"):
                                            if (self.line_ses_rs is None):
                                                self.line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineSesRs()
                                                self.line_ses_rs.parent = self
                                                self._children_name_map["line_ses_rs"] = "line-ses-rs"
                                            return self.line_ses_rs

                                        if (child_yang_name == "line-ua-ss"):
                                            if (self.line_ua_ss is None):
                                                self.line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line.LineUaSs()
                                                self.line_ua_ss.parent = self
                                                self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                            return self.line_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "line-bb-es" or name == "line-bbe-rs" or name == "line-e-bs" or name == "line-e-ss" or name == "line-es-rs" or name == "line-se-ss" or name == "line-ses-rs" or name == "line-ua-ss" or name == "line-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "line-status"):
                                            self.line_status = value
                                            self.line_status.value_namespace = name_space
                                            self.line_status.value_namespace_prefix = name_space_prefix


                                class FeLine(Entity):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_bbe_rs
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`FarEndLineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineBbeRs>`
                                    
                                    .. attribute:: far_end_line_e_bs
                                    
                                    	The number of Errored Block Second
                                    	**type**\:   :py:class:`FarEndLineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEBs>`
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_ebb_es
                                    
                                    	The number of Background Block Errors
                                    	**type**\:   :py:class:`FarEndLineEbbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEbbEs>`
                                    
                                    .. attribute:: far_end_line_es_rs
                                    
                                    	The number of Errored Seconds Ratio
                                    	**type**\:   :py:class:`FarEndLineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEsRs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Second
                                    	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ses_rs
                                    
                                    	The number of Severely Errored Second Ratio
                                    	**type**\:   :py:class:`FarEndLineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSesRs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Second
                                    	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine, self).__init__()

                                        self.yang_name = "fe-line"
                                        self.yang_parent_name = "stm-minute15stm"

                                        self.far_end_line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineBbeRs()
                                        self.far_end_line_bbe_rs.parent = self
                                        self._children_name_map["far_end_line_bbe_rs"] = "far-end-line-bbe-rs"
                                        self._children_yang_names.add("far-end-line-bbe-rs")

                                        self.far_end_line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEBs()
                                        self.far_end_line_e_bs.parent = self
                                        self._children_name_map["far_end_line_e_bs"] = "far-end-line-e-bs"
                                        self._children_yang_names.add("far-end-line-e-bs")

                                        self.far_end_line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                        self._children_yang_names.add("far-end-line-e-ss")

                                        self.far_end_line_ebb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEbbEs()
                                        self.far_end_line_ebb_es.parent = self
                                        self._children_name_map["far_end_line_ebb_es"] = "far-end-line-ebb-es"
                                        self._children_yang_names.add("far-end-line-ebb-es")

                                        self.far_end_line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEsRs()
                                        self.far_end_line_es_rs.parent = self
                                        self._children_name_map["far_end_line_es_rs"] = "far-end-line-es-rs"
                                        self._children_yang_names.add("far-end-line-es-rs")

                                        self.far_end_line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                        self._children_yang_names.add("far-end-line-se-ss")

                                        self.far_end_line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSesRs()
                                        self.far_end_line_ses_rs.parent = self
                                        self._children_name_map["far_end_line_ses_rs"] = "far-end-line-ses-rs"
                                        self._children_yang_names.add("far-end-line-ses-rs")

                                        self.far_end_line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self
                                        self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                        self._children_yang_names.add("far-end-line-ua-ss")


                                    class FarEndLineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineESs, self).__init__()

                                            self.yang_name = "far-end-line-e-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineEsRs(Entity):
                                        """
                                        The number of Errored Seconds Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEsRs, self).__init__()

                                            self.yang_name = "far-end-line-es-rs"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEsRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEsRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-es-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineEbbEs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEbbEs, self).__init__()

                                            self.yang_name = "far-end-line-ebb-es"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEbbEs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEbbEs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-ebb-es" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineBbeRs(Entity):
                                        """
                                        The number of Background Block Errors
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineBbeRs, self).__init__()

                                            self.yang_name = "far-end-line-bbe-rs"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineBbeRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineBbeRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-bbe-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineSeSs(Entity):
                                        """
                                        The number of Severely Errored Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSeSs, self).__init__()

                                            self.yang_name = "far-end-line-se-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineSesRs(Entity):
                                        """
                                        The number of Severely Errored Second Ratio
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  str
                                        
                                        	**length:** 0..8
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSesRs, self).__init__()

                                            self.yang_name = "far-end-line-ses-rs"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.str, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.str, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSesRs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSesRs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-ses-rs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineUaSs(Entity):
                                        """
                                        The number of Unavailable Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineUaSs, self).__init__()

                                            self.yang_name = "far-end-line-ua-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineEBs(Entity):
                                        """
                                        The number of Errored Block Second
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEBs, self).__init__()

                                            self.yang_name = "far-end-line-e-bs"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEBs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEBs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-e-bs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.far_end_line_bbe_rs is not None and self.far_end_line_bbe_rs.has_data()) or
                                            (self.far_end_line_e_bs is not None and self.far_end_line_e_bs.has_data()) or
                                            (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_data()) or
                                            (self.far_end_line_ebb_es is not None and self.far_end_line_ebb_es.has_data()) or
                                            (self.far_end_line_es_rs is not None and self.far_end_line_es_rs.has_data()) or
                                            (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_data()) or
                                            (self.far_end_line_ses_rs is not None and self.far_end_line_ses_rs.has_data()) or
                                            (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.far_end_line_bbe_rs is not None and self.far_end_line_bbe_rs.has_operation()) or
                                            (self.far_end_line_e_bs is not None and self.far_end_line_e_bs.has_operation()) or
                                            (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_operation()) or
                                            (self.far_end_line_ebb_es is not None and self.far_end_line_ebb_es.has_operation()) or
                                            (self.far_end_line_es_rs is not None and self.far_end_line_es_rs.has_operation()) or
                                            (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_operation()) or
                                            (self.far_end_line_ses_rs is not None and self.far_end_line_ses_rs.has_operation()) or
                                            (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fe-line" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "far-end-line-bbe-rs"):
                                            if (self.far_end_line_bbe_rs is None):
                                                self.far_end_line_bbe_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineBbeRs()
                                                self.far_end_line_bbe_rs.parent = self
                                                self._children_name_map["far_end_line_bbe_rs"] = "far-end-line-bbe-rs"
                                            return self.far_end_line_bbe_rs

                                        if (child_yang_name == "far-end-line-e-bs"):
                                            if (self.far_end_line_e_bs is None):
                                                self.far_end_line_e_bs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEBs()
                                                self.far_end_line_e_bs.parent = self
                                                self._children_name_map["far_end_line_e_bs"] = "far-end-line-e-bs"
                                            return self.far_end_line_e_bs

                                        if (child_yang_name == "far-end-line-e-ss"):
                                            if (self.far_end_line_e_ss is None):
                                                self.far_end_line_e_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineESs()
                                                self.far_end_line_e_ss.parent = self
                                                self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                            return self.far_end_line_e_ss

                                        if (child_yang_name == "far-end-line-ebb-es"):
                                            if (self.far_end_line_ebb_es is None):
                                                self.far_end_line_ebb_es = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEbbEs()
                                                self.far_end_line_ebb_es.parent = self
                                                self._children_name_map["far_end_line_ebb_es"] = "far-end-line-ebb-es"
                                            return self.far_end_line_ebb_es

                                        if (child_yang_name == "far-end-line-es-rs"):
                                            if (self.far_end_line_es_rs is None):
                                                self.far_end_line_es_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineEsRs()
                                                self.far_end_line_es_rs.parent = self
                                                self._children_name_map["far_end_line_es_rs"] = "far-end-line-es-rs"
                                            return self.far_end_line_es_rs

                                        if (child_yang_name == "far-end-line-se-ss"):
                                            if (self.far_end_line_se_ss is None):
                                                self.far_end_line_se_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSeSs()
                                                self.far_end_line_se_ss.parent = self
                                                self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                            return self.far_end_line_se_ss

                                        if (child_yang_name == "far-end-line-ses-rs"):
                                            if (self.far_end_line_ses_rs is None):
                                                self.far_end_line_ses_rs = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineSesRs()
                                                self.far_end_line_ses_rs.parent = self
                                                self._children_name_map["far_end_line_ses_rs"] = "far-end-line-ses-rs"
                                            return self.far_end_line_ses_rs

                                        if (child_yang_name == "far-end-line-ua-ss"):
                                            if (self.far_end_line_ua_ss is None):
                                                self.far_end_line_ua_ss = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine.FarEndLineUaSs()
                                                self.far_end_line_ua_ss.parent = self
                                                self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                            return self.far_end_line_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "far-end-line-bbe-rs" or name == "far-end-line-e-bs" or name == "far-end-line-e-ss" or name == "far-end-line-ebb-es" or name == "far-end-line-es-rs" or name == "far-end-line-se-ss" or name == "far-end-line-ses-rs" or name == "far-end-line-ua-ss"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.fe_line is not None and self.fe_line.has_data()) or
                                        (self.line is not None and self.line.has_data()) or
                                        (self.section is not None and self.section.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.fe_line is not None and self.fe_line.has_operation()) or
                                        (self.line is not None and self.line.has_operation()) or
                                        (self.section is not None and self.section.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "stm-minute15stm" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "fe-line"):
                                        if (self.fe_line is None):
                                            self.fe_line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.FeLine()
                                            self.fe_line.parent = self
                                            self._children_name_map["fe_line"] = "fe-line"
                                        return self.fe_line

                                    if (child_yang_name == "line"):
                                        if (self.line is None):
                                            self.line = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Line()
                                            self.line.parent = self
                                            self._children_name_map["line"] = "line"
                                        return self.line

                                    if (child_yang_name == "section"):
                                        if (self.section is None):
                                            self.section = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm.Section()
                                            self.section.parent = self
                                            self._children_name_map["section"] = "section"
                                        return self.section

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fe-line" or name == "line" or name == "section" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.stm_minute15stm:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.stm_minute15stm:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "stm-minute15stms" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "stm-minute15stm"):
                                    for c in self.stm_minute15stm:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms.StmMinute15Stm()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.stm_minute15stm.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "stm-minute15stm"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.stm_minute15stms is not None and self.stm_minute15stms.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.stm_minute15stms is not None and self.stm_minute15stms.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "stm-minute15" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "stm-minute15stms"):
                                if (self.stm_minute15stms is None):
                                    self.stm_minute15stms = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15.StmMinute15Stms()
                                    self.stm_minute15stms.parent = self
                                    self._children_name_map["stm_minute15stms"] = "stm-minute15stms"
                                return self.stm_minute15stms

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "stm-minute15stms"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.stm_hour24 is not None and self.stm_hour24.has_data()) or
                            (self.stm_minute15 is not None and self.stm_minute15.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.stm_hour24 is not None and self.stm_hour24.has_operation()) or
                            (self.stm_minute15 is not None and self.stm_minute15.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "stm-current" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "stm-hour24"):
                            if (self.stm_hour24 is None):
                                self.stm_hour24 = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmHour24()
                                self.stm_hour24.parent = self
                                self._children_name_map["stm_hour24"] = "stm-hour24"
                            return self.stm_hour24

                        if (child_yang_name == "stm-minute15"):
                            if (self.stm_minute15 is None):
                                self.stm_minute15 = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent.StmMinute15()
                                self.stm_minute15.parent = self
                                self._children_name_map["stm_minute15"] = "stm-minute15"
                            return self.stm_minute15

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "stm-hour24" or name == "stm-minute15"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.name.is_set or
                        (self.stm_current is not None and self.stm_current.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        (self.stm_current is not None and self.stm_current.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "stm-port" + "[name='" + self.name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/stm/stm-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "stm-current"):
                        if (self.stm_current is None):
                            self.stm_current = PerformanceManagement.Stm.StmPorts.StmPort.StmCurrent()
                            self.stm_current.parent = self
                            self._children_name_map["stm_current"] = "stm-current"
                        return self.stm_current

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "stm-current" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.stm_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.stm_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "stm-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/stm/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "stm-port"):
                    for c in self.stm_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = PerformanceManagement.Stm.StmPorts.StmPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.stm_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "stm-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.stm_ports is not None and self.stm_ports.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.stm_ports is not None and self.stm_ports.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "stm" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "stm-ports"):
                if (self.stm_ports is None):
                    self.stm_ports = PerformanceManagement.Stm.StmPorts()
                    self.stm_ports.parent = self
                    self._children_name_map["stm_ports"] = "stm-ports"
                return self.stm_ports

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "stm-ports"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Sonet(Entity):
        """
        SONET controller performance data
        
        .. attribute:: sonet_ports
        
        	Port performance data
        	**type**\:   :py:class:`SonetPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PerformanceManagement.Sonet, self).__init__()

            self.yang_name = "sonet"
            self.yang_parent_name = "performance-management"

            self.sonet_ports = PerformanceManagement.Sonet.SonetPorts()
            self.sonet_ports.parent = self
            self._children_name_map["sonet_ports"] = "sonet-ports"
            self._children_yang_names.add("sonet-ports")


        class SonetPorts(Entity):
            """
            Port performance data
            
            .. attribute:: sonet_port
            
            	Port performance data
            	**type**\: list of    :py:class:`SonetPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PerformanceManagement.Sonet.SonetPorts, self).__init__()

                self.yang_name = "sonet-ports"
                self.yang_parent_name = "sonet"

                self.sonet_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(PerformanceManagement.Sonet.SonetPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(PerformanceManagement.Sonet.SonetPorts, self).__setattr__(name, value)


            class SonetPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: sonet_current
                
                	port current performance data
                	**type**\:   :py:class:`SonetCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort, self).__init__()

                    self.yang_name = "sonet-port"
                    self.yang_parent_name = "sonet-ports"

                    self.name = YLeaf(YType.str, "name")

                    self.sonet_current = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent()
                    self.sonet_current.parent = self
                    self._children_name_map["sonet_current"] = "sonet-current"
                    self._children_yang_names.add("sonet-current")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort, self).__setattr__(name, value)


                class SonetCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: sonet_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`SonetHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24>`
                    
                    .. attribute:: sonet_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`SonetMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent, self).__init__()

                        self.yang_name = "sonet-current"
                        self.yang_parent_name = "sonet-port"

                        self.sonet_hour24 = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24()
                        self.sonet_hour24.parent = self
                        self._children_name_map["sonet_hour24"] = "sonet-hour24"
                        self._children_yang_names.add("sonet-hour24")

                        self.sonet_minute15 = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15()
                        self.sonet_minute15.parent = self
                        self._children_name_map["sonet_minute15"] = "sonet-minute15"
                        self._children_yang_names.add("sonet-minute15")


                    class SonetMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: sonet_minute15_paths
                        
                        	port current performance data
                        	**type**\:   :py:class:`SonetMinute15Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths>`
                        
                        .. attribute:: sonet_minute15ocns
                        
                        	port current performance data
                        	**type**\:   :py:class:`SonetMinute15Ocns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15, self).__init__()

                            self.yang_name = "sonet-minute15"
                            self.yang_parent_name = "sonet-current"

                            self.sonet_minute15_paths = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths()
                            self.sonet_minute15_paths.parent = self
                            self._children_name_map["sonet_minute15_paths"] = "sonet-minute15-paths"
                            self._children_yang_names.add("sonet-minute15-paths")

                            self.sonet_minute15ocns = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns()
                            self.sonet_minute15ocns.parent = self
                            self._children_name_map["sonet_minute15ocns"] = "sonet-minute15ocns"
                            self._children_yang_names.add("sonet-minute15ocns")


                        class SonetMinute15Paths(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_minute15_path
                            
                            	port 15\-minute Path performance data
                            	**type**\: list of    :py:class:`SonetMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths, self).__init__()

                                self.yang_name = "sonet-minute15-paths"
                                self.yang_parent_name = "sonet-minute15"

                                self.sonet_minute15_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths, self).__setattr__(name, value)


                            class SonetMinute15Path(Entity):
                                """
                                port 15\-minute Path performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path, self).__init__()

                                    self.yang_name = "sonet-minute15-path"
                                    self.yang_parent_name = "sonet-minute15-paths"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.fe_path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath()
                                    self.fe_path.parent = self
                                    self._children_name_map["fe_path"] = "fe-path"
                                    self._children_yang_names.add("fe-path")

                                    self.path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path()
                                    self.path.parent = self
                                    self._children_name_map["path"] = "path"
                                    self._children_yang_names.add("path")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path, self).__setattr__(name, value)


                                class Path(Entity):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs>`
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_width
                                    
                                    	Indicates the type of the SONET/SDH Path
                                    	**type**\:   :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "sonet-minute15-path"

                                        self.path_status = YLeaf(YType.int32, "path-status")

                                        self.path_width = YLeaf(YType.enumeration, "path-width")

                                        self.path_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs()
                                        self.path_c_vs.parent = self
                                        self._children_name_map["path_c_vs"] = "path-c-vs"
                                        self._children_yang_names.add("path-c-vs")

                                        self.path_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self._children_name_map["path_e_ss"] = "path-e-ss"
                                        self._children_yang_names.add("path-e-ss")

                                        self.path_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self._children_name_map["path_se_ss"] = "path-se-ss"
                                        self._children_yang_names.add("path-se-ss")

                                        self.path_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                        self._children_yang_names.add("path-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_status",
                                                        "path_width") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path, self).__setattr__(name, value)


                                    class PathESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs, self).__init__()

                                            self.yang_name = "path-e-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs, self).__init__()

                                            self.yang_name = "path-se-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs, self).__init__()

                                            self.yang_name = "path-c-vs"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs, self).__init__()

                                            self.yang_name = "path-ua-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_status.is_set or
                                            self.path_width.is_set or
                                            (self.path_c_vs is not None and self.path_c_vs.has_data()) or
                                            (self.path_e_ss is not None and self.path_e_ss.has_data()) or
                                            (self.path_se_ss is not None and self.path_se_ss.has_data()) or
                                            (self.path_ua_ss is not None and self.path_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_status.yfilter != YFilter.not_set or
                                            self.path_width.yfilter != YFilter.not_set or
                                            (self.path_c_vs is not None and self.path_c_vs.has_operation()) or
                                            (self.path_e_ss is not None and self.path_e_ss.has_operation()) or
                                            (self.path_se_ss is not None and self.path_se_ss.has_operation()) or
                                            (self.path_ua_ss is not None and self.path_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_status.get_name_leafdata())
                                        if (self.path_width.is_set or self.path_width.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_width.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "path-c-vs"):
                                            if (self.path_c_vs is None):
                                                self.path_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathCVs()
                                                self.path_c_vs.parent = self
                                                self._children_name_map["path_c_vs"] = "path-c-vs"
                                            return self.path_c_vs

                                        if (child_yang_name == "path-e-ss"):
                                            if (self.path_e_ss is None):
                                                self.path_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathESs()
                                                self.path_e_ss.parent = self
                                                self._children_name_map["path_e_ss"] = "path-e-ss"
                                            return self.path_e_ss

                                        if (child_yang_name == "path-se-ss"):
                                            if (self.path_se_ss is None):
                                                self.path_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathSeSs()
                                                self.path_se_ss.parent = self
                                                self._children_name_map["path_se_ss"] = "path-se-ss"
                                            return self.path_se_ss

                                        if (child_yang_name == "path-ua-ss"):
                                            if (self.path_ua_ss is None):
                                                self.path_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path.PathUaSs()
                                                self.path_ua_ss.parent = self
                                                self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                            return self.path_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "path-c-vs" or name == "path-e-ss" or name == "path-se-ss" or name == "path-ua-ss" or name == "path-status" or name == "path-width"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-status"):
                                            self.path_status = value
                                            self.path_status.value_namespace = name_space
                                            self.path_status.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-width"):
                                            self.path_width = value
                                            self.path_width.value_namespace = name_space
                                            self.path_width.value_namespace_prefix = name_space_prefix


                                class FePath(Entity):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath, self).__init__()

                                        self.yang_name = "fe-path"
                                        self.yang_parent_name = "sonet-minute15-path"

                                        self.far_end_path_c_vs = YLeaf(YType.uint32, "far-end-path-c-vs")

                                        self.far_end_path_e_ss = YLeaf(YType.uint32, "far-end-path-e-ss")

                                        self.far_end_path_se_ss = YLeaf(YType.uint32, "far-end-path-se-ss")

                                        self.far_end_path_ua_ss = YLeaf(YType.uint32, "far-end-path-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("far_end_path_c_vs",
                                                        "far_end_path_e_ss",
                                                        "far_end_path_se_ss",
                                                        "far_end_path_ua_ss") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.far_end_path_c_vs.is_set or
                                            self.far_end_path_e_ss.is_set or
                                            self.far_end_path_se_ss.is_set or
                                            self.far_end_path_ua_ss.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.far_end_path_c_vs.yfilter != YFilter.not_set or
                                            self.far_end_path_e_ss.yfilter != YFilter.not_set or
                                            self.far_end_path_se_ss.yfilter != YFilter.not_set or
                                            self.far_end_path_ua_ss.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fe-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.far_end_path_c_vs.is_set or self.far_end_path_c_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_c_vs.get_name_leafdata())
                                        if (self.far_end_path_e_ss.is_set or self.far_end_path_e_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_e_ss.get_name_leafdata())
                                        if (self.far_end_path_se_ss.is_set or self.far_end_path_se_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_se_ss.get_name_leafdata())
                                        if (self.far_end_path_ua_ss.is_set or self.far_end_path_ua_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_ua_ss.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "far-end-path-c-vs" or name == "far-end-path-e-ss" or name == "far-end-path-se-ss" or name == "far-end-path-ua-ss"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "far-end-path-c-vs"):
                                            self.far_end_path_c_vs = value
                                            self.far_end_path_c_vs.value_namespace = name_space
                                            self.far_end_path_c_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-e-ss"):
                                            self.far_end_path_e_ss = value
                                            self.far_end_path_e_ss.value_namespace = name_space
                                            self.far_end_path_e_ss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-se-ss"):
                                            self.far_end_path_se_ss = value
                                            self.far_end_path_se_ss.value_namespace = name_space
                                            self.far_end_path_se_ss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-ua-ss"):
                                            self.far_end_path_ua_ss = value
                                            self.far_end_path_ua_ss.value_namespace = name_space
                                            self.far_end_path_ua_ss.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.fe_path is not None and self.fe_path.has_data()) or
                                        (self.path is not None and self.path.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.fe_path is not None and self.fe_path.has_operation()) or
                                        (self.path is not None and self.path.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sonet-minute15-path" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "fe-path"):
                                        if (self.fe_path is None):
                                            self.fe_path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.FePath()
                                            self.fe_path.parent = self
                                            self._children_name_map["fe_path"] = "fe-path"
                                        return self.fe_path

                                    if (child_yang_name == "path"):
                                        if (self.path is None):
                                            self.path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path.Path()
                                            self.path.parent = self
                                            self._children_name_map["path"] = "path"
                                        return self.path

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fe-path" or name == "path" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.sonet_minute15_path:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.sonet_minute15_path:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-minute15-paths" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sonet-minute15-path"):
                                    for c in self.sonet_minute15_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths.SonetMinute15Path()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.sonet_minute15_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sonet-minute15-path"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SonetMinute15Ocns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_minute15ocn
                            
                            	port 15\-minute ocn performance data
                            	**type**\: list of    :py:class:`SonetMinute15Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns, self).__init__()

                                self.yang_name = "sonet-minute15ocns"
                                self.yang_parent_name = "sonet-minute15"

                                self.sonet_minute15ocn = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns, self).__setattr__(name, value)


                            class SonetMinute15Ocn(Entity):
                                """
                                port 15\-minute ocn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line>`
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn, self).__init__()

                                    self.yang_name = "sonet-minute15ocn"
                                    self.yang_parent_name = "sonet-minute15ocns"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.fe_line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine()
                                    self.fe_line.parent = self
                                    self._children_name_map["fe_line"] = "fe-line"
                                    self._children_yang_names.add("fe-line")

                                    self.line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line()
                                    self.line.parent = self
                                    self._children_name_map["line"] = "line"
                                    self._children_yang_names.add("line")

                                    self.section = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section()
                                    self.section.parent = self
                                    self._children_name_map["section"] = "section"
                                    self._children_yang_names.add("section")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn, self).__setattr__(name, value)


                                class Section(Entity):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionCVs>`
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionESs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_sef_ss
                                    
                                    	The number of Severely Errored Framing Seconds
                                    	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSefSs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section, self).__init__()

                                        self.yang_name = "section"
                                        self.yang_parent_name = "sonet-minute15ocn"

                                        self.section_status = YLeaf(YType.int32, "section-status")

                                        self.section_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionCVs()
                                        self.section_c_vs.parent = self
                                        self._children_name_map["section_c_vs"] = "section-c-vs"
                                        self._children_yang_names.add("section-c-vs")

                                        self.section_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self._children_name_map["section_e_ss"] = "section-e-ss"
                                        self._children_yang_names.add("section-e-ss")

                                        self.section_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self._children_name_map["section_se_ss"] = "section-se-ss"
                                        self._children_yang_names.add("section-se-ss")

                                        self.section_sef_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSefSs()
                                        self.section_sef_ss.parent = self
                                        self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                        self._children_yang_names.add("section-sef-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("section_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section, self).__setattr__(name, value)


                                    class SectionESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionESs, self).__init__()

                                            self.yang_name = "section-e-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSeSs, self).__init__()

                                            self.yang_name = "section-se-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionSefSs(Entity):
                                        """
                                        The number of Severely Errored Framing Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSefSs, self).__init__()

                                            self.yang_name = "section-sef-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSefSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSefSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-sef-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionCVs, self).__init__()

                                            self.yang_name = "section-c-vs"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.section_status.is_set or
                                            (self.section_c_vs is not None and self.section_c_vs.has_data()) or
                                            (self.section_e_ss is not None and self.section_e_ss.has_data()) or
                                            (self.section_se_ss is not None and self.section_se_ss.has_data()) or
                                            (self.section_sef_ss is not None and self.section_sef_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.section_status.yfilter != YFilter.not_set or
                                            (self.section_c_vs is not None and self.section_c_vs.has_operation()) or
                                            (self.section_e_ss is not None and self.section_e_ss.has_operation()) or
                                            (self.section_se_ss is not None and self.section_se_ss.has_operation()) or
                                            (self.section_sef_ss is not None and self.section_sef_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "section" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.section_status.is_set or self.section_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.section_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "section-c-vs"):
                                            if (self.section_c_vs is None):
                                                self.section_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionCVs()
                                                self.section_c_vs.parent = self
                                                self._children_name_map["section_c_vs"] = "section-c-vs"
                                            return self.section_c_vs

                                        if (child_yang_name == "section-e-ss"):
                                            if (self.section_e_ss is None):
                                                self.section_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionESs()
                                                self.section_e_ss.parent = self
                                                self._children_name_map["section_e_ss"] = "section-e-ss"
                                            return self.section_e_ss

                                        if (child_yang_name == "section-se-ss"):
                                            if (self.section_se_ss is None):
                                                self.section_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSeSs()
                                                self.section_se_ss.parent = self
                                                self._children_name_map["section_se_ss"] = "section-se-ss"
                                            return self.section_se_ss

                                        if (child_yang_name == "section-sef-ss"):
                                            if (self.section_sef_ss is None):
                                                self.section_sef_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section.SectionSefSs()
                                                self.section_sef_ss.parent = self
                                                self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                            return self.section_sef_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "section-c-vs" or name == "section-e-ss" or name == "section-se-ss" or name == "section-sef-ss" or name == "section-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "section-status"):
                                            self.section_status = value
                                            self.section_status.value_namespace = name_space
                                            self.section_status.value_namespace_prefix = name_space_prefix


                                class Line(Entity):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineCVs>`
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineESs>`
                                    
                                    .. attribute:: line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineFcLs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineSeSs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line, self).__init__()

                                        self.yang_name = "line"
                                        self.yang_parent_name = "sonet-minute15ocn"

                                        self.line_status = YLeaf(YType.int32, "line-status")

                                        self.line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineCVs()
                                        self.line_c_vs.parent = self
                                        self._children_name_map["line_c_vs"] = "line-c-vs"
                                        self._children_yang_names.add("line-c-vs")

                                        self.line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self._children_name_map["line_e_ss"] = "line-e-ss"
                                        self._children_yang_names.add("line-e-ss")

                                        self.line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineFcLs()
                                        self.line_fc_ls.parent = self
                                        self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                        self._children_yang_names.add("line-fc-ls")

                                        self.line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self._children_name_map["line_se_ss"] = "line-se-ss"
                                        self._children_yang_names.add("line-se-ss")

                                        self.line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineUaSs()
                                        self.line_ua_ss.parent = self
                                        self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                        self._children_yang_names.add("line-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("line_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line, self).__setattr__(name, value)


                                    class LineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineESs, self).__init__()

                                            self.yang_name = "line-e-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineSeSs, self).__init__()

                                            self.yang_name = "line-se-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineCVs, self).__init__()

                                            self.yang_name = "line-c-vs"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineUaSs, self).__init__()

                                            self.yang_name = "line-ua-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineFcLs, self).__init__()

                                            self.yang_name = "line-fc-ls"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineFcLs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineFcLs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-fc-ls" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.line_status.is_set or
                                            (self.line_c_vs is not None and self.line_c_vs.has_data()) or
                                            (self.line_e_ss is not None and self.line_e_ss.has_data()) or
                                            (self.line_fc_ls is not None and self.line_fc_ls.has_data()) or
                                            (self.line_se_ss is not None and self.line_se_ss.has_data()) or
                                            (self.line_ua_ss is not None and self.line_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.line_status.yfilter != YFilter.not_set or
                                            (self.line_c_vs is not None and self.line_c_vs.has_operation()) or
                                            (self.line_e_ss is not None and self.line_e_ss.has_operation()) or
                                            (self.line_fc_ls is not None and self.line_fc_ls.has_operation()) or
                                            (self.line_se_ss is not None and self.line_se_ss.has_operation()) or
                                            (self.line_ua_ss is not None and self.line_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "line" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.line_status.is_set or self.line_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.line_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "line-c-vs"):
                                            if (self.line_c_vs is None):
                                                self.line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineCVs()
                                                self.line_c_vs.parent = self
                                                self._children_name_map["line_c_vs"] = "line-c-vs"
                                            return self.line_c_vs

                                        if (child_yang_name == "line-e-ss"):
                                            if (self.line_e_ss is None):
                                                self.line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineESs()
                                                self.line_e_ss.parent = self
                                                self._children_name_map["line_e_ss"] = "line-e-ss"
                                            return self.line_e_ss

                                        if (child_yang_name == "line-fc-ls"):
                                            if (self.line_fc_ls is None):
                                                self.line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineFcLs()
                                                self.line_fc_ls.parent = self
                                                self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                            return self.line_fc_ls

                                        if (child_yang_name == "line-se-ss"):
                                            if (self.line_se_ss is None):
                                                self.line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineSeSs()
                                                self.line_se_ss.parent = self
                                                self._children_name_map["line_se_ss"] = "line-se-ss"
                                            return self.line_se_ss

                                        if (child_yang_name == "line-ua-ss"):
                                            if (self.line_ua_ss is None):
                                                self.line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line.LineUaSs()
                                                self.line_ua_ss.parent = self
                                                self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                            return self.line_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "line-c-vs" or name == "line-e-ss" or name == "line-fc-ls" or name == "line-se-ss" or name == "line-ua-ss" or name == "line-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "line-status"):
                                            self.line_status = value
                                            self.line_status.value_namespace = name_space
                                            self.line_status.value_namespace_prefix = name_space_prefix


                                class FeLine(Entity):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineCVs>`
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineFcLs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine, self).__init__()

                                        self.yang_name = "fe-line"
                                        self.yang_parent_name = "sonet-minute15ocn"

                                        self.far_end_line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineCVs()
                                        self.far_end_line_c_vs.parent = self
                                        self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                        self._children_yang_names.add("far-end-line-c-vs")

                                        self.far_end_line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                        self._children_yang_names.add("far-end-line-e-ss")

                                        self.far_end_line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineFcLs()
                                        self.far_end_line_fc_ls.parent = self
                                        self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                        self._children_yang_names.add("far-end-line-fc-ls")

                                        self.far_end_line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                        self._children_yang_names.add("far-end-line-se-ss")

                                        self.far_end_line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self
                                        self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                        self._children_yang_names.add("far-end-line-ua-ss")


                                    class FarEndLineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineESs, self).__init__()

                                            self.yang_name = "far-end-line-e-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineSeSs, self).__init__()

                                            self.yang_name = "far-end-line-se-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineCVs, self).__init__()

                                            self.yang_name = "far-end-line-c-vs"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineUaSs, self).__init__()

                                            self.yang_name = "far-end-line-ua-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineFcLs, self).__init__()

                                            self.yang_name = "far-end-line-fc-ls"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineFcLs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineFcLs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-fc-ls" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_data()) or
                                            (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_data()) or
                                            (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_data()) or
                                            (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_data()) or
                                            (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_operation()) or
                                            (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_operation()) or
                                            (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_operation()) or
                                            (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_operation()) or
                                            (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fe-line" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "far-end-line-c-vs"):
                                            if (self.far_end_line_c_vs is None):
                                                self.far_end_line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineCVs()
                                                self.far_end_line_c_vs.parent = self
                                                self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                            return self.far_end_line_c_vs

                                        if (child_yang_name == "far-end-line-e-ss"):
                                            if (self.far_end_line_e_ss is None):
                                                self.far_end_line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineESs()
                                                self.far_end_line_e_ss.parent = self
                                                self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                            return self.far_end_line_e_ss

                                        if (child_yang_name == "far-end-line-fc-ls"):
                                            if (self.far_end_line_fc_ls is None):
                                                self.far_end_line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineFcLs()
                                                self.far_end_line_fc_ls.parent = self
                                                self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                            return self.far_end_line_fc_ls

                                        if (child_yang_name == "far-end-line-se-ss"):
                                            if (self.far_end_line_se_ss is None):
                                                self.far_end_line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineSeSs()
                                                self.far_end_line_se_ss.parent = self
                                                self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                            return self.far_end_line_se_ss

                                        if (child_yang_name == "far-end-line-ua-ss"):
                                            if (self.far_end_line_ua_ss is None):
                                                self.far_end_line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine.FarEndLineUaSs()
                                                self.far_end_line_ua_ss.parent = self
                                                self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                            return self.far_end_line_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "far-end-line-c-vs" or name == "far-end-line-e-ss" or name == "far-end-line-fc-ls" or name == "far-end-line-se-ss" or name == "far-end-line-ua-ss"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.fe_line is not None and self.fe_line.has_data()) or
                                        (self.line is not None and self.line.has_data()) or
                                        (self.section is not None and self.section.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.fe_line is not None and self.fe_line.has_operation()) or
                                        (self.line is not None and self.line.has_operation()) or
                                        (self.section is not None and self.section.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sonet-minute15ocn" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "fe-line"):
                                        if (self.fe_line is None):
                                            self.fe_line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.FeLine()
                                            self.fe_line.parent = self
                                            self._children_name_map["fe_line"] = "fe-line"
                                        return self.fe_line

                                    if (child_yang_name == "line"):
                                        if (self.line is None):
                                            self.line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Line()
                                            self.line.parent = self
                                            self._children_name_map["line"] = "line"
                                        return self.line

                                    if (child_yang_name == "section"):
                                        if (self.section is None):
                                            self.section = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn.Section()
                                            self.section.parent = self
                                            self._children_name_map["section"] = "section"
                                        return self.section

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fe-line" or name == "line" or name == "section" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.sonet_minute15ocn:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.sonet_minute15ocn:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-minute15ocns" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sonet-minute15ocn"):
                                    for c in self.sonet_minute15ocn:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns.SonetMinute15Ocn()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.sonet_minute15ocn.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sonet-minute15ocn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.sonet_minute15_paths is not None and self.sonet_minute15_paths.has_data()) or
                                (self.sonet_minute15ocns is not None and self.sonet_minute15ocns.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.sonet_minute15_paths is not None and self.sonet_minute15_paths.has_operation()) or
                                (self.sonet_minute15ocns is not None and self.sonet_minute15ocns.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sonet-minute15" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sonet-minute15-paths"):
                                if (self.sonet_minute15_paths is None):
                                    self.sonet_minute15_paths = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Paths()
                                    self.sonet_minute15_paths.parent = self
                                    self._children_name_map["sonet_minute15_paths"] = "sonet-minute15-paths"
                                return self.sonet_minute15_paths

                            if (child_yang_name == "sonet-minute15ocns"):
                                if (self.sonet_minute15ocns is None):
                                    self.sonet_minute15ocns = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15.SonetMinute15Ocns()
                                    self.sonet_minute15ocns.parent = self
                                    self._children_name_map["sonet_minute15ocns"] = "sonet-minute15ocns"
                                return self.sonet_minute15ocns

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sonet-minute15-paths" or name == "sonet-minute15ocns"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SonetHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: sonet_hour24_paths
                        
                        	port current performance data
                        	**type**\:   :py:class:`SonetHour24Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths>`
                        
                        .. attribute:: sonet_hour24ocns
                        
                        	port current performance data
                        	**type**\:   :py:class:`SonetHour24Ocns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24, self).__init__()

                            self.yang_name = "sonet-hour24"
                            self.yang_parent_name = "sonet-current"

                            self.sonet_hour24_paths = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths()
                            self.sonet_hour24_paths.parent = self
                            self._children_name_map["sonet_hour24_paths"] = "sonet-hour24-paths"
                            self._children_yang_names.add("sonet-hour24-paths")

                            self.sonet_hour24ocns = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns()
                            self.sonet_hour24ocns.parent = self
                            self._children_name_map["sonet_hour24ocns"] = "sonet-hour24ocns"
                            self._children_yang_names.add("sonet-hour24ocns")


                        class SonetHour24Ocns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_hour24ocn
                            
                            	port 24 hour ocn performance data
                            	**type**\: list of    :py:class:`SonetHour24Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns, self).__init__()

                                self.yang_name = "sonet-hour24ocns"
                                self.yang_parent_name = "sonet-hour24"

                                self.sonet_hour24ocn = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns, self).__setattr__(name, value)


                            class SonetHour24Ocn(Entity):
                                """
                                port 24 hour ocn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line>`
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn, self).__init__()

                                    self.yang_name = "sonet-hour24ocn"
                                    self.yang_parent_name = "sonet-hour24ocns"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.fe_line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine()
                                    self.fe_line.parent = self
                                    self._children_name_map["fe_line"] = "fe-line"
                                    self._children_yang_names.add("fe-line")

                                    self.line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line()
                                    self.line.parent = self
                                    self._children_name_map["line"] = "line"
                                    self._children_yang_names.add("line")

                                    self.section = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section()
                                    self.section.parent = self
                                    self._children_name_map["section"] = "section"
                                    self._children_yang_names.add("section")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn, self).__setattr__(name, value)


                                class Section(Entity):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionCVs>`
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionESs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_sef_ss
                                    
                                    	The number of Severely Errored Framing Seconds
                                    	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSefSs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section, self).__init__()

                                        self.yang_name = "section"
                                        self.yang_parent_name = "sonet-hour24ocn"

                                        self.section_status = YLeaf(YType.int32, "section-status")

                                        self.section_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionCVs()
                                        self.section_c_vs.parent = self
                                        self._children_name_map["section_c_vs"] = "section-c-vs"
                                        self._children_yang_names.add("section-c-vs")

                                        self.section_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self._children_name_map["section_e_ss"] = "section-e-ss"
                                        self._children_yang_names.add("section-e-ss")

                                        self.section_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self._children_name_map["section_se_ss"] = "section-se-ss"
                                        self._children_yang_names.add("section-se-ss")

                                        self.section_sef_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSefSs()
                                        self.section_sef_ss.parent = self
                                        self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                        self._children_yang_names.add("section-sef-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("section_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section, self).__setattr__(name, value)


                                    class SectionESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionESs, self).__init__()

                                            self.yang_name = "section-e-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSeSs, self).__init__()

                                            self.yang_name = "section-se-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionSefSs(Entity):
                                        """
                                        The number of Severely Errored Framing Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSefSs, self).__init__()

                                            self.yang_name = "section-sef-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSefSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSefSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-sef-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionCVs, self).__init__()

                                            self.yang_name = "section-c-vs"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.section_status.is_set or
                                            (self.section_c_vs is not None and self.section_c_vs.has_data()) or
                                            (self.section_e_ss is not None and self.section_e_ss.has_data()) or
                                            (self.section_se_ss is not None and self.section_se_ss.has_data()) or
                                            (self.section_sef_ss is not None and self.section_sef_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.section_status.yfilter != YFilter.not_set or
                                            (self.section_c_vs is not None and self.section_c_vs.has_operation()) or
                                            (self.section_e_ss is not None and self.section_e_ss.has_operation()) or
                                            (self.section_se_ss is not None and self.section_se_ss.has_operation()) or
                                            (self.section_sef_ss is not None and self.section_sef_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "section" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.section_status.is_set or self.section_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.section_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "section-c-vs"):
                                            if (self.section_c_vs is None):
                                                self.section_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionCVs()
                                                self.section_c_vs.parent = self
                                                self._children_name_map["section_c_vs"] = "section-c-vs"
                                            return self.section_c_vs

                                        if (child_yang_name == "section-e-ss"):
                                            if (self.section_e_ss is None):
                                                self.section_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionESs()
                                                self.section_e_ss.parent = self
                                                self._children_name_map["section_e_ss"] = "section-e-ss"
                                            return self.section_e_ss

                                        if (child_yang_name == "section-se-ss"):
                                            if (self.section_se_ss is None):
                                                self.section_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSeSs()
                                                self.section_se_ss.parent = self
                                                self._children_name_map["section_se_ss"] = "section-se-ss"
                                            return self.section_se_ss

                                        if (child_yang_name == "section-sef-ss"):
                                            if (self.section_sef_ss is None):
                                                self.section_sef_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section.SectionSefSs()
                                                self.section_sef_ss.parent = self
                                                self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                            return self.section_sef_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "section-c-vs" or name == "section-e-ss" or name == "section-se-ss" or name == "section-sef-ss" or name == "section-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "section-status"):
                                            self.section_status = value
                                            self.section_status.value_namespace = name_space
                                            self.section_status.value_namespace_prefix = name_space_prefix


                                class Line(Entity):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineCVs>`
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineESs>`
                                    
                                    .. attribute:: line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineFcLs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineSeSs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line, self).__init__()

                                        self.yang_name = "line"
                                        self.yang_parent_name = "sonet-hour24ocn"

                                        self.line_status = YLeaf(YType.int32, "line-status")

                                        self.line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineCVs()
                                        self.line_c_vs.parent = self
                                        self._children_name_map["line_c_vs"] = "line-c-vs"
                                        self._children_yang_names.add("line-c-vs")

                                        self.line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self._children_name_map["line_e_ss"] = "line-e-ss"
                                        self._children_yang_names.add("line-e-ss")

                                        self.line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineFcLs()
                                        self.line_fc_ls.parent = self
                                        self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                        self._children_yang_names.add("line-fc-ls")

                                        self.line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self._children_name_map["line_se_ss"] = "line-se-ss"
                                        self._children_yang_names.add("line-se-ss")

                                        self.line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineUaSs()
                                        self.line_ua_ss.parent = self
                                        self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                        self._children_yang_names.add("line-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("line_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line, self).__setattr__(name, value)


                                    class LineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineESs, self).__init__()

                                            self.yang_name = "line-e-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineSeSs, self).__init__()

                                            self.yang_name = "line-se-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineCVs, self).__init__()

                                            self.yang_name = "line-c-vs"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineUaSs, self).__init__()

                                            self.yang_name = "line-ua-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineFcLs, self).__init__()

                                            self.yang_name = "line-fc-ls"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineFcLs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineFcLs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-fc-ls" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.line_status.is_set or
                                            (self.line_c_vs is not None and self.line_c_vs.has_data()) or
                                            (self.line_e_ss is not None and self.line_e_ss.has_data()) or
                                            (self.line_fc_ls is not None and self.line_fc_ls.has_data()) or
                                            (self.line_se_ss is not None and self.line_se_ss.has_data()) or
                                            (self.line_ua_ss is not None and self.line_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.line_status.yfilter != YFilter.not_set or
                                            (self.line_c_vs is not None and self.line_c_vs.has_operation()) or
                                            (self.line_e_ss is not None and self.line_e_ss.has_operation()) or
                                            (self.line_fc_ls is not None and self.line_fc_ls.has_operation()) or
                                            (self.line_se_ss is not None and self.line_se_ss.has_operation()) or
                                            (self.line_ua_ss is not None and self.line_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "line" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.line_status.is_set or self.line_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.line_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "line-c-vs"):
                                            if (self.line_c_vs is None):
                                                self.line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineCVs()
                                                self.line_c_vs.parent = self
                                                self._children_name_map["line_c_vs"] = "line-c-vs"
                                            return self.line_c_vs

                                        if (child_yang_name == "line-e-ss"):
                                            if (self.line_e_ss is None):
                                                self.line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineESs()
                                                self.line_e_ss.parent = self
                                                self._children_name_map["line_e_ss"] = "line-e-ss"
                                            return self.line_e_ss

                                        if (child_yang_name == "line-fc-ls"):
                                            if (self.line_fc_ls is None):
                                                self.line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineFcLs()
                                                self.line_fc_ls.parent = self
                                                self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                            return self.line_fc_ls

                                        if (child_yang_name == "line-se-ss"):
                                            if (self.line_se_ss is None):
                                                self.line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineSeSs()
                                                self.line_se_ss.parent = self
                                                self._children_name_map["line_se_ss"] = "line-se-ss"
                                            return self.line_se_ss

                                        if (child_yang_name == "line-ua-ss"):
                                            if (self.line_ua_ss is None):
                                                self.line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line.LineUaSs()
                                                self.line_ua_ss.parent = self
                                                self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                            return self.line_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "line-c-vs" or name == "line-e-ss" or name == "line-fc-ls" or name == "line-se-ss" or name == "line-ua-ss" or name == "line-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "line-status"):
                                            self.line_status = value
                                            self.line_status.value_namespace = name_space
                                            self.line_status.value_namespace_prefix = name_space_prefix


                                class FeLine(Entity):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineCVs>`
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineFcLs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine, self).__init__()

                                        self.yang_name = "fe-line"
                                        self.yang_parent_name = "sonet-hour24ocn"

                                        self.far_end_line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineCVs()
                                        self.far_end_line_c_vs.parent = self
                                        self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                        self._children_yang_names.add("far-end-line-c-vs")

                                        self.far_end_line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                        self._children_yang_names.add("far-end-line-e-ss")

                                        self.far_end_line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineFcLs()
                                        self.far_end_line_fc_ls.parent = self
                                        self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                        self._children_yang_names.add("far-end-line-fc-ls")

                                        self.far_end_line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                        self._children_yang_names.add("far-end-line-se-ss")

                                        self.far_end_line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self
                                        self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                        self._children_yang_names.add("far-end-line-ua-ss")


                                    class FarEndLineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineESs, self).__init__()

                                            self.yang_name = "far-end-line-e-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineSeSs, self).__init__()

                                            self.yang_name = "far-end-line-se-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineCVs, self).__init__()

                                            self.yang_name = "far-end-line-c-vs"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineUaSs, self).__init__()

                                            self.yang_name = "far-end-line-ua-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineFcLs, self).__init__()

                                            self.yang_name = "far-end-line-fc-ls"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineFcLs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineFcLs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-fc-ls" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_data()) or
                                            (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_data()) or
                                            (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_data()) or
                                            (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_data()) or
                                            (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_operation()) or
                                            (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_operation()) or
                                            (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_operation()) or
                                            (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_operation()) or
                                            (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fe-line" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "far-end-line-c-vs"):
                                            if (self.far_end_line_c_vs is None):
                                                self.far_end_line_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineCVs()
                                                self.far_end_line_c_vs.parent = self
                                                self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                            return self.far_end_line_c_vs

                                        if (child_yang_name == "far-end-line-e-ss"):
                                            if (self.far_end_line_e_ss is None):
                                                self.far_end_line_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineESs()
                                                self.far_end_line_e_ss.parent = self
                                                self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                            return self.far_end_line_e_ss

                                        if (child_yang_name == "far-end-line-fc-ls"):
                                            if (self.far_end_line_fc_ls is None):
                                                self.far_end_line_fc_ls = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineFcLs()
                                                self.far_end_line_fc_ls.parent = self
                                                self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                            return self.far_end_line_fc_ls

                                        if (child_yang_name == "far-end-line-se-ss"):
                                            if (self.far_end_line_se_ss is None):
                                                self.far_end_line_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineSeSs()
                                                self.far_end_line_se_ss.parent = self
                                                self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                            return self.far_end_line_se_ss

                                        if (child_yang_name == "far-end-line-ua-ss"):
                                            if (self.far_end_line_ua_ss is None):
                                                self.far_end_line_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine.FarEndLineUaSs()
                                                self.far_end_line_ua_ss.parent = self
                                                self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                            return self.far_end_line_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "far-end-line-c-vs" or name == "far-end-line-e-ss" or name == "far-end-line-fc-ls" or name == "far-end-line-se-ss" or name == "far-end-line-ua-ss"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.fe_line is not None and self.fe_line.has_data()) or
                                        (self.line is not None and self.line.has_data()) or
                                        (self.section is not None and self.section.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.fe_line is not None and self.fe_line.has_operation()) or
                                        (self.line is not None and self.line.has_operation()) or
                                        (self.section is not None and self.section.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sonet-hour24ocn" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "fe-line"):
                                        if (self.fe_line is None):
                                            self.fe_line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.FeLine()
                                            self.fe_line.parent = self
                                            self._children_name_map["fe_line"] = "fe-line"
                                        return self.fe_line

                                    if (child_yang_name == "line"):
                                        if (self.line is None):
                                            self.line = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Line()
                                            self.line.parent = self
                                            self._children_name_map["line"] = "line"
                                        return self.line

                                    if (child_yang_name == "section"):
                                        if (self.section is None):
                                            self.section = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn.Section()
                                            self.section.parent = self
                                            self._children_name_map["section"] = "section"
                                        return self.section

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fe-line" or name == "line" or name == "section" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.sonet_hour24ocn:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.sonet_hour24ocn:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-hour24ocns" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sonet-hour24ocn"):
                                    for c in self.sonet_hour24ocn:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns.SonetHour24Ocn()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.sonet_hour24ocn.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sonet-hour24ocn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SonetHour24Paths(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_hour24_path
                            
                            	port 24 hour Path performance data
                            	**type**\: list of    :py:class:`SonetHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths, self).__init__()

                                self.yang_name = "sonet-hour24-paths"
                                self.yang_parent_name = "sonet-hour24"

                                self.sonet_hour24_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths, self).__setattr__(name, value)


                            class SonetHour24Path(Entity):
                                """
                                port 24 hour Path performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path, self).__init__()

                                    self.yang_name = "sonet-hour24-path"
                                    self.yang_parent_name = "sonet-hour24-paths"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.fe_path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath()
                                    self.fe_path.parent = self
                                    self._children_name_map["fe_path"] = "fe-path"
                                    self._children_yang_names.add("fe-path")

                                    self.path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path()
                                    self.path.parent = self
                                    self._children_name_map["path"] = "path"
                                    self._children_yang_names.add("path")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path, self).__setattr__(name, value)


                                class Path(Entity):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs>`
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_width
                                    
                                    	Indicates the type of the SONET/SDH Path
                                    	**type**\:   :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "sonet-hour24-path"

                                        self.path_status = YLeaf(YType.int32, "path-status")

                                        self.path_width = YLeaf(YType.enumeration, "path-width")

                                        self.path_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs()
                                        self.path_c_vs.parent = self
                                        self._children_name_map["path_c_vs"] = "path-c-vs"
                                        self._children_yang_names.add("path-c-vs")

                                        self.path_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self._children_name_map["path_e_ss"] = "path-e-ss"
                                        self._children_yang_names.add("path-e-ss")

                                        self.path_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self._children_name_map["path_se_ss"] = "path-se-ss"
                                        self._children_yang_names.add("path-se-ss")

                                        self.path_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                        self._children_yang_names.add("path-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_status",
                                                        "path_width") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path, self).__setattr__(name, value)


                                    class PathESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs, self).__init__()

                                            self.yang_name = "path-e-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs, self).__init__()

                                            self.yang_name = "path-se-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs, self).__init__()

                                            self.yang_name = "path-c-vs"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs, self).__init__()

                                            self.yang_name = "path-ua-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_status.is_set or
                                            self.path_width.is_set or
                                            (self.path_c_vs is not None and self.path_c_vs.has_data()) or
                                            (self.path_e_ss is not None and self.path_e_ss.has_data()) or
                                            (self.path_se_ss is not None and self.path_se_ss.has_data()) or
                                            (self.path_ua_ss is not None and self.path_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_status.yfilter != YFilter.not_set or
                                            self.path_width.yfilter != YFilter.not_set or
                                            (self.path_c_vs is not None and self.path_c_vs.has_operation()) or
                                            (self.path_e_ss is not None and self.path_e_ss.has_operation()) or
                                            (self.path_se_ss is not None and self.path_se_ss.has_operation()) or
                                            (self.path_ua_ss is not None and self.path_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_status.get_name_leafdata())
                                        if (self.path_width.is_set or self.path_width.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_width.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "path-c-vs"):
                                            if (self.path_c_vs is None):
                                                self.path_c_vs = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathCVs()
                                                self.path_c_vs.parent = self
                                                self._children_name_map["path_c_vs"] = "path-c-vs"
                                            return self.path_c_vs

                                        if (child_yang_name == "path-e-ss"):
                                            if (self.path_e_ss is None):
                                                self.path_e_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathESs()
                                                self.path_e_ss.parent = self
                                                self._children_name_map["path_e_ss"] = "path-e-ss"
                                            return self.path_e_ss

                                        if (child_yang_name == "path-se-ss"):
                                            if (self.path_se_ss is None):
                                                self.path_se_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathSeSs()
                                                self.path_se_ss.parent = self
                                                self._children_name_map["path_se_ss"] = "path-se-ss"
                                            return self.path_se_ss

                                        if (child_yang_name == "path-ua-ss"):
                                            if (self.path_ua_ss is None):
                                                self.path_ua_ss = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path.PathUaSs()
                                                self.path_ua_ss.parent = self
                                                self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                            return self.path_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "path-c-vs" or name == "path-e-ss" or name == "path-se-ss" or name == "path-ua-ss" or name == "path-status" or name == "path-width"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-status"):
                                            self.path_status = value
                                            self.path_status.value_namespace = name_space
                                            self.path_status.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-width"):
                                            self.path_width = value
                                            self.path_width.value_namespace = name_space
                                            self.path_width.value_namespace_prefix = name_space_prefix


                                class FePath(Entity):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath, self).__init__()

                                        self.yang_name = "fe-path"
                                        self.yang_parent_name = "sonet-hour24-path"

                                        self.far_end_path_c_vs = YLeaf(YType.uint32, "far-end-path-c-vs")

                                        self.far_end_path_e_ss = YLeaf(YType.uint32, "far-end-path-e-ss")

                                        self.far_end_path_se_ss = YLeaf(YType.uint32, "far-end-path-se-ss")

                                        self.far_end_path_ua_ss = YLeaf(YType.uint32, "far-end-path-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("far_end_path_c_vs",
                                                        "far_end_path_e_ss",
                                                        "far_end_path_se_ss",
                                                        "far_end_path_ua_ss") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.far_end_path_c_vs.is_set or
                                            self.far_end_path_e_ss.is_set or
                                            self.far_end_path_se_ss.is_set or
                                            self.far_end_path_ua_ss.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.far_end_path_c_vs.yfilter != YFilter.not_set or
                                            self.far_end_path_e_ss.yfilter != YFilter.not_set or
                                            self.far_end_path_se_ss.yfilter != YFilter.not_set or
                                            self.far_end_path_ua_ss.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fe-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.far_end_path_c_vs.is_set or self.far_end_path_c_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_c_vs.get_name_leafdata())
                                        if (self.far_end_path_e_ss.is_set or self.far_end_path_e_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_e_ss.get_name_leafdata())
                                        if (self.far_end_path_se_ss.is_set or self.far_end_path_se_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_se_ss.get_name_leafdata())
                                        if (self.far_end_path_ua_ss.is_set or self.far_end_path_ua_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_ua_ss.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "far-end-path-c-vs" or name == "far-end-path-e-ss" or name == "far-end-path-se-ss" or name == "far-end-path-ua-ss"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "far-end-path-c-vs"):
                                            self.far_end_path_c_vs = value
                                            self.far_end_path_c_vs.value_namespace = name_space
                                            self.far_end_path_c_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-e-ss"):
                                            self.far_end_path_e_ss = value
                                            self.far_end_path_e_ss.value_namespace = name_space
                                            self.far_end_path_e_ss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-se-ss"):
                                            self.far_end_path_se_ss = value
                                            self.far_end_path_se_ss.value_namespace = name_space
                                            self.far_end_path_se_ss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-ua-ss"):
                                            self.far_end_path_ua_ss = value
                                            self.far_end_path_ua_ss.value_namespace = name_space
                                            self.far_end_path_ua_ss.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.fe_path is not None and self.fe_path.has_data()) or
                                        (self.path is not None and self.path.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.fe_path is not None and self.fe_path.has_operation()) or
                                        (self.path is not None and self.path.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sonet-hour24-path" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "fe-path"):
                                        if (self.fe_path is None):
                                            self.fe_path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.FePath()
                                            self.fe_path.parent = self
                                            self._children_name_map["fe_path"] = "fe-path"
                                        return self.fe_path

                                    if (child_yang_name == "path"):
                                        if (self.path is None):
                                            self.path = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path.Path()
                                            self.path.parent = self
                                            self._children_name_map["path"] = "path"
                                        return self.path

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fe-path" or name == "path" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.sonet_hour24_path:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.sonet_hour24_path:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-hour24-paths" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sonet-hour24-path"):
                                    for c in self.sonet_hour24_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths.SonetHour24Path()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.sonet_hour24_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sonet-hour24-path"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.sonet_hour24_paths is not None and self.sonet_hour24_paths.has_data()) or
                                (self.sonet_hour24ocns is not None and self.sonet_hour24ocns.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.sonet_hour24_paths is not None and self.sonet_hour24_paths.has_operation()) or
                                (self.sonet_hour24ocns is not None and self.sonet_hour24ocns.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sonet-hour24" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sonet-hour24-paths"):
                                if (self.sonet_hour24_paths is None):
                                    self.sonet_hour24_paths = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Paths()
                                    self.sonet_hour24_paths.parent = self
                                    self._children_name_map["sonet_hour24_paths"] = "sonet-hour24-paths"
                                return self.sonet_hour24_paths

                            if (child_yang_name == "sonet-hour24ocns"):
                                if (self.sonet_hour24ocns is None):
                                    self.sonet_hour24ocns = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24.SonetHour24Ocns()
                                    self.sonet_hour24ocns.parent = self
                                    self._children_name_map["sonet_hour24ocns"] = "sonet-hour24ocns"
                                return self.sonet_hour24ocns

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sonet-hour24-paths" or name == "sonet-hour24ocns"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.sonet_hour24 is not None and self.sonet_hour24.has_data()) or
                            (self.sonet_minute15 is not None and self.sonet_minute15.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.sonet_hour24 is not None and self.sonet_hour24.has_operation()) or
                            (self.sonet_minute15 is not None and self.sonet_minute15.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sonet-current" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sonet-hour24"):
                            if (self.sonet_hour24 is None):
                                self.sonet_hour24 = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetHour24()
                                self.sonet_hour24.parent = self
                                self._children_name_map["sonet_hour24"] = "sonet-hour24"
                            return self.sonet_hour24

                        if (child_yang_name == "sonet-minute15"):
                            if (self.sonet_minute15 is None):
                                self.sonet_minute15 = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent.SonetMinute15()
                                self.sonet_minute15.parent = self
                                self._children_name_map["sonet_minute15"] = "sonet-minute15"
                            return self.sonet_minute15

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sonet-hour24" or name == "sonet-minute15"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.name.is_set or
                        (self.sonet_current is not None and self.sonet_current.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        (self.sonet_current is not None and self.sonet_current.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "sonet-port" + "[name='" + self.name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/sonet/sonet-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sonet-current"):
                        if (self.sonet_current is None):
                            self.sonet_current = PerformanceManagement.Sonet.SonetPorts.SonetPort.SonetCurrent()
                            self.sonet_current.parent = self
                            self._children_name_map["sonet_current"] = "sonet-current"
                        return self.sonet_current

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sonet-current" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.sonet_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.sonet_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "sonet-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/sonet/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "sonet-port"):
                    for c in self.sonet_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = PerformanceManagement.Sonet.SonetPorts.SonetPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.sonet_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "sonet-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.sonet_ports is not None and self.sonet_ports.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.sonet_ports is not None and self.sonet_ports.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "sonet" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "sonet-ports"):
                if (self.sonet_ports is None):
                    self.sonet_ports = PerformanceManagement.Sonet.SonetPorts()
                    self.sonet_ports.parent = self
                    self._children_name_map["sonet_ports"] = "sonet-ports"
                return self.sonet_ports

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "sonet-ports"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Optics(Entity):
        """
        OPTICS controller performance data
        
        .. attribute:: optics_ports
        
        	Port performance data
        	**type**\:   :py:class:`OpticsPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PerformanceManagement.Optics, self).__init__()

            self.yang_name = "optics"
            self.yang_parent_name = "performance-management"

            self.optics_ports = PerformanceManagement.Optics.OpticsPorts()
            self.optics_ports.parent = self
            self._children_name_map["optics_ports"] = "optics-ports"
            self._children_yang_names.add("optics-ports")


        class OpticsPorts(Entity):
            """
            Port performance data
            
            .. attribute:: optics_port
            
            	Port performance data
            	**type**\: list of    :py:class:`OpticsPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PerformanceManagement.Optics.OpticsPorts, self).__init__()

                self.yang_name = "optics-ports"
                self.yang_parent_name = "optics"

                self.optics_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(PerformanceManagement.Optics.OpticsPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(PerformanceManagement.Optics.OpticsPorts, self).__setattr__(name, value)


            class OpticsPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: optics_current
                
                	port current performance data
                	**type**\:   :py:class:`OpticsCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort, self).__init__()

                    self.yang_name = "optics-port"
                    self.yang_parent_name = "optics-ports"

                    self.name = YLeaf(YType.str, "name")

                    self.optics_current = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent()
                    self.optics_current.parent = self
                    self._children_name_map["optics_current"] = "optics-current"
                    self._children_yang_names.add("optics-current")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort, self).__setattr__(name, value)


                class OpticsCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: optics_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`OpticsHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24>`
                    
                    .. attribute:: optics_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`OpticsMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15>`
                    
                    .. attribute:: optics_second30
                    
                    	port current performance data
                    	**type**\:   :py:class:`OpticsSecond30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent, self).__init__()

                        self.yang_name = "optics-current"
                        self.yang_parent_name = "optics-port"

                        self.optics_hour24 = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24()
                        self.optics_hour24.parent = self
                        self._children_name_map["optics_hour24"] = "optics-hour24"
                        self._children_yang_names.add("optics-hour24")

                        self.optics_minute15 = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15()
                        self.optics_minute15.parent = self
                        self._children_name_map["optics_minute15"] = "optics-minute15"
                        self._children_yang_names.add("optics-minute15")

                        self.optics_second30 = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30()
                        self.optics_second30.parent = self
                        self._children_name_map["optics_second30"] = "optics-second30"
                        self._children_yang_names.add("optics-second30")


                    class OpticsHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: optics_hour24_optics
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`OpticsHour24Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics>`
                        
                        .. attribute:: optics_hour24fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsHour24Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24, self).__init__()

                            self.yang_name = "optics-hour24"
                            self.yang_parent_name = "optics-current"

                            self.optics_hour24_optics = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics()
                            self.optics_hour24_optics.parent = self
                            self._children_name_map["optics_hour24_optics"] = "optics-hour24-optics"
                            self._children_yang_names.add("optics-hour24-optics")

                            self.optics_hour24fecs = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs()
                            self.optics_hour24fecs.parent = self
                            self._children_name_map["optics_hour24fecs"] = "optics-hour24fecs"
                            self._children_yang_names.add("optics-hour24fecs")


                        class OpticsHour24Optics(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: optics_hour24_optic
                            
                            	port 24 hour optics performance data
                            	**type**\: list of    :py:class:`OpticsHour24Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics, self).__init__()

                                self.yang_name = "optics-hour24-optics"
                                self.yang_parent_name = "optics-hour24"

                                self.optics_hour24_optic = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics, self).__setattr__(name, value)


                            class OpticsHour24Optic(Entity):
                                """
                                port 24 hour optics performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic, self).__init__()

                                    self.yang_name = "optics-hour24-optic"
                                    self.yang_parent_name = "optics-hour24-optics"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.cd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd()
                                    self.cd.parent = self
                                    self._children_name_map["cd"] = "cd"
                                    self._children_yang_names.add("cd")

                                    self.center_wavelength = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self._children_name_map["center_wavelength"] = "center-wavelength"
                                    self._children_yang_names.add("center-wavelength")

                                    self.dgd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd()
                                    self.dgd.parent = self
                                    self._children_name_map["dgd"] = "dgd"
                                    self._children_yang_names.add("dgd")

                                    self.lbc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"
                                    self._children_yang_names.add("lbc")

                                    self.lbc_pc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self._children_name_map["lbc_pc"] = "lbc-pc"
                                    self._children_yang_names.add("lbc-pc")

                                    self.low_sig_freq_off = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                    self._children_yang_names.add("low-sig-freq-off")

                                    self.opr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr()
                                    self.opr.parent = self
                                    self._children_name_map["opr"] = "opr"
                                    self._children_yang_names.add("opr")

                                    self.opt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt()
                                    self.opt.parent = self
                                    self._children_name_map["opt"] = "opt"
                                    self._children_yang_names.add("opt")

                                    self.osnr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr()
                                    self.osnr.parent = self
                                    self._children_name_map["osnr"] = "osnr"
                                    self._children_yang_names.add("osnr")

                                    self.pcr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr()
                                    self.pcr.parent = self
                                    self._children_name_map["pcr"] = "pcr"
                                    self._children_yang_names.add("pcr")

                                    self.pdl = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl()
                                    self.pdl.parent = self
                                    self._children_name_map["pdl"] = "pdl"
                                    self._children_yang_names.add("pdl")

                                    self.pmd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd()
                                    self.pmd.parent = self
                                    self._children_name_map["pmd"] = "pmd"
                                    self._children_yang_names.add("pmd")

                                    self.pn = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn()
                                    self.pn.parent = self
                                    self._children_name_map["pn"] = "pn"
                                    self._children_yang_names.add("pn")

                                    self.rx_sig_pow = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                    self._children_yang_names.add("rx-sig-pow")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic, self).__setattr__(name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LbcPc(Entity):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc, self).__init__()

                                        self.yang_name = "lbc-pc"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc-pc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Opt(Entity):
                                    """
                                    OPT
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt, self).__init__()

                                        self.yang_name = "opt"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Opr(Entity):
                                    """
                                    OPR
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr, self).__init__()

                                        self.yang_name = "opr"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Cd(Entity):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd, self).__init__()

                                        self.yang_name = "cd"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "cd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Dgd(Entity):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd, self).__init__()

                                        self.yang_name = "dgd"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dgd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pmd(Entity):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd, self).__init__()

                                        self.yang_name = "pmd"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pmd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Osnr(Entity):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr, self).__init__()

                                        self.yang_name = "osnr"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "osnr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class CenterWavelength(Entity):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength, self).__init__()

                                        self.yang_name = "center-wavelength"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "center-wavelength" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pdl(Entity):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl, self).__init__()

                                        self.yang_name = "pdl"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pdl" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pcr(Entity):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr, self).__init__()

                                        self.yang_name = "pcr"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pcr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pn(Entity):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn, self).__init__()

                                        self.yang_name = "pn"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pn" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class RxSigPow(Entity):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow, self).__init__()

                                        self.yang_name = "rx-sig-pow"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-sig-pow" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LowSigFreqOff(Entity):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff, self).__init__()

                                        self.yang_name = "low-sig-freq-off"
                                        self.yang_parent_name = "optics-hour24-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "low-sig-freq-off" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.cd is not None and self.cd.has_data()) or
                                        (self.center_wavelength is not None and self.center_wavelength.has_data()) or
                                        (self.dgd is not None and self.dgd.has_data()) or
                                        (self.lbc is not None and self.lbc.has_data()) or
                                        (self.lbc_pc is not None and self.lbc_pc.has_data()) or
                                        (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_data()) or
                                        (self.opr is not None and self.opr.has_data()) or
                                        (self.opt is not None and self.opt.has_data()) or
                                        (self.osnr is not None and self.osnr.has_data()) or
                                        (self.pcr is not None and self.pcr.has_data()) or
                                        (self.pdl is not None and self.pdl.has_data()) or
                                        (self.pmd is not None and self.pmd.has_data()) or
                                        (self.pn is not None and self.pn.has_data()) or
                                        (self.rx_sig_pow is not None and self.rx_sig_pow.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.cd is not None and self.cd.has_operation()) or
                                        (self.center_wavelength is not None and self.center_wavelength.has_operation()) or
                                        (self.dgd is not None and self.dgd.has_operation()) or
                                        (self.lbc is not None and self.lbc.has_operation()) or
                                        (self.lbc_pc is not None and self.lbc_pc.has_operation()) or
                                        (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_operation()) or
                                        (self.opr is not None and self.opr.has_operation()) or
                                        (self.opt is not None and self.opt.has_operation()) or
                                        (self.osnr is not None and self.osnr.has_operation()) or
                                        (self.pcr is not None and self.pcr.has_operation()) or
                                        (self.pdl is not None and self.pdl.has_operation()) or
                                        (self.pmd is not None and self.pmd.has_operation()) or
                                        (self.pn is not None and self.pn.has_operation()) or
                                        (self.rx_sig_pow is not None and self.rx_sig_pow.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "optics-hour24-optic" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "cd"):
                                        if (self.cd is None):
                                            self.cd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Cd()
                                            self.cd.parent = self
                                            self._children_name_map["cd"] = "cd"
                                        return self.cd

                                    if (child_yang_name == "center-wavelength"):
                                        if (self.center_wavelength is None):
                                            self.center_wavelength = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.CenterWavelength()
                                            self.center_wavelength.parent = self
                                            self._children_name_map["center_wavelength"] = "center-wavelength"
                                        return self.center_wavelength

                                    if (child_yang_name == "dgd"):
                                        if (self.dgd is None):
                                            self.dgd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Dgd()
                                            self.dgd.parent = self
                                            self._children_name_map["dgd"] = "dgd"
                                        return self.dgd

                                    if (child_yang_name == "lbc"):
                                        if (self.lbc is None):
                                            self.lbc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Lbc()
                                            self.lbc.parent = self
                                            self._children_name_map["lbc"] = "lbc"
                                        return self.lbc

                                    if (child_yang_name == "lbc-pc"):
                                        if (self.lbc_pc is None):
                                            self.lbc_pc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LbcPc()
                                            self.lbc_pc.parent = self
                                            self._children_name_map["lbc_pc"] = "lbc-pc"
                                        return self.lbc_pc

                                    if (child_yang_name == "low-sig-freq-off"):
                                        if (self.low_sig_freq_off is None):
                                            self.low_sig_freq_off = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.LowSigFreqOff()
                                            self.low_sig_freq_off.parent = self
                                            self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                        return self.low_sig_freq_off

                                    if (child_yang_name == "opr"):
                                        if (self.opr is None):
                                            self.opr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opr()
                                            self.opr.parent = self
                                            self._children_name_map["opr"] = "opr"
                                        return self.opr

                                    if (child_yang_name == "opt"):
                                        if (self.opt is None):
                                            self.opt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Opt()
                                            self.opt.parent = self
                                            self._children_name_map["opt"] = "opt"
                                        return self.opt

                                    if (child_yang_name == "osnr"):
                                        if (self.osnr is None):
                                            self.osnr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Osnr()
                                            self.osnr.parent = self
                                            self._children_name_map["osnr"] = "osnr"
                                        return self.osnr

                                    if (child_yang_name == "pcr"):
                                        if (self.pcr is None):
                                            self.pcr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pcr()
                                            self.pcr.parent = self
                                            self._children_name_map["pcr"] = "pcr"
                                        return self.pcr

                                    if (child_yang_name == "pdl"):
                                        if (self.pdl is None):
                                            self.pdl = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pdl()
                                            self.pdl.parent = self
                                            self._children_name_map["pdl"] = "pdl"
                                        return self.pdl

                                    if (child_yang_name == "pmd"):
                                        if (self.pmd is None):
                                            self.pmd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pmd()
                                            self.pmd.parent = self
                                            self._children_name_map["pmd"] = "pmd"
                                        return self.pmd

                                    if (child_yang_name == "pn"):
                                        if (self.pn is None):
                                            self.pn = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.Pn()
                                            self.pn.parent = self
                                            self._children_name_map["pn"] = "pn"
                                        return self.pn

                                    if (child_yang_name == "rx-sig-pow"):
                                        if (self.rx_sig_pow is None):
                                            self.rx_sig_pow = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic.RxSigPow()
                                            self.rx_sig_pow.parent = self
                                            self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                        return self.rx_sig_pow

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "cd" or name == "center-wavelength" or name == "dgd" or name == "lbc" or name == "lbc-pc" or name == "low-sig-freq-off" or name == "opr" or name == "opt" or name == "osnr" or name == "pcr" or name == "pdl" or name == "pmd" or name == "pn" or name == "rx-sig-pow" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.optics_hour24_optic:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.optics_hour24_optic:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "optics-hour24-optics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "optics-hour24-optic"):
                                    for c in self.optics_hour24_optic:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics.OpticsHour24Optic()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.optics_hour24_optic.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-hour24-optic"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OpticsHour24Fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_hour24fec
                            
                            	port 24 hour fec performance data
                            	**type**\: list of    :py:class:`OpticsHour24Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs, self).__init__()

                                self.yang_name = "optics-hour24fecs"
                                self.yang_parent_name = "optics-hour24"

                                self.optics_hour24fec = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs, self).__setattr__(name, value)


                            class OpticsHour24Fec(Entity):
                                """
                                port 24 hour fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec, self).__init__()

                                    self.yang_name = "optics-hour24fec"
                                    self.yang_parent_name = "optics-hour24fecs"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.ec_bits = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"
                                    self._children_yang_names.add("ec-bits")

                                    self.post_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                    self._children_yang_names.add("post-fec-ber")

                                    self.pre_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                    self._children_yang_names.add("pre-fec-ber")

                                    self.q = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"
                                    self._children_yang_names.add("q")

                                    self.qmargin = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._children_yang_names.add("qmargin")

                                    self.uc_words = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"
                                    self._children_yang_names.add("uc-words")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec, self).__setattr__(name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "optics-hour24fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.EcBits, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.EcBits, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ec-bits" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "optics-hour24fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.UcWords, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.UcWords, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uc-words" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "optics-hour24fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PreFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PreFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pre-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "optics-hour24fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PostFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PostFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "post-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "optics-hour24fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Q, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Q, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "q" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "optics-hour24fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Qmargin, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Qmargin, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "qmargin" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.ec_bits is not None and self.ec_bits.has_data()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                        (self.q is not None and self.q.has_data()) or
                                        (self.qmargin is not None and self.qmargin.has_data()) or
                                        (self.uc_words is not None and self.uc_words.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                        (self.q is not None and self.q.has_operation()) or
                                        (self.qmargin is not None and self.qmargin.has_operation()) or
                                        (self.uc_words is not None and self.uc_words.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "optics-hour24fec" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ec-bits"):
                                        if (self.ec_bits is None):
                                            self.ec_bits = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.EcBits()
                                            self.ec_bits.parent = self
                                            self._children_name_map["ec_bits"] = "ec-bits"
                                        return self.ec_bits

                                    if (child_yang_name == "post-fec-ber"):
                                        if (self.post_fec_ber is None):
                                            self.post_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PostFecBer()
                                            self.post_fec_ber.parent = self
                                            self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                        return self.post_fec_ber

                                    if (child_yang_name == "pre-fec-ber"):
                                        if (self.pre_fec_ber is None):
                                            self.pre_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.PreFecBer()
                                            self.pre_fec_ber.parent = self
                                            self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                        return self.pre_fec_ber

                                    if (child_yang_name == "q"):
                                        if (self.q is None):
                                            self.q = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Q()
                                            self.q.parent = self
                                            self._children_name_map["q"] = "q"
                                        return self.q

                                    if (child_yang_name == "qmargin"):
                                        if (self.qmargin is None):
                                            self.qmargin = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.Qmargin()
                                            self.qmargin.parent = self
                                            self._children_name_map["qmargin"] = "qmargin"
                                        return self.qmargin

                                    if (child_yang_name == "uc-words"):
                                        if (self.uc_words is None):
                                            self.uc_words = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec.UcWords()
                                            self.uc_words.parent = self
                                            self._children_name_map["uc_words"] = "uc-words"
                                        return self.uc_words

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.optics_hour24fec:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.optics_hour24fec:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "optics-hour24fecs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "optics-hour24fec"):
                                    for c in self.optics_hour24fec:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs.OpticsHour24Fec()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.optics_hour24fec.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-hour24fec"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.optics_hour24_optics is not None and self.optics_hour24_optics.has_data()) or
                                (self.optics_hour24fecs is not None and self.optics_hour24fecs.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.optics_hour24_optics is not None and self.optics_hour24_optics.has_operation()) or
                                (self.optics_hour24fecs is not None and self.optics_hour24fecs.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "optics-hour24" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "optics-hour24-optics"):
                                if (self.optics_hour24_optics is None):
                                    self.optics_hour24_optics = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Optics()
                                    self.optics_hour24_optics.parent = self
                                    self._children_name_map["optics_hour24_optics"] = "optics-hour24-optics"
                                return self.optics_hour24_optics

                            if (child_yang_name == "optics-hour24fecs"):
                                if (self.optics_hour24fecs is None):
                                    self.optics_hour24fecs = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24.OpticsHour24Fecs()
                                    self.optics_hour24fecs.parent = self
                                    self._children_name_map["optics_hour24fecs"] = "optics-hour24fecs"
                                return self.optics_hour24fecs

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "optics-hour24-optics" or name == "optics-hour24fecs"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OpticsMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: optics_minute15_optics
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsMinute15Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics>`
                        
                        .. attribute:: optics_minute15fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsMinute15Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15, self).__init__()

                            self.yang_name = "optics-minute15"
                            self.yang_parent_name = "optics-current"

                            self.optics_minute15_optics = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics()
                            self.optics_minute15_optics.parent = self
                            self._children_name_map["optics_minute15_optics"] = "optics-minute15-optics"
                            self._children_yang_names.add("optics-minute15-optics")

                            self.optics_minute15fecs = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs()
                            self.optics_minute15fecs.parent = self
                            self._children_name_map["optics_minute15fecs"] = "optics-minute15fecs"
                            self._children_yang_names.add("optics-minute15fecs")


                        class OpticsMinute15Optics(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_minute15_optic
                            
                            	port 15\-minute optics performance data
                            	**type**\: list of    :py:class:`OpticsMinute15Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics, self).__init__()

                                self.yang_name = "optics-minute15-optics"
                                self.yang_parent_name = "optics-minute15"

                                self.optics_minute15_optic = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics, self).__setattr__(name, value)


                            class OpticsMinute15Optic(Entity):
                                """
                                port 15\-minute optics performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic, self).__init__()

                                    self.yang_name = "optics-minute15-optic"
                                    self.yang_parent_name = "optics-minute15-optics"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.cd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd()
                                    self.cd.parent = self
                                    self._children_name_map["cd"] = "cd"
                                    self._children_yang_names.add("cd")

                                    self.center_wavelength = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self._children_name_map["center_wavelength"] = "center-wavelength"
                                    self._children_yang_names.add("center-wavelength")

                                    self.dgd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd()
                                    self.dgd.parent = self
                                    self._children_name_map["dgd"] = "dgd"
                                    self._children_yang_names.add("dgd")

                                    self.lbc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"
                                    self._children_yang_names.add("lbc")

                                    self.lbc_pc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self._children_name_map["lbc_pc"] = "lbc-pc"
                                    self._children_yang_names.add("lbc-pc")

                                    self.low_sig_freq_off = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                    self._children_yang_names.add("low-sig-freq-off")

                                    self.opr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr()
                                    self.opr.parent = self
                                    self._children_name_map["opr"] = "opr"
                                    self._children_yang_names.add("opr")

                                    self.opt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt()
                                    self.opt.parent = self
                                    self._children_name_map["opt"] = "opt"
                                    self._children_yang_names.add("opt")

                                    self.osnr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr()
                                    self.osnr.parent = self
                                    self._children_name_map["osnr"] = "osnr"
                                    self._children_yang_names.add("osnr")

                                    self.pcr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr()
                                    self.pcr.parent = self
                                    self._children_name_map["pcr"] = "pcr"
                                    self._children_yang_names.add("pcr")

                                    self.pdl = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl()
                                    self.pdl.parent = self
                                    self._children_name_map["pdl"] = "pdl"
                                    self._children_yang_names.add("pdl")

                                    self.pmd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd()
                                    self.pmd.parent = self
                                    self._children_name_map["pmd"] = "pmd"
                                    self._children_yang_names.add("pmd")

                                    self.pn = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn()
                                    self.pn.parent = self
                                    self._children_name_map["pn"] = "pn"
                                    self._children_yang_names.add("pn")

                                    self.rx_sig_pow = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                    self._children_yang_names.add("rx-sig-pow")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic, self).__setattr__(name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LbcPc(Entity):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc, self).__init__()

                                        self.yang_name = "lbc-pc"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc-pc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Opt(Entity):
                                    """
                                    OPT
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt, self).__init__()

                                        self.yang_name = "opt"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Opr(Entity):
                                    """
                                    OPR
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr, self).__init__()

                                        self.yang_name = "opr"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Cd(Entity):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd, self).__init__()

                                        self.yang_name = "cd"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "cd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Dgd(Entity):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd, self).__init__()

                                        self.yang_name = "dgd"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dgd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pmd(Entity):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd, self).__init__()

                                        self.yang_name = "pmd"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pmd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Osnr(Entity):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr, self).__init__()

                                        self.yang_name = "osnr"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "osnr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class CenterWavelength(Entity):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength, self).__init__()

                                        self.yang_name = "center-wavelength"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "center-wavelength" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pdl(Entity):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl, self).__init__()

                                        self.yang_name = "pdl"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pdl" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pcr(Entity):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr, self).__init__()

                                        self.yang_name = "pcr"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pcr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pn(Entity):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn, self).__init__()

                                        self.yang_name = "pn"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pn" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class RxSigPow(Entity):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow, self).__init__()

                                        self.yang_name = "rx-sig-pow"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-sig-pow" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LowSigFreqOff(Entity):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff, self).__init__()

                                        self.yang_name = "low-sig-freq-off"
                                        self.yang_parent_name = "optics-minute15-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "low-sig-freq-off" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.cd is not None and self.cd.has_data()) or
                                        (self.center_wavelength is not None and self.center_wavelength.has_data()) or
                                        (self.dgd is not None and self.dgd.has_data()) or
                                        (self.lbc is not None and self.lbc.has_data()) or
                                        (self.lbc_pc is not None and self.lbc_pc.has_data()) or
                                        (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_data()) or
                                        (self.opr is not None and self.opr.has_data()) or
                                        (self.opt is not None and self.opt.has_data()) or
                                        (self.osnr is not None and self.osnr.has_data()) or
                                        (self.pcr is not None and self.pcr.has_data()) or
                                        (self.pdl is not None and self.pdl.has_data()) or
                                        (self.pmd is not None and self.pmd.has_data()) or
                                        (self.pn is not None and self.pn.has_data()) or
                                        (self.rx_sig_pow is not None and self.rx_sig_pow.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.cd is not None and self.cd.has_operation()) or
                                        (self.center_wavelength is not None and self.center_wavelength.has_operation()) or
                                        (self.dgd is not None and self.dgd.has_operation()) or
                                        (self.lbc is not None and self.lbc.has_operation()) or
                                        (self.lbc_pc is not None and self.lbc_pc.has_operation()) or
                                        (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_operation()) or
                                        (self.opr is not None and self.opr.has_operation()) or
                                        (self.opt is not None and self.opt.has_operation()) or
                                        (self.osnr is not None and self.osnr.has_operation()) or
                                        (self.pcr is not None and self.pcr.has_operation()) or
                                        (self.pdl is not None and self.pdl.has_operation()) or
                                        (self.pmd is not None and self.pmd.has_operation()) or
                                        (self.pn is not None and self.pn.has_operation()) or
                                        (self.rx_sig_pow is not None and self.rx_sig_pow.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "optics-minute15-optic" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "cd"):
                                        if (self.cd is None):
                                            self.cd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Cd()
                                            self.cd.parent = self
                                            self._children_name_map["cd"] = "cd"
                                        return self.cd

                                    if (child_yang_name == "center-wavelength"):
                                        if (self.center_wavelength is None):
                                            self.center_wavelength = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.CenterWavelength()
                                            self.center_wavelength.parent = self
                                            self._children_name_map["center_wavelength"] = "center-wavelength"
                                        return self.center_wavelength

                                    if (child_yang_name == "dgd"):
                                        if (self.dgd is None):
                                            self.dgd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Dgd()
                                            self.dgd.parent = self
                                            self._children_name_map["dgd"] = "dgd"
                                        return self.dgd

                                    if (child_yang_name == "lbc"):
                                        if (self.lbc is None):
                                            self.lbc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Lbc()
                                            self.lbc.parent = self
                                            self._children_name_map["lbc"] = "lbc"
                                        return self.lbc

                                    if (child_yang_name == "lbc-pc"):
                                        if (self.lbc_pc is None):
                                            self.lbc_pc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LbcPc()
                                            self.lbc_pc.parent = self
                                            self._children_name_map["lbc_pc"] = "lbc-pc"
                                        return self.lbc_pc

                                    if (child_yang_name == "low-sig-freq-off"):
                                        if (self.low_sig_freq_off is None):
                                            self.low_sig_freq_off = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.LowSigFreqOff()
                                            self.low_sig_freq_off.parent = self
                                            self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                        return self.low_sig_freq_off

                                    if (child_yang_name == "opr"):
                                        if (self.opr is None):
                                            self.opr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opr()
                                            self.opr.parent = self
                                            self._children_name_map["opr"] = "opr"
                                        return self.opr

                                    if (child_yang_name == "opt"):
                                        if (self.opt is None):
                                            self.opt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Opt()
                                            self.opt.parent = self
                                            self._children_name_map["opt"] = "opt"
                                        return self.opt

                                    if (child_yang_name == "osnr"):
                                        if (self.osnr is None):
                                            self.osnr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Osnr()
                                            self.osnr.parent = self
                                            self._children_name_map["osnr"] = "osnr"
                                        return self.osnr

                                    if (child_yang_name == "pcr"):
                                        if (self.pcr is None):
                                            self.pcr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pcr()
                                            self.pcr.parent = self
                                            self._children_name_map["pcr"] = "pcr"
                                        return self.pcr

                                    if (child_yang_name == "pdl"):
                                        if (self.pdl is None):
                                            self.pdl = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pdl()
                                            self.pdl.parent = self
                                            self._children_name_map["pdl"] = "pdl"
                                        return self.pdl

                                    if (child_yang_name == "pmd"):
                                        if (self.pmd is None):
                                            self.pmd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pmd()
                                            self.pmd.parent = self
                                            self._children_name_map["pmd"] = "pmd"
                                        return self.pmd

                                    if (child_yang_name == "pn"):
                                        if (self.pn is None):
                                            self.pn = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.Pn()
                                            self.pn.parent = self
                                            self._children_name_map["pn"] = "pn"
                                        return self.pn

                                    if (child_yang_name == "rx-sig-pow"):
                                        if (self.rx_sig_pow is None):
                                            self.rx_sig_pow = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic.RxSigPow()
                                            self.rx_sig_pow.parent = self
                                            self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                        return self.rx_sig_pow

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "cd" or name == "center-wavelength" or name == "dgd" or name == "lbc" or name == "lbc-pc" or name == "low-sig-freq-off" or name == "opr" or name == "opt" or name == "osnr" or name == "pcr" or name == "pdl" or name == "pmd" or name == "pn" or name == "rx-sig-pow" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.optics_minute15_optic:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.optics_minute15_optic:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "optics-minute15-optics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "optics-minute15-optic"):
                                    for c in self.optics_minute15_optic:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics.OpticsMinute15Optic()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.optics_minute15_optic.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-minute15-optic"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OpticsMinute15Fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_minute15fec
                            
                            	port 15\-minute fec performance data
                            	**type**\: list of    :py:class:`OpticsMinute15Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs, self).__init__()

                                self.yang_name = "optics-minute15fecs"
                                self.yang_parent_name = "optics-minute15"

                                self.optics_minute15fec = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs, self).__setattr__(name, value)


                            class OpticsMinute15Fec(Entity):
                                """
                                port 15\-minute fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec, self).__init__()

                                    self.yang_name = "optics-minute15fec"
                                    self.yang_parent_name = "optics-minute15fecs"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.ec_bits = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"
                                    self._children_yang_names.add("ec-bits")

                                    self.post_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                    self._children_yang_names.add("post-fec-ber")

                                    self.pre_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                    self._children_yang_names.add("pre-fec-ber")

                                    self.q = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"
                                    self._children_yang_names.add("q")

                                    self.qmargin = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._children_yang_names.add("qmargin")

                                    self.uc_words = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"
                                    self._children_yang_names.add("uc-words")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec, self).__setattr__(name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "optics-minute15fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.EcBits, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.EcBits, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ec-bits" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "optics-minute15fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.UcWords, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.UcWords, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uc-words" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "optics-minute15fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PreFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PreFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pre-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "optics-minute15fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PostFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PostFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "post-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "optics-minute15fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Q, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Q, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "q" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "optics-minute15fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Qmargin, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Qmargin, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "qmargin" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.ec_bits is not None and self.ec_bits.has_data()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                        (self.q is not None and self.q.has_data()) or
                                        (self.qmargin is not None and self.qmargin.has_data()) or
                                        (self.uc_words is not None and self.uc_words.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                        (self.q is not None and self.q.has_operation()) or
                                        (self.qmargin is not None and self.qmargin.has_operation()) or
                                        (self.uc_words is not None and self.uc_words.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "optics-minute15fec" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ec-bits"):
                                        if (self.ec_bits is None):
                                            self.ec_bits = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.EcBits()
                                            self.ec_bits.parent = self
                                            self._children_name_map["ec_bits"] = "ec-bits"
                                        return self.ec_bits

                                    if (child_yang_name == "post-fec-ber"):
                                        if (self.post_fec_ber is None):
                                            self.post_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PostFecBer()
                                            self.post_fec_ber.parent = self
                                            self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                        return self.post_fec_ber

                                    if (child_yang_name == "pre-fec-ber"):
                                        if (self.pre_fec_ber is None):
                                            self.pre_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.PreFecBer()
                                            self.pre_fec_ber.parent = self
                                            self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                        return self.pre_fec_ber

                                    if (child_yang_name == "q"):
                                        if (self.q is None):
                                            self.q = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Q()
                                            self.q.parent = self
                                            self._children_name_map["q"] = "q"
                                        return self.q

                                    if (child_yang_name == "qmargin"):
                                        if (self.qmargin is None):
                                            self.qmargin = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.Qmargin()
                                            self.qmargin.parent = self
                                            self._children_name_map["qmargin"] = "qmargin"
                                        return self.qmargin

                                    if (child_yang_name == "uc-words"):
                                        if (self.uc_words is None):
                                            self.uc_words = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec.UcWords()
                                            self.uc_words.parent = self
                                            self._children_name_map["uc_words"] = "uc-words"
                                        return self.uc_words

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.optics_minute15fec:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.optics_minute15fec:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "optics-minute15fecs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "optics-minute15fec"):
                                    for c in self.optics_minute15fec:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs.OpticsMinute15Fec()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.optics_minute15fec.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-minute15fec"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.optics_minute15_optics is not None and self.optics_minute15_optics.has_data()) or
                                (self.optics_minute15fecs is not None and self.optics_minute15fecs.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.optics_minute15_optics is not None and self.optics_minute15_optics.has_operation()) or
                                (self.optics_minute15fecs is not None and self.optics_minute15fecs.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "optics-minute15" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "optics-minute15-optics"):
                                if (self.optics_minute15_optics is None):
                                    self.optics_minute15_optics = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Optics()
                                    self.optics_minute15_optics.parent = self
                                    self._children_name_map["optics_minute15_optics"] = "optics-minute15-optics"
                                return self.optics_minute15_optics

                            if (child_yang_name == "optics-minute15fecs"):
                                if (self.optics_minute15fecs is None):
                                    self.optics_minute15fecs = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15.OpticsMinute15Fecs()
                                    self.optics_minute15fecs.parent = self
                                    self._children_name_map["optics_minute15fecs"] = "optics-minute15fecs"
                                return self.optics_minute15fecs

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "optics-minute15-optics" or name == "optics-minute15fecs"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OpticsSecond30(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: optics_second30_optics
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsSecond30Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics>`
                        
                        .. attribute:: optics_second30fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsSecond30Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30, self).__init__()

                            self.yang_name = "optics-second30"
                            self.yang_parent_name = "optics-current"

                            self.optics_second30_optics = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics()
                            self.optics_second30_optics.parent = self
                            self._children_name_map["optics_second30_optics"] = "optics-second30-optics"
                            self._children_yang_names.add("optics-second30-optics")

                            self.optics_second30fecs = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs()
                            self.optics_second30fecs.parent = self
                            self._children_name_map["optics_second30fecs"] = "optics-second30fecs"
                            self._children_yang_names.add("optics-second30fecs")


                        class OpticsSecond30Fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_second30fec
                            
                            	port 30\-second fec performance data
                            	**type**\: list of    :py:class:`OpticsSecond30Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs, self).__init__()

                                self.yang_name = "optics-second30fecs"
                                self.yang_parent_name = "optics-second30"

                                self.optics_second30fec = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs, self).__setattr__(name, value)


                            class OpticsSecond30Fec(Entity):
                                """
                                port 30\-second fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec, self).__init__()

                                    self.yang_name = "optics-second30fec"
                                    self.yang_parent_name = "optics-second30fecs"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.ec_bits = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"
                                    self._children_yang_names.add("ec-bits")

                                    self.post_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                    self._children_yang_names.add("post-fec-ber")

                                    self.pre_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                    self._children_yang_names.add("pre-fec-ber")

                                    self.q = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"
                                    self._children_yang_names.add("q")

                                    self.qmargin = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._children_yang_names.add("qmargin")

                                    self.uc_words = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"
                                    self._children_yang_names.add("uc-words")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec, self).__setattr__(name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "optics-second30fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.EcBits, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.EcBits, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ec-bits" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "optics-second30fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.UcWords, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.UcWords, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uc-words" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "optics-second30fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PreFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PreFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pre-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "optics-second30fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PostFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PostFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "post-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "optics-second30fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Q, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Q, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "q" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "optics-second30fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Qmargin, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Qmargin, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "qmargin" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.ec_bits is not None and self.ec_bits.has_data()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                        (self.q is not None and self.q.has_data()) or
                                        (self.qmargin is not None and self.qmargin.has_data()) or
                                        (self.uc_words is not None and self.uc_words.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                        (self.q is not None and self.q.has_operation()) or
                                        (self.qmargin is not None and self.qmargin.has_operation()) or
                                        (self.uc_words is not None and self.uc_words.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "optics-second30fec" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ec-bits"):
                                        if (self.ec_bits is None):
                                            self.ec_bits = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.EcBits()
                                            self.ec_bits.parent = self
                                            self._children_name_map["ec_bits"] = "ec-bits"
                                        return self.ec_bits

                                    if (child_yang_name == "post-fec-ber"):
                                        if (self.post_fec_ber is None):
                                            self.post_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PostFecBer()
                                            self.post_fec_ber.parent = self
                                            self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                        return self.post_fec_ber

                                    if (child_yang_name == "pre-fec-ber"):
                                        if (self.pre_fec_ber is None):
                                            self.pre_fec_ber = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.PreFecBer()
                                            self.pre_fec_ber.parent = self
                                            self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                        return self.pre_fec_ber

                                    if (child_yang_name == "q"):
                                        if (self.q is None):
                                            self.q = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Q()
                                            self.q.parent = self
                                            self._children_name_map["q"] = "q"
                                        return self.q

                                    if (child_yang_name == "qmargin"):
                                        if (self.qmargin is None):
                                            self.qmargin = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.Qmargin()
                                            self.qmargin.parent = self
                                            self._children_name_map["qmargin"] = "qmargin"
                                        return self.qmargin

                                    if (child_yang_name == "uc-words"):
                                        if (self.uc_words is None):
                                            self.uc_words = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec.UcWords()
                                            self.uc_words.parent = self
                                            self._children_name_map["uc_words"] = "uc-words"
                                        return self.uc_words

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.optics_second30fec:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.optics_second30fec:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "optics-second30fecs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "optics-second30fec"):
                                    for c in self.optics_second30fec:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs.OpticsSecond30Fec()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.optics_second30fec.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-second30fec"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OpticsSecond30Optics(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_second30_optic
                            
                            	port 30\-second optics performance data
                            	**type**\: list of    :py:class:`OpticsSecond30Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics, self).__init__()

                                self.yang_name = "optics-second30-optics"
                                self.yang_parent_name = "optics-second30"

                                self.optics_second30_optic = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics, self).__setattr__(name, value)


                            class OpticsSecond30Optic(Entity):
                                """
                                port 30\-second optics performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic, self).__init__()

                                    self.yang_name = "optics-second30-optic"
                                    self.yang_parent_name = "optics-second30-optics"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.cd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd()
                                    self.cd.parent = self
                                    self._children_name_map["cd"] = "cd"
                                    self._children_yang_names.add("cd")

                                    self.center_wavelength = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self._children_name_map["center_wavelength"] = "center-wavelength"
                                    self._children_yang_names.add("center-wavelength")

                                    self.dgd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd()
                                    self.dgd.parent = self
                                    self._children_name_map["dgd"] = "dgd"
                                    self._children_yang_names.add("dgd")

                                    self.lbc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"
                                    self._children_yang_names.add("lbc")

                                    self.lbc_pc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self._children_name_map["lbc_pc"] = "lbc-pc"
                                    self._children_yang_names.add("lbc-pc")

                                    self.low_sig_freq_off = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                    self._children_yang_names.add("low-sig-freq-off")

                                    self.opr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr()
                                    self.opr.parent = self
                                    self._children_name_map["opr"] = "opr"
                                    self._children_yang_names.add("opr")

                                    self.opt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt()
                                    self.opt.parent = self
                                    self._children_name_map["opt"] = "opt"
                                    self._children_yang_names.add("opt")

                                    self.osnr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr()
                                    self.osnr.parent = self
                                    self._children_name_map["osnr"] = "osnr"
                                    self._children_yang_names.add("osnr")

                                    self.pcr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr()
                                    self.pcr.parent = self
                                    self._children_name_map["pcr"] = "pcr"
                                    self._children_yang_names.add("pcr")

                                    self.pdl = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl()
                                    self.pdl.parent = self
                                    self._children_name_map["pdl"] = "pdl"
                                    self._children_yang_names.add("pdl")

                                    self.pmd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd()
                                    self.pmd.parent = self
                                    self._children_name_map["pmd"] = "pmd"
                                    self._children_yang_names.add("pmd")

                                    self.pn = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn()
                                    self.pn.parent = self
                                    self._children_name_map["pn"] = "pn"
                                    self._children_yang_names.add("pn")

                                    self.rx_sig_pow = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                    self._children_yang_names.add("rx-sig-pow")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic, self).__setattr__(name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LbcPc(Entity):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc, self).__init__()

                                        self.yang_name = "lbc-pc"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc-pc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Opt(Entity):
                                    """
                                    OPT
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt, self).__init__()

                                        self.yang_name = "opt"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Opr(Entity):
                                    """
                                    OPR
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr, self).__init__()

                                        self.yang_name = "opr"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Cd(Entity):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd, self).__init__()

                                        self.yang_name = "cd"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "cd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Dgd(Entity):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd, self).__init__()

                                        self.yang_name = "dgd"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dgd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pmd(Entity):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd, self).__init__()

                                        self.yang_name = "pmd"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pmd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Osnr(Entity):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr, self).__init__()

                                        self.yang_name = "osnr"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "osnr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class CenterWavelength(Entity):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength, self).__init__()

                                        self.yang_name = "center-wavelength"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "center-wavelength" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pdl(Entity):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl, self).__init__()

                                        self.yang_name = "pdl"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pdl" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pcr(Entity):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr, self).__init__()

                                        self.yang_name = "pcr"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pcr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pn(Entity):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn, self).__init__()

                                        self.yang_name = "pn"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pn" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class RxSigPow(Entity):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow, self).__init__()

                                        self.yang_name = "rx-sig-pow"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-sig-pow" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LowSigFreqOff(Entity):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff, self).__init__()

                                        self.yang_name = "low-sig-freq-off"
                                        self.yang_parent_name = "optics-second30-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "low-sig-freq-off" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.cd is not None and self.cd.has_data()) or
                                        (self.center_wavelength is not None and self.center_wavelength.has_data()) or
                                        (self.dgd is not None and self.dgd.has_data()) or
                                        (self.lbc is not None and self.lbc.has_data()) or
                                        (self.lbc_pc is not None and self.lbc_pc.has_data()) or
                                        (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_data()) or
                                        (self.opr is not None and self.opr.has_data()) or
                                        (self.opt is not None and self.opt.has_data()) or
                                        (self.osnr is not None and self.osnr.has_data()) or
                                        (self.pcr is not None and self.pcr.has_data()) or
                                        (self.pdl is not None and self.pdl.has_data()) or
                                        (self.pmd is not None and self.pmd.has_data()) or
                                        (self.pn is not None and self.pn.has_data()) or
                                        (self.rx_sig_pow is not None and self.rx_sig_pow.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.cd is not None and self.cd.has_operation()) or
                                        (self.center_wavelength is not None and self.center_wavelength.has_operation()) or
                                        (self.dgd is not None and self.dgd.has_operation()) or
                                        (self.lbc is not None and self.lbc.has_operation()) or
                                        (self.lbc_pc is not None and self.lbc_pc.has_operation()) or
                                        (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_operation()) or
                                        (self.opr is not None and self.opr.has_operation()) or
                                        (self.opt is not None and self.opt.has_operation()) or
                                        (self.osnr is not None and self.osnr.has_operation()) or
                                        (self.pcr is not None and self.pcr.has_operation()) or
                                        (self.pdl is not None and self.pdl.has_operation()) or
                                        (self.pmd is not None and self.pmd.has_operation()) or
                                        (self.pn is not None and self.pn.has_operation()) or
                                        (self.rx_sig_pow is not None and self.rx_sig_pow.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "optics-second30-optic" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "cd"):
                                        if (self.cd is None):
                                            self.cd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Cd()
                                            self.cd.parent = self
                                            self._children_name_map["cd"] = "cd"
                                        return self.cd

                                    if (child_yang_name == "center-wavelength"):
                                        if (self.center_wavelength is None):
                                            self.center_wavelength = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.CenterWavelength()
                                            self.center_wavelength.parent = self
                                            self._children_name_map["center_wavelength"] = "center-wavelength"
                                        return self.center_wavelength

                                    if (child_yang_name == "dgd"):
                                        if (self.dgd is None):
                                            self.dgd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Dgd()
                                            self.dgd.parent = self
                                            self._children_name_map["dgd"] = "dgd"
                                        return self.dgd

                                    if (child_yang_name == "lbc"):
                                        if (self.lbc is None):
                                            self.lbc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Lbc()
                                            self.lbc.parent = self
                                            self._children_name_map["lbc"] = "lbc"
                                        return self.lbc

                                    if (child_yang_name == "lbc-pc"):
                                        if (self.lbc_pc is None):
                                            self.lbc_pc = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LbcPc()
                                            self.lbc_pc.parent = self
                                            self._children_name_map["lbc_pc"] = "lbc-pc"
                                        return self.lbc_pc

                                    if (child_yang_name == "low-sig-freq-off"):
                                        if (self.low_sig_freq_off is None):
                                            self.low_sig_freq_off = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.LowSigFreqOff()
                                            self.low_sig_freq_off.parent = self
                                            self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                        return self.low_sig_freq_off

                                    if (child_yang_name == "opr"):
                                        if (self.opr is None):
                                            self.opr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opr()
                                            self.opr.parent = self
                                            self._children_name_map["opr"] = "opr"
                                        return self.opr

                                    if (child_yang_name == "opt"):
                                        if (self.opt is None):
                                            self.opt = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Opt()
                                            self.opt.parent = self
                                            self._children_name_map["opt"] = "opt"
                                        return self.opt

                                    if (child_yang_name == "osnr"):
                                        if (self.osnr is None):
                                            self.osnr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Osnr()
                                            self.osnr.parent = self
                                            self._children_name_map["osnr"] = "osnr"
                                        return self.osnr

                                    if (child_yang_name == "pcr"):
                                        if (self.pcr is None):
                                            self.pcr = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pcr()
                                            self.pcr.parent = self
                                            self._children_name_map["pcr"] = "pcr"
                                        return self.pcr

                                    if (child_yang_name == "pdl"):
                                        if (self.pdl is None):
                                            self.pdl = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pdl()
                                            self.pdl.parent = self
                                            self._children_name_map["pdl"] = "pdl"
                                        return self.pdl

                                    if (child_yang_name == "pmd"):
                                        if (self.pmd is None):
                                            self.pmd = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pmd()
                                            self.pmd.parent = self
                                            self._children_name_map["pmd"] = "pmd"
                                        return self.pmd

                                    if (child_yang_name == "pn"):
                                        if (self.pn is None):
                                            self.pn = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.Pn()
                                            self.pn.parent = self
                                            self._children_name_map["pn"] = "pn"
                                        return self.pn

                                    if (child_yang_name == "rx-sig-pow"):
                                        if (self.rx_sig_pow is None):
                                            self.rx_sig_pow = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic.RxSigPow()
                                            self.rx_sig_pow.parent = self
                                            self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                        return self.rx_sig_pow

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "cd" or name == "center-wavelength" or name == "dgd" or name == "lbc" or name == "lbc-pc" or name == "low-sig-freq-off" or name == "opr" or name == "opt" or name == "osnr" or name == "pcr" or name == "pdl" or name == "pmd" or name == "pn" or name == "rx-sig-pow" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.optics_second30_optic:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.optics_second30_optic:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "optics-second30-optics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "optics-second30-optic"):
                                    for c in self.optics_second30_optic:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics.OpticsSecond30Optic()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.optics_second30_optic.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-second30-optic"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.optics_second30_optics is not None and self.optics_second30_optics.has_data()) or
                                (self.optics_second30fecs is not None and self.optics_second30fecs.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.optics_second30_optics is not None and self.optics_second30_optics.has_operation()) or
                                (self.optics_second30fecs is not None and self.optics_second30fecs.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "optics-second30" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "optics-second30-optics"):
                                if (self.optics_second30_optics is None):
                                    self.optics_second30_optics = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Optics()
                                    self.optics_second30_optics.parent = self
                                    self._children_name_map["optics_second30_optics"] = "optics-second30-optics"
                                return self.optics_second30_optics

                            if (child_yang_name == "optics-second30fecs"):
                                if (self.optics_second30fecs is None):
                                    self.optics_second30fecs = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30.OpticsSecond30Fecs()
                                    self.optics_second30fecs.parent = self
                                    self._children_name_map["optics_second30fecs"] = "optics-second30fecs"
                                return self.optics_second30fecs

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "optics-second30-optics" or name == "optics-second30fecs"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.optics_hour24 is not None and self.optics_hour24.has_data()) or
                            (self.optics_minute15 is not None and self.optics_minute15.has_data()) or
                            (self.optics_second30 is not None and self.optics_second30.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.optics_hour24 is not None and self.optics_hour24.has_operation()) or
                            (self.optics_minute15 is not None and self.optics_minute15.has_operation()) or
                            (self.optics_second30 is not None and self.optics_second30.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "optics-current" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "optics-hour24"):
                            if (self.optics_hour24 is None):
                                self.optics_hour24 = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsHour24()
                                self.optics_hour24.parent = self
                                self._children_name_map["optics_hour24"] = "optics-hour24"
                            return self.optics_hour24

                        if (child_yang_name == "optics-minute15"):
                            if (self.optics_minute15 is None):
                                self.optics_minute15 = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsMinute15()
                                self.optics_minute15.parent = self
                                self._children_name_map["optics_minute15"] = "optics-minute15"
                            return self.optics_minute15

                        if (child_yang_name == "optics-second30"):
                            if (self.optics_second30 is None):
                                self.optics_second30 = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent.OpticsSecond30()
                                self.optics_second30.parent = self
                                self._children_name_map["optics_second30"] = "optics-second30"
                            return self.optics_second30

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "optics-hour24" or name == "optics-minute15" or name == "optics-second30"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.name.is_set or
                        (self.optics_current is not None and self.optics_current.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        (self.optics_current is not None and self.optics_current.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "optics-port" + "[name='" + self.name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/optics/optics-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "optics-current"):
                        if (self.optics_current is None):
                            self.optics_current = PerformanceManagement.Optics.OpticsPorts.OpticsPort.OpticsCurrent()
                            self.optics_current.parent = self
                            self._children_name_map["optics_current"] = "optics-current"
                        return self.optics_current

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "optics-current" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.optics_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.optics_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "optics-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/optics/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "optics-port"):
                    for c in self.optics_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = PerformanceManagement.Optics.OpticsPorts.OpticsPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.optics_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "optics-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.optics_ports is not None and self.optics_ports.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.optics_ports is not None and self.optics_ports.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "optics" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "optics-ports"):
                if (self.optics_ports is None):
                    self.optics_ports = PerformanceManagement.Optics.OpticsPorts()
                    self.optics_ports.parent = self
                    self._children_name_map["optics_ports"] = "optics-ports"
                return self.optics_ports

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "optics-ports"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Sts(Entity):
        """
        STS controller performance data
        
        .. attribute:: sts_ports
        
        	Port performance data
        	**type**\:   :py:class:`StsPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PerformanceManagement.Sts, self).__init__()

            self.yang_name = "sts"
            self.yang_parent_name = "performance-management"

            self.sts_ports = PerformanceManagement.Sts.StsPorts()
            self.sts_ports.parent = self
            self._children_name_map["sts_ports"] = "sts-ports"
            self._children_yang_names.add("sts-ports")


        class StsPorts(Entity):
            """
            Port performance data
            
            .. attribute:: sts_port
            
            	Port performance data
            	**type**\: list of    :py:class:`StsPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PerformanceManagement.Sts.StsPorts, self).__init__()

                self.yang_name = "sts-ports"
                self.yang_parent_name = "sts"

                self.sts_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(PerformanceManagement.Sts.StsPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(PerformanceManagement.Sts.StsPorts, self).__setattr__(name, value)


            class StsPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: sts_current
                
                	port current performance data
                	**type**\:   :py:class:`StsCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagement.Sts.StsPorts.StsPort, self).__init__()

                    self.yang_name = "sts-port"
                    self.yang_parent_name = "sts-ports"

                    self.name = YLeaf(YType.str, "name")

                    self.sts_current = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent()
                    self.sts_current.parent = self
                    self._children_name_map["sts_current"] = "sts-current"
                    self._children_yang_names.add("sts-current")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PerformanceManagement.Sts.StsPorts.StsPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PerformanceManagement.Sts.StsPorts.StsPort, self).__setattr__(name, value)


                class StsCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: sts_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`StsHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24>`
                    
                    .. attribute:: sts_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`StsMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent, self).__init__()

                        self.yang_name = "sts-current"
                        self.yang_parent_name = "sts-port"

                        self.sts_hour24 = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24()
                        self.sts_hour24.parent = self
                        self._children_name_map["sts_hour24"] = "sts-hour24"
                        self._children_yang_names.add("sts-hour24")

                        self.sts_minute15 = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15()
                        self.sts_minute15.parent = self
                        self._children_name_map["sts_minute15"] = "sts-minute15"
                        self._children_yang_names.add("sts-minute15")


                    class StsMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: sts_minute15_paths
                        
                        	port current performance data
                        	**type**\:   :py:class:`StsMinute15Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15, self).__init__()

                            self.yang_name = "sts-minute15"
                            self.yang_parent_name = "sts-current"

                            self.sts_minute15_paths = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths()
                            self.sts_minute15_paths.parent = self
                            self._children_name_map["sts_minute15_paths"] = "sts-minute15-paths"
                            self._children_yang_names.add("sts-minute15-paths")


                        class StsMinute15Paths(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sts_minute15_path
                            
                            	port 15\-minute Path performance data
                            	**type**\: list of    :py:class:`StsMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths, self).__init__()

                                self.yang_name = "sts-minute15-paths"
                                self.yang_parent_name = "sts-minute15"

                                self.sts_minute15_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths, self).__setattr__(name, value)


                            class StsMinute15Path(Entity):
                                """
                                port 15\-minute Path performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path, self).__init__()

                                    self.yang_name = "sts-minute15-path"
                                    self.yang_parent_name = "sts-minute15-paths"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.fe_path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath()
                                    self.fe_path.parent = self
                                    self._children_name_map["fe_path"] = "fe-path"
                                    self._children_yang_names.add("fe-path")

                                    self.path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path()
                                    self.path.parent = self
                                    self._children_name_map["path"] = "path"
                                    self._children_yang_names.add("path")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path, self).__setattr__(name, value)


                                class Path(Entity):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs>`
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_width
                                    
                                    	Indicates the type of the SONET/SDH Path
                                    	**type**\:   :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "sts-minute15-path"

                                        self.path_status = YLeaf(YType.int32, "path-status")

                                        self.path_width = YLeaf(YType.enumeration, "path-width")

                                        self.path_c_vs = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs()
                                        self.path_c_vs.parent = self
                                        self._children_name_map["path_c_vs"] = "path-c-vs"
                                        self._children_yang_names.add("path-c-vs")

                                        self.path_e_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self._children_name_map["path_e_ss"] = "path-e-ss"
                                        self._children_yang_names.add("path-e-ss")

                                        self.path_se_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self._children_name_map["path_se_ss"] = "path-se-ss"
                                        self._children_yang_names.add("path-se-ss")

                                        self.path_ua_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                        self._children_yang_names.add("path-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_status",
                                                        "path_width") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path, self).__setattr__(name, value)


                                    class PathESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs, self).__init__()

                                            self.yang_name = "path-e-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs, self).__init__()

                                            self.yang_name = "path-se-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs, self).__init__()

                                            self.yang_name = "path-c-vs"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs, self).__init__()

                                            self.yang_name = "path-ua-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_status.is_set or
                                            self.path_width.is_set or
                                            (self.path_c_vs is not None and self.path_c_vs.has_data()) or
                                            (self.path_e_ss is not None and self.path_e_ss.has_data()) or
                                            (self.path_se_ss is not None and self.path_se_ss.has_data()) or
                                            (self.path_ua_ss is not None and self.path_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_status.yfilter != YFilter.not_set or
                                            self.path_width.yfilter != YFilter.not_set or
                                            (self.path_c_vs is not None and self.path_c_vs.has_operation()) or
                                            (self.path_e_ss is not None and self.path_e_ss.has_operation()) or
                                            (self.path_se_ss is not None and self.path_se_ss.has_operation()) or
                                            (self.path_ua_ss is not None and self.path_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_status.get_name_leafdata())
                                        if (self.path_width.is_set or self.path_width.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_width.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "path-c-vs"):
                                            if (self.path_c_vs is None):
                                                self.path_c_vs = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathCVs()
                                                self.path_c_vs.parent = self
                                                self._children_name_map["path_c_vs"] = "path-c-vs"
                                            return self.path_c_vs

                                        if (child_yang_name == "path-e-ss"):
                                            if (self.path_e_ss is None):
                                                self.path_e_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathESs()
                                                self.path_e_ss.parent = self
                                                self._children_name_map["path_e_ss"] = "path-e-ss"
                                            return self.path_e_ss

                                        if (child_yang_name == "path-se-ss"):
                                            if (self.path_se_ss is None):
                                                self.path_se_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathSeSs()
                                                self.path_se_ss.parent = self
                                                self._children_name_map["path_se_ss"] = "path-se-ss"
                                            return self.path_se_ss

                                        if (child_yang_name == "path-ua-ss"):
                                            if (self.path_ua_ss is None):
                                                self.path_ua_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path.PathUaSs()
                                                self.path_ua_ss.parent = self
                                                self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                            return self.path_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "path-c-vs" or name == "path-e-ss" or name == "path-se-ss" or name == "path-ua-ss" or name == "path-status" or name == "path-width"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-status"):
                                            self.path_status = value
                                            self.path_status.value_namespace = name_space
                                            self.path_status.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-width"):
                                            self.path_width = value
                                            self.path_width.value_namespace = name_space
                                            self.path_width.value_namespace_prefix = name_space_prefix


                                class FePath(Entity):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath, self).__init__()

                                        self.yang_name = "fe-path"
                                        self.yang_parent_name = "sts-minute15-path"

                                        self.far_end_path_c_vs = YLeaf(YType.uint32, "far-end-path-c-vs")

                                        self.far_end_path_e_ss = YLeaf(YType.uint32, "far-end-path-e-ss")

                                        self.far_end_path_se_ss = YLeaf(YType.uint32, "far-end-path-se-ss")

                                        self.far_end_path_ua_ss = YLeaf(YType.uint32, "far-end-path-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("far_end_path_c_vs",
                                                        "far_end_path_e_ss",
                                                        "far_end_path_se_ss",
                                                        "far_end_path_ua_ss") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.far_end_path_c_vs.is_set or
                                            self.far_end_path_e_ss.is_set or
                                            self.far_end_path_se_ss.is_set or
                                            self.far_end_path_ua_ss.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.far_end_path_c_vs.yfilter != YFilter.not_set or
                                            self.far_end_path_e_ss.yfilter != YFilter.not_set or
                                            self.far_end_path_se_ss.yfilter != YFilter.not_set or
                                            self.far_end_path_ua_ss.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fe-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.far_end_path_c_vs.is_set or self.far_end_path_c_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_c_vs.get_name_leafdata())
                                        if (self.far_end_path_e_ss.is_set or self.far_end_path_e_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_e_ss.get_name_leafdata())
                                        if (self.far_end_path_se_ss.is_set or self.far_end_path_se_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_se_ss.get_name_leafdata())
                                        if (self.far_end_path_ua_ss.is_set or self.far_end_path_ua_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_ua_ss.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "far-end-path-c-vs" or name == "far-end-path-e-ss" or name == "far-end-path-se-ss" or name == "far-end-path-ua-ss"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "far-end-path-c-vs"):
                                            self.far_end_path_c_vs = value
                                            self.far_end_path_c_vs.value_namespace = name_space
                                            self.far_end_path_c_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-e-ss"):
                                            self.far_end_path_e_ss = value
                                            self.far_end_path_e_ss.value_namespace = name_space
                                            self.far_end_path_e_ss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-se-ss"):
                                            self.far_end_path_se_ss = value
                                            self.far_end_path_se_ss.value_namespace = name_space
                                            self.far_end_path_se_ss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-ua-ss"):
                                            self.far_end_path_ua_ss = value
                                            self.far_end_path_ua_ss.value_namespace = name_space
                                            self.far_end_path_ua_ss.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.fe_path is not None and self.fe_path.has_data()) or
                                        (self.path is not None and self.path.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.fe_path is not None and self.fe_path.has_operation()) or
                                        (self.path is not None and self.path.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sts-minute15-path" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "fe-path"):
                                        if (self.fe_path is None):
                                            self.fe_path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.FePath()
                                            self.fe_path.parent = self
                                            self._children_name_map["fe_path"] = "fe-path"
                                        return self.fe_path

                                    if (child_yang_name == "path"):
                                        if (self.path is None):
                                            self.path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path.Path()
                                            self.path.parent = self
                                            self._children_name_map["path"] = "path"
                                        return self.path

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fe-path" or name == "path" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.sts_minute15_path:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.sts_minute15_path:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sts-minute15-paths" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sts-minute15-path"):
                                    for c in self.sts_minute15_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths.StsMinute15Path()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.sts_minute15_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sts-minute15-path"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.sts_minute15_paths is not None and self.sts_minute15_paths.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.sts_minute15_paths is not None and self.sts_minute15_paths.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sts-minute15" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sts-minute15-paths"):
                                if (self.sts_minute15_paths is None):
                                    self.sts_minute15_paths = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15.StsMinute15Paths()
                                    self.sts_minute15_paths.parent = self
                                    self._children_name_map["sts_minute15_paths"] = "sts-minute15-paths"
                                return self.sts_minute15_paths

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sts-minute15-paths"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class StsHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: sts_hour24_paths
                        
                        	port current performance data
                        	**type**\:   :py:class:`StsHour24Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24, self).__init__()

                            self.yang_name = "sts-hour24"
                            self.yang_parent_name = "sts-current"

                            self.sts_hour24_paths = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths()
                            self.sts_hour24_paths.parent = self
                            self._children_name_map["sts_hour24_paths"] = "sts-hour24-paths"
                            self._children_yang_names.add("sts-hour24-paths")


                        class StsHour24Paths(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sts_hour24_path
                            
                            	port 24 hour Path performance data
                            	**type**\: list of    :py:class:`StsHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths, self).__init__()

                                self.yang_name = "sts-hour24-paths"
                                self.yang_parent_name = "sts-hour24"

                                self.sts_hour24_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths, self).__setattr__(name, value)


                            class StsHour24Path(Entity):
                                """
                                port 24 hour Path performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_path
                                
                                	Far End PATH
                                	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: path
                                
                                	PATH
                                	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path, self).__init__()

                                    self.yang_name = "sts-hour24-path"
                                    self.yang_parent_name = "sts-hour24-paths"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.fe_path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath()
                                    self.fe_path.parent = self
                                    self._children_name_map["fe_path"] = "fe-path"
                                    self._children_yang_names.add("fe-path")

                                    self.path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path()
                                    self.path.parent = self
                                    self._children_name_map["path"] = "path"
                                    self._children_yang_names.add("path")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path, self).__setattr__(name, value)


                                class Path(Entity):
                                    """
                                    PATH
                                    
                                    .. attribute:: path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs>`
                                    
                                    .. attribute:: path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs>`
                                    
                                    .. attribute:: path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs>`
                                    
                                    .. attribute:: path_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs>`
                                    
                                    .. attribute:: path_width
                                    
                                    	Indicates the type of the SONET/SDH Path
                                    	**type**\:   :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "sts-hour24-path"

                                        self.path_status = YLeaf(YType.int32, "path-status")

                                        self.path_width = YLeaf(YType.enumeration, "path-width")

                                        self.path_c_vs = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs()
                                        self.path_c_vs.parent = self
                                        self._children_name_map["path_c_vs"] = "path-c-vs"
                                        self._children_yang_names.add("path-c-vs")

                                        self.path_e_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs()
                                        self.path_e_ss.parent = self
                                        self._children_name_map["path_e_ss"] = "path-e-ss"
                                        self._children_yang_names.add("path-e-ss")

                                        self.path_se_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs()
                                        self.path_se_ss.parent = self
                                        self._children_name_map["path_se_ss"] = "path-se-ss"
                                        self._children_yang_names.add("path-se-ss")

                                        self.path_ua_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs()
                                        self.path_ua_ss.parent = self
                                        self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                        self._children_yang_names.add("path-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("path_status",
                                                        "path_width") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path, self).__setattr__(name, value)


                                    class PathESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs, self).__init__()

                                            self.yang_name = "path-e-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs, self).__init__()

                                            self.yang_name = "path-se-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs, self).__init__()

                                            self.yang_name = "path-c-vs"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class PathUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs, self).__init__()

                                            self.yang_name = "path-ua-ss"
                                            self.yang_parent_name = "path"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "path-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.path_status.is_set or
                                            self.path_width.is_set or
                                            (self.path_c_vs is not None and self.path_c_vs.has_data()) or
                                            (self.path_e_ss is not None and self.path_e_ss.has_data()) or
                                            (self.path_se_ss is not None and self.path_se_ss.has_data()) or
                                            (self.path_ua_ss is not None and self.path_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.path_status.yfilter != YFilter.not_set or
                                            self.path_width.yfilter != YFilter.not_set or
                                            (self.path_c_vs is not None and self.path_c_vs.has_operation()) or
                                            (self.path_e_ss is not None and self.path_e_ss.has_operation()) or
                                            (self.path_se_ss is not None and self.path_se_ss.has_operation()) or
                                            (self.path_ua_ss is not None and self.path_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_status.get_name_leafdata())
                                        if (self.path_width.is_set or self.path_width.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.path_width.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "path-c-vs"):
                                            if (self.path_c_vs is None):
                                                self.path_c_vs = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathCVs()
                                                self.path_c_vs.parent = self
                                                self._children_name_map["path_c_vs"] = "path-c-vs"
                                            return self.path_c_vs

                                        if (child_yang_name == "path-e-ss"):
                                            if (self.path_e_ss is None):
                                                self.path_e_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathESs()
                                                self.path_e_ss.parent = self
                                                self._children_name_map["path_e_ss"] = "path-e-ss"
                                            return self.path_e_ss

                                        if (child_yang_name == "path-se-ss"):
                                            if (self.path_se_ss is None):
                                                self.path_se_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathSeSs()
                                                self.path_se_ss.parent = self
                                                self._children_name_map["path_se_ss"] = "path-se-ss"
                                            return self.path_se_ss

                                        if (child_yang_name == "path-ua-ss"):
                                            if (self.path_ua_ss is None):
                                                self.path_ua_ss = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path.PathUaSs()
                                                self.path_ua_ss.parent = self
                                                self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                            return self.path_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "path-c-vs" or name == "path-e-ss" or name == "path-se-ss" or name == "path-ua-ss" or name == "path-status" or name == "path-width"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "path-status"):
                                            self.path_status = value
                                            self.path_status.value_namespace = name_space
                                            self.path_status.value_namespace_prefix = name_space_prefix
                                        if(value_path == "path-width"):
                                            self.path_width = value
                                            self.path_width.value_namespace = name_space
                                            self.path_width.value_namespace_prefix = name_space_prefix


                                class FePath(Entity):
                                    """
                                    Far End PATH
                                    
                                    .. attribute:: far_end_path_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: far_end_path_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: far_end_path_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath, self).__init__()

                                        self.yang_name = "fe-path"
                                        self.yang_parent_name = "sts-hour24-path"

                                        self.far_end_path_c_vs = YLeaf(YType.uint32, "far-end-path-c-vs")

                                        self.far_end_path_e_ss = YLeaf(YType.uint32, "far-end-path-e-ss")

                                        self.far_end_path_se_ss = YLeaf(YType.uint32, "far-end-path-se-ss")

                                        self.far_end_path_ua_ss = YLeaf(YType.uint32, "far-end-path-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("far_end_path_c_vs",
                                                        "far_end_path_e_ss",
                                                        "far_end_path_se_ss",
                                                        "far_end_path_ua_ss") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.far_end_path_c_vs.is_set or
                                            self.far_end_path_e_ss.is_set or
                                            self.far_end_path_se_ss.is_set or
                                            self.far_end_path_ua_ss.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.far_end_path_c_vs.yfilter != YFilter.not_set or
                                            self.far_end_path_e_ss.yfilter != YFilter.not_set or
                                            self.far_end_path_se_ss.yfilter != YFilter.not_set or
                                            self.far_end_path_ua_ss.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fe-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.far_end_path_c_vs.is_set or self.far_end_path_c_vs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_c_vs.get_name_leafdata())
                                        if (self.far_end_path_e_ss.is_set or self.far_end_path_e_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_e_ss.get_name_leafdata())
                                        if (self.far_end_path_se_ss.is_set or self.far_end_path_se_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_se_ss.get_name_leafdata())
                                        if (self.far_end_path_ua_ss.is_set or self.far_end_path_ua_ss.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.far_end_path_ua_ss.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "far-end-path-c-vs" or name == "far-end-path-e-ss" or name == "far-end-path-se-ss" or name == "far-end-path-ua-ss"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "far-end-path-c-vs"):
                                            self.far_end_path_c_vs = value
                                            self.far_end_path_c_vs.value_namespace = name_space
                                            self.far_end_path_c_vs.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-e-ss"):
                                            self.far_end_path_e_ss = value
                                            self.far_end_path_e_ss.value_namespace = name_space
                                            self.far_end_path_e_ss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-se-ss"):
                                            self.far_end_path_se_ss = value
                                            self.far_end_path_se_ss.value_namespace = name_space
                                            self.far_end_path_se_ss.value_namespace_prefix = name_space_prefix
                                        if(value_path == "far-end-path-ua-ss"):
                                            self.far_end_path_ua_ss = value
                                            self.far_end_path_ua_ss.value_namespace = name_space
                                            self.far_end_path_ua_ss.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.fe_path is not None and self.fe_path.has_data()) or
                                        (self.path is not None and self.path.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.fe_path is not None and self.fe_path.has_operation()) or
                                        (self.path is not None and self.path.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sts-hour24-path" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "fe-path"):
                                        if (self.fe_path is None):
                                            self.fe_path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.FePath()
                                            self.fe_path.parent = self
                                            self._children_name_map["fe_path"] = "fe-path"
                                        return self.fe_path

                                    if (child_yang_name == "path"):
                                        if (self.path is None):
                                            self.path = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path.Path()
                                            self.path.parent = self
                                            self._children_name_map["path"] = "path"
                                        return self.path

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fe-path" or name == "path" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.sts_hour24_path:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.sts_hour24_path:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sts-hour24-paths" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sts-hour24-path"):
                                    for c in self.sts_hour24_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths.StsHour24Path()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.sts_hour24_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sts-hour24-path"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.sts_hour24_paths is not None and self.sts_hour24_paths.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.sts_hour24_paths is not None and self.sts_hour24_paths.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sts-hour24" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sts-hour24-paths"):
                                if (self.sts_hour24_paths is None):
                                    self.sts_hour24_paths = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24.StsHour24Paths()
                                    self.sts_hour24_paths.parent = self
                                    self._children_name_map["sts_hour24_paths"] = "sts-hour24-paths"
                                return self.sts_hour24_paths

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sts-hour24-paths"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.sts_hour24 is not None and self.sts_hour24.has_data()) or
                            (self.sts_minute15 is not None and self.sts_minute15.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.sts_hour24 is not None and self.sts_hour24.has_operation()) or
                            (self.sts_minute15 is not None and self.sts_minute15.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sts-current" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sts-hour24"):
                            if (self.sts_hour24 is None):
                                self.sts_hour24 = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsHour24()
                                self.sts_hour24.parent = self
                                self._children_name_map["sts_hour24"] = "sts-hour24"
                            return self.sts_hour24

                        if (child_yang_name == "sts-minute15"):
                            if (self.sts_minute15 is None):
                                self.sts_minute15 = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent.StsMinute15()
                                self.sts_minute15.parent = self
                                self._children_name_map["sts_minute15"] = "sts-minute15"
                            return self.sts_minute15

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sts-hour24" or name == "sts-minute15"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.name.is_set or
                        (self.sts_current is not None and self.sts_current.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        (self.sts_current is not None and self.sts_current.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "sts-port" + "[name='" + self.name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/sts/sts-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sts-current"):
                        if (self.sts_current is None):
                            self.sts_current = PerformanceManagement.Sts.StsPorts.StsPort.StsCurrent()
                            self.sts_current.parent = self
                            self._children_name_map["sts_current"] = "sts-current"
                        return self.sts_current

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sts-current" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.sts_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.sts_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "sts-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/sts/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "sts-port"):
                    for c in self.sts_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = PerformanceManagement.Sts.StsPorts.StsPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.sts_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "sts-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.sts_ports is not None and self.sts_ports.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.sts_ports is not None and self.sts_ports.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "sts" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "sts-ports"):
                if (self.sts_ports is None):
                    self.sts_ports = PerformanceManagement.Sts.StsPorts()
                    self.sts_ports.parent = self
                    self._children_name_map["sts_ports"] = "sts-ports"
                return self.sts_ports

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "sts-ports"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Dwdm(Entity):
        """
        DWDM controller performance data
        
        .. attribute:: dwdm_ports
        
        	Port performance data
        	**type**\:   :py:class:`DwdmPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PerformanceManagement.Dwdm, self).__init__()

            self.yang_name = "dwdm"
            self.yang_parent_name = "performance-management"

            self.dwdm_ports = PerformanceManagement.Dwdm.DwdmPorts()
            self.dwdm_ports.parent = self
            self._children_name_map["dwdm_ports"] = "dwdm-ports"
            self._children_yang_names.add("dwdm-ports")


        class DwdmPorts(Entity):
            """
            Port performance data
            
            .. attribute:: dwdm_port
            
            	Port performance data
            	**type**\: list of    :py:class:`DwdmPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PerformanceManagement.Dwdm.DwdmPorts, self).__init__()

                self.yang_name = "dwdm-ports"
                self.yang_parent_name = "dwdm"

                self.dwdm_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(PerformanceManagement.Dwdm.DwdmPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(PerformanceManagement.Dwdm.DwdmPorts, self).__setattr__(name, value)


            class DwdmPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: dwdm_current
                
                	port current performance data
                	**type**\:   :py:class:`DwdmCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort, self).__init__()

                    self.yang_name = "dwdm-port"
                    self.yang_parent_name = "dwdm-ports"

                    self.name = YLeaf(YType.str, "name")

                    self.dwdm_current = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent()
                    self.dwdm_current.parent = self
                    self._children_name_map["dwdm_current"] = "dwdm-current"
                    self._children_yang_names.add("dwdm-current")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort, self).__setattr__(name, value)


                class DwdmCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: dwdm_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`DwdmHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24>`
                    
                    .. attribute:: dwdm_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`DwdmMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent, self).__init__()

                        self.yang_name = "dwdm-current"
                        self.yang_parent_name = "dwdm-port"

                        self.dwdm_hour24 = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24()
                        self.dwdm_hour24.parent = self
                        self._children_name_map["dwdm_hour24"] = "dwdm-hour24"
                        self._children_yang_names.add("dwdm-hour24")

                        self.dwdm_minute15 = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15()
                        self.dwdm_minute15.parent = self
                        self._children_name_map["dwdm_minute15"] = "dwdm-minute15"
                        self._children_yang_names.add("dwdm-minute15")


                    class DwdmMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: dwdm_minute15_optics
                        
                        	port current performance data
                        	**type**\:   :py:class:`DwdmMinute15Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics>`
                        
                        .. attribute:: dwdm_minute15fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`DwdmMinute15Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs>`
                        
                        .. attribute:: dwdm_minute15otns
                        
                        	port current performance data
                        	**type**\:   :py:class:`DwdmMinute15Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15, self).__init__()

                            self.yang_name = "dwdm-minute15"
                            self.yang_parent_name = "dwdm-current"

                            self.dwdm_minute15_optics = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics()
                            self.dwdm_minute15_optics.parent = self
                            self._children_name_map["dwdm_minute15_optics"] = "dwdm-minute15-optics"
                            self._children_yang_names.add("dwdm-minute15-optics")

                            self.dwdm_minute15fecs = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs()
                            self.dwdm_minute15fecs.parent = self
                            self._children_name_map["dwdm_minute15fecs"] = "dwdm-minute15fecs"
                            self._children_yang_names.add("dwdm-minute15fecs")

                            self.dwdm_minute15otns = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns()
                            self.dwdm_minute15otns.parent = self
                            self._children_name_map["dwdm_minute15otns"] = "dwdm-minute15otns"
                            self._children_yang_names.add("dwdm-minute15otns")


                        class DwdmMinute15Fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_minute15fec
                            
                            	port 15\-minute fec performance data
                            	**type**\: list of    :py:class:`DwdmMinute15Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs, self).__init__()

                                self.yang_name = "dwdm-minute15fecs"
                                self.yang_parent_name = "dwdm-minute15"

                                self.dwdm_minute15fec = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs, self).__setattr__(name, value)


                            class DwdmMinute15Fec(Entity):
                                """
                                port 15\-minute fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec, self).__init__()

                                    self.yang_name = "dwdm-minute15fec"
                                    self.yang_parent_name = "dwdm-minute15fecs"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.ec_bits = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"
                                    self._children_yang_names.add("ec-bits")

                                    self.post_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                    self._children_yang_names.add("post-fec-ber")

                                    self.pre_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                    self._children_yang_names.add("pre-fec-ber")

                                    self.q = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"
                                    self._children_yang_names.add("q")

                                    self.qmargin = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._children_yang_names.add("qmargin")

                                    self.uc_words = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"
                                    self._children_yang_names.add("uc-words")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec, self).__setattr__(name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "dwdm-minute15fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.EcBits, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.EcBits, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ec-bits" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "dwdm-minute15fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.UcWords, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.UcWords, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uc-words" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "dwdm-minute15fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PreFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PreFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pre-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "dwdm-minute15fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PostFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PostFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "post-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "dwdm-minute15fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Q, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Q, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "q" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "dwdm-minute15fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Qmargin, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Qmargin, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "qmargin" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.ec_bits is not None and self.ec_bits.has_data()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                        (self.q is not None and self.q.has_data()) or
                                        (self.qmargin is not None and self.qmargin.has_data()) or
                                        (self.uc_words is not None and self.uc_words.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                        (self.q is not None and self.q.has_operation()) or
                                        (self.qmargin is not None and self.qmargin.has_operation()) or
                                        (self.uc_words is not None and self.uc_words.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dwdm-minute15fec" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ec-bits"):
                                        if (self.ec_bits is None):
                                            self.ec_bits = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.EcBits()
                                            self.ec_bits.parent = self
                                            self._children_name_map["ec_bits"] = "ec-bits"
                                        return self.ec_bits

                                    if (child_yang_name == "post-fec-ber"):
                                        if (self.post_fec_ber is None):
                                            self.post_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PostFecBer()
                                            self.post_fec_ber.parent = self
                                            self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                        return self.post_fec_ber

                                    if (child_yang_name == "pre-fec-ber"):
                                        if (self.pre_fec_ber is None):
                                            self.pre_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.PreFecBer()
                                            self.pre_fec_ber.parent = self
                                            self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                        return self.pre_fec_ber

                                    if (child_yang_name == "q"):
                                        if (self.q is None):
                                            self.q = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Q()
                                            self.q.parent = self
                                            self._children_name_map["q"] = "q"
                                        return self.q

                                    if (child_yang_name == "qmargin"):
                                        if (self.qmargin is None):
                                            self.qmargin = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.Qmargin()
                                            self.qmargin.parent = self
                                            self._children_name_map["qmargin"] = "qmargin"
                                        return self.qmargin

                                    if (child_yang_name == "uc-words"):
                                        if (self.uc_words is None):
                                            self.uc_words = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec.UcWords()
                                            self.uc_words.parent = self
                                            self._children_name_map["uc_words"] = "uc-words"
                                        return self.uc_words

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.dwdm_minute15fec:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.dwdm_minute15fec:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dwdm-minute15fecs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dwdm-minute15fec"):
                                    for c in self.dwdm_minute15fec:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs.DwdmMinute15Fec()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.dwdm_minute15fec.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dwdm-minute15fec"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DwdmMinute15Optics(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_minute15_optic
                            
                            	port 15\-minute optics performance data
                            	**type**\: list of    :py:class:`DwdmMinute15Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics, self).__init__()

                                self.yang_name = "dwdm-minute15-optics"
                                self.yang_parent_name = "dwdm-minute15"

                                self.dwdm_minute15_optic = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics, self).__setattr__(name, value)


                            class DwdmMinute15Optic(Entity):
                                """
                                port 15\-minute optics performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic, self).__init__()

                                    self.yang_name = "dwdm-minute15-optic"
                                    self.yang_parent_name = "dwdm-minute15-optics"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.cd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd()
                                    self.cd.parent = self
                                    self._children_name_map["cd"] = "cd"
                                    self._children_yang_names.add("cd")

                                    self.center_wavelength = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self._children_name_map["center_wavelength"] = "center-wavelength"
                                    self._children_yang_names.add("center-wavelength")

                                    self.dgd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd()
                                    self.dgd.parent = self
                                    self._children_name_map["dgd"] = "dgd"
                                    self._children_yang_names.add("dgd")

                                    self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"
                                    self._children_yang_names.add("lbc")

                                    self.lbc_pc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self._children_name_map["lbc_pc"] = "lbc-pc"
                                    self._children_yang_names.add("lbc-pc")

                                    self.low_sig_freq_off = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                    self._children_yang_names.add("low-sig-freq-off")

                                    self.opr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr()
                                    self.opr.parent = self
                                    self._children_name_map["opr"] = "opr"
                                    self._children_yang_names.add("opr")

                                    self.opt = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt()
                                    self.opt.parent = self
                                    self._children_name_map["opt"] = "opt"
                                    self._children_yang_names.add("opt")

                                    self.osnr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr()
                                    self.osnr.parent = self
                                    self._children_name_map["osnr"] = "osnr"
                                    self._children_yang_names.add("osnr")

                                    self.pcr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr()
                                    self.pcr.parent = self
                                    self._children_name_map["pcr"] = "pcr"
                                    self._children_yang_names.add("pcr")

                                    self.pdl = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl()
                                    self.pdl.parent = self
                                    self._children_name_map["pdl"] = "pdl"
                                    self._children_yang_names.add("pdl")

                                    self.pmd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd()
                                    self.pmd.parent = self
                                    self._children_name_map["pmd"] = "pmd"
                                    self._children_yang_names.add("pmd")

                                    self.pn = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn()
                                    self.pn.parent = self
                                    self._children_name_map["pn"] = "pn"
                                    self._children_yang_names.add("pn")

                                    self.rx_sig_pow = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                    self._children_yang_names.add("rx-sig-pow")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic, self).__setattr__(name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LbcPc(Entity):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc, self).__init__()

                                        self.yang_name = "lbc-pc"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc-pc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Opt(Entity):
                                    """
                                    OPT
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt, self).__init__()

                                        self.yang_name = "opt"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Opr(Entity):
                                    """
                                    OPR
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr, self).__init__()

                                        self.yang_name = "opr"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Cd(Entity):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd, self).__init__()

                                        self.yang_name = "cd"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "cd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Dgd(Entity):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd, self).__init__()

                                        self.yang_name = "dgd"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dgd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pmd(Entity):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd, self).__init__()

                                        self.yang_name = "pmd"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pmd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Osnr(Entity):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr, self).__init__()

                                        self.yang_name = "osnr"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "osnr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class CenterWavelength(Entity):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength, self).__init__()

                                        self.yang_name = "center-wavelength"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "center-wavelength" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pdl(Entity):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl, self).__init__()

                                        self.yang_name = "pdl"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pdl" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pcr(Entity):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr, self).__init__()

                                        self.yang_name = "pcr"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pcr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pn(Entity):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn, self).__init__()

                                        self.yang_name = "pn"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pn" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class RxSigPow(Entity):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow, self).__init__()

                                        self.yang_name = "rx-sig-pow"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-sig-pow" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LowSigFreqOff(Entity):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff, self).__init__()

                                        self.yang_name = "low-sig-freq-off"
                                        self.yang_parent_name = "dwdm-minute15-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "low-sig-freq-off" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.cd is not None and self.cd.has_data()) or
                                        (self.center_wavelength is not None and self.center_wavelength.has_data()) or
                                        (self.dgd is not None and self.dgd.has_data()) or
                                        (self.lbc is not None and self.lbc.has_data()) or
                                        (self.lbc_pc is not None and self.lbc_pc.has_data()) or
                                        (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_data()) or
                                        (self.opr is not None and self.opr.has_data()) or
                                        (self.opt is not None and self.opt.has_data()) or
                                        (self.osnr is not None and self.osnr.has_data()) or
                                        (self.pcr is not None and self.pcr.has_data()) or
                                        (self.pdl is not None and self.pdl.has_data()) or
                                        (self.pmd is not None and self.pmd.has_data()) or
                                        (self.pn is not None and self.pn.has_data()) or
                                        (self.rx_sig_pow is not None and self.rx_sig_pow.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.cd is not None and self.cd.has_operation()) or
                                        (self.center_wavelength is not None and self.center_wavelength.has_operation()) or
                                        (self.dgd is not None and self.dgd.has_operation()) or
                                        (self.lbc is not None and self.lbc.has_operation()) or
                                        (self.lbc_pc is not None and self.lbc_pc.has_operation()) or
                                        (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_operation()) or
                                        (self.opr is not None and self.opr.has_operation()) or
                                        (self.opt is not None and self.opt.has_operation()) or
                                        (self.osnr is not None and self.osnr.has_operation()) or
                                        (self.pcr is not None and self.pcr.has_operation()) or
                                        (self.pdl is not None and self.pdl.has_operation()) or
                                        (self.pmd is not None and self.pmd.has_operation()) or
                                        (self.pn is not None and self.pn.has_operation()) or
                                        (self.rx_sig_pow is not None and self.rx_sig_pow.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dwdm-minute15-optic" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "cd"):
                                        if (self.cd is None):
                                            self.cd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Cd()
                                            self.cd.parent = self
                                            self._children_name_map["cd"] = "cd"
                                        return self.cd

                                    if (child_yang_name == "center-wavelength"):
                                        if (self.center_wavelength is None):
                                            self.center_wavelength = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.CenterWavelength()
                                            self.center_wavelength.parent = self
                                            self._children_name_map["center_wavelength"] = "center-wavelength"
                                        return self.center_wavelength

                                    if (child_yang_name == "dgd"):
                                        if (self.dgd is None):
                                            self.dgd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Dgd()
                                            self.dgd.parent = self
                                            self._children_name_map["dgd"] = "dgd"
                                        return self.dgd

                                    if (child_yang_name == "lbc"):
                                        if (self.lbc is None):
                                            self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Lbc()
                                            self.lbc.parent = self
                                            self._children_name_map["lbc"] = "lbc"
                                        return self.lbc

                                    if (child_yang_name == "lbc-pc"):
                                        if (self.lbc_pc is None):
                                            self.lbc_pc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LbcPc()
                                            self.lbc_pc.parent = self
                                            self._children_name_map["lbc_pc"] = "lbc-pc"
                                        return self.lbc_pc

                                    if (child_yang_name == "low-sig-freq-off"):
                                        if (self.low_sig_freq_off is None):
                                            self.low_sig_freq_off = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.LowSigFreqOff()
                                            self.low_sig_freq_off.parent = self
                                            self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                        return self.low_sig_freq_off

                                    if (child_yang_name == "opr"):
                                        if (self.opr is None):
                                            self.opr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opr()
                                            self.opr.parent = self
                                            self._children_name_map["opr"] = "opr"
                                        return self.opr

                                    if (child_yang_name == "opt"):
                                        if (self.opt is None):
                                            self.opt = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Opt()
                                            self.opt.parent = self
                                            self._children_name_map["opt"] = "opt"
                                        return self.opt

                                    if (child_yang_name == "osnr"):
                                        if (self.osnr is None):
                                            self.osnr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Osnr()
                                            self.osnr.parent = self
                                            self._children_name_map["osnr"] = "osnr"
                                        return self.osnr

                                    if (child_yang_name == "pcr"):
                                        if (self.pcr is None):
                                            self.pcr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pcr()
                                            self.pcr.parent = self
                                            self._children_name_map["pcr"] = "pcr"
                                        return self.pcr

                                    if (child_yang_name == "pdl"):
                                        if (self.pdl is None):
                                            self.pdl = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pdl()
                                            self.pdl.parent = self
                                            self._children_name_map["pdl"] = "pdl"
                                        return self.pdl

                                    if (child_yang_name == "pmd"):
                                        if (self.pmd is None):
                                            self.pmd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pmd()
                                            self.pmd.parent = self
                                            self._children_name_map["pmd"] = "pmd"
                                        return self.pmd

                                    if (child_yang_name == "pn"):
                                        if (self.pn is None):
                                            self.pn = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.Pn()
                                            self.pn.parent = self
                                            self._children_name_map["pn"] = "pn"
                                        return self.pn

                                    if (child_yang_name == "rx-sig-pow"):
                                        if (self.rx_sig_pow is None):
                                            self.rx_sig_pow = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic.RxSigPow()
                                            self.rx_sig_pow.parent = self
                                            self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                        return self.rx_sig_pow

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "cd" or name == "center-wavelength" or name == "dgd" or name == "lbc" or name == "lbc-pc" or name == "low-sig-freq-off" or name == "opr" or name == "opt" or name == "osnr" or name == "pcr" or name == "pdl" or name == "pmd" or name == "pn" or name == "rx-sig-pow" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.dwdm_minute15_optic:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.dwdm_minute15_optic:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dwdm-minute15-optics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dwdm-minute15-optic"):
                                    for c in self.dwdm_minute15_optic:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics.DwdmMinute15Optic()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.dwdm_minute15_optic.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dwdm-minute15-optic"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DwdmMinute15Otns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_minute15otn
                            
                            	port 15\-minute otn performance data
                            	**type**\: list of    :py:class:`DwdmMinute15Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns, self).__init__()

                                self.yang_name = "dwdm-minute15otns"
                                self.yang_parent_name = "dwdm-minute15"

                                self.dwdm_minute15otn = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns, self).__setattr__(name, value)


                            class DwdmMinute15Otn(Entity):
                                """
                                port 15\-minute otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn, self).__init__()

                                    self.yang_name = "dwdm-minute15otn"
                                    self.yang_parent_name = "dwdm-minute15otns"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.bbe_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"
                                    self._children_yang_names.add("bbe-fe")

                                    self.bbe_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"
                                    self._children_yang_names.add("bbe-ne")

                                    self.bber_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"
                                    self._children_yang_names.add("bber-fe")

                                    self.bber_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"
                                    self._children_yang_names.add("bber-ne")

                                    self.es_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"
                                    self._children_yang_names.add("es-fe")

                                    self.es_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"
                                    self._children_yang_names.add("es-ne")

                                    self.esr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"
                                    self._children_yang_names.add("esr-fe")

                                    self.esr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"
                                    self._children_yang_names.add("esr-ne")

                                    self.fc_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._children_yang_names.add("fc-fe")

                                    self.fc_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"
                                    self._children_yang_names.add("fc-ne")

                                    self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"
                                    self._children_yang_names.add("lbc")

                                    self.ses_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"
                                    self._children_yang_names.add("ses-fe")

                                    self.ses_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"
                                    self._children_yang_names.add("ses-ne")

                                    self.sesr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"
                                    self._children_yang_names.add("sesr-fe")

                                    self.sesr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"
                                    self._children_yang_names.add("sesr-ne")

                                    self.uas_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"
                                    self._children_yang_names.add("uas-fe")

                                    self.uas_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"
                                    self._children_yang_names.add("uas-ne")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn, self).__setattr__(name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.Lbc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.Lbc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "dwdm-minute15otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                        (self.bber_fe is not None and self.bber_fe.has_data()) or
                                        (self.bber_ne is not None and self.bber_ne.has_data()) or
                                        (self.es_fe is not None and self.es_fe.has_data()) or
                                        (self.es_ne is not None and self.es_ne.has_data()) or
                                        (self.esr_fe is not None and self.esr_fe.has_data()) or
                                        (self.esr_ne is not None and self.esr_ne.has_data()) or
                                        (self.fc_fe is not None and self.fc_fe.has_data()) or
                                        (self.fc_ne is not None and self.fc_ne.has_data()) or
                                        (self.lbc is not None and self.lbc.has_data()) or
                                        (self.ses_fe is not None and self.ses_fe.has_data()) or
                                        (self.ses_ne is not None and self.ses_ne.has_data()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                        (self.uas_fe is not None and self.uas_fe.has_data()) or
                                        (self.uas_ne is not None and self.uas_ne.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                        (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                        (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                        (self.es_fe is not None and self.es_fe.has_operation()) or
                                        (self.es_ne is not None and self.es_ne.has_operation()) or
                                        (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                        (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                        (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                        (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                        (self.lbc is not None and self.lbc.has_operation()) or
                                        (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                        (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                        (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                        (self.uas_ne is not None and self.uas_ne.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dwdm-minute15otn" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "bbe-fe"):
                                        if (self.bbe_fe is None):
                                            self.bbe_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeFe()
                                            self.bbe_fe.parent = self
                                            self._children_name_map["bbe_fe"] = "bbe-fe"
                                        return self.bbe_fe

                                    if (child_yang_name == "bbe-ne"):
                                        if (self.bbe_ne is None):
                                            self.bbe_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BbeNe()
                                            self.bbe_ne.parent = self
                                            self._children_name_map["bbe_ne"] = "bbe-ne"
                                        return self.bbe_ne

                                    if (child_yang_name == "bber-fe"):
                                        if (self.bber_fe is None):
                                            self.bber_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberFe()
                                            self.bber_fe.parent = self
                                            self._children_name_map["bber_fe"] = "bber-fe"
                                        return self.bber_fe

                                    if (child_yang_name == "bber-ne"):
                                        if (self.bber_ne is None):
                                            self.bber_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.BberNe()
                                            self.bber_ne.parent = self
                                            self._children_name_map["bber_ne"] = "bber-ne"
                                        return self.bber_ne

                                    if (child_yang_name == "es-fe"):
                                        if (self.es_fe is None):
                                            self.es_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsFe()
                                            self.es_fe.parent = self
                                            self._children_name_map["es_fe"] = "es-fe"
                                        return self.es_fe

                                    if (child_yang_name == "es-ne"):
                                        if (self.es_ne is None):
                                            self.es_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsNe()
                                            self.es_ne.parent = self
                                            self._children_name_map["es_ne"] = "es-ne"
                                        return self.es_ne

                                    if (child_yang_name == "esr-fe"):
                                        if (self.esr_fe is None):
                                            self.esr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrFe()
                                            self.esr_fe.parent = self
                                            self._children_name_map["esr_fe"] = "esr-fe"
                                        return self.esr_fe

                                    if (child_yang_name == "esr-ne"):
                                        if (self.esr_ne is None):
                                            self.esr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.EsrNe()
                                            self.esr_ne.parent = self
                                            self._children_name_map["esr_ne"] = "esr-ne"
                                        return self.esr_ne

                                    if (child_yang_name == "fc-fe"):
                                        if (self.fc_fe is None):
                                            self.fc_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcFe()
                                            self.fc_fe.parent = self
                                            self._children_name_map["fc_fe"] = "fc-fe"
                                        return self.fc_fe

                                    if (child_yang_name == "fc-ne"):
                                        if (self.fc_ne is None):
                                            self.fc_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.FcNe()
                                            self.fc_ne.parent = self
                                            self._children_name_map["fc_ne"] = "fc-ne"
                                        return self.fc_ne

                                    if (child_yang_name == "lbc"):
                                        if (self.lbc is None):
                                            self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.Lbc()
                                            self.lbc.parent = self
                                            self._children_name_map["lbc"] = "lbc"
                                        return self.lbc

                                    if (child_yang_name == "ses-fe"):
                                        if (self.ses_fe is None):
                                            self.ses_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesFe()
                                            self.ses_fe.parent = self
                                            self._children_name_map["ses_fe"] = "ses-fe"
                                        return self.ses_fe

                                    if (child_yang_name == "ses-ne"):
                                        if (self.ses_ne is None):
                                            self.ses_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesNe()
                                            self.ses_ne.parent = self
                                            self._children_name_map["ses_ne"] = "ses-ne"
                                        return self.ses_ne

                                    if (child_yang_name == "sesr-fe"):
                                        if (self.sesr_fe is None):
                                            self.sesr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrFe()
                                            self.sesr_fe.parent = self
                                            self._children_name_map["sesr_fe"] = "sesr-fe"
                                        return self.sesr_fe

                                    if (child_yang_name == "sesr-ne"):
                                        if (self.sesr_ne is None):
                                            self.sesr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.SesrNe()
                                            self.sesr_ne.parent = self
                                            self._children_name_map["sesr_ne"] = "sesr-ne"
                                        return self.sesr_ne

                                    if (child_yang_name == "uas-fe"):
                                        if (self.uas_fe is None):
                                            self.uas_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasFe()
                                            self.uas_fe.parent = self
                                            self._children_name_map["uas_fe"] = "uas-fe"
                                        return self.uas_fe

                                    if (child_yang_name == "uas-ne"):
                                        if (self.uas_ne is None):
                                            self.uas_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn.UasNe()
                                            self.uas_ne.parent = self
                                            self._children_name_map["uas_ne"] = "uas-ne"
                                        return self.uas_ne

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.dwdm_minute15otn:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.dwdm_minute15otn:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dwdm-minute15otns" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dwdm-minute15otn"):
                                    for c in self.dwdm_minute15otn:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns.DwdmMinute15Otn()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.dwdm_minute15otn.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dwdm-minute15otn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.dwdm_minute15_optics is not None and self.dwdm_minute15_optics.has_data()) or
                                (self.dwdm_minute15fecs is not None and self.dwdm_minute15fecs.has_data()) or
                                (self.dwdm_minute15otns is not None and self.dwdm_minute15otns.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.dwdm_minute15_optics is not None and self.dwdm_minute15_optics.has_operation()) or
                                (self.dwdm_minute15fecs is not None and self.dwdm_minute15fecs.has_operation()) or
                                (self.dwdm_minute15otns is not None and self.dwdm_minute15otns.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dwdm-minute15" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dwdm-minute15-optics"):
                                if (self.dwdm_minute15_optics is None):
                                    self.dwdm_minute15_optics = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Optics()
                                    self.dwdm_minute15_optics.parent = self
                                    self._children_name_map["dwdm_minute15_optics"] = "dwdm-minute15-optics"
                                return self.dwdm_minute15_optics

                            if (child_yang_name == "dwdm-minute15fecs"):
                                if (self.dwdm_minute15fecs is None):
                                    self.dwdm_minute15fecs = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Fecs()
                                    self.dwdm_minute15fecs.parent = self
                                    self._children_name_map["dwdm_minute15fecs"] = "dwdm-minute15fecs"
                                return self.dwdm_minute15fecs

                            if (child_yang_name == "dwdm-minute15otns"):
                                if (self.dwdm_minute15otns is None):
                                    self.dwdm_minute15otns = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15.DwdmMinute15Otns()
                                    self.dwdm_minute15otns.parent = self
                                    self._children_name_map["dwdm_minute15otns"] = "dwdm-minute15otns"
                                return self.dwdm_minute15otns

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dwdm-minute15-optics" or name == "dwdm-minute15fecs" or name == "dwdm-minute15otns"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class DwdmHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: dwdm_hour24_optics
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`DwdmHour24Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics>`
                        
                        .. attribute:: dwdm_hour24fecs
                        
                        	port current performance data
                        	**type**\:   :py:class:`DwdmHour24Fecs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs>`
                        
                        .. attribute:: dwdm_hour24otns
                        
                        	port 24 hour performance data
                        	**type**\:   :py:class:`DwdmHour24Otns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24, self).__init__()

                            self.yang_name = "dwdm-hour24"
                            self.yang_parent_name = "dwdm-current"

                            self.dwdm_hour24_optics = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics()
                            self.dwdm_hour24_optics.parent = self
                            self._children_name_map["dwdm_hour24_optics"] = "dwdm-hour24-optics"
                            self._children_yang_names.add("dwdm-hour24-optics")

                            self.dwdm_hour24fecs = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs()
                            self.dwdm_hour24fecs.parent = self
                            self._children_name_map["dwdm_hour24fecs"] = "dwdm-hour24fecs"
                            self._children_yang_names.add("dwdm-hour24fecs")

                            self.dwdm_hour24otns = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns()
                            self.dwdm_hour24otns.parent = self
                            self._children_name_map["dwdm_hour24otns"] = "dwdm-hour24otns"
                            self._children_yang_names.add("dwdm-hour24otns")


                        class DwdmHour24Optics(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: dwdm_hour24_optic
                            
                            	port 24 hour optics performance data
                            	**type**\: list of    :py:class:`DwdmHour24Optic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics, self).__init__()

                                self.yang_name = "dwdm-hour24-optics"
                                self.yang_parent_name = "dwdm-hour24"

                                self.dwdm_hour24_optic = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics, self).__setattr__(name, value)


                            class DwdmHour24Optic(Entity):
                                """
                                port 24 hour optics performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: cd
                                
                                	Chromatic Dispersion
                                	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd>`
                                
                                .. attribute:: center_wavelength
                                
                                	Center Wavelength/Frequency
                                	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength>`
                                
                                .. attribute:: dgd
                                
                                	Differential group Delay
                                	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc>`
                                
                                .. attribute:: lbc_pc
                                
                                	LBC in percentage
                                	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc>`
                                
                                .. attribute:: low_sig_freq_off
                                
                                	low freq sig off
                                	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff>`
                                
                                .. attribute:: opr
                                
                                	OPR
                                	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr>`
                                
                                .. attribute:: opt
                                
                                	OPT
                                	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt>`
                                
                                .. attribute:: osnr
                                
                                	Optical Signal to Noise Ratio
                                	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr>`
                                
                                .. attribute:: pcr
                                
                                	Polarization Change Rate
                                	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr>`
                                
                                .. attribute:: pdl
                                
                                	Polarization Dependent Loss
                                	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl>`
                                
                                .. attribute:: pmd
                                
                                	Polarization Mode Dispersion
                                	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd>`
                                
                                .. attribute:: pn
                                
                                	Phase Noise
                                	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn>`
                                
                                .. attribute:: rx_sig_pow
                                
                                	Rx signal power
                                	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic, self).__init__()

                                    self.yang_name = "dwdm-hour24-optic"
                                    self.yang_parent_name = "dwdm-hour24-optics"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.cd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd()
                                    self.cd.parent = self
                                    self._children_name_map["cd"] = "cd"
                                    self._children_yang_names.add("cd")

                                    self.center_wavelength = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength()
                                    self.center_wavelength.parent = self
                                    self._children_name_map["center_wavelength"] = "center-wavelength"
                                    self._children_yang_names.add("center-wavelength")

                                    self.dgd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd()
                                    self.dgd.parent = self
                                    self._children_name_map["dgd"] = "dgd"
                                    self._children_yang_names.add("dgd")

                                    self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"
                                    self._children_yang_names.add("lbc")

                                    self.lbc_pc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc()
                                    self.lbc_pc.parent = self
                                    self._children_name_map["lbc_pc"] = "lbc-pc"
                                    self._children_yang_names.add("lbc-pc")

                                    self.low_sig_freq_off = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff()
                                    self.low_sig_freq_off.parent = self
                                    self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                    self._children_yang_names.add("low-sig-freq-off")

                                    self.opr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr()
                                    self.opr.parent = self
                                    self._children_name_map["opr"] = "opr"
                                    self._children_yang_names.add("opr")

                                    self.opt = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt()
                                    self.opt.parent = self
                                    self._children_name_map["opt"] = "opt"
                                    self._children_yang_names.add("opt")

                                    self.osnr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr()
                                    self.osnr.parent = self
                                    self._children_name_map["osnr"] = "osnr"
                                    self._children_yang_names.add("osnr")

                                    self.pcr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr()
                                    self.pcr.parent = self
                                    self._children_name_map["pcr"] = "pcr"
                                    self._children_yang_names.add("pcr")

                                    self.pdl = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl()
                                    self.pdl.parent = self
                                    self._children_name_map["pdl"] = "pdl"
                                    self._children_yang_names.add("pdl")

                                    self.pmd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd()
                                    self.pmd.parent = self
                                    self._children_name_map["pmd"] = "pmd"
                                    self._children_yang_names.add("pmd")

                                    self.pn = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn()
                                    self.pn.parent = self
                                    self._children_name_map["pn"] = "pn"
                                    self._children_yang_names.add("pn")

                                    self.rx_sig_pow = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow()
                                    self.rx_sig_pow.parent = self
                                    self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                    self._children_yang_names.add("rx-sig-pow")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic, self).__setattr__(name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LbcPc(Entity):
                                    """
                                    LBC in percentage
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc, self).__init__()

                                        self.yang_name = "lbc-pc"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc-pc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Opt(Entity):
                                    """
                                    OPT
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt, self).__init__()

                                        self.yang_name = "opt"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Opr(Entity):
                                    """
                                    OPR
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr, self).__init__()

                                        self.yang_name = "opr"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "opr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Cd(Entity):
                                    """
                                    Chromatic Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd, self).__init__()

                                        self.yang_name = "cd"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "cd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Dgd(Entity):
                                    """
                                    Differential group Delay
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd, self).__init__()

                                        self.yang_name = "dgd"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dgd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pmd(Entity):
                                    """
                                    Polarization Mode Dispersion
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd, self).__init__()

                                        self.yang_name = "pmd"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pmd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Osnr(Entity):
                                    """
                                    Optical Signal to Noise Ratio
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr, self).__init__()

                                        self.yang_name = "osnr"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "osnr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class CenterWavelength(Entity):
                                    """
                                    Center Wavelength/Frequency
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength, self).__init__()

                                        self.yang_name = "center-wavelength"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "center-wavelength" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pdl(Entity):
                                    """
                                    Polarization Dependent Loss
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl, self).__init__()

                                        self.yang_name = "pdl"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pdl" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pcr(Entity):
                                    """
                                    Polarization Change Rate
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr, self).__init__()

                                        self.yang_name = "pcr"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pcr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Pn(Entity):
                                    """
                                    Phase Noise
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn, self).__init__()

                                        self.yang_name = "pn"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pn" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class RxSigPow(Entity):
                                    """
                                    Rx signal power
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow, self).__init__()

                                        self.yang_name = "rx-sig-pow"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-sig-pow" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LowSigFreqOff(Entity):
                                    """
                                    low freq sig off
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA on max
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff, self).__init__()

                                        self.yang_name = "low-sig-freq-off"
                                        self.yang_parent_name = "dwdm-hour24-optic"

                                        self.average = YLeaf(YType.int32, "average")

                                        self.maximum = YLeaf(YType.int32, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                        self.minimum = YLeaf(YType.int32, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "low-sig-freq-off" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.cd is not None and self.cd.has_data()) or
                                        (self.center_wavelength is not None and self.center_wavelength.has_data()) or
                                        (self.dgd is not None and self.dgd.has_data()) or
                                        (self.lbc is not None and self.lbc.has_data()) or
                                        (self.lbc_pc is not None and self.lbc_pc.has_data()) or
                                        (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_data()) or
                                        (self.opr is not None and self.opr.has_data()) or
                                        (self.opt is not None and self.opt.has_data()) or
                                        (self.osnr is not None and self.osnr.has_data()) or
                                        (self.pcr is not None and self.pcr.has_data()) or
                                        (self.pdl is not None and self.pdl.has_data()) or
                                        (self.pmd is not None and self.pmd.has_data()) or
                                        (self.pn is not None and self.pn.has_data()) or
                                        (self.rx_sig_pow is not None and self.rx_sig_pow.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.cd is not None and self.cd.has_operation()) or
                                        (self.center_wavelength is not None and self.center_wavelength.has_operation()) or
                                        (self.dgd is not None and self.dgd.has_operation()) or
                                        (self.lbc is not None and self.lbc.has_operation()) or
                                        (self.lbc_pc is not None and self.lbc_pc.has_operation()) or
                                        (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_operation()) or
                                        (self.opr is not None and self.opr.has_operation()) or
                                        (self.opt is not None and self.opt.has_operation()) or
                                        (self.osnr is not None and self.osnr.has_operation()) or
                                        (self.pcr is not None and self.pcr.has_operation()) or
                                        (self.pdl is not None and self.pdl.has_operation()) or
                                        (self.pmd is not None and self.pmd.has_operation()) or
                                        (self.pn is not None and self.pn.has_operation()) or
                                        (self.rx_sig_pow is not None and self.rx_sig_pow.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dwdm-hour24-optic" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "cd"):
                                        if (self.cd is None):
                                            self.cd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Cd()
                                            self.cd.parent = self
                                            self._children_name_map["cd"] = "cd"
                                        return self.cd

                                    if (child_yang_name == "center-wavelength"):
                                        if (self.center_wavelength is None):
                                            self.center_wavelength = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.CenterWavelength()
                                            self.center_wavelength.parent = self
                                            self._children_name_map["center_wavelength"] = "center-wavelength"
                                        return self.center_wavelength

                                    if (child_yang_name == "dgd"):
                                        if (self.dgd is None):
                                            self.dgd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Dgd()
                                            self.dgd.parent = self
                                            self._children_name_map["dgd"] = "dgd"
                                        return self.dgd

                                    if (child_yang_name == "lbc"):
                                        if (self.lbc is None):
                                            self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Lbc()
                                            self.lbc.parent = self
                                            self._children_name_map["lbc"] = "lbc"
                                        return self.lbc

                                    if (child_yang_name == "lbc-pc"):
                                        if (self.lbc_pc is None):
                                            self.lbc_pc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LbcPc()
                                            self.lbc_pc.parent = self
                                            self._children_name_map["lbc_pc"] = "lbc-pc"
                                        return self.lbc_pc

                                    if (child_yang_name == "low-sig-freq-off"):
                                        if (self.low_sig_freq_off is None):
                                            self.low_sig_freq_off = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.LowSigFreqOff()
                                            self.low_sig_freq_off.parent = self
                                            self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                        return self.low_sig_freq_off

                                    if (child_yang_name == "opr"):
                                        if (self.opr is None):
                                            self.opr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opr()
                                            self.opr.parent = self
                                            self._children_name_map["opr"] = "opr"
                                        return self.opr

                                    if (child_yang_name == "opt"):
                                        if (self.opt is None):
                                            self.opt = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Opt()
                                            self.opt.parent = self
                                            self._children_name_map["opt"] = "opt"
                                        return self.opt

                                    if (child_yang_name == "osnr"):
                                        if (self.osnr is None):
                                            self.osnr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Osnr()
                                            self.osnr.parent = self
                                            self._children_name_map["osnr"] = "osnr"
                                        return self.osnr

                                    if (child_yang_name == "pcr"):
                                        if (self.pcr is None):
                                            self.pcr = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pcr()
                                            self.pcr.parent = self
                                            self._children_name_map["pcr"] = "pcr"
                                        return self.pcr

                                    if (child_yang_name == "pdl"):
                                        if (self.pdl is None):
                                            self.pdl = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pdl()
                                            self.pdl.parent = self
                                            self._children_name_map["pdl"] = "pdl"
                                        return self.pdl

                                    if (child_yang_name == "pmd"):
                                        if (self.pmd is None):
                                            self.pmd = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pmd()
                                            self.pmd.parent = self
                                            self._children_name_map["pmd"] = "pmd"
                                        return self.pmd

                                    if (child_yang_name == "pn"):
                                        if (self.pn is None):
                                            self.pn = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.Pn()
                                            self.pn.parent = self
                                            self._children_name_map["pn"] = "pn"
                                        return self.pn

                                    if (child_yang_name == "rx-sig-pow"):
                                        if (self.rx_sig_pow is None):
                                            self.rx_sig_pow = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic.RxSigPow()
                                            self.rx_sig_pow.parent = self
                                            self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                        return self.rx_sig_pow

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "cd" or name == "center-wavelength" or name == "dgd" or name == "lbc" or name == "lbc-pc" or name == "low-sig-freq-off" or name == "opr" or name == "opt" or name == "osnr" or name == "pcr" or name == "pdl" or name == "pmd" or name == "pn" or name == "rx-sig-pow" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.dwdm_hour24_optic:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.dwdm_hour24_optic:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dwdm-hour24-optics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dwdm-hour24-optic"):
                                    for c in self.dwdm_hour24_optic:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics.DwdmHour24Optic()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.dwdm_hour24_optic.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dwdm-hour24-optic"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DwdmHour24Fecs(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_hour24fec
                            
                            	port 24 hour fec performance data
                            	**type**\: list of    :py:class:`DwdmHour24Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs, self).__init__()

                                self.yang_name = "dwdm-hour24fecs"
                                self.yang_parent_name = "dwdm-hour24"

                                self.dwdm_hour24fec = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs, self).__setattr__(name, value)


                            class DwdmHour24Fec(Entity):
                                """
                                port 24 hour fec performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ec_bits
                                
                                	EC BITS
                                	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.EcBits>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: post_fec_ber
                                
                                	Post FEC BER
                                	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PostFecBer>`
                                
                                .. attribute:: pre_fec_ber
                                
                                	Pre FEC BER
                                	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PreFecBer>`
                                
                                .. attribute:: q
                                
                                	Q
                                	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Q>`
                                
                                .. attribute:: qmargin
                                
                                	Q Margin
                                	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Qmargin>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uc_words
                                
                                	UC WORDS
                                	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.UcWords>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec, self).__init__()

                                    self.yang_name = "dwdm-hour24fec"
                                    self.yang_parent_name = "dwdm-hour24fecs"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.ec_bits = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.EcBits()
                                    self.ec_bits.parent = self
                                    self._children_name_map["ec_bits"] = "ec-bits"
                                    self._children_yang_names.add("ec-bits")

                                    self.post_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PostFecBer()
                                    self.post_fec_ber.parent = self
                                    self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                    self._children_yang_names.add("post-fec-ber")

                                    self.pre_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PreFecBer()
                                    self.pre_fec_ber.parent = self
                                    self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                    self._children_yang_names.add("pre-fec-ber")

                                    self.q = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Q()
                                    self.q.parent = self
                                    self._children_name_map["q"] = "q"
                                    self._children_yang_names.add("q")

                                    self.qmargin = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Qmargin()
                                    self.qmargin.parent = self
                                    self._children_name_map["qmargin"] = "qmargin"
                                    self._children_yang_names.add("qmargin")

                                    self.uc_words = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.UcWords()
                                    self.uc_words.parent = self
                                    self._children_name_map["uc_words"] = "uc-words"
                                    self._children_yang_names.add("uc-words")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec, self).__setattr__(name, value)


                                class EcBits(Entity):
                                    """
                                    EC BITS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.EcBits, self).__init__()

                                        self.yang_name = "ec-bits"
                                        self.yang_parent_name = "dwdm-hour24fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.EcBits, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.EcBits, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ec-bits" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class UcWords(Entity):
                                    """
                                    UC WORDS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.UcWords, self).__init__()

                                        self.yang_name = "uc-words"
                                        self.yang_parent_name = "dwdm-hour24fec"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.UcWords, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.UcWords, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uc-words" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PreFecBer(Entity):
                                    """
                                    Pre FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PreFecBer, self).__init__()

                                        self.yang_name = "pre-fec-ber"
                                        self.yang_parent_name = "dwdm-hour24fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PreFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PreFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pre-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class PostFecBer(Entity):
                                    """
                                    Post FEC BER
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PostFecBer, self).__init__()

                                        self.yang_name = "post-fec-ber"
                                        self.yang_parent_name = "dwdm-hour24fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PostFecBer, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PostFecBer, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "post-fec-ber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Q(Entity):
                                    """
                                    Q
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Q, self).__init__()

                                        self.yang_name = "q"
                                        self.yang_parent_name = "dwdm-hour24fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Q, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Q, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "q" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Qmargin(Entity):
                                    """
                                    Q Margin
                                    
                                    .. attribute:: average
                                    
                                    	average
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum
                                    
                                    	maximum
                                    	**type**\:  str
                                    
                                    .. attribute:: maximum_tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_threshold
                                    
                                    	maximum threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum
                                    
                                    	minimum
                                    	**type**\:  str
                                    
                                    .. attribute:: minimum_tca_report
                                    
                                    	enable/disable to report TCA on min
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_threshold
                                    
                                    	minimun threshold
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Qmargin, self).__init__()

                                        self.yang_name = "qmargin"
                                        self.yang_parent_name = "dwdm-hour24fec"

                                        self.average = YLeaf(YType.str, "average")

                                        self.maximum = YLeaf(YType.str, "maximum")

                                        self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                        self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                        self.minimum = YLeaf(YType.str, "minimum")

                                        self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                        self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("average",
                                                        "maximum",
                                                        "maximum_tca_report",
                                                        "maximum_threshold",
                                                        "minimum",
                                                        "minimum_tca_report",
                                                        "minimum_threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Qmargin, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Qmargin, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.average.is_set or
                                            self.maximum.is_set or
                                            self.maximum_tca_report.is_set or
                                            self.maximum_threshold.is_set or
                                            self.minimum.is_set or
                                            self.minimum_tca_report.is_set or
                                            self.minimum_threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.average.yfilter != YFilter.not_set or
                                            self.maximum.yfilter != YFilter.not_set or
                                            self.maximum_tca_report.yfilter != YFilter.not_set or
                                            self.maximum_threshold.yfilter != YFilter.not_set or
                                            self.minimum.yfilter != YFilter.not_set or
                                            self.minimum_tca_report.yfilter != YFilter.not_set or
                                            self.minimum_threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "qmargin" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.average.get_name_leafdata())
                                        if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum.get_name_leafdata())
                                        if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                        if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                        if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum.get_name_leafdata())
                                        if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                        if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "average"):
                                            self.average = value
                                            self.average.value_namespace = name_space
                                            self.average.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum"):
                                            self.maximum = value
                                            self.maximum.value_namespace = name_space
                                            self.maximum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-tca-report"):
                                            self.maximum_tca_report = value
                                            self.maximum_tca_report.value_namespace = name_space
                                            self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "maximum-threshold"):
                                            self.maximum_threshold = value
                                            self.maximum_threshold.value_namespace = name_space
                                            self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum"):
                                            self.minimum = value
                                            self.minimum.value_namespace = name_space
                                            self.minimum.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-tca-report"):
                                            self.minimum_tca_report = value
                                            self.minimum_tca_report.value_namespace = name_space
                                            self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "minimum-threshold"):
                                            self.minimum_threshold = value
                                            self.minimum_threshold.value_namespace = name_space
                                            self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.ec_bits is not None and self.ec_bits.has_data()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                        (self.q is not None and self.q.has_data()) or
                                        (self.qmargin is not None and self.qmargin.has_data()) or
                                        (self.uc_words is not None and self.uc_words.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                        (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                        (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                        (self.q is not None and self.q.has_operation()) or
                                        (self.qmargin is not None and self.qmargin.has_operation()) or
                                        (self.uc_words is not None and self.uc_words.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dwdm-hour24fec" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ec-bits"):
                                        if (self.ec_bits is None):
                                            self.ec_bits = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.EcBits()
                                            self.ec_bits.parent = self
                                            self._children_name_map["ec_bits"] = "ec-bits"
                                        return self.ec_bits

                                    if (child_yang_name == "post-fec-ber"):
                                        if (self.post_fec_ber is None):
                                            self.post_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PostFecBer()
                                            self.post_fec_ber.parent = self
                                            self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                        return self.post_fec_ber

                                    if (child_yang_name == "pre-fec-ber"):
                                        if (self.pre_fec_ber is None):
                                            self.pre_fec_ber = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.PreFecBer()
                                            self.pre_fec_ber.parent = self
                                            self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                        return self.pre_fec_ber

                                    if (child_yang_name == "q"):
                                        if (self.q is None):
                                            self.q = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Q()
                                            self.q.parent = self
                                            self._children_name_map["q"] = "q"
                                        return self.q

                                    if (child_yang_name == "qmargin"):
                                        if (self.qmargin is None):
                                            self.qmargin = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.Qmargin()
                                            self.qmargin.parent = self
                                            self._children_name_map["qmargin"] = "qmargin"
                                        return self.qmargin

                                    if (child_yang_name == "uc-words"):
                                        if (self.uc_words is None):
                                            self.uc_words = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec.UcWords()
                                            self.uc_words.parent = self
                                            self._children_name_map["uc_words"] = "uc-words"
                                        return self.uc_words

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.dwdm_hour24fec:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.dwdm_hour24fec:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dwdm-hour24fecs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dwdm-hour24fec"):
                                    for c in self.dwdm_hour24fec:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs.DwdmHour24Fec()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.dwdm_hour24fec.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dwdm-hour24fec"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DwdmHour24Otns(Entity):
                            """
                            port 24 hour performance data
                            
                            .. attribute:: dwdm_hour24otn
                            
                            	port 24 hour otn performance data
                            	**type**\: list of    :py:class:`DwdmHour24Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns, self).__init__()

                                self.yang_name = "dwdm-hour24otns"
                                self.yang_parent_name = "dwdm-hour24"

                                self.dwdm_hour24otn = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns, self).__setattr__(name, value)


                            class DwdmHour24Otn(Entity):
                                """
                                port 24 hour otn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: bbe_fe
                                
                                	BBE SM FE
                                	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeFe>`
                                
                                .. attribute:: bbe_ne
                                
                                	BBE SM NE
                                	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeNe>`
                                
                                .. attribute:: bber_fe
                                
                                	BBER SM FE
                                	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberFe>`
                                
                                .. attribute:: bber_ne
                                
                                	BBER SM NE
                                	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberNe>`
                                
                                .. attribute:: es_fe
                                
                                	ES SM FE
                                	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsFe>`
                                
                                .. attribute:: es_ne
                                
                                	ES SM NE
                                	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsNe>`
                                
                                .. attribute:: esr_fe
                                
                                	ESR PM FE
                                	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrFe>`
                                
                                .. attribute:: esr_ne
                                
                                	ESR PM NE
                                	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrNe>`
                                
                                .. attribute:: fc_fe
                                
                                	FC SM FE
                                	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcFe>`
                                
                                .. attribute:: fc_ne
                                
                                	FC SM NE
                                	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcNe>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: lbc
                                
                                	LBC
                                	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.Lbc>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: ses_fe
                                
                                	SES SM FE
                                	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesFe>`
                                
                                .. attribute:: ses_ne
                                
                                	SES SM NE
                                	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesNe>`
                                
                                .. attribute:: sesr_fe
                                
                                	SESR SM FE
                                	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrFe>`
                                
                                .. attribute:: sesr_ne
                                
                                	SESR SM NE
                                	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrNe>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                .. attribute:: uas_fe
                                
                                	UAS SM FE
                                	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasFe>`
                                
                                .. attribute:: uas_ne
                                
                                	UAS SM NE
                                	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasNe>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn, self).__init__()

                                    self.yang_name = "dwdm-hour24otn"
                                    self.yang_parent_name = "dwdm-hour24otns"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.bbe_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeFe()
                                    self.bbe_fe.parent = self
                                    self._children_name_map["bbe_fe"] = "bbe-fe"
                                    self._children_yang_names.add("bbe-fe")

                                    self.bbe_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeNe()
                                    self.bbe_ne.parent = self
                                    self._children_name_map["bbe_ne"] = "bbe-ne"
                                    self._children_yang_names.add("bbe-ne")

                                    self.bber_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberFe()
                                    self.bber_fe.parent = self
                                    self._children_name_map["bber_fe"] = "bber-fe"
                                    self._children_yang_names.add("bber-fe")

                                    self.bber_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberNe()
                                    self.bber_ne.parent = self
                                    self._children_name_map["bber_ne"] = "bber-ne"
                                    self._children_yang_names.add("bber-ne")

                                    self.es_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsFe()
                                    self.es_fe.parent = self
                                    self._children_name_map["es_fe"] = "es-fe"
                                    self._children_yang_names.add("es-fe")

                                    self.es_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsNe()
                                    self.es_ne.parent = self
                                    self._children_name_map["es_ne"] = "es-ne"
                                    self._children_yang_names.add("es-ne")

                                    self.esr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrFe()
                                    self.esr_fe.parent = self
                                    self._children_name_map["esr_fe"] = "esr-fe"
                                    self._children_yang_names.add("esr-fe")

                                    self.esr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrNe()
                                    self.esr_ne.parent = self
                                    self._children_name_map["esr_ne"] = "esr-ne"
                                    self._children_yang_names.add("esr-ne")

                                    self.fc_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcFe()
                                    self.fc_fe.parent = self
                                    self._children_name_map["fc_fe"] = "fc-fe"
                                    self._children_yang_names.add("fc-fe")

                                    self.fc_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcNe()
                                    self.fc_ne.parent = self
                                    self._children_name_map["fc_ne"] = "fc-ne"
                                    self._children_yang_names.add("fc-ne")

                                    self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.Lbc()
                                    self.lbc.parent = self
                                    self._children_name_map["lbc"] = "lbc"
                                    self._children_yang_names.add("lbc")

                                    self.ses_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesFe()
                                    self.ses_fe.parent = self
                                    self._children_name_map["ses_fe"] = "ses-fe"
                                    self._children_yang_names.add("ses-fe")

                                    self.ses_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesNe()
                                    self.ses_ne.parent = self
                                    self._children_name_map["ses_ne"] = "ses-ne"
                                    self._children_yang_names.add("ses-ne")

                                    self.sesr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrFe()
                                    self.sesr_fe.parent = self
                                    self._children_name_map["sesr_fe"] = "sesr-fe"
                                    self._children_yang_names.add("sesr-fe")

                                    self.sesr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrNe()
                                    self.sesr_ne.parent = self
                                    self._children_name_map["sesr_ne"] = "sesr-ne"
                                    self._children_yang_names.add("sesr-ne")

                                    self.uas_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasFe()
                                    self.uas_fe.parent = self
                                    self._children_name_map["uas_fe"] = "uas-fe"
                                    self._children_yang_names.add("uas-fe")

                                    self.uas_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasNe()
                                    self.uas_ne.parent = self
                                    self._children_name_map["uas_ne"] = "uas-ne"
                                    self._children_yang_names.add("uas-ne")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn, self).__setattr__(name, value)


                                class Lbc(Entity):
                                    """
                                    LBC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.Lbc, self).__init__()

                                        self.yang_name = "lbc"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.Lbc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.Lbc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lbc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsNe(Entity):
                                    """
                                    ES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsNe, self).__init__()

                                        self.yang_name = "es-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrNe(Entity):
                                    """
                                    ESR PM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrNe, self).__init__()

                                        self.yang_name = "esr-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesNe(Entity):
                                    """
                                    SES SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesNe, self).__init__()

                                        self.yang_name = "ses-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrNe(Entity):
                                    """
                                    SESR SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrNe, self).__init__()

                                        self.yang_name = "sesr-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasNe(Entity):
                                    """
                                    UAS SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasNe, self).__init__()

                                        self.yang_name = "uas-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeNe(Entity):
                                    """
                                    BBE SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeNe, self).__init__()

                                        self.yang_name = "bbe-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberNe(Entity):
                                    """
                                    BBER SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberNe, self).__init__()

                                        self.yang_name = "bber-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcNe(Entity):
                                    """
                                    FC SM NE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcNe, self).__init__()

                                        self.yang_name = "fc-ne"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcNe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcNe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-ne" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsFe(Entity):
                                    """
                                    ES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsFe, self).__init__()

                                        self.yang_name = "es-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "es-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class EsrFe(Entity):
                                    """
                                    ESR PM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrFe, self).__init__()

                                        self.yang_name = "esr-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "esr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesFe(Entity):
                                    """
                                    SES SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesFe, self).__init__()

                                        self.yang_name = "ses-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ses-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class SesrFe(Entity):
                                    """
                                    SESR SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrFe, self).__init__()

                                        self.yang_name = "sesr-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sesr-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class UasFe(Entity):
                                    """
                                    UAS SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasFe, self).__init__()

                                        self.yang_name = "uas-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "uas-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BbeFe(Entity):
                                    """
                                    BBE SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeFe, self).__init__()

                                        self.yang_name = "bbe-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bbe-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class BberFe(Entity):
                                    """
                                    BBER SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberFe, self).__init__()

                                        self.yang_name = "bber-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bber-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix


                                class FcFe(Entity):
                                    """
                                    FC SM FE
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcFe, self).__init__()

                                        self.yang_name = "fc-fe"
                                        self.yang_parent_name = "dwdm-hour24otn"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcFe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcFe, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fc-fe" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                        (self.bber_fe is not None and self.bber_fe.has_data()) or
                                        (self.bber_ne is not None and self.bber_ne.has_data()) or
                                        (self.es_fe is not None and self.es_fe.has_data()) or
                                        (self.es_ne is not None and self.es_ne.has_data()) or
                                        (self.esr_fe is not None and self.esr_fe.has_data()) or
                                        (self.esr_ne is not None and self.esr_ne.has_data()) or
                                        (self.fc_fe is not None and self.fc_fe.has_data()) or
                                        (self.fc_ne is not None and self.fc_ne.has_data()) or
                                        (self.lbc is not None and self.lbc.has_data()) or
                                        (self.ses_fe is not None and self.ses_fe.has_data()) or
                                        (self.ses_ne is not None and self.ses_ne.has_data()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                        (self.uas_fe is not None and self.uas_fe.has_data()) or
                                        (self.uas_ne is not None and self.uas_ne.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                        (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                        (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                        (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                        (self.es_fe is not None and self.es_fe.has_operation()) or
                                        (self.es_ne is not None and self.es_ne.has_operation()) or
                                        (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                        (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                        (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                        (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                        (self.lbc is not None and self.lbc.has_operation()) or
                                        (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                        (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                        (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                        (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                        (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                        (self.uas_ne is not None and self.uas_ne.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dwdm-hour24otn" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "bbe-fe"):
                                        if (self.bbe_fe is None):
                                            self.bbe_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeFe()
                                            self.bbe_fe.parent = self
                                            self._children_name_map["bbe_fe"] = "bbe-fe"
                                        return self.bbe_fe

                                    if (child_yang_name == "bbe-ne"):
                                        if (self.bbe_ne is None):
                                            self.bbe_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BbeNe()
                                            self.bbe_ne.parent = self
                                            self._children_name_map["bbe_ne"] = "bbe-ne"
                                        return self.bbe_ne

                                    if (child_yang_name == "bber-fe"):
                                        if (self.bber_fe is None):
                                            self.bber_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberFe()
                                            self.bber_fe.parent = self
                                            self._children_name_map["bber_fe"] = "bber-fe"
                                        return self.bber_fe

                                    if (child_yang_name == "bber-ne"):
                                        if (self.bber_ne is None):
                                            self.bber_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.BberNe()
                                            self.bber_ne.parent = self
                                            self._children_name_map["bber_ne"] = "bber-ne"
                                        return self.bber_ne

                                    if (child_yang_name == "es-fe"):
                                        if (self.es_fe is None):
                                            self.es_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsFe()
                                            self.es_fe.parent = self
                                            self._children_name_map["es_fe"] = "es-fe"
                                        return self.es_fe

                                    if (child_yang_name == "es-ne"):
                                        if (self.es_ne is None):
                                            self.es_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsNe()
                                            self.es_ne.parent = self
                                            self._children_name_map["es_ne"] = "es-ne"
                                        return self.es_ne

                                    if (child_yang_name == "esr-fe"):
                                        if (self.esr_fe is None):
                                            self.esr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrFe()
                                            self.esr_fe.parent = self
                                            self._children_name_map["esr_fe"] = "esr-fe"
                                        return self.esr_fe

                                    if (child_yang_name == "esr-ne"):
                                        if (self.esr_ne is None):
                                            self.esr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.EsrNe()
                                            self.esr_ne.parent = self
                                            self._children_name_map["esr_ne"] = "esr-ne"
                                        return self.esr_ne

                                    if (child_yang_name == "fc-fe"):
                                        if (self.fc_fe is None):
                                            self.fc_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcFe()
                                            self.fc_fe.parent = self
                                            self._children_name_map["fc_fe"] = "fc-fe"
                                        return self.fc_fe

                                    if (child_yang_name == "fc-ne"):
                                        if (self.fc_ne is None):
                                            self.fc_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.FcNe()
                                            self.fc_ne.parent = self
                                            self._children_name_map["fc_ne"] = "fc-ne"
                                        return self.fc_ne

                                    if (child_yang_name == "lbc"):
                                        if (self.lbc is None):
                                            self.lbc = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.Lbc()
                                            self.lbc.parent = self
                                            self._children_name_map["lbc"] = "lbc"
                                        return self.lbc

                                    if (child_yang_name == "ses-fe"):
                                        if (self.ses_fe is None):
                                            self.ses_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesFe()
                                            self.ses_fe.parent = self
                                            self._children_name_map["ses_fe"] = "ses-fe"
                                        return self.ses_fe

                                    if (child_yang_name == "ses-ne"):
                                        if (self.ses_ne is None):
                                            self.ses_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesNe()
                                            self.ses_ne.parent = self
                                            self._children_name_map["ses_ne"] = "ses-ne"
                                        return self.ses_ne

                                    if (child_yang_name == "sesr-fe"):
                                        if (self.sesr_fe is None):
                                            self.sesr_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrFe()
                                            self.sesr_fe.parent = self
                                            self._children_name_map["sesr_fe"] = "sesr-fe"
                                        return self.sesr_fe

                                    if (child_yang_name == "sesr-ne"):
                                        if (self.sesr_ne is None):
                                            self.sesr_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.SesrNe()
                                            self.sesr_ne.parent = self
                                            self._children_name_map["sesr_ne"] = "sesr-ne"
                                        return self.sesr_ne

                                    if (child_yang_name == "uas-fe"):
                                        if (self.uas_fe is None):
                                            self.uas_fe = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasFe()
                                            self.uas_fe.parent = self
                                            self._children_name_map["uas_fe"] = "uas-fe"
                                        return self.uas_fe

                                    if (child_yang_name == "uas-ne"):
                                        if (self.uas_ne is None):
                                            self.uas_ne = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn.UasNe()
                                            self.uas_ne.parent = self
                                            self._children_name_map["uas_ne"] = "uas-ne"
                                        return self.uas_ne

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.dwdm_hour24otn:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.dwdm_hour24otn:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dwdm-hour24otns" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dwdm-hour24otn"):
                                    for c in self.dwdm_hour24otn:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns.DwdmHour24Otn()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.dwdm_hour24otn.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dwdm-hour24otn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.dwdm_hour24_optics is not None and self.dwdm_hour24_optics.has_data()) or
                                (self.dwdm_hour24fecs is not None and self.dwdm_hour24fecs.has_data()) or
                                (self.dwdm_hour24otns is not None and self.dwdm_hour24otns.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.dwdm_hour24_optics is not None and self.dwdm_hour24_optics.has_operation()) or
                                (self.dwdm_hour24fecs is not None and self.dwdm_hour24fecs.has_operation()) or
                                (self.dwdm_hour24otns is not None and self.dwdm_hour24otns.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dwdm-hour24" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dwdm-hour24-optics"):
                                if (self.dwdm_hour24_optics is None):
                                    self.dwdm_hour24_optics = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Optics()
                                    self.dwdm_hour24_optics.parent = self
                                    self._children_name_map["dwdm_hour24_optics"] = "dwdm-hour24-optics"
                                return self.dwdm_hour24_optics

                            if (child_yang_name == "dwdm-hour24fecs"):
                                if (self.dwdm_hour24fecs is None):
                                    self.dwdm_hour24fecs = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Fecs()
                                    self.dwdm_hour24fecs.parent = self
                                    self._children_name_map["dwdm_hour24fecs"] = "dwdm-hour24fecs"
                                return self.dwdm_hour24fecs

                            if (child_yang_name == "dwdm-hour24otns"):
                                if (self.dwdm_hour24otns is None):
                                    self.dwdm_hour24otns = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24.DwdmHour24Otns()
                                    self.dwdm_hour24otns.parent = self
                                    self._children_name_map["dwdm_hour24otns"] = "dwdm-hour24otns"
                                return self.dwdm_hour24otns

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dwdm-hour24-optics" or name == "dwdm-hour24fecs" or name == "dwdm-hour24otns"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.dwdm_hour24 is not None and self.dwdm_hour24.has_data()) or
                            (self.dwdm_minute15 is not None and self.dwdm_minute15.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.dwdm_hour24 is not None and self.dwdm_hour24.has_operation()) or
                            (self.dwdm_minute15 is not None and self.dwdm_minute15.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "dwdm-current" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dwdm-hour24"):
                            if (self.dwdm_hour24 is None):
                                self.dwdm_hour24 = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmHour24()
                                self.dwdm_hour24.parent = self
                                self._children_name_map["dwdm_hour24"] = "dwdm-hour24"
                            return self.dwdm_hour24

                        if (child_yang_name == "dwdm-minute15"):
                            if (self.dwdm_minute15 is None):
                                self.dwdm_minute15 = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent.DwdmMinute15()
                                self.dwdm_minute15.parent = self
                                self._children_name_map["dwdm_minute15"] = "dwdm-minute15"
                            return self.dwdm_minute15

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dwdm-hour24" or name == "dwdm-minute15"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.name.is_set or
                        (self.dwdm_current is not None and self.dwdm_current.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        (self.dwdm_current is not None and self.dwdm_current.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "dwdm-port" + "[name='" + self.name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/dwdm/dwdm-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "dwdm-current"):
                        if (self.dwdm_current is None):
                            self.dwdm_current = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort.DwdmCurrent()
                            self.dwdm_current.parent = self
                            self._children_name_map["dwdm_current"] = "dwdm-current"
                        return self.dwdm_current

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "dwdm-current" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.dwdm_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.dwdm_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "dwdm-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/dwdm/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "dwdm-port"):
                    for c in self.dwdm_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = PerformanceManagement.Dwdm.DwdmPorts.DwdmPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.dwdm_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "dwdm-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.dwdm_ports is not None and self.dwdm_ports.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.dwdm_ports is not None and self.dwdm_ports.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "dwdm" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "dwdm-ports"):
                if (self.dwdm_ports is None):
                    self.dwdm_ports = PerformanceManagement.Dwdm.DwdmPorts()
                    self.dwdm_ports.parent = self
                    self._children_name_map["dwdm_ports"] = "dwdm-ports"
                return self.dwdm_ports

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "dwdm-ports"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Oc(Entity):
        """
        OC controller performance data
        
        .. attribute:: oc_ports
        
        	Port performance data
        	**type**\:   :py:class:`OcPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PerformanceManagement.Oc, self).__init__()

            self.yang_name = "oc"
            self.yang_parent_name = "performance-management"

            self.oc_ports = PerformanceManagement.Oc.OcPorts()
            self.oc_ports.parent = self
            self._children_name_map["oc_ports"] = "oc-ports"
            self._children_yang_names.add("oc-ports")


        class OcPorts(Entity):
            """
            Port performance data
            
            .. attribute:: oc_port
            
            	Port performance data
            	**type**\: list of    :py:class:`OcPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PerformanceManagement.Oc.OcPorts, self).__init__()

                self.yang_name = "oc-ports"
                self.yang_parent_name = "oc"

                self.oc_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(PerformanceManagement.Oc.OcPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(PerformanceManagement.Oc.OcPorts, self).__setattr__(name, value)


            class OcPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: oc_current
                
                	port current performance data
                	**type**\:   :py:class:`OcCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagement.Oc.OcPorts.OcPort, self).__init__()

                    self.yang_name = "oc-port"
                    self.yang_parent_name = "oc-ports"

                    self.name = YLeaf(YType.str, "name")

                    self.oc_current = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent()
                    self.oc_current.parent = self
                    self._children_name_map["oc_current"] = "oc-current"
                    self._children_yang_names.add("oc-current")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PerformanceManagement.Oc.OcPorts.OcPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PerformanceManagement.Oc.OcPorts.OcPort, self).__setattr__(name, value)


                class OcCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: oc_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`OcHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24>`
                    
                    .. attribute:: oc_minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`OcMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent, self).__init__()

                        self.yang_name = "oc-current"
                        self.yang_parent_name = "oc-port"

                        self.oc_hour24 = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24()
                        self.oc_hour24.parent = self
                        self._children_name_map["oc_hour24"] = "oc-hour24"
                        self._children_yang_names.add("oc-hour24")

                        self.oc_minute15 = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15()
                        self.oc_minute15.parent = self
                        self._children_name_map["oc_minute15"] = "oc-minute15"
                        self._children_yang_names.add("oc-minute15")


                    class OcHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: oc_hour24ocns
                        
                        	port current performance data
                        	**type**\:   :py:class:`OcHour24Ocns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24, self).__init__()

                            self.yang_name = "oc-hour24"
                            self.yang_parent_name = "oc-current"

                            self.oc_hour24ocns = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns()
                            self.oc_hour24ocns.parent = self
                            self._children_name_map["oc_hour24ocns"] = "oc-hour24ocns"
                            self._children_yang_names.add("oc-hour24ocns")


                        class OcHour24Ocns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: oc_hour24ocn
                            
                            	port 24 hour ocn performance data
                            	**type**\: list of    :py:class:`OcHour24Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns, self).__init__()

                                self.yang_name = "oc-hour24ocns"
                                self.yang_parent_name = "oc-hour24"

                                self.oc_hour24ocn = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns, self).__setattr__(name, value)


                            class OcHour24Ocn(Entity):
                                """
                                port 24 hour ocn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line>`
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn, self).__init__()

                                    self.yang_name = "oc-hour24ocn"
                                    self.yang_parent_name = "oc-hour24ocns"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.fe_line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine()
                                    self.fe_line.parent = self
                                    self._children_name_map["fe_line"] = "fe-line"
                                    self._children_yang_names.add("fe-line")

                                    self.line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line()
                                    self.line.parent = self
                                    self._children_name_map["line"] = "line"
                                    self._children_yang_names.add("line")

                                    self.section = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section()
                                    self.section.parent = self
                                    self._children_name_map["section"] = "section"
                                    self._children_yang_names.add("section")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn, self).__setattr__(name, value)


                                class Section(Entity):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionCVs>`
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionESs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_sef_ss
                                    
                                    	The number of Severely Errored Framing Seconds
                                    	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSefSs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section, self).__init__()

                                        self.yang_name = "section"
                                        self.yang_parent_name = "oc-hour24ocn"

                                        self.section_status = YLeaf(YType.int32, "section-status")

                                        self.section_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionCVs()
                                        self.section_c_vs.parent = self
                                        self._children_name_map["section_c_vs"] = "section-c-vs"
                                        self._children_yang_names.add("section-c-vs")

                                        self.section_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self._children_name_map["section_e_ss"] = "section-e-ss"
                                        self._children_yang_names.add("section-e-ss")

                                        self.section_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self._children_name_map["section_se_ss"] = "section-se-ss"
                                        self._children_yang_names.add("section-se-ss")

                                        self.section_sef_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSefSs()
                                        self.section_sef_ss.parent = self
                                        self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                        self._children_yang_names.add("section-sef-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("section_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section, self).__setattr__(name, value)


                                    class SectionESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionESs, self).__init__()

                                            self.yang_name = "section-e-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSeSs, self).__init__()

                                            self.yang_name = "section-se-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionSefSs(Entity):
                                        """
                                        The number of Severely Errored Framing Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSefSs, self).__init__()

                                            self.yang_name = "section-sef-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSefSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSefSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-sef-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionCVs, self).__init__()

                                            self.yang_name = "section-c-vs"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.section_status.is_set or
                                            (self.section_c_vs is not None and self.section_c_vs.has_data()) or
                                            (self.section_e_ss is not None and self.section_e_ss.has_data()) or
                                            (self.section_se_ss is not None and self.section_se_ss.has_data()) or
                                            (self.section_sef_ss is not None and self.section_sef_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.section_status.yfilter != YFilter.not_set or
                                            (self.section_c_vs is not None and self.section_c_vs.has_operation()) or
                                            (self.section_e_ss is not None and self.section_e_ss.has_operation()) or
                                            (self.section_se_ss is not None and self.section_se_ss.has_operation()) or
                                            (self.section_sef_ss is not None and self.section_sef_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "section" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.section_status.is_set or self.section_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.section_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "section-c-vs"):
                                            if (self.section_c_vs is None):
                                                self.section_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionCVs()
                                                self.section_c_vs.parent = self
                                                self._children_name_map["section_c_vs"] = "section-c-vs"
                                            return self.section_c_vs

                                        if (child_yang_name == "section-e-ss"):
                                            if (self.section_e_ss is None):
                                                self.section_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionESs()
                                                self.section_e_ss.parent = self
                                                self._children_name_map["section_e_ss"] = "section-e-ss"
                                            return self.section_e_ss

                                        if (child_yang_name == "section-se-ss"):
                                            if (self.section_se_ss is None):
                                                self.section_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSeSs()
                                                self.section_se_ss.parent = self
                                                self._children_name_map["section_se_ss"] = "section-se-ss"
                                            return self.section_se_ss

                                        if (child_yang_name == "section-sef-ss"):
                                            if (self.section_sef_ss is None):
                                                self.section_sef_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section.SectionSefSs()
                                                self.section_sef_ss.parent = self
                                                self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                            return self.section_sef_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "section-c-vs" or name == "section-e-ss" or name == "section-se-ss" or name == "section-sef-ss" or name == "section-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "section-status"):
                                            self.section_status = value
                                            self.section_status.value_namespace = name_space
                                            self.section_status.value_namespace_prefix = name_space_prefix


                                class Line(Entity):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineCVs>`
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineESs>`
                                    
                                    .. attribute:: line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineFcLs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineSeSs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line, self).__init__()

                                        self.yang_name = "line"
                                        self.yang_parent_name = "oc-hour24ocn"

                                        self.line_status = YLeaf(YType.int32, "line-status")

                                        self.line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineCVs()
                                        self.line_c_vs.parent = self
                                        self._children_name_map["line_c_vs"] = "line-c-vs"
                                        self._children_yang_names.add("line-c-vs")

                                        self.line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self._children_name_map["line_e_ss"] = "line-e-ss"
                                        self._children_yang_names.add("line-e-ss")

                                        self.line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineFcLs()
                                        self.line_fc_ls.parent = self
                                        self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                        self._children_yang_names.add("line-fc-ls")

                                        self.line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self._children_name_map["line_se_ss"] = "line-se-ss"
                                        self._children_yang_names.add("line-se-ss")

                                        self.line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineUaSs()
                                        self.line_ua_ss.parent = self
                                        self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                        self._children_yang_names.add("line-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("line_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line, self).__setattr__(name, value)


                                    class LineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineESs, self).__init__()

                                            self.yang_name = "line-e-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineSeSs, self).__init__()

                                            self.yang_name = "line-se-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineCVs, self).__init__()

                                            self.yang_name = "line-c-vs"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineUaSs, self).__init__()

                                            self.yang_name = "line-ua-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineFcLs, self).__init__()

                                            self.yang_name = "line-fc-ls"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineFcLs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineFcLs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-fc-ls" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.line_status.is_set or
                                            (self.line_c_vs is not None and self.line_c_vs.has_data()) or
                                            (self.line_e_ss is not None and self.line_e_ss.has_data()) or
                                            (self.line_fc_ls is not None and self.line_fc_ls.has_data()) or
                                            (self.line_se_ss is not None and self.line_se_ss.has_data()) or
                                            (self.line_ua_ss is not None and self.line_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.line_status.yfilter != YFilter.not_set or
                                            (self.line_c_vs is not None and self.line_c_vs.has_operation()) or
                                            (self.line_e_ss is not None and self.line_e_ss.has_operation()) or
                                            (self.line_fc_ls is not None and self.line_fc_ls.has_operation()) or
                                            (self.line_se_ss is not None and self.line_se_ss.has_operation()) or
                                            (self.line_ua_ss is not None and self.line_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "line" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.line_status.is_set or self.line_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.line_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "line-c-vs"):
                                            if (self.line_c_vs is None):
                                                self.line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineCVs()
                                                self.line_c_vs.parent = self
                                                self._children_name_map["line_c_vs"] = "line-c-vs"
                                            return self.line_c_vs

                                        if (child_yang_name == "line-e-ss"):
                                            if (self.line_e_ss is None):
                                                self.line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineESs()
                                                self.line_e_ss.parent = self
                                                self._children_name_map["line_e_ss"] = "line-e-ss"
                                            return self.line_e_ss

                                        if (child_yang_name == "line-fc-ls"):
                                            if (self.line_fc_ls is None):
                                                self.line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineFcLs()
                                                self.line_fc_ls.parent = self
                                                self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                            return self.line_fc_ls

                                        if (child_yang_name == "line-se-ss"):
                                            if (self.line_se_ss is None):
                                                self.line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineSeSs()
                                                self.line_se_ss.parent = self
                                                self._children_name_map["line_se_ss"] = "line-se-ss"
                                            return self.line_se_ss

                                        if (child_yang_name == "line-ua-ss"):
                                            if (self.line_ua_ss is None):
                                                self.line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line.LineUaSs()
                                                self.line_ua_ss.parent = self
                                                self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                            return self.line_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "line-c-vs" or name == "line-e-ss" or name == "line-fc-ls" or name == "line-se-ss" or name == "line-ua-ss" or name == "line-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "line-status"):
                                            self.line_status = value
                                            self.line_status.value_namespace = name_space
                                            self.line_status.value_namespace_prefix = name_space_prefix


                                class FeLine(Entity):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineCVs>`
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineFcLs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine, self).__init__()

                                        self.yang_name = "fe-line"
                                        self.yang_parent_name = "oc-hour24ocn"

                                        self.far_end_line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineCVs()
                                        self.far_end_line_c_vs.parent = self
                                        self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                        self._children_yang_names.add("far-end-line-c-vs")

                                        self.far_end_line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                        self._children_yang_names.add("far-end-line-e-ss")

                                        self.far_end_line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineFcLs()
                                        self.far_end_line_fc_ls.parent = self
                                        self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                        self._children_yang_names.add("far-end-line-fc-ls")

                                        self.far_end_line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                        self._children_yang_names.add("far-end-line-se-ss")

                                        self.far_end_line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self
                                        self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                        self._children_yang_names.add("far-end-line-ua-ss")


                                    class FarEndLineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineESs, self).__init__()

                                            self.yang_name = "far-end-line-e-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineSeSs, self).__init__()

                                            self.yang_name = "far-end-line-se-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineCVs, self).__init__()

                                            self.yang_name = "far-end-line-c-vs"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineUaSs, self).__init__()

                                            self.yang_name = "far-end-line-ua-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineFcLs, self).__init__()

                                            self.yang_name = "far-end-line-fc-ls"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineFcLs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineFcLs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-fc-ls" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_data()) or
                                            (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_data()) or
                                            (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_data()) or
                                            (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_data()) or
                                            (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_operation()) or
                                            (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_operation()) or
                                            (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_operation()) or
                                            (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_operation()) or
                                            (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fe-line" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "far-end-line-c-vs"):
                                            if (self.far_end_line_c_vs is None):
                                                self.far_end_line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineCVs()
                                                self.far_end_line_c_vs.parent = self
                                                self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                            return self.far_end_line_c_vs

                                        if (child_yang_name == "far-end-line-e-ss"):
                                            if (self.far_end_line_e_ss is None):
                                                self.far_end_line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineESs()
                                                self.far_end_line_e_ss.parent = self
                                                self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                            return self.far_end_line_e_ss

                                        if (child_yang_name == "far-end-line-fc-ls"):
                                            if (self.far_end_line_fc_ls is None):
                                                self.far_end_line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineFcLs()
                                                self.far_end_line_fc_ls.parent = self
                                                self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                            return self.far_end_line_fc_ls

                                        if (child_yang_name == "far-end-line-se-ss"):
                                            if (self.far_end_line_se_ss is None):
                                                self.far_end_line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineSeSs()
                                                self.far_end_line_se_ss.parent = self
                                                self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                            return self.far_end_line_se_ss

                                        if (child_yang_name == "far-end-line-ua-ss"):
                                            if (self.far_end_line_ua_ss is None):
                                                self.far_end_line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine.FarEndLineUaSs()
                                                self.far_end_line_ua_ss.parent = self
                                                self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                            return self.far_end_line_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "far-end-line-c-vs" or name == "far-end-line-e-ss" or name == "far-end-line-fc-ls" or name == "far-end-line-se-ss" or name == "far-end-line-ua-ss"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.fe_line is not None and self.fe_line.has_data()) or
                                        (self.line is not None and self.line.has_data()) or
                                        (self.section is not None and self.section.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.fe_line is not None and self.fe_line.has_operation()) or
                                        (self.line is not None and self.line.has_operation()) or
                                        (self.section is not None and self.section.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "oc-hour24ocn" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "fe-line"):
                                        if (self.fe_line is None):
                                            self.fe_line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.FeLine()
                                            self.fe_line.parent = self
                                            self._children_name_map["fe_line"] = "fe-line"
                                        return self.fe_line

                                    if (child_yang_name == "line"):
                                        if (self.line is None):
                                            self.line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Line()
                                            self.line.parent = self
                                            self._children_name_map["line"] = "line"
                                        return self.line

                                    if (child_yang_name == "section"):
                                        if (self.section is None):
                                            self.section = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn.Section()
                                            self.section.parent = self
                                            self._children_name_map["section"] = "section"
                                        return self.section

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fe-line" or name == "line" or name == "section" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.oc_hour24ocn:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.oc_hour24ocn:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "oc-hour24ocns" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "oc-hour24ocn"):
                                    for c in self.oc_hour24ocn:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns.OcHour24Ocn()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.oc_hour24ocn.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "oc-hour24ocn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.oc_hour24ocns is not None and self.oc_hour24ocns.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.oc_hour24ocns is not None and self.oc_hour24ocns.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "oc-hour24" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "oc-hour24ocns"):
                                if (self.oc_hour24ocns is None):
                                    self.oc_hour24ocns = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24.OcHour24Ocns()
                                    self.oc_hour24ocns.parent = self
                                    self._children_name_map["oc_hour24ocns"] = "oc-hour24ocns"
                                return self.oc_hour24ocns

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "oc-hour24ocns"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OcMinute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: oc_minute15ocns
                        
                        	port current performance data
                        	**type**\:   :py:class:`OcMinute15Ocns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15, self).__init__()

                            self.yang_name = "oc-minute15"
                            self.yang_parent_name = "oc-current"

                            self.oc_minute15ocns = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns()
                            self.oc_minute15ocns.parent = self
                            self._children_name_map["oc_minute15ocns"] = "oc-minute15ocns"
                            self._children_yang_names.add("oc-minute15ocns")


                        class OcMinute15Ocns(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: oc_minute15ocn
                            
                            	port 15\-minute ocn performance data
                            	**type**\: list of    :py:class:`OcMinute15Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns, self).__init__()

                                self.yang_name = "oc-minute15ocns"
                                self.yang_parent_name = "oc-minute15"

                                self.oc_minute15ocn = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns, self).__setattr__(name, value)


                            class OcMinute15Ocn(Entity):
                                """
                                port 15\-minute ocn performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: fe_line
                                
                                	FarEnd LINE
                                	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: line
                                
                                	LINE
                                	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line>`
                                
                                .. attribute:: section
                                
                                	SECTION
                                	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn, self).__init__()

                                    self.yang_name = "oc-minute15ocn"
                                    self.yang_parent_name = "oc-minute15ocns"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.fe_line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine()
                                    self.fe_line.parent = self
                                    self._children_name_map["fe_line"] = "fe-line"
                                    self._children_yang_names.add("fe-line")

                                    self.line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line()
                                    self.line.parent = self
                                    self._children_name_map["line"] = "line"
                                    self._children_yang_names.add("line")

                                    self.section = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section()
                                    self.section.parent = self
                                    self._children_name_map["section"] = "section"
                                    self._children_yang_names.add("section")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear_time",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn, self).__setattr__(name, value)


                                class Section(Entity):
                                    """
                                    SECTION
                                    
                                    .. attribute:: section_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionCVs>`
                                    
                                    .. attribute:: section_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionESs>`
                                    
                                    .. attribute:: section_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSeSs>`
                                    
                                    .. attribute:: section_sef_ss
                                    
                                    	The number of Severely Errored Framing Seconds
                                    	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSefSs>`
                                    
                                    .. attribute:: section_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section, self).__init__()

                                        self.yang_name = "section"
                                        self.yang_parent_name = "oc-minute15ocn"

                                        self.section_status = YLeaf(YType.int32, "section-status")

                                        self.section_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionCVs()
                                        self.section_c_vs.parent = self
                                        self._children_name_map["section_c_vs"] = "section-c-vs"
                                        self._children_yang_names.add("section-c-vs")

                                        self.section_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionESs()
                                        self.section_e_ss.parent = self
                                        self._children_name_map["section_e_ss"] = "section-e-ss"
                                        self._children_yang_names.add("section-e-ss")

                                        self.section_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSeSs()
                                        self.section_se_ss.parent = self
                                        self._children_name_map["section_se_ss"] = "section-se-ss"
                                        self._children_yang_names.add("section-se-ss")

                                        self.section_sef_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSefSs()
                                        self.section_sef_ss.parent = self
                                        self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                        self._children_yang_names.add("section-sef-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("section_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section, self).__setattr__(name, value)


                                    class SectionESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionESs, self).__init__()

                                            self.yang_name = "section-e-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSeSs, self).__init__()

                                            self.yang_name = "section-se-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionSefSs(Entity):
                                        """
                                        The number of Severely Errored Framing Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSefSs, self).__init__()

                                            self.yang_name = "section-sef-ss"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSefSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSefSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-sef-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class SectionCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionCVs, self).__init__()

                                            self.yang_name = "section-c-vs"
                                            self.yang_parent_name = "section"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "section-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.section_status.is_set or
                                            (self.section_c_vs is not None and self.section_c_vs.has_data()) or
                                            (self.section_e_ss is not None and self.section_e_ss.has_data()) or
                                            (self.section_se_ss is not None and self.section_se_ss.has_data()) or
                                            (self.section_sef_ss is not None and self.section_sef_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.section_status.yfilter != YFilter.not_set or
                                            (self.section_c_vs is not None and self.section_c_vs.has_operation()) or
                                            (self.section_e_ss is not None and self.section_e_ss.has_operation()) or
                                            (self.section_se_ss is not None and self.section_se_ss.has_operation()) or
                                            (self.section_sef_ss is not None and self.section_sef_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "section" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.section_status.is_set or self.section_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.section_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "section-c-vs"):
                                            if (self.section_c_vs is None):
                                                self.section_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionCVs()
                                                self.section_c_vs.parent = self
                                                self._children_name_map["section_c_vs"] = "section-c-vs"
                                            return self.section_c_vs

                                        if (child_yang_name == "section-e-ss"):
                                            if (self.section_e_ss is None):
                                                self.section_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionESs()
                                                self.section_e_ss.parent = self
                                                self._children_name_map["section_e_ss"] = "section-e-ss"
                                            return self.section_e_ss

                                        if (child_yang_name == "section-se-ss"):
                                            if (self.section_se_ss is None):
                                                self.section_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSeSs()
                                                self.section_se_ss.parent = self
                                                self._children_name_map["section_se_ss"] = "section-se-ss"
                                            return self.section_se_ss

                                        if (child_yang_name == "section-sef-ss"):
                                            if (self.section_sef_ss is None):
                                                self.section_sef_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section.SectionSefSs()
                                                self.section_sef_ss.parent = self
                                                self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                            return self.section_sef_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "section-c-vs" or name == "section-e-ss" or name == "section-se-ss" or name == "section-sef-ss" or name == "section-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "section-status"):
                                            self.section_status = value
                                            self.section_status.value_namespace = name_space
                                            self.section_status.value_namespace_prefix = name_space_prefix


                                class Line(Entity):
                                    """
                                    LINE
                                    
                                    .. attribute:: line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineCVs>`
                                    
                                    .. attribute:: line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineESs>`
                                    
                                    .. attribute:: line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineFcLs>`
                                    
                                    .. attribute:: line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineSeSs>`
                                    
                                    .. attribute:: line_status
                                    
                                    	 status of the interface
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line, self).__init__()

                                        self.yang_name = "line"
                                        self.yang_parent_name = "oc-minute15ocn"

                                        self.line_status = YLeaf(YType.int32, "line-status")

                                        self.line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineCVs()
                                        self.line_c_vs.parent = self
                                        self._children_name_map["line_c_vs"] = "line-c-vs"
                                        self._children_yang_names.add("line-c-vs")

                                        self.line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineESs()
                                        self.line_e_ss.parent = self
                                        self._children_name_map["line_e_ss"] = "line-e-ss"
                                        self._children_yang_names.add("line-e-ss")

                                        self.line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineFcLs()
                                        self.line_fc_ls.parent = self
                                        self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                        self._children_yang_names.add("line-fc-ls")

                                        self.line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineSeSs()
                                        self.line_se_ss.parent = self
                                        self._children_name_map["line_se_ss"] = "line-se-ss"
                                        self._children_yang_names.add("line-se-ss")

                                        self.line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineUaSs()
                                        self.line_ua_ss.parent = self
                                        self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                        self._children_yang_names.add("line-ua-ss")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("line_status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line, self).__setattr__(name, value)


                                    class LineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineESs, self).__init__()

                                            self.yang_name = "line-e-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineSeSs, self).__init__()

                                            self.yang_name = "line-se-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineCVs, self).__init__()

                                            self.yang_name = "line-c-vs"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineUaSs, self).__init__()

                                            self.yang_name = "line-ua-ss"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class LineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineFcLs, self).__init__()

                                            self.yang_name = "line-fc-ls"
                                            self.yang_parent_name = "line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineFcLs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineFcLs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "line-fc-ls" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.line_status.is_set or
                                            (self.line_c_vs is not None and self.line_c_vs.has_data()) or
                                            (self.line_e_ss is not None and self.line_e_ss.has_data()) or
                                            (self.line_fc_ls is not None and self.line_fc_ls.has_data()) or
                                            (self.line_se_ss is not None and self.line_se_ss.has_data()) or
                                            (self.line_ua_ss is not None and self.line_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.line_status.yfilter != YFilter.not_set or
                                            (self.line_c_vs is not None and self.line_c_vs.has_operation()) or
                                            (self.line_e_ss is not None and self.line_e_ss.has_operation()) or
                                            (self.line_fc_ls is not None and self.line_fc_ls.has_operation()) or
                                            (self.line_se_ss is not None and self.line_se_ss.has_operation()) or
                                            (self.line_ua_ss is not None and self.line_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "line" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.line_status.is_set or self.line_status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.line_status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "line-c-vs"):
                                            if (self.line_c_vs is None):
                                                self.line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineCVs()
                                                self.line_c_vs.parent = self
                                                self._children_name_map["line_c_vs"] = "line-c-vs"
                                            return self.line_c_vs

                                        if (child_yang_name == "line-e-ss"):
                                            if (self.line_e_ss is None):
                                                self.line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineESs()
                                                self.line_e_ss.parent = self
                                                self._children_name_map["line_e_ss"] = "line-e-ss"
                                            return self.line_e_ss

                                        if (child_yang_name == "line-fc-ls"):
                                            if (self.line_fc_ls is None):
                                                self.line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineFcLs()
                                                self.line_fc_ls.parent = self
                                                self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                            return self.line_fc_ls

                                        if (child_yang_name == "line-se-ss"):
                                            if (self.line_se_ss is None):
                                                self.line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineSeSs()
                                                self.line_se_ss.parent = self
                                                self._children_name_map["line_se_ss"] = "line-se-ss"
                                            return self.line_se_ss

                                        if (child_yang_name == "line-ua-ss"):
                                            if (self.line_ua_ss is None):
                                                self.line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line.LineUaSs()
                                                self.line_ua_ss.parent = self
                                                self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                            return self.line_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "line-c-vs" or name == "line-e-ss" or name == "line-fc-ls" or name == "line-se-ss" or name == "line-ua-ss" or name == "line-status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "line-status"):
                                            self.line_status = value
                                            self.line_status.value_namespace = name_space
                                            self.line_status.value_namespace_prefix = name_space_prefix


                                class FeLine(Entity):
                                    """
                                    FarEnd LINE
                                    
                                    .. attribute:: far_end_line_c_vs
                                    
                                    	The number of Coding Violations
                                    	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineCVs>`
                                    
                                    .. attribute:: far_end_line_e_ss
                                    
                                    	The number of Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineESs>`
                                    
                                    .. attribute:: far_end_line_fc_ls
                                    
                                    	The number of Failure counts Seconds
                                    	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineFcLs>`
                                    
                                    .. attribute:: far_end_line_se_ss
                                    
                                    	The number of Severely Errored Seconds
                                    	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineSeSs>`
                                    
                                    .. attribute:: far_end_line_ua_ss
                                    
                                    	The number of Unavailable Seconds
                                    	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineUaSs>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine, self).__init__()

                                        self.yang_name = "fe-line"
                                        self.yang_parent_name = "oc-minute15ocn"

                                        self.far_end_line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineCVs()
                                        self.far_end_line_c_vs.parent = self
                                        self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                        self._children_yang_names.add("far-end-line-c-vs")

                                        self.far_end_line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineESs()
                                        self.far_end_line_e_ss.parent = self
                                        self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                        self._children_yang_names.add("far-end-line-e-ss")

                                        self.far_end_line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineFcLs()
                                        self.far_end_line_fc_ls.parent = self
                                        self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                        self._children_yang_names.add("far-end-line-fc-ls")

                                        self.far_end_line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineSeSs()
                                        self.far_end_line_se_ss.parent = self
                                        self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                        self._children_yang_names.add("far-end-line-se-ss")

                                        self.far_end_line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineUaSs()
                                        self.far_end_line_ua_ss.parent = self
                                        self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                        self._children_yang_names.add("far-end-line-ua-ss")


                                    class FarEndLineESs(Entity):
                                        """
                                        The number of Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineESs, self).__init__()

                                            self.yang_name = "far-end-line-e-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineESs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineESs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-e-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineSeSs(Entity):
                                        """
                                        The number of Severely Errored Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineSeSs, self).__init__()

                                            self.yang_name = "far-end-line-se-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineSeSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineSeSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-se-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineCVs(Entity):
                                        """
                                        The number of Coding Violations
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineCVs, self).__init__()

                                            self.yang_name = "far-end-line-c-vs"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineCVs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineCVs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-c-vs" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineUaSs(Entity):
                                        """
                                        The number of Unavailable Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineUaSs, self).__init__()

                                            self.yang_name = "far-end-line-ua-ss"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineUaSs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineUaSs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-ua-ss" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix


                                    class FarEndLineFcLs(Entity):
                                        """
                                        The number of Failure counts Seconds
                                        
                                        .. attribute:: data
                                        
                                        	the number in the interval
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tca_report
                                        
                                        	enable/disable to report TCA
                                        	**type**\:  bool
                                        
                                        .. attribute:: threshold
                                        
                                        	the threshold users set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineFcLs, self).__init__()

                                            self.yang_name = "far-end-line-fc-ls"
                                            self.yang_parent_name = "fe-line"

                                            self.data = YLeaf(YType.uint32, "data")

                                            self.tca_report = YLeaf(YType.boolean, "tca-report")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("data",
                                                            "tca_report",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineFcLs, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineFcLs, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.data.is_set or
                                                self.tca_report.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.data.yfilter != YFilter.not_set or
                                                self.tca_report.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "far-end-line-fc-ls" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.data.get_name_leafdata())
                                            if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tca_report.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "data" or name == "tca-report" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "data"):
                                                self.data = value
                                                self.data.value_namespace = name_space
                                                self.data.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tca-report"):
                                                self.tca_report = value
                                                self.tca_report.value_namespace = name_space
                                                self.tca_report.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_data()) or
                                            (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_data()) or
                                            (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_data()) or
                                            (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_data()) or
                                            (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_operation()) or
                                            (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_operation()) or
                                            (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_operation()) or
                                            (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_operation()) or
                                            (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fe-line" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "far-end-line-c-vs"):
                                            if (self.far_end_line_c_vs is None):
                                                self.far_end_line_c_vs = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineCVs()
                                                self.far_end_line_c_vs.parent = self
                                                self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                            return self.far_end_line_c_vs

                                        if (child_yang_name == "far-end-line-e-ss"):
                                            if (self.far_end_line_e_ss is None):
                                                self.far_end_line_e_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineESs()
                                                self.far_end_line_e_ss.parent = self
                                                self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                            return self.far_end_line_e_ss

                                        if (child_yang_name == "far-end-line-fc-ls"):
                                            if (self.far_end_line_fc_ls is None):
                                                self.far_end_line_fc_ls = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineFcLs()
                                                self.far_end_line_fc_ls.parent = self
                                                self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                            return self.far_end_line_fc_ls

                                        if (child_yang_name == "far-end-line-se-ss"):
                                            if (self.far_end_line_se_ss is None):
                                                self.far_end_line_se_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineSeSs()
                                                self.far_end_line_se_ss.parent = self
                                                self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                            return self.far_end_line_se_ss

                                        if (child_yang_name == "far-end-line-ua-ss"):
                                            if (self.far_end_line_ua_ss is None):
                                                self.far_end_line_ua_ss = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine.FarEndLineUaSs()
                                                self.far_end_line_ua_ss.parent = self
                                                self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                            return self.far_end_line_ua_ss

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "far-end-line-c-vs" or name == "far-end-line-e-ss" or name == "far-end-line-fc-ls" or name == "far-end-line-se-ss" or name == "far-end-line-ua-ss"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.fe_line is not None and self.fe_line.has_data()) or
                                        (self.line is not None and self.line.has_data()) or
                                        (self.section is not None and self.section.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.fe_line is not None and self.fe_line.has_operation()) or
                                        (self.line is not None and self.line.has_operation()) or
                                        (self.section is not None and self.section.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "oc-minute15ocn" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "fe-line"):
                                        if (self.fe_line is None):
                                            self.fe_line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.FeLine()
                                            self.fe_line.parent = self
                                            self._children_name_map["fe_line"] = "fe-line"
                                        return self.fe_line

                                    if (child_yang_name == "line"):
                                        if (self.line is None):
                                            self.line = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Line()
                                            self.line.parent = self
                                            self._children_name_map["line"] = "line"
                                        return self.line

                                    if (child_yang_name == "section"):
                                        if (self.section is None):
                                            self.section = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn.Section()
                                            self.section.parent = self
                                            self._children_name_map["section"] = "section"
                                        return self.section

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "fe-line" or name == "line" or name == "section" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.oc_minute15ocn:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.oc_minute15ocn:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "oc-minute15ocns" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "oc-minute15ocn"):
                                    for c in self.oc_minute15ocn:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns.OcMinute15Ocn()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.oc_minute15ocn.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "oc-minute15ocn"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.oc_minute15ocns is not None and self.oc_minute15ocns.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.oc_minute15ocns is not None and self.oc_minute15ocns.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "oc-minute15" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "oc-minute15ocns"):
                                if (self.oc_minute15ocns is None):
                                    self.oc_minute15ocns = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15.OcMinute15Ocns()
                                    self.oc_minute15ocns.parent = self
                                    self._children_name_map["oc_minute15ocns"] = "oc-minute15ocns"
                                return self.oc_minute15ocns

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "oc-minute15ocns"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.oc_hour24 is not None and self.oc_hour24.has_data()) or
                            (self.oc_minute15 is not None and self.oc_minute15.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.oc_hour24 is not None and self.oc_hour24.has_operation()) or
                            (self.oc_minute15 is not None and self.oc_minute15.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "oc-current" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "oc-hour24"):
                            if (self.oc_hour24 is None):
                                self.oc_hour24 = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcHour24()
                                self.oc_hour24.parent = self
                                self._children_name_map["oc_hour24"] = "oc-hour24"
                            return self.oc_hour24

                        if (child_yang_name == "oc-minute15"):
                            if (self.oc_minute15 is None):
                                self.oc_minute15 = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent.OcMinute15()
                                self.oc_minute15.parent = self
                                self._children_name_map["oc_minute15"] = "oc-minute15"
                            return self.oc_minute15

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "oc-hour24" or name == "oc-minute15"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.name.is_set or
                        (self.oc_current is not None and self.oc_current.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        (self.oc_current is not None and self.oc_current.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "oc-port" + "[name='" + self.name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/oc/oc-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "oc-current"):
                        if (self.oc_current is None):
                            self.oc_current = PerformanceManagement.Oc.OcPorts.OcPort.OcCurrent()
                            self.oc_current.parent = self
                            self._children_name_map["oc_current"] = "oc-current"
                        return self.oc_current

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "oc-current" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.oc_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.oc_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "oc-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/oc/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "oc-port"):
                    for c in self.oc_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = PerformanceManagement.Oc.OcPorts.OcPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.oc_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "oc-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.oc_ports is not None and self.oc_ports.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.oc_ports is not None and self.oc_ports.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "oc" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "oc-ports"):
                if (self.oc_ports is None):
                    self.oc_ports = PerformanceManagement.Oc.OcPorts()
                    self.oc_ports.parent = self
                    self._children_name_map["oc_ports"] = "oc-ports"
                return self.oc_ports

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "oc-ports"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Ethernet(Entity):
        """
        EHERNET controller performance data
        
        .. attribute:: ethernet_ports
        
        	Port performance data
        	**type**\:   :py:class:`EthernetPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PerformanceManagement.Ethernet, self).__init__()

            self.yang_name = "ethernet"
            self.yang_parent_name = "performance-management"

            self.ethernet_ports = PerformanceManagement.Ethernet.EthernetPorts()
            self.ethernet_ports.parent = self
            self._children_name_map["ethernet_ports"] = "ethernet-ports"
            self._children_yang_names.add("ethernet-ports")


        class EthernetPorts(Entity):
            """
            Port performance data
            
            .. attribute:: ethernet_port
            
            	Port performance data
            	**type**\: list of    :py:class:`EthernetPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PerformanceManagement.Ethernet.EthernetPorts, self).__init__()

                self.yang_name = "ethernet-ports"
                self.yang_parent_name = "ethernet"

                self.ethernet_port = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(PerformanceManagement.Ethernet.EthernetPorts, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(PerformanceManagement.Ethernet.EthernetPorts, self).__setattr__(name, value)


            class EthernetPort(Entity):
                """
                Port performance data
                
                .. attribute:: name  <key>
                
                	Port name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ethernet_current
                
                	port current performance data
                	**type**\:   :py:class:`EthernetCurrent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort, self).__init__()

                    self.yang_name = "ethernet-port"
                    self.yang_parent_name = "ethernet-ports"

                    self.name = YLeaf(YType.str, "name")

                    self.ethernet_current = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent()
                    self.ethernet_current.parent = self
                    self._children_name_map["ethernet_current"] = "ethernet-current"
                    self._children_yang_names.add("ethernet-current")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort, self).__setattr__(name, value)


                class EthernetCurrent(Entity):
                    """
                    port current performance data
                    
                    .. attribute:: ethernet_hour24
                    
                    	port current performance data
                    	**type**\:   :py:class:`EthernetHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24>`
                    
                    .. attribute:: ethernet_second30
                    
                    	port current performance data
                    	**type**\:   :py:class:`EthernetSecond30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30>`
                    
                    .. attribute:: minute15
                    
                    	port current performance data
                    	**type**\:   :py:class:`Minute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent, self).__init__()

                        self.yang_name = "ethernet-current"
                        self.yang_parent_name = "ethernet-port"

                        self.ethernet_hour24 = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24()
                        self.ethernet_hour24.parent = self
                        self._children_name_map["ethernet_hour24"] = "ethernet-hour24"
                        self._children_yang_names.add("ethernet-hour24")

                        self.ethernet_second30 = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30()
                        self.ethernet_second30.parent = self
                        self._children_name_map["ethernet_second30"] = "ethernet-second30"
                        self._children_yang_names.add("ethernet-second30")

                        self.minute15 = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15()
                        self.minute15.parent = self
                        self._children_name_map["minute15"] = "minute15"
                        self._children_yang_names.add("minute15")


                    class EthernetSecond30(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: second30_ethers
                        
                        	ETHERNET port interval performance data
                        	**type**\:   :py:class:`Second30Ethers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30, self).__init__()

                            self.yang_name = "ethernet-second30"
                            self.yang_parent_name = "ethernet-current"

                            self.second30_ethers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers()
                            self.second30_ethers.parent = self
                            self._children_name_map["second30_ethers"] = "second30-ethers"
                            self._children_yang_names.add("second30-ethers")


                        class Second30Ethers(Entity):
                            """
                            ETHERNET port interval performance data
                            
                            .. attribute:: second30_ether
                            
                            	ETHERNET port 30 second ether performance data
                            	**type**\: list of    :py:class:`Second30Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers, self).__init__()

                                self.yang_name = "second30-ethers"
                                self.yang_parent_name = "ethernet-second30"

                                self.second30_ether = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers, self).__setattr__(name, value)


                            class Second30Ether(Entity):
                                """
                                ETHERNET port 30 second ether performance
                                data
                                
                                .. attribute:: slot_number  <key>
                                
                                	interval slot number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ether10241518_octet
                                
                                	OFO OCTET
                                	**type**\:   :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet>`
                                
                                .. attribute:: ether128255_octet
                                
                                	TFF OCTET
                                	**type**\:   :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet>`
                                
                                .. attribute:: ether256511_octet
                                
                                	FOO OCTET
                                	**type**\:   :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet>`
                                
                                .. attribute:: ether5121023_octet
                                
                                	OZTT OCTET
                                	**type**\:   :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet>`
                                
                                .. attribute:: ether64_octets
                                
                                	SIXTY FOUR OCTET
                                	**type**\:   :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets>`
                                
                                .. attribute:: ether65127_octet
                                
                                	OCTET
                                	**type**\:   :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet>`
                                
                                .. attribute:: ether_stat_broadcast_pkt
                                
                                	ETHER STAT BROADCAST PKT
                                	**type**\:   :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt>`
                                
                                .. attribute:: ether_stat_multicast_pkt
                                
                                	ETHER STAT MULTICAST PKT
                                	**type**\:   :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt>`
                                
                                .. attribute:: ether_stat_undersized_pkt
                                
                                	ETHER STAT UNDERSIZED PKT
                                	**type**\:   :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt>`
                                
                                .. attribute:: fcs_errors_stat
                                
                                	FCS ERR
                                	**type**\:   :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat>`
                                
                                .. attribute:: if_in_errors
                                
                                	IFIN ERRORS
                                	**type**\:   :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors>`
                                
                                .. attribute:: if_in_octets
                                
                                	IFIN OCTETS
                                	**type**\:   :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets>`
                                
                                .. attribute:: in8021q_frames
                                
                                	INPUT 802 1Q FRAMES
                                	**type**\:   :py:class:`In8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021QFrames>`
                                
                                .. attribute:: in_bcast_pkt
                                
                                	IN BCAST
                                	**type**\:   :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt>`
                                
                                .. attribute:: in_drop_abort
                                
                                	INPUT DROP ABORT
                                	**type**\:   :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort>`
                                
                                .. attribute:: in_drop_invalid_dmac
                                
                                	INPUT DROP INVALID DMAC
                                	**type**\:   :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac>`
                                
                                .. attribute:: in_drop_invalid_encap
                                
                                	INPUT DROP INVALID ENCAP
                                	**type**\:   :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap>`
                                
                                .. attribute:: in_drop_invalid_vlan
                                
                                	INPUT DROP INVALID VLAN
                                	**type**\:   :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan>`
                                
                                .. attribute:: in_drop_other
                                
                                	INPUT DROP OTHER
                                	**type**\:   :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther>`
                                
                                .. attribute:: in_drop_overrun
                                
                                	INPUT DROP OVERRUN
                                	**type**\:   :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun>`
                                
                                .. attribute:: in_error_collisions
                                
                                	IN ERROR COLLISIONS
                                	**type**\:   :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions>`
                                
                                .. attribute:: in_error_fragments
                                
                                	IN ERROR FRAGMENTS
                                	**type**\:   :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments>`
                                
                                .. attribute:: in_error_giant
                                
                                	IN ERROR GIANT
                                	**type**\:   :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant>`
                                
                                .. attribute:: in_error_jabbers
                                
                                	IN ERROR JABBERS
                                	**type**\:   :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers>`
                                
                                .. attribute:: in_error_other
                                
                                	IN ERROR OTHER
                                	**type**\:   :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther>`
                                
                                .. attribute:: in_error_runt
                                
                                	IN ERROR RUNT
                                	**type**\:   :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt>`
                                
                                .. attribute:: in_error_symbol
                                
                                	IN ERROR SYMBOL
                                	**type**\:   :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol>`
                                
                                .. attribute:: in_good_bytes
                                
                                	INPUT GOOD BYTES
                                	**type**\:   :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes>`
                                
                                .. attribute:: in_good_pkts
                                
                                	INPUT GOOD PKTS
                                	**type**\:   :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts>`
                                
                                .. attribute:: in_mcast_pkt
                                
                                	IN MCAST
                                	**type**\:   :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt>`
                                
                                .. attribute:: in_mib_giant
                                
                                	INPUT MIB GIANT
                                	**type**\:   :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant>`
                                
                                .. attribute:: in_mib_jabber
                                
                                	INPUT MIB JABBER
                                	**type**\:   :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber>`
                                
                                .. attribute:: in_mibcrc
                                
                                	IN MIB CRC
                                	**type**\:   :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc>`
                                
                                .. attribute:: in_pause_frame
                                
                                	INPUT PAUSE FRAME
                                	**type**\:   :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame>`
                                
                                .. attribute:: in_pkt64_octet
                                
                                	IN PKT 64 OCTET
                                	**type**\:   :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet>`
                                
                                .. attribute:: in_pkts1024_to1518_octets
                                
                                	IN PKTS 1024 1518 OCTETS
                                	**type**\:   :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets>`
                                
                                .. attribute:: in_pkts128_to255_octets
                                
                                	IN PKTS 128 255 OCTETS
                                	**type**\:   :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets>`
                                
                                .. attribute:: in_pkts1519_max_octets
                                
                                	INPUT PKTS 1519MAX OCTETS
                                	**type**\:   :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets>`
                                
                                .. attribute:: in_pkts256_to511_octets
                                
                                	IN PKTS 256 511 OCTETS
                                	**type**\:   :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets>`
                                
                                .. attribute:: in_pkts512_to1023_octets
                                
                                	IN PKTS 512 1023 OCTETS
                                	**type**\:   :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets>`
                                
                                .. attribute:: in_pkts65_to127_octets
                                
                                	IN PKTS 65 127OCTETS
                                	**type**\:   :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets>`
                                
                                .. attribute:: in_ucast_pkt
                                
                                	IN UCAST
                                	**type**\:   :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: jabber_stat
                                
                                	JABBER STATS
                                	**type**\:   :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat>`
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: long_frames_stat
                                
                                	LONG FRAMES
                                	**type**\:   :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat>`
                                
                                .. attribute:: octet_stat
                                
                                	OCTET STAT
                                	**type**\:   :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat>`
                                
                                .. attribute:: out8021q_frames
                                
                                	OUT 802 1Q FRAMES
                                	**type**\:   :py:class:`Out8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021QFrames>`
                                
                                .. attribute:: out_bcast_pkt
                                
                                	OUT BCAST
                                	**type**\:   :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt>`
                                
                                .. attribute:: out_drop_abort
                                
                                	OUT DROP ABORT
                                	**type**\:   :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort>`
                                
                                .. attribute:: out_drop_other
                                
                                	OUT DROP OTHER
                                	**type**\:   :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther>`
                                
                                .. attribute:: out_drop_underrun
                                
                                	OUT DROP UNDERRUN
                                	**type**\:   :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun>`
                                
                                .. attribute:: out_error_other
                                
                                	OUT ERROR OTHER
                                	**type**\:   :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther>`
                                
                                .. attribute:: out_good_bytes
                                
                                	OUT GOOD BYTES
                                	**type**\:   :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes>`
                                
                                .. attribute:: out_good_pkts
                                
                                	OUT GOOD PKTS
                                	**type**\:   :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts>`
                                
                                .. attribute:: out_mcast_pkt
                                
                                	OUT MCAST
                                	**type**\:   :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt>`
                                
                                .. attribute:: out_octets
                                
                                	OUT OCTET
                                	**type**\:   :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets>`
                                
                                .. attribute:: out_pause_frames
                                
                                	OUT PAUSE FRAMES
                                	**type**\:   :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames>`
                                
                                .. attribute:: out_pkts10241518_octets
                                
                                	OUT PKTS 1024 1518 OCTETS
                                	**type**\:   :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets>`
                                
                                .. attribute:: out_pkts128255_octets
                                
                                	OUT PKTS 128 255 OCTETS
                                	**type**\:   :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets>`
                                
                                .. attribute:: out_pkts1519_max_octets
                                
                                	OUT PKTS 1519 MAX OCTETS
                                	**type**\:   :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets>`
                                
                                .. attribute:: out_pkts256511_octets
                                
                                	OUT PKTS 256 511 OCTETS
                                	**type**\:   :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets>`
                                
                                .. attribute:: out_pkts5121023_octets
                                
                                	OUT PKTS 512 1023 OCTETS
                                	**type**\:   :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets>`
                                
                                .. attribute:: out_pkts65127_octets
                                
                                	OUT PKTS 65 127OCTETS
                                	**type**\:   :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets>`
                                
                                .. attribute:: out_ucast_pkt
                                
                                	OUT UCAST
                                	**type**\:   :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt>`
                                
                                .. attribute:: outpkt64octet
                                
                                	OUT PKT 64 OCTET
                                	**type**\:   :py:class:`Outpkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64Octet>`
                                
                                .. attribute:: oversize_pkt_stat
                                
                                	OVERSIZE PKT
                                	**type**\:   :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat>`
                                
                                .. attribute:: rx_pkt
                                
                                	RX PKT
                                	**type**\:   :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt>`
                                
                                .. attribute:: rx_util
                                
                                	Rx Utilization in Percent
                                	**type**\:   :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: stat_pkt
                                
                                	STAT PKT
                                	**type**\:   :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: tx_bad_fcs
                                
                                	TX Bad Fcs
                                	**type**\:   :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs>`
                                
                                .. attribute:: tx_fragments
                                
                                	TX Fragments
                                	**type**\:   :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments>`
                                
                                .. attribute:: tx_jabber
                                
                                	TX Jabber
                                	**type**\:   :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber>`
                                
                                .. attribute:: tx_oversized_pkt
                                
                                	TX Oversized Pkt
                                	**type**\:   :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt>`
                                
                                .. attribute:: tx_pkt
                                
                                	TX PKT
                                	**type**\:   :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt>`
                                
                                .. attribute:: tx_undersized_pkt
                                
                                	TX Undersized Pkt
                                	**type**\:   :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt>`
                                
                                .. attribute:: tx_util
                                
                                	Tx Utilization in Percent
                                	**type**\:   :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether, self).__init__()

                                    self.yang_name = "second30-ether"
                                    self.yang_parent_name = "second30-ethers"

                                    self.slot_number = YLeaf(YType.int32, "slot-number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.ether10241518_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet()
                                    self.ether10241518_octet.parent = self
                                    self._children_name_map["ether10241518_octet"] = "ether10241518-octet"
                                    self._children_yang_names.add("ether10241518-octet")

                                    self.ether128255_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet()
                                    self.ether128255_octet.parent = self
                                    self._children_name_map["ether128255_octet"] = "ether128255-octet"
                                    self._children_yang_names.add("ether128255-octet")

                                    self.ether256511_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet()
                                    self.ether256511_octet.parent = self
                                    self._children_name_map["ether256511_octet"] = "ether256511-octet"
                                    self._children_yang_names.add("ether256511-octet")

                                    self.ether5121023_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet()
                                    self.ether5121023_octet.parent = self
                                    self._children_name_map["ether5121023_octet"] = "ether5121023-octet"
                                    self._children_yang_names.add("ether5121023-octet")

                                    self.ether64_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets()
                                    self.ether64_octets.parent = self
                                    self._children_name_map["ether64_octets"] = "ether64-octets"
                                    self._children_yang_names.add("ether64-octets")

                                    self.ether65127_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet()
                                    self.ether65127_octet.parent = self
                                    self._children_name_map["ether65127_octet"] = "ether65127-octet"
                                    self._children_yang_names.add("ether65127-octet")

                                    self.ether_stat_broadcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt()
                                    self.ether_stat_broadcast_pkt.parent = self
                                    self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"
                                    self._children_yang_names.add("ether-stat-broadcast-pkt")

                                    self.ether_stat_multicast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt()
                                    self.ether_stat_multicast_pkt.parent = self
                                    self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"
                                    self._children_yang_names.add("ether-stat-multicast-pkt")

                                    self.ether_stat_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt()
                                    self.ether_stat_undersized_pkt.parent = self
                                    self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"
                                    self._children_yang_names.add("ether-stat-undersized-pkt")

                                    self.fcs_errors_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat()
                                    self.fcs_errors_stat.parent = self
                                    self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"
                                    self._children_yang_names.add("fcs-errors-stat")

                                    self.if_in_errors = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors()
                                    self.if_in_errors.parent = self
                                    self._children_name_map["if_in_errors"] = "if-in-errors"
                                    self._children_yang_names.add("if-in-errors")

                                    self.if_in_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets()
                                    self.if_in_octets.parent = self
                                    self._children_name_map["if_in_octets"] = "if-in-octets"
                                    self._children_yang_names.add("if-in-octets")

                                    self.in8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021QFrames()
                                    self.in8021q_frames.parent = self
                                    self._children_name_map["in8021q_frames"] = "in8021q-frames"
                                    self._children_yang_names.add("in8021q-frames")

                                    self.in_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt()
                                    self.in_bcast_pkt.parent = self
                                    self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"
                                    self._children_yang_names.add("in-bcast-pkt")

                                    self.in_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort()
                                    self.in_drop_abort.parent = self
                                    self._children_name_map["in_drop_abort"] = "in-drop-abort"
                                    self._children_yang_names.add("in-drop-abort")

                                    self.in_drop_invalid_dmac = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac()
                                    self.in_drop_invalid_dmac.parent = self
                                    self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"
                                    self._children_yang_names.add("in-drop-invalid-dmac")

                                    self.in_drop_invalid_encap = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap()
                                    self.in_drop_invalid_encap.parent = self
                                    self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"
                                    self._children_yang_names.add("in-drop-invalid-encap")

                                    self.in_drop_invalid_vlan = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan()
                                    self.in_drop_invalid_vlan.parent = self
                                    self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"
                                    self._children_yang_names.add("in-drop-invalid-vlan")

                                    self.in_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther()
                                    self.in_drop_other.parent = self
                                    self._children_name_map["in_drop_other"] = "in-drop-other"
                                    self._children_yang_names.add("in-drop-other")

                                    self.in_drop_overrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun()
                                    self.in_drop_overrun.parent = self
                                    self._children_name_map["in_drop_overrun"] = "in-drop-overrun"
                                    self._children_yang_names.add("in-drop-overrun")

                                    self.in_error_collisions = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions()
                                    self.in_error_collisions.parent = self
                                    self._children_name_map["in_error_collisions"] = "in-error-collisions"
                                    self._children_yang_names.add("in-error-collisions")

                                    self.in_error_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments()
                                    self.in_error_fragments.parent = self
                                    self._children_name_map["in_error_fragments"] = "in-error-fragments"
                                    self._children_yang_names.add("in-error-fragments")

                                    self.in_error_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant()
                                    self.in_error_giant.parent = self
                                    self._children_name_map["in_error_giant"] = "in-error-giant"
                                    self._children_yang_names.add("in-error-giant")

                                    self.in_error_jabbers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers()
                                    self.in_error_jabbers.parent = self
                                    self._children_name_map["in_error_jabbers"] = "in-error-jabbers"
                                    self._children_yang_names.add("in-error-jabbers")

                                    self.in_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther()
                                    self.in_error_other.parent = self
                                    self._children_name_map["in_error_other"] = "in-error-other"
                                    self._children_yang_names.add("in-error-other")

                                    self.in_error_runt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt()
                                    self.in_error_runt.parent = self
                                    self._children_name_map["in_error_runt"] = "in-error-runt"
                                    self._children_yang_names.add("in-error-runt")

                                    self.in_error_symbol = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol()
                                    self.in_error_symbol.parent = self
                                    self._children_name_map["in_error_symbol"] = "in-error-symbol"
                                    self._children_yang_names.add("in-error-symbol")

                                    self.in_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes()
                                    self.in_good_bytes.parent = self
                                    self._children_name_map["in_good_bytes"] = "in-good-bytes"
                                    self._children_yang_names.add("in-good-bytes")

                                    self.in_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts()
                                    self.in_good_pkts.parent = self
                                    self._children_name_map["in_good_pkts"] = "in-good-pkts"
                                    self._children_yang_names.add("in-good-pkts")

                                    self.in_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt()
                                    self.in_mcast_pkt.parent = self
                                    self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"
                                    self._children_yang_names.add("in-mcast-pkt")

                                    self.in_mib_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant()
                                    self.in_mib_giant.parent = self
                                    self._children_name_map["in_mib_giant"] = "in-mib-giant"
                                    self._children_yang_names.add("in-mib-giant")

                                    self.in_mib_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber()
                                    self.in_mib_jabber.parent = self
                                    self._children_name_map["in_mib_jabber"] = "in-mib-jabber"
                                    self._children_yang_names.add("in-mib-jabber")

                                    self.in_mibcrc = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc()
                                    self.in_mibcrc.parent = self
                                    self._children_name_map["in_mibcrc"] = "in-mibcrc"
                                    self._children_yang_names.add("in-mibcrc")

                                    self.in_pause_frame = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame()
                                    self.in_pause_frame.parent = self
                                    self._children_name_map["in_pause_frame"] = "in-pause-frame"
                                    self._children_yang_names.add("in-pause-frame")

                                    self.in_pkt64_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet()
                                    self.in_pkt64_octet.parent = self
                                    self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"
                                    self._children_yang_names.add("in-pkt64-octet")

                                    self.in_pkts1024_to1518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets()
                                    self.in_pkts1024_to1518_octets.parent = self
                                    self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"
                                    self._children_yang_names.add("in-pkts1024-to1518-octets")

                                    self.in_pkts128_to255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets()
                                    self.in_pkts128_to255_octets.parent = self
                                    self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"
                                    self._children_yang_names.add("in-pkts128-to255-octets")

                                    self.in_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets()
                                    self.in_pkts1519_max_octets.parent = self
                                    self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"
                                    self._children_yang_names.add("in-pkts1519-max-octets")

                                    self.in_pkts256_to511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets()
                                    self.in_pkts256_to511_octets.parent = self
                                    self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"
                                    self._children_yang_names.add("in-pkts256-to511-octets")

                                    self.in_pkts512_to1023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets()
                                    self.in_pkts512_to1023_octets.parent = self
                                    self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"
                                    self._children_yang_names.add("in-pkts512-to1023-octets")

                                    self.in_pkts65_to127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets()
                                    self.in_pkts65_to127_octets.parent = self
                                    self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"
                                    self._children_yang_names.add("in-pkts65-to127-octets")

                                    self.in_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt()
                                    self.in_ucast_pkt.parent = self
                                    self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"
                                    self._children_yang_names.add("in-ucast-pkt")

                                    self.jabber_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat()
                                    self.jabber_stat.parent = self
                                    self._children_name_map["jabber_stat"] = "jabber-stat"
                                    self._children_yang_names.add("jabber-stat")

                                    self.long_frames_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat()
                                    self.long_frames_stat.parent = self
                                    self._children_name_map["long_frames_stat"] = "long-frames-stat"
                                    self._children_yang_names.add("long-frames-stat")

                                    self.octet_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat()
                                    self.octet_stat.parent = self
                                    self._children_name_map["octet_stat"] = "octet-stat"
                                    self._children_yang_names.add("octet-stat")

                                    self.out8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021QFrames()
                                    self.out8021q_frames.parent = self
                                    self._children_name_map["out8021q_frames"] = "out8021q-frames"
                                    self._children_yang_names.add("out8021q-frames")

                                    self.out_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt()
                                    self.out_bcast_pkt.parent = self
                                    self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"
                                    self._children_yang_names.add("out-bcast-pkt")

                                    self.out_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort()
                                    self.out_drop_abort.parent = self
                                    self._children_name_map["out_drop_abort"] = "out-drop-abort"
                                    self._children_yang_names.add("out-drop-abort")

                                    self.out_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther()
                                    self.out_drop_other.parent = self
                                    self._children_name_map["out_drop_other"] = "out-drop-other"
                                    self._children_yang_names.add("out-drop-other")

                                    self.out_drop_underrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun()
                                    self.out_drop_underrun.parent = self
                                    self._children_name_map["out_drop_underrun"] = "out-drop-underrun"
                                    self._children_yang_names.add("out-drop-underrun")

                                    self.out_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther()
                                    self.out_error_other.parent = self
                                    self._children_name_map["out_error_other"] = "out-error-other"
                                    self._children_yang_names.add("out-error-other")

                                    self.out_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes()
                                    self.out_good_bytes.parent = self
                                    self._children_name_map["out_good_bytes"] = "out-good-bytes"
                                    self._children_yang_names.add("out-good-bytes")

                                    self.out_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts()
                                    self.out_good_pkts.parent = self
                                    self._children_name_map["out_good_pkts"] = "out-good-pkts"
                                    self._children_yang_names.add("out-good-pkts")

                                    self.out_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt()
                                    self.out_mcast_pkt.parent = self
                                    self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"
                                    self._children_yang_names.add("out-mcast-pkt")

                                    self.out_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets()
                                    self.out_octets.parent = self
                                    self._children_name_map["out_octets"] = "out-octets"
                                    self._children_yang_names.add("out-octets")

                                    self.out_pause_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames()
                                    self.out_pause_frames.parent = self
                                    self._children_name_map["out_pause_frames"] = "out-pause-frames"
                                    self._children_yang_names.add("out-pause-frames")

                                    self.out_pkts10241518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets()
                                    self.out_pkts10241518_octets.parent = self
                                    self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"
                                    self._children_yang_names.add("out-pkts10241518-octets")

                                    self.out_pkts128255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets()
                                    self.out_pkts128255_octets.parent = self
                                    self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"
                                    self._children_yang_names.add("out-pkts128255-octets")

                                    self.out_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets()
                                    self.out_pkts1519_max_octets.parent = self
                                    self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"
                                    self._children_yang_names.add("out-pkts1519-max-octets")

                                    self.out_pkts256511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets()
                                    self.out_pkts256511_octets.parent = self
                                    self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"
                                    self._children_yang_names.add("out-pkts256511-octets")

                                    self.out_pkts5121023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets()
                                    self.out_pkts5121023_octets.parent = self
                                    self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"
                                    self._children_yang_names.add("out-pkts5121023-octets")

                                    self.out_pkts65127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets()
                                    self.out_pkts65127_octets.parent = self
                                    self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"
                                    self._children_yang_names.add("out-pkts65127-octets")

                                    self.out_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt()
                                    self.out_ucast_pkt.parent = self
                                    self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"
                                    self._children_yang_names.add("out-ucast-pkt")

                                    self.outpkt64octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64Octet()
                                    self.outpkt64octet.parent = self
                                    self._children_name_map["outpkt64octet"] = "outpkt64octet"
                                    self._children_yang_names.add("outpkt64octet")

                                    self.oversize_pkt_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat()
                                    self.oversize_pkt_stat.parent = self
                                    self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"
                                    self._children_yang_names.add("oversize-pkt-stat")

                                    self.rx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt()
                                    self.rx_pkt.parent = self
                                    self._children_name_map["rx_pkt"] = "rx-pkt"
                                    self._children_yang_names.add("rx-pkt")

                                    self.rx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil()
                                    self.rx_util.parent = self
                                    self._children_name_map["rx_util"] = "rx-util"
                                    self._children_yang_names.add("rx-util")

                                    self.stat_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt()
                                    self.stat_pkt.parent = self
                                    self._children_name_map["stat_pkt"] = "stat-pkt"
                                    self._children_yang_names.add("stat-pkt")

                                    self.tx_bad_fcs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs()
                                    self.tx_bad_fcs.parent = self
                                    self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                    self._children_yang_names.add("tx-bad-fcs")

                                    self.tx_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments()
                                    self.tx_fragments.parent = self
                                    self._children_name_map["tx_fragments"] = "tx-fragments"
                                    self._children_yang_names.add("tx-fragments")

                                    self.tx_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber()
                                    self.tx_jabber.parent = self
                                    self._children_name_map["tx_jabber"] = "tx-jabber"
                                    self._children_yang_names.add("tx-jabber")

                                    self.tx_oversized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt()
                                    self.tx_oversized_pkt.parent = self
                                    self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"
                                    self._children_yang_names.add("tx-oversized-pkt")

                                    self.tx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt()
                                    self.tx_pkt.parent = self
                                    self._children_name_map["tx_pkt"] = "tx-pkt"
                                    self._children_yang_names.add("tx-pkt")

                                    self.tx_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt()
                                    self.tx_undersized_pkt.parent = self
                                    self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"
                                    self._children_yang_names.add("tx-undersized-pkt")

                                    self.tx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil()
                                    self.tx_util.parent = self
                                    self._children_name_map["tx_util"] = "tx-util"
                                    self._children_yang_names.add("tx-util")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("slot_number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether, self).__setattr__(name, value)


                                class RxPkt(Entity):
                                    """
                                    RX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt, self).__init__()

                                        self.yang_name = "rx-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class StatPkt(Entity):
                                    """
                                    STAT PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt, self).__init__()

                                        self.yang_name = "stat-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "stat-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OctetStat(Entity):
                                    """
                                    OCTET STAT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat, self).__init__()

                                        self.yang_name = "octet-stat"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "octet-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OversizePktStat(Entity):
                                    """
                                    OVERSIZE PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat, self).__init__()

                                        self.yang_name = "oversize-pkt-stat"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "oversize-pkt-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class FcsErrorsStat(Entity):
                                    """
                                    FCS ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat, self).__init__()

                                        self.yang_name = "fcs-errors-stat"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fcs-errors-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LongFramesStat(Entity):
                                    """
                                    LONG FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat, self).__init__()

                                        self.yang_name = "long-frames-stat"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "long-frames-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class JabberStat(Entity):
                                    """
                                    JABBER STATS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat, self).__init__()

                                        self.yang_name = "jabber-stat"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "jabber-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether64Octets(Entity):
                                    """
                                    SIXTY FOUR OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets, self).__init__()

                                        self.yang_name = "ether64-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether64-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether65127Octet(Entity):
                                    """
                                    OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet, self).__init__()

                                        self.yang_name = "ether65127-octet"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether65127-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether128255Octet(Entity):
                                    """
                                    TFF OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet, self).__init__()

                                        self.yang_name = "ether128255-octet"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether128255-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether256511Octet(Entity):
                                    """
                                    FOO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet, self).__init__()

                                        self.yang_name = "ether256511-octet"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether256511-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether5121023Octet(Entity):
                                    """
                                    OZTT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet, self).__init__()

                                        self.yang_name = "ether5121023-octet"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether5121023-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether10241518Octet(Entity):
                                    """
                                    OFO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet, self).__init__()

                                        self.yang_name = "ether10241518-octet"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether10241518-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InUcastPkt(Entity):
                                    """
                                    IN UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt, self).__init__()

                                        self.yang_name = "in-ucast-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-ucast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InMcastPkt(Entity):
                                    """
                                    IN MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt, self).__init__()

                                        self.yang_name = "in-mcast-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-mcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InBcastPkt(Entity):
                                    """
                                    IN BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt, self).__init__()

                                        self.yang_name = "in-bcast-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-bcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutUcastPkt(Entity):
                                    """
                                    OUT UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt, self).__init__()

                                        self.yang_name = "out-ucast-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-ucast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutBcastPkt(Entity):
                                    """
                                    OUT BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt, self).__init__()

                                        self.yang_name = "out-bcast-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-bcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutMcastPkt(Entity):
                                    """
                                    OUT MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt, self).__init__()

                                        self.yang_name = "out-mcast-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-mcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxPkt(Entity):
                                    """
                                    TX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt, self).__init__()

                                        self.yang_name = "tx-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class IfInErrors(Entity):
                                    """
                                    IFIN ERRORS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors, self).__init__()

                                        self.yang_name = "if-in-errors"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "if-in-errors" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class IfInOctets(Entity):
                                    """
                                    IFIN OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets, self).__init__()

                                        self.yang_name = "if-in-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "if-in-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class EtherStatMulticastPkt(Entity):
                                    """
                                    ETHER STAT MULTICAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt, self).__init__()

                                        self.yang_name = "ether-stat-multicast-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether-stat-multicast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class EtherStatBroadcastPkt(Entity):
                                    """
                                    ETHER STAT BROADCAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt, self).__init__()

                                        self.yang_name = "ether-stat-broadcast-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether-stat-broadcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class EtherStatUndersizedPkt(Entity):
                                    """
                                    ETHER STAT UNDERSIZED PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt, self).__init__()

                                        self.yang_name = "ether-stat-undersized-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether-stat-undersized-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutOctets(Entity):
                                    """
                                    OUT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets, self).__init__()

                                        self.yang_name = "out-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPauseFrame(Entity):
                                    """
                                    INPUT PAUSE FRAME
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame, self).__init__()

                                        self.yang_name = "in-pause-frame"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pause-frame" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InGoodBytes(Entity):
                                    """
                                    INPUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes, self).__init__()

                                        self.yang_name = "in-good-bytes"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-good-bytes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class In8021QFrames(Entity):
                                    """
                                    INPUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021QFrames, self).__init__()

                                        self.yang_name = "in8021q-frames"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021QFrames, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021QFrames, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in8021q-frames" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts1519MaxOctets(Entity):
                                    """
                                    INPUT PKTS 1519MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "in-pkts1519-max-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts1519-max-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InGoodPkts(Entity):
                                    """
                                    INPUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts, self).__init__()

                                        self.yang_name = "in-good-pkts"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-good-pkts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropOverrun(Entity):
                                    """
                                    INPUT DROP OVERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun, self).__init__()

                                        self.yang_name = "in-drop-overrun"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-overrun" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropAbort(Entity):
                                    """
                                    INPUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort, self).__init__()

                                        self.yang_name = "in-drop-abort"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-abort" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropInvalidVlan(Entity):
                                    """
                                    INPUT DROP INVALID VLAN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan, self).__init__()

                                        self.yang_name = "in-drop-invalid-vlan"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-invalid-vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropInvalidDmac(Entity):
                                    """
                                    INPUT DROP INVALID DMAC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac, self).__init__()

                                        self.yang_name = "in-drop-invalid-dmac"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-invalid-dmac" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropInvalidEncap(Entity):
                                    """
                                    INPUT DROP INVALID ENCAP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap, self).__init__()

                                        self.yang_name = "in-drop-invalid-encap"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-invalid-encap" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropOther(Entity):
                                    """
                                    INPUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther, self).__init__()

                                        self.yang_name = "in-drop-other"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-other" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InMibGiant(Entity):
                                    """
                                    INPUT MIB GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant, self).__init__()

                                        self.yang_name = "in-mib-giant"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-mib-giant" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InMibJabber(Entity):
                                    """
                                    INPUT MIB JABBER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber, self).__init__()

                                        self.yang_name = "in-mib-jabber"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-mib-jabber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InMibcrc(Entity):
                                    """
                                    IN MIB CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc, self).__init__()

                                        self.yang_name = "in-mibcrc"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-mibcrc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorCollisions(Entity):
                                    """
                                    IN ERROR COLLISIONS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions, self).__init__()

                                        self.yang_name = "in-error-collisions"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-collisions" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorSymbol(Entity):
                                    """
                                    IN ERROR SYMBOL
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol, self).__init__()

                                        self.yang_name = "in-error-symbol"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-symbol" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutGoodBytes(Entity):
                                    """
                                    OUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes, self).__init__()

                                        self.yang_name = "out-good-bytes"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-good-bytes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Out8021QFrames(Entity):
                                    """
                                    OUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021QFrames, self).__init__()

                                        self.yang_name = "out8021q-frames"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021QFrames, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021QFrames, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out8021q-frames" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPauseFrames(Entity):
                                    """
                                    OUT PAUSE FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames, self).__init__()

                                        self.yang_name = "out-pause-frames"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pause-frames" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts1519MaxOctets(Entity):
                                    """
                                    OUT PKTS 1519 MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "out-pkts1519-max-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts1519-max-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutGoodPkts(Entity):
                                    """
                                    OUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts, self).__init__()

                                        self.yang_name = "out-good-pkts"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-good-pkts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutDropUnderrun(Entity):
                                    """
                                    OUT DROP UNDERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun, self).__init__()

                                        self.yang_name = "out-drop-underrun"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-drop-underrun" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutDropAbort(Entity):
                                    """
                                    OUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort, self).__init__()

                                        self.yang_name = "out-drop-abort"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-drop-abort" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutDropOther(Entity):
                                    """
                                    OUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther, self).__init__()

                                        self.yang_name = "out-drop-other"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-drop-other" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutErrorOther(Entity):
                                    """
                                    OUT ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther, self).__init__()

                                        self.yang_name = "out-error-other"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-error-other" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorGiant(Entity):
                                    """
                                    IN ERROR GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant, self).__init__()

                                        self.yang_name = "in-error-giant"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-giant" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorRunt(Entity):
                                    """
                                    IN ERROR RUNT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt, self).__init__()

                                        self.yang_name = "in-error-runt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-runt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorJabbers(Entity):
                                    """
                                    IN ERROR JABBERS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers, self).__init__()

                                        self.yang_name = "in-error-jabbers"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-jabbers" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorFragments(Entity):
                                    """
                                    IN ERROR FRAGMENTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments, self).__init__()

                                        self.yang_name = "in-error-fragments"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-fragments" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorOther(Entity):
                                    """
                                    IN ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther, self).__init__()

                                        self.yang_name = "in-error-other"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-other" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkt64Octet(Entity):
                                    """
                                    IN PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet, self).__init__()

                                        self.yang_name = "in-pkt64-octet"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkt64-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts65To127Octets(Entity):
                                    """
                                    IN PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets, self).__init__()

                                        self.yang_name = "in-pkts65-to127-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts65-to127-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts128To255Octets(Entity):
                                    """
                                    IN PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets, self).__init__()

                                        self.yang_name = "in-pkts128-to255-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts128-to255-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts256To511Octets(Entity):
                                    """
                                    IN PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets, self).__init__()

                                        self.yang_name = "in-pkts256-to511-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts256-to511-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts512To1023Octets(Entity):
                                    """
                                    IN PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets, self).__init__()

                                        self.yang_name = "in-pkts512-to1023-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts512-to1023-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts1024To1518Octets(Entity):
                                    """
                                    IN PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets, self).__init__()

                                        self.yang_name = "in-pkts1024-to1518-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts1024-to1518-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Outpkt64Octet(Entity):
                                    """
                                    OUT PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64Octet, self).__init__()

                                        self.yang_name = "outpkt64octet"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "outpkt64octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts65127Octets(Entity):
                                    """
                                    OUT PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets, self).__init__()

                                        self.yang_name = "out-pkts65127-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts65127-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts128255Octets(Entity):
                                    """
                                    OUT PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets, self).__init__()

                                        self.yang_name = "out-pkts128255-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts128255-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts256511Octets(Entity):
                                    """
                                    OUT PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets, self).__init__()

                                        self.yang_name = "out-pkts256511-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts256511-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts5121023Octets(Entity):
                                    """
                                    OUT PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets, self).__init__()

                                        self.yang_name = "out-pkts5121023-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts5121023-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts10241518Octets(Entity):
                                    """
                                    OUT PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets, self).__init__()

                                        self.yang_name = "out-pkts10241518-octets"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts10241518-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class RxUtil(Entity):
                                    """
                                    Rx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil, self).__init__()

                                        self.yang_name = "rx-util"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-util" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxUtil(Entity):
                                    """
                                    Tx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil, self).__init__()

                                        self.yang_name = "tx-util"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-util" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxUndersizedPkt(Entity):
                                    """
                                    TX Undersized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt, self).__init__()

                                        self.yang_name = "tx-undersized-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-undersized-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxOversizedPkt(Entity):
                                    """
                                    TX Oversized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt, self).__init__()

                                        self.yang_name = "tx-oversized-pkt"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-oversized-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxFragments(Entity):
                                    """
                                    TX Fragments
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments, self).__init__()

                                        self.yang_name = "tx-fragments"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-fragments" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxJabber(Entity):
                                    """
                                    TX Jabber
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber, self).__init__()

                                        self.yang_name = "tx-jabber"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-jabber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxBadFcs(Entity):
                                    """
                                    TX Bad Fcs
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs, self).__init__()

                                        self.yang_name = "tx-bad-fcs"
                                        self.yang_parent_name = "second30-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-bad-fcs" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.slot_number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.ether10241518_octet is not None and self.ether10241518_octet.has_data()) or
                                        (self.ether128255_octet is not None and self.ether128255_octet.has_data()) or
                                        (self.ether256511_octet is not None and self.ether256511_octet.has_data()) or
                                        (self.ether5121023_octet is not None and self.ether5121023_octet.has_data()) or
                                        (self.ether64_octets is not None and self.ether64_octets.has_data()) or
                                        (self.ether65127_octet is not None and self.ether65127_octet.has_data()) or
                                        (self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt.has_data()) or
                                        (self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt.has_data()) or
                                        (self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt.has_data()) or
                                        (self.fcs_errors_stat is not None and self.fcs_errors_stat.has_data()) or
                                        (self.if_in_errors is not None and self.if_in_errors.has_data()) or
                                        (self.if_in_octets is not None and self.if_in_octets.has_data()) or
                                        (self.in8021q_frames is not None and self.in8021q_frames.has_data()) or
                                        (self.in_bcast_pkt is not None and self.in_bcast_pkt.has_data()) or
                                        (self.in_drop_abort is not None and self.in_drop_abort.has_data()) or
                                        (self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac.has_data()) or
                                        (self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap.has_data()) or
                                        (self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan.has_data()) or
                                        (self.in_drop_other is not None and self.in_drop_other.has_data()) or
                                        (self.in_drop_overrun is not None and self.in_drop_overrun.has_data()) or
                                        (self.in_error_collisions is not None and self.in_error_collisions.has_data()) or
                                        (self.in_error_fragments is not None and self.in_error_fragments.has_data()) or
                                        (self.in_error_giant is not None and self.in_error_giant.has_data()) or
                                        (self.in_error_jabbers is not None and self.in_error_jabbers.has_data()) or
                                        (self.in_error_other is not None and self.in_error_other.has_data()) or
                                        (self.in_error_runt is not None and self.in_error_runt.has_data()) or
                                        (self.in_error_symbol is not None and self.in_error_symbol.has_data()) or
                                        (self.in_good_bytes is not None and self.in_good_bytes.has_data()) or
                                        (self.in_good_pkts is not None and self.in_good_pkts.has_data()) or
                                        (self.in_mcast_pkt is not None and self.in_mcast_pkt.has_data()) or
                                        (self.in_mib_giant is not None and self.in_mib_giant.has_data()) or
                                        (self.in_mib_jabber is not None and self.in_mib_jabber.has_data()) or
                                        (self.in_mibcrc is not None and self.in_mibcrc.has_data()) or
                                        (self.in_pause_frame is not None and self.in_pause_frame.has_data()) or
                                        (self.in_pkt64_octet is not None and self.in_pkt64_octet.has_data()) or
                                        (self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets.has_data()) or
                                        (self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets.has_data()) or
                                        (self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets.has_data()) or
                                        (self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets.has_data()) or
                                        (self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets.has_data()) or
                                        (self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets.has_data()) or
                                        (self.in_ucast_pkt is not None and self.in_ucast_pkt.has_data()) or
                                        (self.jabber_stat is not None and self.jabber_stat.has_data()) or
                                        (self.long_frames_stat is not None and self.long_frames_stat.has_data()) or
                                        (self.octet_stat is not None and self.octet_stat.has_data()) or
                                        (self.out8021q_frames is not None and self.out8021q_frames.has_data()) or
                                        (self.out_bcast_pkt is not None and self.out_bcast_pkt.has_data()) or
                                        (self.out_drop_abort is not None and self.out_drop_abort.has_data()) or
                                        (self.out_drop_other is not None and self.out_drop_other.has_data()) or
                                        (self.out_drop_underrun is not None and self.out_drop_underrun.has_data()) or
                                        (self.out_error_other is not None and self.out_error_other.has_data()) or
                                        (self.out_good_bytes is not None and self.out_good_bytes.has_data()) or
                                        (self.out_good_pkts is not None and self.out_good_pkts.has_data()) or
                                        (self.out_mcast_pkt is not None and self.out_mcast_pkt.has_data()) or
                                        (self.out_octets is not None and self.out_octets.has_data()) or
                                        (self.out_pause_frames is not None and self.out_pause_frames.has_data()) or
                                        (self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets.has_data()) or
                                        (self.out_pkts128255_octets is not None and self.out_pkts128255_octets.has_data()) or
                                        (self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets.has_data()) or
                                        (self.out_pkts256511_octets is not None and self.out_pkts256511_octets.has_data()) or
                                        (self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets.has_data()) or
                                        (self.out_pkts65127_octets is not None and self.out_pkts65127_octets.has_data()) or
                                        (self.out_ucast_pkt is not None and self.out_ucast_pkt.has_data()) or
                                        (self.outpkt64octet is not None and self.outpkt64octet.has_data()) or
                                        (self.oversize_pkt_stat is not None and self.oversize_pkt_stat.has_data()) or
                                        (self.rx_pkt is not None and self.rx_pkt.has_data()) or
                                        (self.rx_util is not None and self.rx_util.has_data()) or
                                        (self.stat_pkt is not None and self.stat_pkt.has_data()) or
                                        (self.tx_bad_fcs is not None and self.tx_bad_fcs.has_data()) or
                                        (self.tx_fragments is not None and self.tx_fragments.has_data()) or
                                        (self.tx_jabber is not None and self.tx_jabber.has_data()) or
                                        (self.tx_oversized_pkt is not None and self.tx_oversized_pkt.has_data()) or
                                        (self.tx_pkt is not None and self.tx_pkt.has_data()) or
                                        (self.tx_undersized_pkt is not None and self.tx_undersized_pkt.has_data()) or
                                        (self.tx_util is not None and self.tx_util.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.slot_number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.ether10241518_octet is not None and self.ether10241518_octet.has_operation()) or
                                        (self.ether128255_octet is not None and self.ether128255_octet.has_operation()) or
                                        (self.ether256511_octet is not None and self.ether256511_octet.has_operation()) or
                                        (self.ether5121023_octet is not None and self.ether5121023_octet.has_operation()) or
                                        (self.ether64_octets is not None and self.ether64_octets.has_operation()) or
                                        (self.ether65127_octet is not None and self.ether65127_octet.has_operation()) or
                                        (self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt.has_operation()) or
                                        (self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt.has_operation()) or
                                        (self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt.has_operation()) or
                                        (self.fcs_errors_stat is not None and self.fcs_errors_stat.has_operation()) or
                                        (self.if_in_errors is not None and self.if_in_errors.has_operation()) or
                                        (self.if_in_octets is not None and self.if_in_octets.has_operation()) or
                                        (self.in8021q_frames is not None and self.in8021q_frames.has_operation()) or
                                        (self.in_bcast_pkt is not None and self.in_bcast_pkt.has_operation()) or
                                        (self.in_drop_abort is not None and self.in_drop_abort.has_operation()) or
                                        (self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac.has_operation()) or
                                        (self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap.has_operation()) or
                                        (self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan.has_operation()) or
                                        (self.in_drop_other is not None and self.in_drop_other.has_operation()) or
                                        (self.in_drop_overrun is not None and self.in_drop_overrun.has_operation()) or
                                        (self.in_error_collisions is not None and self.in_error_collisions.has_operation()) or
                                        (self.in_error_fragments is not None and self.in_error_fragments.has_operation()) or
                                        (self.in_error_giant is not None and self.in_error_giant.has_operation()) or
                                        (self.in_error_jabbers is not None and self.in_error_jabbers.has_operation()) or
                                        (self.in_error_other is not None and self.in_error_other.has_operation()) or
                                        (self.in_error_runt is not None and self.in_error_runt.has_operation()) or
                                        (self.in_error_symbol is not None and self.in_error_symbol.has_operation()) or
                                        (self.in_good_bytes is not None and self.in_good_bytes.has_operation()) or
                                        (self.in_good_pkts is not None and self.in_good_pkts.has_operation()) or
                                        (self.in_mcast_pkt is not None and self.in_mcast_pkt.has_operation()) or
                                        (self.in_mib_giant is not None and self.in_mib_giant.has_operation()) or
                                        (self.in_mib_jabber is not None and self.in_mib_jabber.has_operation()) or
                                        (self.in_mibcrc is not None and self.in_mibcrc.has_operation()) or
                                        (self.in_pause_frame is not None and self.in_pause_frame.has_operation()) or
                                        (self.in_pkt64_octet is not None and self.in_pkt64_octet.has_operation()) or
                                        (self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets.has_operation()) or
                                        (self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets.has_operation()) or
                                        (self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets.has_operation()) or
                                        (self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets.has_operation()) or
                                        (self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets.has_operation()) or
                                        (self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets.has_operation()) or
                                        (self.in_ucast_pkt is not None and self.in_ucast_pkt.has_operation()) or
                                        (self.jabber_stat is not None and self.jabber_stat.has_operation()) or
                                        (self.long_frames_stat is not None and self.long_frames_stat.has_operation()) or
                                        (self.octet_stat is not None and self.octet_stat.has_operation()) or
                                        (self.out8021q_frames is not None and self.out8021q_frames.has_operation()) or
                                        (self.out_bcast_pkt is not None and self.out_bcast_pkt.has_operation()) or
                                        (self.out_drop_abort is not None and self.out_drop_abort.has_operation()) or
                                        (self.out_drop_other is not None and self.out_drop_other.has_operation()) or
                                        (self.out_drop_underrun is not None and self.out_drop_underrun.has_operation()) or
                                        (self.out_error_other is not None and self.out_error_other.has_operation()) or
                                        (self.out_good_bytes is not None and self.out_good_bytes.has_operation()) or
                                        (self.out_good_pkts is not None and self.out_good_pkts.has_operation()) or
                                        (self.out_mcast_pkt is not None and self.out_mcast_pkt.has_operation()) or
                                        (self.out_octets is not None and self.out_octets.has_operation()) or
                                        (self.out_pause_frames is not None and self.out_pause_frames.has_operation()) or
                                        (self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets.has_operation()) or
                                        (self.out_pkts128255_octets is not None and self.out_pkts128255_octets.has_operation()) or
                                        (self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets.has_operation()) or
                                        (self.out_pkts256511_octets is not None and self.out_pkts256511_octets.has_operation()) or
                                        (self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets.has_operation()) or
                                        (self.out_pkts65127_octets is not None and self.out_pkts65127_octets.has_operation()) or
                                        (self.out_ucast_pkt is not None and self.out_ucast_pkt.has_operation()) or
                                        (self.outpkt64octet is not None and self.outpkt64octet.has_operation()) or
                                        (self.oversize_pkt_stat is not None and self.oversize_pkt_stat.has_operation()) or
                                        (self.rx_pkt is not None and self.rx_pkt.has_operation()) or
                                        (self.rx_util is not None and self.rx_util.has_operation()) or
                                        (self.stat_pkt is not None and self.stat_pkt.has_operation()) or
                                        (self.tx_bad_fcs is not None and self.tx_bad_fcs.has_operation()) or
                                        (self.tx_fragments is not None and self.tx_fragments.has_operation()) or
                                        (self.tx_jabber is not None and self.tx_jabber.has_operation()) or
                                        (self.tx_oversized_pkt is not None and self.tx_oversized_pkt.has_operation()) or
                                        (self.tx_pkt is not None and self.tx_pkt.has_operation()) or
                                        (self.tx_undersized_pkt is not None and self.tx_undersized_pkt.has_operation()) or
                                        (self.tx_util is not None and self.tx_util.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "second30-ether" + "[slot-number='" + self.slot_number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.slot_number.is_set or self.slot_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.slot_number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ether10241518-octet"):
                                        if (self.ether10241518_octet is None):
                                            self.ether10241518_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether10241518Octet()
                                            self.ether10241518_octet.parent = self
                                            self._children_name_map["ether10241518_octet"] = "ether10241518-octet"
                                        return self.ether10241518_octet

                                    if (child_yang_name == "ether128255-octet"):
                                        if (self.ether128255_octet is None):
                                            self.ether128255_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether128255Octet()
                                            self.ether128255_octet.parent = self
                                            self._children_name_map["ether128255_octet"] = "ether128255-octet"
                                        return self.ether128255_octet

                                    if (child_yang_name == "ether256511-octet"):
                                        if (self.ether256511_octet is None):
                                            self.ether256511_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether256511Octet()
                                            self.ether256511_octet.parent = self
                                            self._children_name_map["ether256511_octet"] = "ether256511-octet"
                                        return self.ether256511_octet

                                    if (child_yang_name == "ether5121023-octet"):
                                        if (self.ether5121023_octet is None):
                                            self.ether5121023_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether5121023Octet()
                                            self.ether5121023_octet.parent = self
                                            self._children_name_map["ether5121023_octet"] = "ether5121023-octet"
                                        return self.ether5121023_octet

                                    if (child_yang_name == "ether64-octets"):
                                        if (self.ether64_octets is None):
                                            self.ether64_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether64Octets()
                                            self.ether64_octets.parent = self
                                            self._children_name_map["ether64_octets"] = "ether64-octets"
                                        return self.ether64_octets

                                    if (child_yang_name == "ether65127-octet"):
                                        if (self.ether65127_octet is None):
                                            self.ether65127_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Ether65127Octet()
                                            self.ether65127_octet.parent = self
                                            self._children_name_map["ether65127_octet"] = "ether65127-octet"
                                        return self.ether65127_octet

                                    if (child_yang_name == "ether-stat-broadcast-pkt"):
                                        if (self.ether_stat_broadcast_pkt is None):
                                            self.ether_stat_broadcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatBroadcastPkt()
                                            self.ether_stat_broadcast_pkt.parent = self
                                            self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"
                                        return self.ether_stat_broadcast_pkt

                                    if (child_yang_name == "ether-stat-multicast-pkt"):
                                        if (self.ether_stat_multicast_pkt is None):
                                            self.ether_stat_multicast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatMulticastPkt()
                                            self.ether_stat_multicast_pkt.parent = self
                                            self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"
                                        return self.ether_stat_multicast_pkt

                                    if (child_yang_name == "ether-stat-undersized-pkt"):
                                        if (self.ether_stat_undersized_pkt is None):
                                            self.ether_stat_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.EtherStatUndersizedPkt()
                                            self.ether_stat_undersized_pkt.parent = self
                                            self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"
                                        return self.ether_stat_undersized_pkt

                                    if (child_yang_name == "fcs-errors-stat"):
                                        if (self.fcs_errors_stat is None):
                                            self.fcs_errors_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.FcsErrorsStat()
                                            self.fcs_errors_stat.parent = self
                                            self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"
                                        return self.fcs_errors_stat

                                    if (child_yang_name == "if-in-errors"):
                                        if (self.if_in_errors is None):
                                            self.if_in_errors = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInErrors()
                                            self.if_in_errors.parent = self
                                            self._children_name_map["if_in_errors"] = "if-in-errors"
                                        return self.if_in_errors

                                    if (child_yang_name == "if-in-octets"):
                                        if (self.if_in_octets is None):
                                            self.if_in_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.IfInOctets()
                                            self.if_in_octets.parent = self
                                            self._children_name_map["if_in_octets"] = "if-in-octets"
                                        return self.if_in_octets

                                    if (child_yang_name == "in8021q-frames"):
                                        if (self.in8021q_frames is None):
                                            self.in8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.In8021QFrames()
                                            self.in8021q_frames.parent = self
                                            self._children_name_map["in8021q_frames"] = "in8021q-frames"
                                        return self.in8021q_frames

                                    if (child_yang_name == "in-bcast-pkt"):
                                        if (self.in_bcast_pkt is None):
                                            self.in_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InBcastPkt()
                                            self.in_bcast_pkt.parent = self
                                            self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"
                                        return self.in_bcast_pkt

                                    if (child_yang_name == "in-drop-abort"):
                                        if (self.in_drop_abort is None):
                                            self.in_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropAbort()
                                            self.in_drop_abort.parent = self
                                            self._children_name_map["in_drop_abort"] = "in-drop-abort"
                                        return self.in_drop_abort

                                    if (child_yang_name == "in-drop-invalid-dmac"):
                                        if (self.in_drop_invalid_dmac is None):
                                            self.in_drop_invalid_dmac = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidDmac()
                                            self.in_drop_invalid_dmac.parent = self
                                            self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"
                                        return self.in_drop_invalid_dmac

                                    if (child_yang_name == "in-drop-invalid-encap"):
                                        if (self.in_drop_invalid_encap is None):
                                            self.in_drop_invalid_encap = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidEncap()
                                            self.in_drop_invalid_encap.parent = self
                                            self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"
                                        return self.in_drop_invalid_encap

                                    if (child_yang_name == "in-drop-invalid-vlan"):
                                        if (self.in_drop_invalid_vlan is None):
                                            self.in_drop_invalid_vlan = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropInvalidVlan()
                                            self.in_drop_invalid_vlan.parent = self
                                            self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"
                                        return self.in_drop_invalid_vlan

                                    if (child_yang_name == "in-drop-other"):
                                        if (self.in_drop_other is None):
                                            self.in_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOther()
                                            self.in_drop_other.parent = self
                                            self._children_name_map["in_drop_other"] = "in-drop-other"
                                        return self.in_drop_other

                                    if (child_yang_name == "in-drop-overrun"):
                                        if (self.in_drop_overrun is None):
                                            self.in_drop_overrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InDropOverrun()
                                            self.in_drop_overrun.parent = self
                                            self._children_name_map["in_drop_overrun"] = "in-drop-overrun"
                                        return self.in_drop_overrun

                                    if (child_yang_name == "in-error-collisions"):
                                        if (self.in_error_collisions is None):
                                            self.in_error_collisions = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorCollisions()
                                            self.in_error_collisions.parent = self
                                            self._children_name_map["in_error_collisions"] = "in-error-collisions"
                                        return self.in_error_collisions

                                    if (child_yang_name == "in-error-fragments"):
                                        if (self.in_error_fragments is None):
                                            self.in_error_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorFragments()
                                            self.in_error_fragments.parent = self
                                            self._children_name_map["in_error_fragments"] = "in-error-fragments"
                                        return self.in_error_fragments

                                    if (child_yang_name == "in-error-giant"):
                                        if (self.in_error_giant is None):
                                            self.in_error_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorGiant()
                                            self.in_error_giant.parent = self
                                            self._children_name_map["in_error_giant"] = "in-error-giant"
                                        return self.in_error_giant

                                    if (child_yang_name == "in-error-jabbers"):
                                        if (self.in_error_jabbers is None):
                                            self.in_error_jabbers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorJabbers()
                                            self.in_error_jabbers.parent = self
                                            self._children_name_map["in_error_jabbers"] = "in-error-jabbers"
                                        return self.in_error_jabbers

                                    if (child_yang_name == "in-error-other"):
                                        if (self.in_error_other is None):
                                            self.in_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorOther()
                                            self.in_error_other.parent = self
                                            self._children_name_map["in_error_other"] = "in-error-other"
                                        return self.in_error_other

                                    if (child_yang_name == "in-error-runt"):
                                        if (self.in_error_runt is None):
                                            self.in_error_runt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorRunt()
                                            self.in_error_runt.parent = self
                                            self._children_name_map["in_error_runt"] = "in-error-runt"
                                        return self.in_error_runt

                                    if (child_yang_name == "in-error-symbol"):
                                        if (self.in_error_symbol is None):
                                            self.in_error_symbol = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InErrorSymbol()
                                            self.in_error_symbol.parent = self
                                            self._children_name_map["in_error_symbol"] = "in-error-symbol"
                                        return self.in_error_symbol

                                    if (child_yang_name == "in-good-bytes"):
                                        if (self.in_good_bytes is None):
                                            self.in_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodBytes()
                                            self.in_good_bytes.parent = self
                                            self._children_name_map["in_good_bytes"] = "in-good-bytes"
                                        return self.in_good_bytes

                                    if (child_yang_name == "in-good-pkts"):
                                        if (self.in_good_pkts is None):
                                            self.in_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InGoodPkts()
                                            self.in_good_pkts.parent = self
                                            self._children_name_map["in_good_pkts"] = "in-good-pkts"
                                        return self.in_good_pkts

                                    if (child_yang_name == "in-mcast-pkt"):
                                        if (self.in_mcast_pkt is None):
                                            self.in_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMcastPkt()
                                            self.in_mcast_pkt.parent = self
                                            self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"
                                        return self.in_mcast_pkt

                                    if (child_yang_name == "in-mib-giant"):
                                        if (self.in_mib_giant is None):
                                            self.in_mib_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibGiant()
                                            self.in_mib_giant.parent = self
                                            self._children_name_map["in_mib_giant"] = "in-mib-giant"
                                        return self.in_mib_giant

                                    if (child_yang_name == "in-mib-jabber"):
                                        if (self.in_mib_jabber is None):
                                            self.in_mib_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibJabber()
                                            self.in_mib_jabber.parent = self
                                            self._children_name_map["in_mib_jabber"] = "in-mib-jabber"
                                        return self.in_mib_jabber

                                    if (child_yang_name == "in-mibcrc"):
                                        if (self.in_mibcrc is None):
                                            self.in_mibcrc = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InMibcrc()
                                            self.in_mibcrc.parent = self
                                            self._children_name_map["in_mibcrc"] = "in-mibcrc"
                                        return self.in_mibcrc

                                    if (child_yang_name == "in-pause-frame"):
                                        if (self.in_pause_frame is None):
                                            self.in_pause_frame = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPauseFrame()
                                            self.in_pause_frame.parent = self
                                            self._children_name_map["in_pause_frame"] = "in-pause-frame"
                                        return self.in_pause_frame

                                    if (child_yang_name == "in-pkt64-octet"):
                                        if (self.in_pkt64_octet is None):
                                            self.in_pkt64_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkt64Octet()
                                            self.in_pkt64_octet.parent = self
                                            self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"
                                        return self.in_pkt64_octet

                                    if (child_yang_name == "in-pkts1024-to1518-octets"):
                                        if (self.in_pkts1024_to1518_octets is None):
                                            self.in_pkts1024_to1518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1024To1518Octets()
                                            self.in_pkts1024_to1518_octets.parent = self
                                            self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"
                                        return self.in_pkts1024_to1518_octets

                                    if (child_yang_name == "in-pkts128-to255-octets"):
                                        if (self.in_pkts128_to255_octets is None):
                                            self.in_pkts128_to255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts128To255Octets()
                                            self.in_pkts128_to255_octets.parent = self
                                            self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"
                                        return self.in_pkts128_to255_octets

                                    if (child_yang_name == "in-pkts1519-max-octets"):
                                        if (self.in_pkts1519_max_octets is None):
                                            self.in_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts1519MaxOctets()
                                            self.in_pkts1519_max_octets.parent = self
                                            self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"
                                        return self.in_pkts1519_max_octets

                                    if (child_yang_name == "in-pkts256-to511-octets"):
                                        if (self.in_pkts256_to511_octets is None):
                                            self.in_pkts256_to511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts256To511Octets()
                                            self.in_pkts256_to511_octets.parent = self
                                            self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"
                                        return self.in_pkts256_to511_octets

                                    if (child_yang_name == "in-pkts512-to1023-octets"):
                                        if (self.in_pkts512_to1023_octets is None):
                                            self.in_pkts512_to1023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts512To1023Octets()
                                            self.in_pkts512_to1023_octets.parent = self
                                            self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"
                                        return self.in_pkts512_to1023_octets

                                    if (child_yang_name == "in-pkts65-to127-octets"):
                                        if (self.in_pkts65_to127_octets is None):
                                            self.in_pkts65_to127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InPkts65To127Octets()
                                            self.in_pkts65_to127_octets.parent = self
                                            self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"
                                        return self.in_pkts65_to127_octets

                                    if (child_yang_name == "in-ucast-pkt"):
                                        if (self.in_ucast_pkt is None):
                                            self.in_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.InUcastPkt()
                                            self.in_ucast_pkt.parent = self
                                            self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"
                                        return self.in_ucast_pkt

                                    if (child_yang_name == "jabber-stat"):
                                        if (self.jabber_stat is None):
                                            self.jabber_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.JabberStat()
                                            self.jabber_stat.parent = self
                                            self._children_name_map["jabber_stat"] = "jabber-stat"
                                        return self.jabber_stat

                                    if (child_yang_name == "long-frames-stat"):
                                        if (self.long_frames_stat is None):
                                            self.long_frames_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.LongFramesStat()
                                            self.long_frames_stat.parent = self
                                            self._children_name_map["long_frames_stat"] = "long-frames-stat"
                                        return self.long_frames_stat

                                    if (child_yang_name == "octet-stat"):
                                        if (self.octet_stat is None):
                                            self.octet_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OctetStat()
                                            self.octet_stat.parent = self
                                            self._children_name_map["octet_stat"] = "octet-stat"
                                        return self.octet_stat

                                    if (child_yang_name == "out8021q-frames"):
                                        if (self.out8021q_frames is None):
                                            self.out8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Out8021QFrames()
                                            self.out8021q_frames.parent = self
                                            self._children_name_map["out8021q_frames"] = "out8021q-frames"
                                        return self.out8021q_frames

                                    if (child_yang_name == "out-bcast-pkt"):
                                        if (self.out_bcast_pkt is None):
                                            self.out_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutBcastPkt()
                                            self.out_bcast_pkt.parent = self
                                            self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"
                                        return self.out_bcast_pkt

                                    if (child_yang_name == "out-drop-abort"):
                                        if (self.out_drop_abort is None):
                                            self.out_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropAbort()
                                            self.out_drop_abort.parent = self
                                            self._children_name_map["out_drop_abort"] = "out-drop-abort"
                                        return self.out_drop_abort

                                    if (child_yang_name == "out-drop-other"):
                                        if (self.out_drop_other is None):
                                            self.out_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropOther()
                                            self.out_drop_other.parent = self
                                            self._children_name_map["out_drop_other"] = "out-drop-other"
                                        return self.out_drop_other

                                    if (child_yang_name == "out-drop-underrun"):
                                        if (self.out_drop_underrun is None):
                                            self.out_drop_underrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutDropUnderrun()
                                            self.out_drop_underrun.parent = self
                                            self._children_name_map["out_drop_underrun"] = "out-drop-underrun"
                                        return self.out_drop_underrun

                                    if (child_yang_name == "out-error-other"):
                                        if (self.out_error_other is None):
                                            self.out_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutErrorOther()
                                            self.out_error_other.parent = self
                                            self._children_name_map["out_error_other"] = "out-error-other"
                                        return self.out_error_other

                                    if (child_yang_name == "out-good-bytes"):
                                        if (self.out_good_bytes is None):
                                            self.out_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodBytes()
                                            self.out_good_bytes.parent = self
                                            self._children_name_map["out_good_bytes"] = "out-good-bytes"
                                        return self.out_good_bytes

                                    if (child_yang_name == "out-good-pkts"):
                                        if (self.out_good_pkts is None):
                                            self.out_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutGoodPkts()
                                            self.out_good_pkts.parent = self
                                            self._children_name_map["out_good_pkts"] = "out-good-pkts"
                                        return self.out_good_pkts

                                    if (child_yang_name == "out-mcast-pkt"):
                                        if (self.out_mcast_pkt is None):
                                            self.out_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutMcastPkt()
                                            self.out_mcast_pkt.parent = self
                                            self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"
                                        return self.out_mcast_pkt

                                    if (child_yang_name == "out-octets"):
                                        if (self.out_octets is None):
                                            self.out_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutOctets()
                                            self.out_octets.parent = self
                                            self._children_name_map["out_octets"] = "out-octets"
                                        return self.out_octets

                                    if (child_yang_name == "out-pause-frames"):
                                        if (self.out_pause_frames is None):
                                            self.out_pause_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPauseFrames()
                                            self.out_pause_frames.parent = self
                                            self._children_name_map["out_pause_frames"] = "out-pause-frames"
                                        return self.out_pause_frames

                                    if (child_yang_name == "out-pkts10241518-octets"):
                                        if (self.out_pkts10241518_octets is None):
                                            self.out_pkts10241518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts10241518Octets()
                                            self.out_pkts10241518_octets.parent = self
                                            self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"
                                        return self.out_pkts10241518_octets

                                    if (child_yang_name == "out-pkts128255-octets"):
                                        if (self.out_pkts128255_octets is None):
                                            self.out_pkts128255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts128255Octets()
                                            self.out_pkts128255_octets.parent = self
                                            self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"
                                        return self.out_pkts128255_octets

                                    if (child_yang_name == "out-pkts1519-max-octets"):
                                        if (self.out_pkts1519_max_octets is None):
                                            self.out_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts1519MaxOctets()
                                            self.out_pkts1519_max_octets.parent = self
                                            self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"
                                        return self.out_pkts1519_max_octets

                                    if (child_yang_name == "out-pkts256511-octets"):
                                        if (self.out_pkts256511_octets is None):
                                            self.out_pkts256511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts256511Octets()
                                            self.out_pkts256511_octets.parent = self
                                            self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"
                                        return self.out_pkts256511_octets

                                    if (child_yang_name == "out-pkts5121023-octets"):
                                        if (self.out_pkts5121023_octets is None):
                                            self.out_pkts5121023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts5121023Octets()
                                            self.out_pkts5121023_octets.parent = self
                                            self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"
                                        return self.out_pkts5121023_octets

                                    if (child_yang_name == "out-pkts65127-octets"):
                                        if (self.out_pkts65127_octets is None):
                                            self.out_pkts65127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutPkts65127Octets()
                                            self.out_pkts65127_octets.parent = self
                                            self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"
                                        return self.out_pkts65127_octets

                                    if (child_yang_name == "out-ucast-pkt"):
                                        if (self.out_ucast_pkt is None):
                                            self.out_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OutUcastPkt()
                                            self.out_ucast_pkt.parent = self
                                            self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"
                                        return self.out_ucast_pkt

                                    if (child_yang_name == "outpkt64octet"):
                                        if (self.outpkt64octet is None):
                                            self.outpkt64octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.Outpkt64Octet()
                                            self.outpkt64octet.parent = self
                                            self._children_name_map["outpkt64octet"] = "outpkt64octet"
                                        return self.outpkt64octet

                                    if (child_yang_name == "oversize-pkt-stat"):
                                        if (self.oversize_pkt_stat is None):
                                            self.oversize_pkt_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.OversizePktStat()
                                            self.oversize_pkt_stat.parent = self
                                            self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"
                                        return self.oversize_pkt_stat

                                    if (child_yang_name == "rx-pkt"):
                                        if (self.rx_pkt is None):
                                            self.rx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxPkt()
                                            self.rx_pkt.parent = self
                                            self._children_name_map["rx_pkt"] = "rx-pkt"
                                        return self.rx_pkt

                                    if (child_yang_name == "rx-util"):
                                        if (self.rx_util is None):
                                            self.rx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.RxUtil()
                                            self.rx_util.parent = self
                                            self._children_name_map["rx_util"] = "rx-util"
                                        return self.rx_util

                                    if (child_yang_name == "stat-pkt"):
                                        if (self.stat_pkt is None):
                                            self.stat_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.StatPkt()
                                            self.stat_pkt.parent = self
                                            self._children_name_map["stat_pkt"] = "stat-pkt"
                                        return self.stat_pkt

                                    if (child_yang_name == "tx-bad-fcs"):
                                        if (self.tx_bad_fcs is None):
                                            self.tx_bad_fcs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxBadFcs()
                                            self.tx_bad_fcs.parent = self
                                            self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                        return self.tx_bad_fcs

                                    if (child_yang_name == "tx-fragments"):
                                        if (self.tx_fragments is None):
                                            self.tx_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxFragments()
                                            self.tx_fragments.parent = self
                                            self._children_name_map["tx_fragments"] = "tx-fragments"
                                        return self.tx_fragments

                                    if (child_yang_name == "tx-jabber"):
                                        if (self.tx_jabber is None):
                                            self.tx_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxJabber()
                                            self.tx_jabber.parent = self
                                            self._children_name_map["tx_jabber"] = "tx-jabber"
                                        return self.tx_jabber

                                    if (child_yang_name == "tx-oversized-pkt"):
                                        if (self.tx_oversized_pkt is None):
                                            self.tx_oversized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxOversizedPkt()
                                            self.tx_oversized_pkt.parent = self
                                            self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"
                                        return self.tx_oversized_pkt

                                    if (child_yang_name == "tx-pkt"):
                                        if (self.tx_pkt is None):
                                            self.tx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxPkt()
                                            self.tx_pkt.parent = self
                                            self._children_name_map["tx_pkt"] = "tx-pkt"
                                        return self.tx_pkt

                                    if (child_yang_name == "tx-undersized-pkt"):
                                        if (self.tx_undersized_pkt is None):
                                            self.tx_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUndersizedPkt()
                                            self.tx_undersized_pkt.parent = self
                                            self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"
                                        return self.tx_undersized_pkt

                                    if (child_yang_name == "tx-util"):
                                        if (self.tx_util is None):
                                            self.tx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether.TxUtil()
                                            self.tx_util.parent = self
                                            self._children_name_map["tx_util"] = "tx-util"
                                        return self.tx_util

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ether10241518-octet" or name == "ether128255-octet" or name == "ether256511-octet" or name == "ether5121023-octet" or name == "ether64-octets" or name == "ether65127-octet" or name == "ether-stat-broadcast-pkt" or name == "ether-stat-multicast-pkt" or name == "ether-stat-undersized-pkt" or name == "fcs-errors-stat" or name == "if-in-errors" or name == "if-in-octets" or name == "in8021q-frames" or name == "in-bcast-pkt" or name == "in-drop-abort" or name == "in-drop-invalid-dmac" or name == "in-drop-invalid-encap" or name == "in-drop-invalid-vlan" or name == "in-drop-other" or name == "in-drop-overrun" or name == "in-error-collisions" or name == "in-error-fragments" or name == "in-error-giant" or name == "in-error-jabbers" or name == "in-error-other" or name == "in-error-runt" or name == "in-error-symbol" or name == "in-good-bytes" or name == "in-good-pkts" or name == "in-mcast-pkt" or name == "in-mib-giant" or name == "in-mib-jabber" or name == "in-mibcrc" or name == "in-pause-frame" or name == "in-pkt64-octet" or name == "in-pkts1024-to1518-octets" or name == "in-pkts128-to255-octets" or name == "in-pkts1519-max-octets" or name == "in-pkts256-to511-octets" or name == "in-pkts512-to1023-octets" or name == "in-pkts65-to127-octets" or name == "in-ucast-pkt" or name == "jabber-stat" or name == "long-frames-stat" or name == "octet-stat" or name == "out8021q-frames" or name == "out-bcast-pkt" or name == "out-drop-abort" or name == "out-drop-other" or name == "out-drop-underrun" or name == "out-error-other" or name == "out-good-bytes" or name == "out-good-pkts" or name == "out-mcast-pkt" or name == "out-octets" or name == "out-pause-frames" or name == "out-pkts10241518-octets" or name == "out-pkts128255-octets" or name == "out-pkts1519-max-octets" or name == "out-pkts256511-octets" or name == "out-pkts5121023-octets" or name == "out-pkts65127-octets" or name == "out-ucast-pkt" or name == "outpkt64octet" or name == "oversize-pkt-stat" or name == "rx-pkt" or name == "rx-util" or name == "stat-pkt" or name == "tx-bad-fcs" or name == "tx-fragments" or name == "tx-jabber" or name == "tx-oversized-pkt" or name == "tx-pkt" or name == "tx-undersized-pkt" or name == "tx-util" or name == "slot-number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "slot-number"):
                                        self.slot_number = value
                                        self.slot_number.value_namespace = name_space
                                        self.slot_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.second30_ether:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.second30_ether:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "second30-ethers" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "second30-ether"):
                                    for c in self.second30_ether:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers.Second30Ether()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.second30_ether.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "second30-ether"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.second30_ethers is not None and self.second30_ethers.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.second30_ethers is not None and self.second30_ethers.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ethernet-second30" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "second30-ethers"):
                                if (self.second30_ethers is None):
                                    self.second30_ethers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30.Second30Ethers()
                                    self.second30_ethers.parent = self
                                    self._children_name_map["second30_ethers"] = "second30-ethers"
                                return self.second30_ethers

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "second30-ethers"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class EthernetHour24(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: ethernet_hour24_ether_s
                        
                        	port current performance data
                        	**type**\:   :py:class:`EthernetHour24EtherS <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24, self).__init__()

                            self.yang_name = "ethernet-hour24"
                            self.yang_parent_name = "ethernet-current"

                            self.ethernet_hour24_ether_s = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS()
                            self.ethernet_hour24_ether_s.parent = self
                            self._children_name_map["ethernet_hour24_ether_s"] = "ethernet-hour24-ether-s"
                            self._children_yang_names.add("ethernet-hour24-ether-s")


                        class EthernetHour24EtherS(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: ethernet_hour24_ether
                            
                            	port 24 hour ethernet performance data
                            	**type**\: list of    :py:class:`EthernetHour24Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS, self).__init__()

                                self.yang_name = "ethernet-hour24-ether-s"
                                self.yang_parent_name = "ethernet-hour24"

                                self.ethernet_hour24_ether = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS, self).__setattr__(name, value)


                            class EthernetHour24Ether(Entity):
                                """
                                port 24 hour ethernet performance data
                                
                                .. attribute:: number  <key>
                                
                                	channel number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ether10241518_octet
                                
                                	OFO OCTET
                                	**type**\:   :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet>`
                                
                                .. attribute:: ether128255_octet
                                
                                	TFF OCTET
                                	**type**\:   :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet>`
                                
                                .. attribute:: ether256511_octet
                                
                                	FOO OCTET
                                	**type**\:   :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet>`
                                
                                .. attribute:: ether5121023_octet
                                
                                	OZTT OCTET
                                	**type**\:   :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet>`
                                
                                .. attribute:: ether64_octets
                                
                                	SIXTY FOUR OCTET
                                	**type**\:   :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets>`
                                
                                .. attribute:: ether65127_octet
                                
                                	OCTET
                                	**type**\:   :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet>`
                                
                                .. attribute:: ether_stat_broadcast_pkt
                                
                                	ETHER STAT BROADCAST PKT
                                	**type**\:   :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt>`
                                
                                .. attribute:: ether_stat_multicast_pkt
                                
                                	ETHER STAT MULTICAST PKT
                                	**type**\:   :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt>`
                                
                                .. attribute:: ether_stat_undersized_pkt
                                
                                	ETHER STAT UNDERSIZED PKT
                                	**type**\:   :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt>`
                                
                                .. attribute:: fcs_errors_stat
                                
                                	FCS ERR
                                	**type**\:   :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat>`
                                
                                .. attribute:: if_in_errors
                                
                                	IFIN ERRORS
                                	**type**\:   :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors>`
                                
                                .. attribute:: if_in_octets
                                
                                	IFIN OCTETS
                                	**type**\:   :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets>`
                                
                                .. attribute:: in8021q_frames
                                
                                	INPUT 802 1Q FRAMES
                                	**type**\:   :py:class:`In8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021QFrames>`
                                
                                .. attribute:: in_bcast_pkt
                                
                                	IN BCAST
                                	**type**\:   :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt>`
                                
                                .. attribute:: in_drop_abort
                                
                                	INPUT DROP ABORT
                                	**type**\:   :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort>`
                                
                                .. attribute:: in_drop_invalid_dmac
                                
                                	INPUT DROP INVALID DMAC
                                	**type**\:   :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac>`
                                
                                .. attribute:: in_drop_invalid_encap
                                
                                	INPUT DROP INVALID ENCAP
                                	**type**\:   :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap>`
                                
                                .. attribute:: in_drop_invalid_vlan
                                
                                	INPUT DROP INVALID VLAN
                                	**type**\:   :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan>`
                                
                                .. attribute:: in_drop_other
                                
                                	INPUT DROP OTHER
                                	**type**\:   :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther>`
                                
                                .. attribute:: in_drop_overrun
                                
                                	INPUT DROP OVERRUN
                                	**type**\:   :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun>`
                                
                                .. attribute:: in_error_collisions
                                
                                	IN ERROR COLLISIONS
                                	**type**\:   :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions>`
                                
                                .. attribute:: in_error_fragments
                                
                                	IN ERROR FRAGMENTS
                                	**type**\:   :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments>`
                                
                                .. attribute:: in_error_giant
                                
                                	IN ERROR GIANT
                                	**type**\:   :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant>`
                                
                                .. attribute:: in_error_jabbers
                                
                                	IN ERROR JABBERS
                                	**type**\:   :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers>`
                                
                                .. attribute:: in_error_other
                                
                                	IN ERROR OTHER
                                	**type**\:   :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther>`
                                
                                .. attribute:: in_error_runt
                                
                                	IN ERROR RUNT
                                	**type**\:   :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt>`
                                
                                .. attribute:: in_error_symbol
                                
                                	IN ERROR SYMBOL
                                	**type**\:   :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol>`
                                
                                .. attribute:: in_good_bytes
                                
                                	INPUT GOOD BYTES
                                	**type**\:   :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes>`
                                
                                .. attribute:: in_good_pkts
                                
                                	INPUT GOOD PKTS
                                	**type**\:   :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts>`
                                
                                .. attribute:: in_mcast_pkt
                                
                                	IN MCAST
                                	**type**\:   :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt>`
                                
                                .. attribute:: in_mib_giant
                                
                                	INPUT MIB GIANT
                                	**type**\:   :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant>`
                                
                                .. attribute:: in_mib_jabber
                                
                                	INPUT MIB JABBER
                                	**type**\:   :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber>`
                                
                                .. attribute:: in_mibcrc
                                
                                	IN MIB CRC
                                	**type**\:   :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc>`
                                
                                .. attribute:: in_pause_frame
                                
                                	INPUT PAUSE FRAME
                                	**type**\:   :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame>`
                                
                                .. attribute:: in_pkt64_octet
                                
                                	IN PKT 64 OCTET
                                	**type**\:   :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet>`
                                
                                .. attribute:: in_pkts1024_to1518_octets
                                
                                	IN PKTS 1024 1518 OCTETS
                                	**type**\:   :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets>`
                                
                                .. attribute:: in_pkts128_to255_octets
                                
                                	IN PKTS 128 255 OCTETS
                                	**type**\:   :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets>`
                                
                                .. attribute:: in_pkts1519_max_octets
                                
                                	INPUT PKTS 1519MAX OCTETS
                                	**type**\:   :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets>`
                                
                                .. attribute:: in_pkts256_to511_octets
                                
                                	IN PKTS 256 511 OCTETS
                                	**type**\:   :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets>`
                                
                                .. attribute:: in_pkts512_to1023_octets
                                
                                	IN PKTS 512 1023 OCTETS
                                	**type**\:   :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets>`
                                
                                .. attribute:: in_pkts65_to127_octets
                                
                                	IN PKTS 65 127OCTETS
                                	**type**\:   :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets>`
                                
                                .. attribute:: in_ucast_pkt
                                
                                	IN UCAST
                                	**type**\:   :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: jabber_stat
                                
                                	JABBER STATS
                                	**type**\:   :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat>`
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: long_frames_stat
                                
                                	LONG FRAMES
                                	**type**\:   :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat>`
                                
                                .. attribute:: octet_stat
                                
                                	OCTET STAT
                                	**type**\:   :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat>`
                                
                                .. attribute:: out8021q_frames
                                
                                	OUT 802 1Q FRAMES
                                	**type**\:   :py:class:`Out8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021QFrames>`
                                
                                .. attribute:: out_bcast_pkt
                                
                                	OUT BCAST
                                	**type**\:   :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt>`
                                
                                .. attribute:: out_drop_abort
                                
                                	OUT DROP ABORT
                                	**type**\:   :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort>`
                                
                                .. attribute:: out_drop_other
                                
                                	OUT DROP OTHER
                                	**type**\:   :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther>`
                                
                                .. attribute:: out_drop_underrun
                                
                                	OUT DROP UNDERRUN
                                	**type**\:   :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun>`
                                
                                .. attribute:: out_error_other
                                
                                	OUT ERROR OTHER
                                	**type**\:   :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther>`
                                
                                .. attribute:: out_good_bytes
                                
                                	OUT GOOD BYTES
                                	**type**\:   :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes>`
                                
                                .. attribute:: out_good_pkts
                                
                                	OUT GOOD PKTS
                                	**type**\:   :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts>`
                                
                                .. attribute:: out_mcast_pkt
                                
                                	OUT MCAST
                                	**type**\:   :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt>`
                                
                                .. attribute:: out_octets
                                
                                	OUT OCTET
                                	**type**\:   :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets>`
                                
                                .. attribute:: out_pause_frames
                                
                                	OUT PAUSE FRAMES
                                	**type**\:   :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames>`
                                
                                .. attribute:: out_pkts10241518_octets
                                
                                	OUT PKTS 1024 1518 OCTETS
                                	**type**\:   :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets>`
                                
                                .. attribute:: out_pkts128255_octets
                                
                                	OUT PKTS 128 255 OCTETS
                                	**type**\:   :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets>`
                                
                                .. attribute:: out_pkts1519_max_octets
                                
                                	OUT PKTS 1519 MAX OCTETS
                                	**type**\:   :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets>`
                                
                                .. attribute:: out_pkts256511_octets
                                
                                	OUT PKTS 256 511 OCTETS
                                	**type**\:   :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets>`
                                
                                .. attribute:: out_pkts5121023_octets
                                
                                	OUT PKTS 512 1023 OCTETS
                                	**type**\:   :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets>`
                                
                                .. attribute:: out_pkts65127_octets
                                
                                	OUT PKTS 65 127OCTETS
                                	**type**\:   :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets>`
                                
                                .. attribute:: out_ucast_pkt
                                
                                	OUT UCAST
                                	**type**\:   :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt>`
                                
                                .. attribute:: outpkt64octet
                                
                                	OUT PKT 64 OCTET
                                	**type**\:   :py:class:`Outpkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64Octet>`
                                
                                .. attribute:: oversize_pkt_stat
                                
                                	OVERSIZE PKT
                                	**type**\:   :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat>`
                                
                                .. attribute:: rx_pkt
                                
                                	RX PKT
                                	**type**\:   :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt>`
                                
                                .. attribute:: rx_util
                                
                                	Rx Utilization in Percent
                                	**type**\:   :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: stat_pkt
                                
                                	STAT PKT
                                	**type**\:   :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: tx_bad_fcs
                                
                                	TX Bad Fcs
                                	**type**\:   :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs>`
                                
                                .. attribute:: tx_fragments
                                
                                	TX Fragments
                                	**type**\:   :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments>`
                                
                                .. attribute:: tx_jabber
                                
                                	TX Jabber
                                	**type**\:   :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber>`
                                
                                .. attribute:: tx_oversized_pkt
                                
                                	TX Oversized Pkt
                                	**type**\:   :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt>`
                                
                                .. attribute:: tx_pkt
                                
                                	TX PKT
                                	**type**\:   :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt>`
                                
                                .. attribute:: tx_undersized_pkt
                                
                                	TX Undersized Pkt
                                	**type**\:   :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt>`
                                
                                .. attribute:: tx_util
                                
                                	Tx Utilization in Percent
                                	**type**\:   :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether, self).__init__()

                                    self.yang_name = "ethernet-hour24-ether"
                                    self.yang_parent_name = "ethernet-hour24-ether-s"

                                    self.number = YLeaf(YType.int32, "number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.ether10241518_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet()
                                    self.ether10241518_octet.parent = self
                                    self._children_name_map["ether10241518_octet"] = "ether10241518-octet"
                                    self._children_yang_names.add("ether10241518-octet")

                                    self.ether128255_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet()
                                    self.ether128255_octet.parent = self
                                    self._children_name_map["ether128255_octet"] = "ether128255-octet"
                                    self._children_yang_names.add("ether128255-octet")

                                    self.ether256511_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet()
                                    self.ether256511_octet.parent = self
                                    self._children_name_map["ether256511_octet"] = "ether256511-octet"
                                    self._children_yang_names.add("ether256511-octet")

                                    self.ether5121023_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet()
                                    self.ether5121023_octet.parent = self
                                    self._children_name_map["ether5121023_octet"] = "ether5121023-octet"
                                    self._children_yang_names.add("ether5121023-octet")

                                    self.ether64_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets()
                                    self.ether64_octets.parent = self
                                    self._children_name_map["ether64_octets"] = "ether64-octets"
                                    self._children_yang_names.add("ether64-octets")

                                    self.ether65127_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet()
                                    self.ether65127_octet.parent = self
                                    self._children_name_map["ether65127_octet"] = "ether65127-octet"
                                    self._children_yang_names.add("ether65127-octet")

                                    self.ether_stat_broadcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt()
                                    self.ether_stat_broadcast_pkt.parent = self
                                    self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"
                                    self._children_yang_names.add("ether-stat-broadcast-pkt")

                                    self.ether_stat_multicast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt()
                                    self.ether_stat_multicast_pkt.parent = self
                                    self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"
                                    self._children_yang_names.add("ether-stat-multicast-pkt")

                                    self.ether_stat_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt()
                                    self.ether_stat_undersized_pkt.parent = self
                                    self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"
                                    self._children_yang_names.add("ether-stat-undersized-pkt")

                                    self.fcs_errors_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat()
                                    self.fcs_errors_stat.parent = self
                                    self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"
                                    self._children_yang_names.add("fcs-errors-stat")

                                    self.if_in_errors = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors()
                                    self.if_in_errors.parent = self
                                    self._children_name_map["if_in_errors"] = "if-in-errors"
                                    self._children_yang_names.add("if-in-errors")

                                    self.if_in_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets()
                                    self.if_in_octets.parent = self
                                    self._children_name_map["if_in_octets"] = "if-in-octets"
                                    self._children_yang_names.add("if-in-octets")

                                    self.in8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021QFrames()
                                    self.in8021q_frames.parent = self
                                    self._children_name_map["in8021q_frames"] = "in8021q-frames"
                                    self._children_yang_names.add("in8021q-frames")

                                    self.in_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt()
                                    self.in_bcast_pkt.parent = self
                                    self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"
                                    self._children_yang_names.add("in-bcast-pkt")

                                    self.in_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort()
                                    self.in_drop_abort.parent = self
                                    self._children_name_map["in_drop_abort"] = "in-drop-abort"
                                    self._children_yang_names.add("in-drop-abort")

                                    self.in_drop_invalid_dmac = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac()
                                    self.in_drop_invalid_dmac.parent = self
                                    self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"
                                    self._children_yang_names.add("in-drop-invalid-dmac")

                                    self.in_drop_invalid_encap = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap()
                                    self.in_drop_invalid_encap.parent = self
                                    self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"
                                    self._children_yang_names.add("in-drop-invalid-encap")

                                    self.in_drop_invalid_vlan = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan()
                                    self.in_drop_invalid_vlan.parent = self
                                    self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"
                                    self._children_yang_names.add("in-drop-invalid-vlan")

                                    self.in_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther()
                                    self.in_drop_other.parent = self
                                    self._children_name_map["in_drop_other"] = "in-drop-other"
                                    self._children_yang_names.add("in-drop-other")

                                    self.in_drop_overrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun()
                                    self.in_drop_overrun.parent = self
                                    self._children_name_map["in_drop_overrun"] = "in-drop-overrun"
                                    self._children_yang_names.add("in-drop-overrun")

                                    self.in_error_collisions = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions()
                                    self.in_error_collisions.parent = self
                                    self._children_name_map["in_error_collisions"] = "in-error-collisions"
                                    self._children_yang_names.add("in-error-collisions")

                                    self.in_error_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments()
                                    self.in_error_fragments.parent = self
                                    self._children_name_map["in_error_fragments"] = "in-error-fragments"
                                    self._children_yang_names.add("in-error-fragments")

                                    self.in_error_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant()
                                    self.in_error_giant.parent = self
                                    self._children_name_map["in_error_giant"] = "in-error-giant"
                                    self._children_yang_names.add("in-error-giant")

                                    self.in_error_jabbers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers()
                                    self.in_error_jabbers.parent = self
                                    self._children_name_map["in_error_jabbers"] = "in-error-jabbers"
                                    self._children_yang_names.add("in-error-jabbers")

                                    self.in_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther()
                                    self.in_error_other.parent = self
                                    self._children_name_map["in_error_other"] = "in-error-other"
                                    self._children_yang_names.add("in-error-other")

                                    self.in_error_runt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt()
                                    self.in_error_runt.parent = self
                                    self._children_name_map["in_error_runt"] = "in-error-runt"
                                    self._children_yang_names.add("in-error-runt")

                                    self.in_error_symbol = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol()
                                    self.in_error_symbol.parent = self
                                    self._children_name_map["in_error_symbol"] = "in-error-symbol"
                                    self._children_yang_names.add("in-error-symbol")

                                    self.in_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes()
                                    self.in_good_bytes.parent = self
                                    self._children_name_map["in_good_bytes"] = "in-good-bytes"
                                    self._children_yang_names.add("in-good-bytes")

                                    self.in_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts()
                                    self.in_good_pkts.parent = self
                                    self._children_name_map["in_good_pkts"] = "in-good-pkts"
                                    self._children_yang_names.add("in-good-pkts")

                                    self.in_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt()
                                    self.in_mcast_pkt.parent = self
                                    self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"
                                    self._children_yang_names.add("in-mcast-pkt")

                                    self.in_mib_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant()
                                    self.in_mib_giant.parent = self
                                    self._children_name_map["in_mib_giant"] = "in-mib-giant"
                                    self._children_yang_names.add("in-mib-giant")

                                    self.in_mib_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber()
                                    self.in_mib_jabber.parent = self
                                    self._children_name_map["in_mib_jabber"] = "in-mib-jabber"
                                    self._children_yang_names.add("in-mib-jabber")

                                    self.in_mibcrc = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc()
                                    self.in_mibcrc.parent = self
                                    self._children_name_map["in_mibcrc"] = "in-mibcrc"
                                    self._children_yang_names.add("in-mibcrc")

                                    self.in_pause_frame = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame()
                                    self.in_pause_frame.parent = self
                                    self._children_name_map["in_pause_frame"] = "in-pause-frame"
                                    self._children_yang_names.add("in-pause-frame")

                                    self.in_pkt64_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet()
                                    self.in_pkt64_octet.parent = self
                                    self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"
                                    self._children_yang_names.add("in-pkt64-octet")

                                    self.in_pkts1024_to1518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets()
                                    self.in_pkts1024_to1518_octets.parent = self
                                    self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"
                                    self._children_yang_names.add("in-pkts1024-to1518-octets")

                                    self.in_pkts128_to255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets()
                                    self.in_pkts128_to255_octets.parent = self
                                    self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"
                                    self._children_yang_names.add("in-pkts128-to255-octets")

                                    self.in_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets()
                                    self.in_pkts1519_max_octets.parent = self
                                    self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"
                                    self._children_yang_names.add("in-pkts1519-max-octets")

                                    self.in_pkts256_to511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets()
                                    self.in_pkts256_to511_octets.parent = self
                                    self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"
                                    self._children_yang_names.add("in-pkts256-to511-octets")

                                    self.in_pkts512_to1023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets()
                                    self.in_pkts512_to1023_octets.parent = self
                                    self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"
                                    self._children_yang_names.add("in-pkts512-to1023-octets")

                                    self.in_pkts65_to127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets()
                                    self.in_pkts65_to127_octets.parent = self
                                    self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"
                                    self._children_yang_names.add("in-pkts65-to127-octets")

                                    self.in_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt()
                                    self.in_ucast_pkt.parent = self
                                    self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"
                                    self._children_yang_names.add("in-ucast-pkt")

                                    self.jabber_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat()
                                    self.jabber_stat.parent = self
                                    self._children_name_map["jabber_stat"] = "jabber-stat"
                                    self._children_yang_names.add("jabber-stat")

                                    self.long_frames_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat()
                                    self.long_frames_stat.parent = self
                                    self._children_name_map["long_frames_stat"] = "long-frames-stat"
                                    self._children_yang_names.add("long-frames-stat")

                                    self.octet_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat()
                                    self.octet_stat.parent = self
                                    self._children_name_map["octet_stat"] = "octet-stat"
                                    self._children_yang_names.add("octet-stat")

                                    self.out8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021QFrames()
                                    self.out8021q_frames.parent = self
                                    self._children_name_map["out8021q_frames"] = "out8021q-frames"
                                    self._children_yang_names.add("out8021q-frames")

                                    self.out_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt()
                                    self.out_bcast_pkt.parent = self
                                    self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"
                                    self._children_yang_names.add("out-bcast-pkt")

                                    self.out_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort()
                                    self.out_drop_abort.parent = self
                                    self._children_name_map["out_drop_abort"] = "out-drop-abort"
                                    self._children_yang_names.add("out-drop-abort")

                                    self.out_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther()
                                    self.out_drop_other.parent = self
                                    self._children_name_map["out_drop_other"] = "out-drop-other"
                                    self._children_yang_names.add("out-drop-other")

                                    self.out_drop_underrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun()
                                    self.out_drop_underrun.parent = self
                                    self._children_name_map["out_drop_underrun"] = "out-drop-underrun"
                                    self._children_yang_names.add("out-drop-underrun")

                                    self.out_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther()
                                    self.out_error_other.parent = self
                                    self._children_name_map["out_error_other"] = "out-error-other"
                                    self._children_yang_names.add("out-error-other")

                                    self.out_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes()
                                    self.out_good_bytes.parent = self
                                    self._children_name_map["out_good_bytes"] = "out-good-bytes"
                                    self._children_yang_names.add("out-good-bytes")

                                    self.out_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts()
                                    self.out_good_pkts.parent = self
                                    self._children_name_map["out_good_pkts"] = "out-good-pkts"
                                    self._children_yang_names.add("out-good-pkts")

                                    self.out_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt()
                                    self.out_mcast_pkt.parent = self
                                    self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"
                                    self._children_yang_names.add("out-mcast-pkt")

                                    self.out_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets()
                                    self.out_octets.parent = self
                                    self._children_name_map["out_octets"] = "out-octets"
                                    self._children_yang_names.add("out-octets")

                                    self.out_pause_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames()
                                    self.out_pause_frames.parent = self
                                    self._children_name_map["out_pause_frames"] = "out-pause-frames"
                                    self._children_yang_names.add("out-pause-frames")

                                    self.out_pkts10241518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets()
                                    self.out_pkts10241518_octets.parent = self
                                    self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"
                                    self._children_yang_names.add("out-pkts10241518-octets")

                                    self.out_pkts128255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets()
                                    self.out_pkts128255_octets.parent = self
                                    self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"
                                    self._children_yang_names.add("out-pkts128255-octets")

                                    self.out_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets()
                                    self.out_pkts1519_max_octets.parent = self
                                    self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"
                                    self._children_yang_names.add("out-pkts1519-max-octets")

                                    self.out_pkts256511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets()
                                    self.out_pkts256511_octets.parent = self
                                    self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"
                                    self._children_yang_names.add("out-pkts256511-octets")

                                    self.out_pkts5121023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets()
                                    self.out_pkts5121023_octets.parent = self
                                    self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"
                                    self._children_yang_names.add("out-pkts5121023-octets")

                                    self.out_pkts65127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets()
                                    self.out_pkts65127_octets.parent = self
                                    self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"
                                    self._children_yang_names.add("out-pkts65127-octets")

                                    self.out_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt()
                                    self.out_ucast_pkt.parent = self
                                    self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"
                                    self._children_yang_names.add("out-ucast-pkt")

                                    self.outpkt64octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64Octet()
                                    self.outpkt64octet.parent = self
                                    self._children_name_map["outpkt64octet"] = "outpkt64octet"
                                    self._children_yang_names.add("outpkt64octet")

                                    self.oversize_pkt_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat()
                                    self.oversize_pkt_stat.parent = self
                                    self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"
                                    self._children_yang_names.add("oversize-pkt-stat")

                                    self.rx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt()
                                    self.rx_pkt.parent = self
                                    self._children_name_map["rx_pkt"] = "rx-pkt"
                                    self._children_yang_names.add("rx-pkt")

                                    self.rx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil()
                                    self.rx_util.parent = self
                                    self._children_name_map["rx_util"] = "rx-util"
                                    self._children_yang_names.add("rx-util")

                                    self.stat_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt()
                                    self.stat_pkt.parent = self
                                    self._children_name_map["stat_pkt"] = "stat-pkt"
                                    self._children_yang_names.add("stat-pkt")

                                    self.tx_bad_fcs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs()
                                    self.tx_bad_fcs.parent = self
                                    self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                    self._children_yang_names.add("tx-bad-fcs")

                                    self.tx_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments()
                                    self.tx_fragments.parent = self
                                    self._children_name_map["tx_fragments"] = "tx-fragments"
                                    self._children_yang_names.add("tx-fragments")

                                    self.tx_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber()
                                    self.tx_jabber.parent = self
                                    self._children_name_map["tx_jabber"] = "tx-jabber"
                                    self._children_yang_names.add("tx-jabber")

                                    self.tx_oversized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt()
                                    self.tx_oversized_pkt.parent = self
                                    self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"
                                    self._children_yang_names.add("tx-oversized-pkt")

                                    self.tx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt()
                                    self.tx_pkt.parent = self
                                    self._children_name_map["tx_pkt"] = "tx-pkt"
                                    self._children_yang_names.add("tx-pkt")

                                    self.tx_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt()
                                    self.tx_undersized_pkt.parent = self
                                    self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"
                                    self._children_yang_names.add("tx-undersized-pkt")

                                    self.tx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil()
                                    self.tx_util.parent = self
                                    self._children_name_map["tx_util"] = "tx-util"
                                    self._children_yang_names.add("tx-util")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether, self).__setattr__(name, value)


                                class RxPkt(Entity):
                                    """
                                    RX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt, self).__init__()

                                        self.yang_name = "rx-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class StatPkt(Entity):
                                    """
                                    STAT PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt, self).__init__()

                                        self.yang_name = "stat-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "stat-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OctetStat(Entity):
                                    """
                                    OCTET STAT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat, self).__init__()

                                        self.yang_name = "octet-stat"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "octet-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OversizePktStat(Entity):
                                    """
                                    OVERSIZE PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat, self).__init__()

                                        self.yang_name = "oversize-pkt-stat"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "oversize-pkt-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class FcsErrorsStat(Entity):
                                    """
                                    FCS ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat, self).__init__()

                                        self.yang_name = "fcs-errors-stat"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fcs-errors-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LongFramesStat(Entity):
                                    """
                                    LONG FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat, self).__init__()

                                        self.yang_name = "long-frames-stat"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "long-frames-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class JabberStat(Entity):
                                    """
                                    JABBER STATS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat, self).__init__()

                                        self.yang_name = "jabber-stat"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "jabber-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether64Octets(Entity):
                                    """
                                    SIXTY FOUR OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets, self).__init__()

                                        self.yang_name = "ether64-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether64-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether65127Octet(Entity):
                                    """
                                    OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet, self).__init__()

                                        self.yang_name = "ether65127-octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether65127-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether128255Octet(Entity):
                                    """
                                    TFF OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet, self).__init__()

                                        self.yang_name = "ether128255-octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether128255-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether256511Octet(Entity):
                                    """
                                    FOO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet, self).__init__()

                                        self.yang_name = "ether256511-octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether256511-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether5121023Octet(Entity):
                                    """
                                    OZTT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet, self).__init__()

                                        self.yang_name = "ether5121023-octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether5121023-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether10241518Octet(Entity):
                                    """
                                    OFO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet, self).__init__()

                                        self.yang_name = "ether10241518-octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether10241518-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InUcastPkt(Entity):
                                    """
                                    IN UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt, self).__init__()

                                        self.yang_name = "in-ucast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-ucast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InMcastPkt(Entity):
                                    """
                                    IN MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt, self).__init__()

                                        self.yang_name = "in-mcast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-mcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InBcastPkt(Entity):
                                    """
                                    IN BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt, self).__init__()

                                        self.yang_name = "in-bcast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-bcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutUcastPkt(Entity):
                                    """
                                    OUT UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt, self).__init__()

                                        self.yang_name = "out-ucast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-ucast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutBcastPkt(Entity):
                                    """
                                    OUT BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt, self).__init__()

                                        self.yang_name = "out-bcast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-bcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutMcastPkt(Entity):
                                    """
                                    OUT MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt, self).__init__()

                                        self.yang_name = "out-mcast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-mcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxPkt(Entity):
                                    """
                                    TX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt, self).__init__()

                                        self.yang_name = "tx-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class IfInErrors(Entity):
                                    """
                                    IFIN ERRORS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors, self).__init__()

                                        self.yang_name = "if-in-errors"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "if-in-errors" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class IfInOctets(Entity):
                                    """
                                    IFIN OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets, self).__init__()

                                        self.yang_name = "if-in-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "if-in-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class EtherStatMulticastPkt(Entity):
                                    """
                                    ETHER STAT MULTICAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt, self).__init__()

                                        self.yang_name = "ether-stat-multicast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether-stat-multicast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class EtherStatBroadcastPkt(Entity):
                                    """
                                    ETHER STAT BROADCAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt, self).__init__()

                                        self.yang_name = "ether-stat-broadcast-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether-stat-broadcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class EtherStatUndersizedPkt(Entity):
                                    """
                                    ETHER STAT UNDERSIZED PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt, self).__init__()

                                        self.yang_name = "ether-stat-undersized-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether-stat-undersized-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutOctets(Entity):
                                    """
                                    OUT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets, self).__init__()

                                        self.yang_name = "out-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPauseFrame(Entity):
                                    """
                                    INPUT PAUSE FRAME
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame, self).__init__()

                                        self.yang_name = "in-pause-frame"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pause-frame" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InGoodBytes(Entity):
                                    """
                                    INPUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes, self).__init__()

                                        self.yang_name = "in-good-bytes"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-good-bytes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class In8021QFrames(Entity):
                                    """
                                    INPUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021QFrames, self).__init__()

                                        self.yang_name = "in8021q-frames"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021QFrames, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021QFrames, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in8021q-frames" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts1519MaxOctets(Entity):
                                    """
                                    INPUT PKTS 1519MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "in-pkts1519-max-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts1519-max-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InGoodPkts(Entity):
                                    """
                                    INPUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts, self).__init__()

                                        self.yang_name = "in-good-pkts"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-good-pkts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropOverrun(Entity):
                                    """
                                    INPUT DROP OVERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun, self).__init__()

                                        self.yang_name = "in-drop-overrun"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-overrun" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropAbort(Entity):
                                    """
                                    INPUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort, self).__init__()

                                        self.yang_name = "in-drop-abort"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-abort" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropInvalidVlan(Entity):
                                    """
                                    INPUT DROP INVALID VLAN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan, self).__init__()

                                        self.yang_name = "in-drop-invalid-vlan"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-invalid-vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropInvalidDmac(Entity):
                                    """
                                    INPUT DROP INVALID DMAC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac, self).__init__()

                                        self.yang_name = "in-drop-invalid-dmac"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-invalid-dmac" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropInvalidEncap(Entity):
                                    """
                                    INPUT DROP INVALID ENCAP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap, self).__init__()

                                        self.yang_name = "in-drop-invalid-encap"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-invalid-encap" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropOther(Entity):
                                    """
                                    INPUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther, self).__init__()

                                        self.yang_name = "in-drop-other"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-other" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InMibGiant(Entity):
                                    """
                                    INPUT MIB GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant, self).__init__()

                                        self.yang_name = "in-mib-giant"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-mib-giant" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InMibJabber(Entity):
                                    """
                                    INPUT MIB JABBER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber, self).__init__()

                                        self.yang_name = "in-mib-jabber"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-mib-jabber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InMibcrc(Entity):
                                    """
                                    IN MIB CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc, self).__init__()

                                        self.yang_name = "in-mibcrc"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-mibcrc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorCollisions(Entity):
                                    """
                                    IN ERROR COLLISIONS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions, self).__init__()

                                        self.yang_name = "in-error-collisions"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-collisions" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorSymbol(Entity):
                                    """
                                    IN ERROR SYMBOL
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol, self).__init__()

                                        self.yang_name = "in-error-symbol"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-symbol" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutGoodBytes(Entity):
                                    """
                                    OUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes, self).__init__()

                                        self.yang_name = "out-good-bytes"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-good-bytes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Out8021QFrames(Entity):
                                    """
                                    OUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021QFrames, self).__init__()

                                        self.yang_name = "out8021q-frames"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021QFrames, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021QFrames, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out8021q-frames" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPauseFrames(Entity):
                                    """
                                    OUT PAUSE FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames, self).__init__()

                                        self.yang_name = "out-pause-frames"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pause-frames" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts1519MaxOctets(Entity):
                                    """
                                    OUT PKTS 1519 MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "out-pkts1519-max-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts1519-max-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutGoodPkts(Entity):
                                    """
                                    OUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts, self).__init__()

                                        self.yang_name = "out-good-pkts"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-good-pkts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutDropUnderrun(Entity):
                                    """
                                    OUT DROP UNDERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun, self).__init__()

                                        self.yang_name = "out-drop-underrun"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-drop-underrun" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutDropAbort(Entity):
                                    """
                                    OUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort, self).__init__()

                                        self.yang_name = "out-drop-abort"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-drop-abort" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutDropOther(Entity):
                                    """
                                    OUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther, self).__init__()

                                        self.yang_name = "out-drop-other"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-drop-other" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutErrorOther(Entity):
                                    """
                                    OUT ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther, self).__init__()

                                        self.yang_name = "out-error-other"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-error-other" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorGiant(Entity):
                                    """
                                    IN ERROR GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant, self).__init__()

                                        self.yang_name = "in-error-giant"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-giant" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorRunt(Entity):
                                    """
                                    IN ERROR RUNT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt, self).__init__()

                                        self.yang_name = "in-error-runt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-runt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorJabbers(Entity):
                                    """
                                    IN ERROR JABBERS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers, self).__init__()

                                        self.yang_name = "in-error-jabbers"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-jabbers" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorFragments(Entity):
                                    """
                                    IN ERROR FRAGMENTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments, self).__init__()

                                        self.yang_name = "in-error-fragments"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-fragments" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorOther(Entity):
                                    """
                                    IN ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther, self).__init__()

                                        self.yang_name = "in-error-other"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-other" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkt64Octet(Entity):
                                    """
                                    IN PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet, self).__init__()

                                        self.yang_name = "in-pkt64-octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkt64-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts65To127Octets(Entity):
                                    """
                                    IN PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets, self).__init__()

                                        self.yang_name = "in-pkts65-to127-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts65-to127-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts128To255Octets(Entity):
                                    """
                                    IN PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets, self).__init__()

                                        self.yang_name = "in-pkts128-to255-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts128-to255-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts256To511Octets(Entity):
                                    """
                                    IN PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets, self).__init__()

                                        self.yang_name = "in-pkts256-to511-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts256-to511-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts512To1023Octets(Entity):
                                    """
                                    IN PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets, self).__init__()

                                        self.yang_name = "in-pkts512-to1023-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts512-to1023-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts1024To1518Octets(Entity):
                                    """
                                    IN PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets, self).__init__()

                                        self.yang_name = "in-pkts1024-to1518-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts1024-to1518-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Outpkt64Octet(Entity):
                                    """
                                    OUT PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64Octet, self).__init__()

                                        self.yang_name = "outpkt64octet"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "outpkt64octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts65127Octets(Entity):
                                    """
                                    OUT PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets, self).__init__()

                                        self.yang_name = "out-pkts65127-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts65127-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts128255Octets(Entity):
                                    """
                                    OUT PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets, self).__init__()

                                        self.yang_name = "out-pkts128255-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts128255-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts256511Octets(Entity):
                                    """
                                    OUT PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets, self).__init__()

                                        self.yang_name = "out-pkts256511-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts256511-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts5121023Octets(Entity):
                                    """
                                    OUT PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets, self).__init__()

                                        self.yang_name = "out-pkts5121023-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts5121023-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts10241518Octets(Entity):
                                    """
                                    OUT PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets, self).__init__()

                                        self.yang_name = "out-pkts10241518-octets"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts10241518-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class RxUtil(Entity):
                                    """
                                    Rx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil, self).__init__()

                                        self.yang_name = "rx-util"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-util" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxUtil(Entity):
                                    """
                                    Tx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil, self).__init__()

                                        self.yang_name = "tx-util"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-util" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxUndersizedPkt(Entity):
                                    """
                                    TX Undersized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt, self).__init__()

                                        self.yang_name = "tx-undersized-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-undersized-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxOversizedPkt(Entity):
                                    """
                                    TX Oversized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt, self).__init__()

                                        self.yang_name = "tx-oversized-pkt"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-oversized-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxFragments(Entity):
                                    """
                                    TX Fragments
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments, self).__init__()

                                        self.yang_name = "tx-fragments"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-fragments" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxJabber(Entity):
                                    """
                                    TX Jabber
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber, self).__init__()

                                        self.yang_name = "tx-jabber"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-jabber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxBadFcs(Entity):
                                    """
                                    TX Bad Fcs
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs, self).__init__()

                                        self.yang_name = "tx-bad-fcs"
                                        self.yang_parent_name = "ethernet-hour24-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-bad-fcs" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.ether10241518_octet is not None and self.ether10241518_octet.has_data()) or
                                        (self.ether128255_octet is not None and self.ether128255_octet.has_data()) or
                                        (self.ether256511_octet is not None and self.ether256511_octet.has_data()) or
                                        (self.ether5121023_octet is not None and self.ether5121023_octet.has_data()) or
                                        (self.ether64_octets is not None and self.ether64_octets.has_data()) or
                                        (self.ether65127_octet is not None and self.ether65127_octet.has_data()) or
                                        (self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt.has_data()) or
                                        (self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt.has_data()) or
                                        (self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt.has_data()) or
                                        (self.fcs_errors_stat is not None and self.fcs_errors_stat.has_data()) or
                                        (self.if_in_errors is not None and self.if_in_errors.has_data()) or
                                        (self.if_in_octets is not None and self.if_in_octets.has_data()) or
                                        (self.in8021q_frames is not None and self.in8021q_frames.has_data()) or
                                        (self.in_bcast_pkt is not None and self.in_bcast_pkt.has_data()) or
                                        (self.in_drop_abort is not None and self.in_drop_abort.has_data()) or
                                        (self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac.has_data()) or
                                        (self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap.has_data()) or
                                        (self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan.has_data()) or
                                        (self.in_drop_other is not None and self.in_drop_other.has_data()) or
                                        (self.in_drop_overrun is not None and self.in_drop_overrun.has_data()) or
                                        (self.in_error_collisions is not None and self.in_error_collisions.has_data()) or
                                        (self.in_error_fragments is not None and self.in_error_fragments.has_data()) or
                                        (self.in_error_giant is not None and self.in_error_giant.has_data()) or
                                        (self.in_error_jabbers is not None and self.in_error_jabbers.has_data()) or
                                        (self.in_error_other is not None and self.in_error_other.has_data()) or
                                        (self.in_error_runt is not None and self.in_error_runt.has_data()) or
                                        (self.in_error_symbol is not None and self.in_error_symbol.has_data()) or
                                        (self.in_good_bytes is not None and self.in_good_bytes.has_data()) or
                                        (self.in_good_pkts is not None and self.in_good_pkts.has_data()) or
                                        (self.in_mcast_pkt is not None and self.in_mcast_pkt.has_data()) or
                                        (self.in_mib_giant is not None and self.in_mib_giant.has_data()) or
                                        (self.in_mib_jabber is not None and self.in_mib_jabber.has_data()) or
                                        (self.in_mibcrc is not None and self.in_mibcrc.has_data()) or
                                        (self.in_pause_frame is not None and self.in_pause_frame.has_data()) or
                                        (self.in_pkt64_octet is not None and self.in_pkt64_octet.has_data()) or
                                        (self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets.has_data()) or
                                        (self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets.has_data()) or
                                        (self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets.has_data()) or
                                        (self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets.has_data()) or
                                        (self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets.has_data()) or
                                        (self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets.has_data()) or
                                        (self.in_ucast_pkt is not None and self.in_ucast_pkt.has_data()) or
                                        (self.jabber_stat is not None and self.jabber_stat.has_data()) or
                                        (self.long_frames_stat is not None and self.long_frames_stat.has_data()) or
                                        (self.octet_stat is not None and self.octet_stat.has_data()) or
                                        (self.out8021q_frames is not None and self.out8021q_frames.has_data()) or
                                        (self.out_bcast_pkt is not None and self.out_bcast_pkt.has_data()) or
                                        (self.out_drop_abort is not None and self.out_drop_abort.has_data()) or
                                        (self.out_drop_other is not None and self.out_drop_other.has_data()) or
                                        (self.out_drop_underrun is not None and self.out_drop_underrun.has_data()) or
                                        (self.out_error_other is not None and self.out_error_other.has_data()) or
                                        (self.out_good_bytes is not None and self.out_good_bytes.has_data()) or
                                        (self.out_good_pkts is not None and self.out_good_pkts.has_data()) or
                                        (self.out_mcast_pkt is not None and self.out_mcast_pkt.has_data()) or
                                        (self.out_octets is not None and self.out_octets.has_data()) or
                                        (self.out_pause_frames is not None and self.out_pause_frames.has_data()) or
                                        (self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets.has_data()) or
                                        (self.out_pkts128255_octets is not None and self.out_pkts128255_octets.has_data()) or
                                        (self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets.has_data()) or
                                        (self.out_pkts256511_octets is not None and self.out_pkts256511_octets.has_data()) or
                                        (self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets.has_data()) or
                                        (self.out_pkts65127_octets is not None and self.out_pkts65127_octets.has_data()) or
                                        (self.out_ucast_pkt is not None and self.out_ucast_pkt.has_data()) or
                                        (self.outpkt64octet is not None and self.outpkt64octet.has_data()) or
                                        (self.oversize_pkt_stat is not None and self.oversize_pkt_stat.has_data()) or
                                        (self.rx_pkt is not None and self.rx_pkt.has_data()) or
                                        (self.rx_util is not None and self.rx_util.has_data()) or
                                        (self.stat_pkt is not None and self.stat_pkt.has_data()) or
                                        (self.tx_bad_fcs is not None and self.tx_bad_fcs.has_data()) or
                                        (self.tx_fragments is not None and self.tx_fragments.has_data()) or
                                        (self.tx_jabber is not None and self.tx_jabber.has_data()) or
                                        (self.tx_oversized_pkt is not None and self.tx_oversized_pkt.has_data()) or
                                        (self.tx_pkt is not None and self.tx_pkt.has_data()) or
                                        (self.tx_undersized_pkt is not None and self.tx_undersized_pkt.has_data()) or
                                        (self.tx_util is not None and self.tx_util.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.ether10241518_octet is not None and self.ether10241518_octet.has_operation()) or
                                        (self.ether128255_octet is not None and self.ether128255_octet.has_operation()) or
                                        (self.ether256511_octet is not None and self.ether256511_octet.has_operation()) or
                                        (self.ether5121023_octet is not None and self.ether5121023_octet.has_operation()) or
                                        (self.ether64_octets is not None and self.ether64_octets.has_operation()) or
                                        (self.ether65127_octet is not None and self.ether65127_octet.has_operation()) or
                                        (self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt.has_operation()) or
                                        (self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt.has_operation()) or
                                        (self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt.has_operation()) or
                                        (self.fcs_errors_stat is not None and self.fcs_errors_stat.has_operation()) or
                                        (self.if_in_errors is not None and self.if_in_errors.has_operation()) or
                                        (self.if_in_octets is not None and self.if_in_octets.has_operation()) or
                                        (self.in8021q_frames is not None and self.in8021q_frames.has_operation()) or
                                        (self.in_bcast_pkt is not None and self.in_bcast_pkt.has_operation()) or
                                        (self.in_drop_abort is not None and self.in_drop_abort.has_operation()) or
                                        (self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac.has_operation()) or
                                        (self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap.has_operation()) or
                                        (self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan.has_operation()) or
                                        (self.in_drop_other is not None and self.in_drop_other.has_operation()) or
                                        (self.in_drop_overrun is not None and self.in_drop_overrun.has_operation()) or
                                        (self.in_error_collisions is not None and self.in_error_collisions.has_operation()) or
                                        (self.in_error_fragments is not None and self.in_error_fragments.has_operation()) or
                                        (self.in_error_giant is not None and self.in_error_giant.has_operation()) or
                                        (self.in_error_jabbers is not None and self.in_error_jabbers.has_operation()) or
                                        (self.in_error_other is not None and self.in_error_other.has_operation()) or
                                        (self.in_error_runt is not None and self.in_error_runt.has_operation()) or
                                        (self.in_error_symbol is not None and self.in_error_symbol.has_operation()) or
                                        (self.in_good_bytes is not None and self.in_good_bytes.has_operation()) or
                                        (self.in_good_pkts is not None and self.in_good_pkts.has_operation()) or
                                        (self.in_mcast_pkt is not None and self.in_mcast_pkt.has_operation()) or
                                        (self.in_mib_giant is not None and self.in_mib_giant.has_operation()) or
                                        (self.in_mib_jabber is not None and self.in_mib_jabber.has_operation()) or
                                        (self.in_mibcrc is not None and self.in_mibcrc.has_operation()) or
                                        (self.in_pause_frame is not None and self.in_pause_frame.has_operation()) or
                                        (self.in_pkt64_octet is not None and self.in_pkt64_octet.has_operation()) or
                                        (self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets.has_operation()) or
                                        (self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets.has_operation()) or
                                        (self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets.has_operation()) or
                                        (self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets.has_operation()) or
                                        (self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets.has_operation()) or
                                        (self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets.has_operation()) or
                                        (self.in_ucast_pkt is not None and self.in_ucast_pkt.has_operation()) or
                                        (self.jabber_stat is not None and self.jabber_stat.has_operation()) or
                                        (self.long_frames_stat is not None and self.long_frames_stat.has_operation()) or
                                        (self.octet_stat is not None and self.octet_stat.has_operation()) or
                                        (self.out8021q_frames is not None and self.out8021q_frames.has_operation()) or
                                        (self.out_bcast_pkt is not None and self.out_bcast_pkt.has_operation()) or
                                        (self.out_drop_abort is not None and self.out_drop_abort.has_operation()) or
                                        (self.out_drop_other is not None and self.out_drop_other.has_operation()) or
                                        (self.out_drop_underrun is not None and self.out_drop_underrun.has_operation()) or
                                        (self.out_error_other is not None and self.out_error_other.has_operation()) or
                                        (self.out_good_bytes is not None and self.out_good_bytes.has_operation()) or
                                        (self.out_good_pkts is not None and self.out_good_pkts.has_operation()) or
                                        (self.out_mcast_pkt is not None and self.out_mcast_pkt.has_operation()) or
                                        (self.out_octets is not None and self.out_octets.has_operation()) or
                                        (self.out_pause_frames is not None and self.out_pause_frames.has_operation()) or
                                        (self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets.has_operation()) or
                                        (self.out_pkts128255_octets is not None and self.out_pkts128255_octets.has_operation()) or
                                        (self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets.has_operation()) or
                                        (self.out_pkts256511_octets is not None and self.out_pkts256511_octets.has_operation()) or
                                        (self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets.has_operation()) or
                                        (self.out_pkts65127_octets is not None and self.out_pkts65127_octets.has_operation()) or
                                        (self.out_ucast_pkt is not None and self.out_ucast_pkt.has_operation()) or
                                        (self.outpkt64octet is not None and self.outpkt64octet.has_operation()) or
                                        (self.oversize_pkt_stat is not None and self.oversize_pkt_stat.has_operation()) or
                                        (self.rx_pkt is not None and self.rx_pkt.has_operation()) or
                                        (self.rx_util is not None and self.rx_util.has_operation()) or
                                        (self.stat_pkt is not None and self.stat_pkt.has_operation()) or
                                        (self.tx_bad_fcs is not None and self.tx_bad_fcs.has_operation()) or
                                        (self.tx_fragments is not None and self.tx_fragments.has_operation()) or
                                        (self.tx_jabber is not None and self.tx_jabber.has_operation()) or
                                        (self.tx_oversized_pkt is not None and self.tx_oversized_pkt.has_operation()) or
                                        (self.tx_pkt is not None and self.tx_pkt.has_operation()) or
                                        (self.tx_undersized_pkt is not None and self.tx_undersized_pkt.has_operation()) or
                                        (self.tx_util is not None and self.tx_util.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet-hour24-ether" + "[number='" + self.number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ether10241518-octet"):
                                        if (self.ether10241518_octet is None):
                                            self.ether10241518_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether10241518Octet()
                                            self.ether10241518_octet.parent = self
                                            self._children_name_map["ether10241518_octet"] = "ether10241518-octet"
                                        return self.ether10241518_octet

                                    if (child_yang_name == "ether128255-octet"):
                                        if (self.ether128255_octet is None):
                                            self.ether128255_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether128255Octet()
                                            self.ether128255_octet.parent = self
                                            self._children_name_map["ether128255_octet"] = "ether128255-octet"
                                        return self.ether128255_octet

                                    if (child_yang_name == "ether256511-octet"):
                                        if (self.ether256511_octet is None):
                                            self.ether256511_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether256511Octet()
                                            self.ether256511_octet.parent = self
                                            self._children_name_map["ether256511_octet"] = "ether256511-octet"
                                        return self.ether256511_octet

                                    if (child_yang_name == "ether5121023-octet"):
                                        if (self.ether5121023_octet is None):
                                            self.ether5121023_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether5121023Octet()
                                            self.ether5121023_octet.parent = self
                                            self._children_name_map["ether5121023_octet"] = "ether5121023-octet"
                                        return self.ether5121023_octet

                                    if (child_yang_name == "ether64-octets"):
                                        if (self.ether64_octets is None):
                                            self.ether64_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether64Octets()
                                            self.ether64_octets.parent = self
                                            self._children_name_map["ether64_octets"] = "ether64-octets"
                                        return self.ether64_octets

                                    if (child_yang_name == "ether65127-octet"):
                                        if (self.ether65127_octet is None):
                                            self.ether65127_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Ether65127Octet()
                                            self.ether65127_octet.parent = self
                                            self._children_name_map["ether65127_octet"] = "ether65127-octet"
                                        return self.ether65127_octet

                                    if (child_yang_name == "ether-stat-broadcast-pkt"):
                                        if (self.ether_stat_broadcast_pkt is None):
                                            self.ether_stat_broadcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatBroadcastPkt()
                                            self.ether_stat_broadcast_pkt.parent = self
                                            self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"
                                        return self.ether_stat_broadcast_pkt

                                    if (child_yang_name == "ether-stat-multicast-pkt"):
                                        if (self.ether_stat_multicast_pkt is None):
                                            self.ether_stat_multicast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatMulticastPkt()
                                            self.ether_stat_multicast_pkt.parent = self
                                            self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"
                                        return self.ether_stat_multicast_pkt

                                    if (child_yang_name == "ether-stat-undersized-pkt"):
                                        if (self.ether_stat_undersized_pkt is None):
                                            self.ether_stat_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.EtherStatUndersizedPkt()
                                            self.ether_stat_undersized_pkt.parent = self
                                            self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"
                                        return self.ether_stat_undersized_pkt

                                    if (child_yang_name == "fcs-errors-stat"):
                                        if (self.fcs_errors_stat is None):
                                            self.fcs_errors_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.FcsErrorsStat()
                                            self.fcs_errors_stat.parent = self
                                            self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"
                                        return self.fcs_errors_stat

                                    if (child_yang_name == "if-in-errors"):
                                        if (self.if_in_errors is None):
                                            self.if_in_errors = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInErrors()
                                            self.if_in_errors.parent = self
                                            self._children_name_map["if_in_errors"] = "if-in-errors"
                                        return self.if_in_errors

                                    if (child_yang_name == "if-in-octets"):
                                        if (self.if_in_octets is None):
                                            self.if_in_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.IfInOctets()
                                            self.if_in_octets.parent = self
                                            self._children_name_map["if_in_octets"] = "if-in-octets"
                                        return self.if_in_octets

                                    if (child_yang_name == "in8021q-frames"):
                                        if (self.in8021q_frames is None):
                                            self.in8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.In8021QFrames()
                                            self.in8021q_frames.parent = self
                                            self._children_name_map["in8021q_frames"] = "in8021q-frames"
                                        return self.in8021q_frames

                                    if (child_yang_name == "in-bcast-pkt"):
                                        if (self.in_bcast_pkt is None):
                                            self.in_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InBcastPkt()
                                            self.in_bcast_pkt.parent = self
                                            self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"
                                        return self.in_bcast_pkt

                                    if (child_yang_name == "in-drop-abort"):
                                        if (self.in_drop_abort is None):
                                            self.in_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropAbort()
                                            self.in_drop_abort.parent = self
                                            self._children_name_map["in_drop_abort"] = "in-drop-abort"
                                        return self.in_drop_abort

                                    if (child_yang_name == "in-drop-invalid-dmac"):
                                        if (self.in_drop_invalid_dmac is None):
                                            self.in_drop_invalid_dmac = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidDmac()
                                            self.in_drop_invalid_dmac.parent = self
                                            self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"
                                        return self.in_drop_invalid_dmac

                                    if (child_yang_name == "in-drop-invalid-encap"):
                                        if (self.in_drop_invalid_encap is None):
                                            self.in_drop_invalid_encap = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidEncap()
                                            self.in_drop_invalid_encap.parent = self
                                            self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"
                                        return self.in_drop_invalid_encap

                                    if (child_yang_name == "in-drop-invalid-vlan"):
                                        if (self.in_drop_invalid_vlan is None):
                                            self.in_drop_invalid_vlan = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropInvalidVlan()
                                            self.in_drop_invalid_vlan.parent = self
                                            self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"
                                        return self.in_drop_invalid_vlan

                                    if (child_yang_name == "in-drop-other"):
                                        if (self.in_drop_other is None):
                                            self.in_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOther()
                                            self.in_drop_other.parent = self
                                            self._children_name_map["in_drop_other"] = "in-drop-other"
                                        return self.in_drop_other

                                    if (child_yang_name == "in-drop-overrun"):
                                        if (self.in_drop_overrun is None):
                                            self.in_drop_overrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InDropOverrun()
                                            self.in_drop_overrun.parent = self
                                            self._children_name_map["in_drop_overrun"] = "in-drop-overrun"
                                        return self.in_drop_overrun

                                    if (child_yang_name == "in-error-collisions"):
                                        if (self.in_error_collisions is None):
                                            self.in_error_collisions = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorCollisions()
                                            self.in_error_collisions.parent = self
                                            self._children_name_map["in_error_collisions"] = "in-error-collisions"
                                        return self.in_error_collisions

                                    if (child_yang_name == "in-error-fragments"):
                                        if (self.in_error_fragments is None):
                                            self.in_error_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorFragments()
                                            self.in_error_fragments.parent = self
                                            self._children_name_map["in_error_fragments"] = "in-error-fragments"
                                        return self.in_error_fragments

                                    if (child_yang_name == "in-error-giant"):
                                        if (self.in_error_giant is None):
                                            self.in_error_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorGiant()
                                            self.in_error_giant.parent = self
                                            self._children_name_map["in_error_giant"] = "in-error-giant"
                                        return self.in_error_giant

                                    if (child_yang_name == "in-error-jabbers"):
                                        if (self.in_error_jabbers is None):
                                            self.in_error_jabbers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorJabbers()
                                            self.in_error_jabbers.parent = self
                                            self._children_name_map["in_error_jabbers"] = "in-error-jabbers"
                                        return self.in_error_jabbers

                                    if (child_yang_name == "in-error-other"):
                                        if (self.in_error_other is None):
                                            self.in_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorOther()
                                            self.in_error_other.parent = self
                                            self._children_name_map["in_error_other"] = "in-error-other"
                                        return self.in_error_other

                                    if (child_yang_name == "in-error-runt"):
                                        if (self.in_error_runt is None):
                                            self.in_error_runt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorRunt()
                                            self.in_error_runt.parent = self
                                            self._children_name_map["in_error_runt"] = "in-error-runt"
                                        return self.in_error_runt

                                    if (child_yang_name == "in-error-symbol"):
                                        if (self.in_error_symbol is None):
                                            self.in_error_symbol = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InErrorSymbol()
                                            self.in_error_symbol.parent = self
                                            self._children_name_map["in_error_symbol"] = "in-error-symbol"
                                        return self.in_error_symbol

                                    if (child_yang_name == "in-good-bytes"):
                                        if (self.in_good_bytes is None):
                                            self.in_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodBytes()
                                            self.in_good_bytes.parent = self
                                            self._children_name_map["in_good_bytes"] = "in-good-bytes"
                                        return self.in_good_bytes

                                    if (child_yang_name == "in-good-pkts"):
                                        if (self.in_good_pkts is None):
                                            self.in_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InGoodPkts()
                                            self.in_good_pkts.parent = self
                                            self._children_name_map["in_good_pkts"] = "in-good-pkts"
                                        return self.in_good_pkts

                                    if (child_yang_name == "in-mcast-pkt"):
                                        if (self.in_mcast_pkt is None):
                                            self.in_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMcastPkt()
                                            self.in_mcast_pkt.parent = self
                                            self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"
                                        return self.in_mcast_pkt

                                    if (child_yang_name == "in-mib-giant"):
                                        if (self.in_mib_giant is None):
                                            self.in_mib_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibGiant()
                                            self.in_mib_giant.parent = self
                                            self._children_name_map["in_mib_giant"] = "in-mib-giant"
                                        return self.in_mib_giant

                                    if (child_yang_name == "in-mib-jabber"):
                                        if (self.in_mib_jabber is None):
                                            self.in_mib_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibJabber()
                                            self.in_mib_jabber.parent = self
                                            self._children_name_map["in_mib_jabber"] = "in-mib-jabber"
                                        return self.in_mib_jabber

                                    if (child_yang_name == "in-mibcrc"):
                                        if (self.in_mibcrc is None):
                                            self.in_mibcrc = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InMibcrc()
                                            self.in_mibcrc.parent = self
                                            self._children_name_map["in_mibcrc"] = "in-mibcrc"
                                        return self.in_mibcrc

                                    if (child_yang_name == "in-pause-frame"):
                                        if (self.in_pause_frame is None):
                                            self.in_pause_frame = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPauseFrame()
                                            self.in_pause_frame.parent = self
                                            self._children_name_map["in_pause_frame"] = "in-pause-frame"
                                        return self.in_pause_frame

                                    if (child_yang_name == "in-pkt64-octet"):
                                        if (self.in_pkt64_octet is None):
                                            self.in_pkt64_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkt64Octet()
                                            self.in_pkt64_octet.parent = self
                                            self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"
                                        return self.in_pkt64_octet

                                    if (child_yang_name == "in-pkts1024-to1518-octets"):
                                        if (self.in_pkts1024_to1518_octets is None):
                                            self.in_pkts1024_to1518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1024To1518Octets()
                                            self.in_pkts1024_to1518_octets.parent = self
                                            self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"
                                        return self.in_pkts1024_to1518_octets

                                    if (child_yang_name == "in-pkts128-to255-octets"):
                                        if (self.in_pkts128_to255_octets is None):
                                            self.in_pkts128_to255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts128To255Octets()
                                            self.in_pkts128_to255_octets.parent = self
                                            self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"
                                        return self.in_pkts128_to255_octets

                                    if (child_yang_name == "in-pkts1519-max-octets"):
                                        if (self.in_pkts1519_max_octets is None):
                                            self.in_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts1519MaxOctets()
                                            self.in_pkts1519_max_octets.parent = self
                                            self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"
                                        return self.in_pkts1519_max_octets

                                    if (child_yang_name == "in-pkts256-to511-octets"):
                                        if (self.in_pkts256_to511_octets is None):
                                            self.in_pkts256_to511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts256To511Octets()
                                            self.in_pkts256_to511_octets.parent = self
                                            self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"
                                        return self.in_pkts256_to511_octets

                                    if (child_yang_name == "in-pkts512-to1023-octets"):
                                        if (self.in_pkts512_to1023_octets is None):
                                            self.in_pkts512_to1023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts512To1023Octets()
                                            self.in_pkts512_to1023_octets.parent = self
                                            self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"
                                        return self.in_pkts512_to1023_octets

                                    if (child_yang_name == "in-pkts65-to127-octets"):
                                        if (self.in_pkts65_to127_octets is None):
                                            self.in_pkts65_to127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InPkts65To127Octets()
                                            self.in_pkts65_to127_octets.parent = self
                                            self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"
                                        return self.in_pkts65_to127_octets

                                    if (child_yang_name == "in-ucast-pkt"):
                                        if (self.in_ucast_pkt is None):
                                            self.in_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.InUcastPkt()
                                            self.in_ucast_pkt.parent = self
                                            self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"
                                        return self.in_ucast_pkt

                                    if (child_yang_name == "jabber-stat"):
                                        if (self.jabber_stat is None):
                                            self.jabber_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.JabberStat()
                                            self.jabber_stat.parent = self
                                            self._children_name_map["jabber_stat"] = "jabber-stat"
                                        return self.jabber_stat

                                    if (child_yang_name == "long-frames-stat"):
                                        if (self.long_frames_stat is None):
                                            self.long_frames_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.LongFramesStat()
                                            self.long_frames_stat.parent = self
                                            self._children_name_map["long_frames_stat"] = "long-frames-stat"
                                        return self.long_frames_stat

                                    if (child_yang_name == "octet-stat"):
                                        if (self.octet_stat is None):
                                            self.octet_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OctetStat()
                                            self.octet_stat.parent = self
                                            self._children_name_map["octet_stat"] = "octet-stat"
                                        return self.octet_stat

                                    if (child_yang_name == "out8021q-frames"):
                                        if (self.out8021q_frames is None):
                                            self.out8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Out8021QFrames()
                                            self.out8021q_frames.parent = self
                                            self._children_name_map["out8021q_frames"] = "out8021q-frames"
                                        return self.out8021q_frames

                                    if (child_yang_name == "out-bcast-pkt"):
                                        if (self.out_bcast_pkt is None):
                                            self.out_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutBcastPkt()
                                            self.out_bcast_pkt.parent = self
                                            self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"
                                        return self.out_bcast_pkt

                                    if (child_yang_name == "out-drop-abort"):
                                        if (self.out_drop_abort is None):
                                            self.out_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropAbort()
                                            self.out_drop_abort.parent = self
                                            self._children_name_map["out_drop_abort"] = "out-drop-abort"
                                        return self.out_drop_abort

                                    if (child_yang_name == "out-drop-other"):
                                        if (self.out_drop_other is None):
                                            self.out_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropOther()
                                            self.out_drop_other.parent = self
                                            self._children_name_map["out_drop_other"] = "out-drop-other"
                                        return self.out_drop_other

                                    if (child_yang_name == "out-drop-underrun"):
                                        if (self.out_drop_underrun is None):
                                            self.out_drop_underrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutDropUnderrun()
                                            self.out_drop_underrun.parent = self
                                            self._children_name_map["out_drop_underrun"] = "out-drop-underrun"
                                        return self.out_drop_underrun

                                    if (child_yang_name == "out-error-other"):
                                        if (self.out_error_other is None):
                                            self.out_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutErrorOther()
                                            self.out_error_other.parent = self
                                            self._children_name_map["out_error_other"] = "out-error-other"
                                        return self.out_error_other

                                    if (child_yang_name == "out-good-bytes"):
                                        if (self.out_good_bytes is None):
                                            self.out_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodBytes()
                                            self.out_good_bytes.parent = self
                                            self._children_name_map["out_good_bytes"] = "out-good-bytes"
                                        return self.out_good_bytes

                                    if (child_yang_name == "out-good-pkts"):
                                        if (self.out_good_pkts is None):
                                            self.out_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutGoodPkts()
                                            self.out_good_pkts.parent = self
                                            self._children_name_map["out_good_pkts"] = "out-good-pkts"
                                        return self.out_good_pkts

                                    if (child_yang_name == "out-mcast-pkt"):
                                        if (self.out_mcast_pkt is None):
                                            self.out_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutMcastPkt()
                                            self.out_mcast_pkt.parent = self
                                            self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"
                                        return self.out_mcast_pkt

                                    if (child_yang_name == "out-octets"):
                                        if (self.out_octets is None):
                                            self.out_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutOctets()
                                            self.out_octets.parent = self
                                            self._children_name_map["out_octets"] = "out-octets"
                                        return self.out_octets

                                    if (child_yang_name == "out-pause-frames"):
                                        if (self.out_pause_frames is None):
                                            self.out_pause_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPauseFrames()
                                            self.out_pause_frames.parent = self
                                            self._children_name_map["out_pause_frames"] = "out-pause-frames"
                                        return self.out_pause_frames

                                    if (child_yang_name == "out-pkts10241518-octets"):
                                        if (self.out_pkts10241518_octets is None):
                                            self.out_pkts10241518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts10241518Octets()
                                            self.out_pkts10241518_octets.parent = self
                                            self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"
                                        return self.out_pkts10241518_octets

                                    if (child_yang_name == "out-pkts128255-octets"):
                                        if (self.out_pkts128255_octets is None):
                                            self.out_pkts128255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts128255Octets()
                                            self.out_pkts128255_octets.parent = self
                                            self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"
                                        return self.out_pkts128255_octets

                                    if (child_yang_name == "out-pkts1519-max-octets"):
                                        if (self.out_pkts1519_max_octets is None):
                                            self.out_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts1519MaxOctets()
                                            self.out_pkts1519_max_octets.parent = self
                                            self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"
                                        return self.out_pkts1519_max_octets

                                    if (child_yang_name == "out-pkts256511-octets"):
                                        if (self.out_pkts256511_octets is None):
                                            self.out_pkts256511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts256511Octets()
                                            self.out_pkts256511_octets.parent = self
                                            self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"
                                        return self.out_pkts256511_octets

                                    if (child_yang_name == "out-pkts5121023-octets"):
                                        if (self.out_pkts5121023_octets is None):
                                            self.out_pkts5121023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts5121023Octets()
                                            self.out_pkts5121023_octets.parent = self
                                            self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"
                                        return self.out_pkts5121023_octets

                                    if (child_yang_name == "out-pkts65127-octets"):
                                        if (self.out_pkts65127_octets is None):
                                            self.out_pkts65127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutPkts65127Octets()
                                            self.out_pkts65127_octets.parent = self
                                            self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"
                                        return self.out_pkts65127_octets

                                    if (child_yang_name == "out-ucast-pkt"):
                                        if (self.out_ucast_pkt is None):
                                            self.out_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OutUcastPkt()
                                            self.out_ucast_pkt.parent = self
                                            self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"
                                        return self.out_ucast_pkt

                                    if (child_yang_name == "outpkt64octet"):
                                        if (self.outpkt64octet is None):
                                            self.outpkt64octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.Outpkt64Octet()
                                            self.outpkt64octet.parent = self
                                            self._children_name_map["outpkt64octet"] = "outpkt64octet"
                                        return self.outpkt64octet

                                    if (child_yang_name == "oversize-pkt-stat"):
                                        if (self.oversize_pkt_stat is None):
                                            self.oversize_pkt_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.OversizePktStat()
                                            self.oversize_pkt_stat.parent = self
                                            self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"
                                        return self.oversize_pkt_stat

                                    if (child_yang_name == "rx-pkt"):
                                        if (self.rx_pkt is None):
                                            self.rx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxPkt()
                                            self.rx_pkt.parent = self
                                            self._children_name_map["rx_pkt"] = "rx-pkt"
                                        return self.rx_pkt

                                    if (child_yang_name == "rx-util"):
                                        if (self.rx_util is None):
                                            self.rx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.RxUtil()
                                            self.rx_util.parent = self
                                            self._children_name_map["rx_util"] = "rx-util"
                                        return self.rx_util

                                    if (child_yang_name == "stat-pkt"):
                                        if (self.stat_pkt is None):
                                            self.stat_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.StatPkt()
                                            self.stat_pkt.parent = self
                                            self._children_name_map["stat_pkt"] = "stat-pkt"
                                        return self.stat_pkt

                                    if (child_yang_name == "tx-bad-fcs"):
                                        if (self.tx_bad_fcs is None):
                                            self.tx_bad_fcs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxBadFcs()
                                            self.tx_bad_fcs.parent = self
                                            self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                        return self.tx_bad_fcs

                                    if (child_yang_name == "tx-fragments"):
                                        if (self.tx_fragments is None):
                                            self.tx_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxFragments()
                                            self.tx_fragments.parent = self
                                            self._children_name_map["tx_fragments"] = "tx-fragments"
                                        return self.tx_fragments

                                    if (child_yang_name == "tx-jabber"):
                                        if (self.tx_jabber is None):
                                            self.tx_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxJabber()
                                            self.tx_jabber.parent = self
                                            self._children_name_map["tx_jabber"] = "tx-jabber"
                                        return self.tx_jabber

                                    if (child_yang_name == "tx-oversized-pkt"):
                                        if (self.tx_oversized_pkt is None):
                                            self.tx_oversized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxOversizedPkt()
                                            self.tx_oversized_pkt.parent = self
                                            self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"
                                        return self.tx_oversized_pkt

                                    if (child_yang_name == "tx-pkt"):
                                        if (self.tx_pkt is None):
                                            self.tx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxPkt()
                                            self.tx_pkt.parent = self
                                            self._children_name_map["tx_pkt"] = "tx-pkt"
                                        return self.tx_pkt

                                    if (child_yang_name == "tx-undersized-pkt"):
                                        if (self.tx_undersized_pkt is None):
                                            self.tx_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUndersizedPkt()
                                            self.tx_undersized_pkt.parent = self
                                            self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"
                                        return self.tx_undersized_pkt

                                    if (child_yang_name == "tx-util"):
                                        if (self.tx_util is None):
                                            self.tx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether.TxUtil()
                                            self.tx_util.parent = self
                                            self._children_name_map["tx_util"] = "tx-util"
                                        return self.tx_util

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ether10241518-octet" or name == "ether128255-octet" or name == "ether256511-octet" or name == "ether5121023-octet" or name == "ether64-octets" or name == "ether65127-octet" or name == "ether-stat-broadcast-pkt" or name == "ether-stat-multicast-pkt" or name == "ether-stat-undersized-pkt" or name == "fcs-errors-stat" or name == "if-in-errors" or name == "if-in-octets" or name == "in8021q-frames" or name == "in-bcast-pkt" or name == "in-drop-abort" or name == "in-drop-invalid-dmac" or name == "in-drop-invalid-encap" or name == "in-drop-invalid-vlan" or name == "in-drop-other" or name == "in-drop-overrun" or name == "in-error-collisions" or name == "in-error-fragments" or name == "in-error-giant" or name == "in-error-jabbers" or name == "in-error-other" or name == "in-error-runt" or name == "in-error-symbol" or name == "in-good-bytes" or name == "in-good-pkts" or name == "in-mcast-pkt" or name == "in-mib-giant" or name == "in-mib-jabber" or name == "in-mibcrc" or name == "in-pause-frame" or name == "in-pkt64-octet" or name == "in-pkts1024-to1518-octets" or name == "in-pkts128-to255-octets" or name == "in-pkts1519-max-octets" or name == "in-pkts256-to511-octets" or name == "in-pkts512-to1023-octets" or name == "in-pkts65-to127-octets" or name == "in-ucast-pkt" or name == "jabber-stat" or name == "long-frames-stat" or name == "octet-stat" or name == "out8021q-frames" or name == "out-bcast-pkt" or name == "out-drop-abort" or name == "out-drop-other" or name == "out-drop-underrun" or name == "out-error-other" or name == "out-good-bytes" or name == "out-good-pkts" or name == "out-mcast-pkt" or name == "out-octets" or name == "out-pause-frames" or name == "out-pkts10241518-octets" or name == "out-pkts128255-octets" or name == "out-pkts1519-max-octets" or name == "out-pkts256511-octets" or name == "out-pkts5121023-octets" or name == "out-pkts65127-octets" or name == "out-ucast-pkt" or name == "outpkt64octet" or name == "oversize-pkt-stat" or name == "rx-pkt" or name == "rx-util" or name == "stat-pkt" or name == "tx-bad-fcs" or name == "tx-fragments" or name == "tx-jabber" or name == "tx-oversized-pkt" or name == "tx-pkt" or name == "tx-undersized-pkt" or name == "tx-util" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "number"):
                                        self.number = value
                                        self.number.value_namespace = name_space
                                        self.number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.ethernet_hour24_ether:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.ethernet_hour24_ether:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ethernet-hour24-ether-s" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ethernet-hour24-ether"):
                                    for c in self.ethernet_hour24_ether:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS.EthernetHour24Ether()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.ethernet_hour24_ether.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ethernet-hour24-ether"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.ethernet_hour24_ether_s is not None and self.ethernet_hour24_ether_s.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.ethernet_hour24_ether_s is not None and self.ethernet_hour24_ether_s.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ethernet-hour24" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ethernet-hour24-ether-s"):
                                if (self.ethernet_hour24_ether_s is None):
                                    self.ethernet_hour24_ether_s = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24.EthernetHour24EtherS()
                                    self.ethernet_hour24_ether_s.parent = self
                                    self._children_name_map["ethernet_hour24_ether_s"] = "ethernet-hour24-ether-s"
                                return self.ethernet_hour24_ether_s

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ethernet-hour24-ether-s"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Minute15(Entity):
                        """
                        port current performance data
                        
                        .. attribute:: minute15_ethers
                        
                        	ETHERNET port interval performance data
                        	**type**\:   :py:class:`Minute15Ethers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15, self).__init__()

                            self.yang_name = "minute15"
                            self.yang_parent_name = "ethernet-current"

                            self.minute15_ethers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers()
                            self.minute15_ethers.parent = self
                            self._children_name_map["minute15_ethers"] = "minute15-ethers"
                            self._children_yang_names.add("minute15-ethers")


                        class Minute15Ethers(Entity):
                            """
                            ETHERNET port interval performance data
                            
                            .. attribute:: minute15_ether
                            
                            	ETHERNET port 15\-minute ether performance data
                            	**type**\: list of    :py:class:`Minute15Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers, self).__init__()

                                self.yang_name = "minute15-ethers"
                                self.yang_parent_name = "minute15"

                                self.minute15_ether = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers, self).__setattr__(name, value)


                            class Minute15Ether(Entity):
                                """
                                ETHERNET port 15\-minute ether performance
                                data
                                
                                .. attribute:: slot_number  <key>
                                
                                	interval slot number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ether10241518_octet
                                
                                	OFO OCTET
                                	**type**\:   :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet>`
                                
                                .. attribute:: ether128255_octet
                                
                                	TFF OCTET
                                	**type**\:   :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet>`
                                
                                .. attribute:: ether256511_octet
                                
                                	FOO OCTET
                                	**type**\:   :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet>`
                                
                                .. attribute:: ether5121023_octet
                                
                                	OZTT OCTET
                                	**type**\:   :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet>`
                                
                                .. attribute:: ether64_octets
                                
                                	SIXTY FOUR OCTET
                                	**type**\:   :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets>`
                                
                                .. attribute:: ether65127_octet
                                
                                	OCTET
                                	**type**\:   :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet>`
                                
                                .. attribute:: ether_stat_broadcast_pkt
                                
                                	ETHER STAT BROADCAST PKT
                                	**type**\:   :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt>`
                                
                                .. attribute:: ether_stat_multicast_pkt
                                
                                	ETHER STAT MULTICAST PKT
                                	**type**\:   :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt>`
                                
                                .. attribute:: ether_stat_undersized_pkt
                                
                                	ETHER STAT UNDERSIZED PKT
                                	**type**\:   :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt>`
                                
                                .. attribute:: fcs_errors_stat
                                
                                	FCS ERR
                                	**type**\:   :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat>`
                                
                                .. attribute:: if_in_errors
                                
                                	IFIN ERRORS
                                	**type**\:   :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors>`
                                
                                .. attribute:: if_in_octets
                                
                                	IFIN OCTETS
                                	**type**\:   :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets>`
                                
                                .. attribute:: in8021q_frames
                                
                                	INPUT 802 1Q FRAMES
                                	**type**\:   :py:class:`In8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021QFrames>`
                                
                                .. attribute:: in_bcast_pkt
                                
                                	IN BCAST
                                	**type**\:   :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt>`
                                
                                .. attribute:: in_drop_abort
                                
                                	INPUT DROP ABORT
                                	**type**\:   :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort>`
                                
                                .. attribute:: in_drop_invalid_dmac
                                
                                	INPUT DROP INVALID DMAC
                                	**type**\:   :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac>`
                                
                                .. attribute:: in_drop_invalid_encap
                                
                                	INPUT DROP INVALID ENCAP
                                	**type**\:   :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap>`
                                
                                .. attribute:: in_drop_invalid_vlan
                                
                                	INPUT DROP INVALID VLAN
                                	**type**\:   :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan>`
                                
                                .. attribute:: in_drop_other
                                
                                	INPUT DROP OTHER
                                	**type**\:   :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther>`
                                
                                .. attribute:: in_drop_overrun
                                
                                	INPUT DROP OVERRUN
                                	**type**\:   :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun>`
                                
                                .. attribute:: in_error_collisions
                                
                                	IN ERROR COLLISIONS
                                	**type**\:   :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions>`
                                
                                .. attribute:: in_error_fragments
                                
                                	IN ERROR FRAGMENTS
                                	**type**\:   :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments>`
                                
                                .. attribute:: in_error_giant
                                
                                	IN ERROR GIANT
                                	**type**\:   :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant>`
                                
                                .. attribute:: in_error_jabbers
                                
                                	IN ERROR JABBERS
                                	**type**\:   :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers>`
                                
                                .. attribute:: in_error_other
                                
                                	IN ERROR OTHER
                                	**type**\:   :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther>`
                                
                                .. attribute:: in_error_runt
                                
                                	IN ERROR RUNT
                                	**type**\:   :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt>`
                                
                                .. attribute:: in_error_symbol
                                
                                	IN ERROR SYMBOL
                                	**type**\:   :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol>`
                                
                                .. attribute:: in_good_bytes
                                
                                	INPUT GOOD BYTES
                                	**type**\:   :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes>`
                                
                                .. attribute:: in_good_pkts
                                
                                	INPUT GOOD PKTS
                                	**type**\:   :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts>`
                                
                                .. attribute:: in_mcast_pkt
                                
                                	IN MCAST
                                	**type**\:   :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt>`
                                
                                .. attribute:: in_mib_giant
                                
                                	INPUT MIB GIANT
                                	**type**\:   :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant>`
                                
                                .. attribute:: in_mib_jabber
                                
                                	INPUT MIB JABBER
                                	**type**\:   :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber>`
                                
                                .. attribute:: in_mibcrc
                                
                                	IN MIB CRC
                                	**type**\:   :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc>`
                                
                                .. attribute:: in_pause_frame
                                
                                	INPUT PAUSE FRAME
                                	**type**\:   :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame>`
                                
                                .. attribute:: in_pkt64_octet
                                
                                	IN PKT 64 OCTET
                                	**type**\:   :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet>`
                                
                                .. attribute:: in_pkts1024_to1518_octets
                                
                                	IN PKTS 1024 1518 OCTETS
                                	**type**\:   :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets>`
                                
                                .. attribute:: in_pkts128_to255_octets
                                
                                	IN PKTS 128 255 OCTETS
                                	**type**\:   :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets>`
                                
                                .. attribute:: in_pkts1519_max_octets
                                
                                	INPUT PKTS 1519MAX OCTETS
                                	**type**\:   :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets>`
                                
                                .. attribute:: in_pkts256_to511_octets
                                
                                	IN PKTS 256 511 OCTETS
                                	**type**\:   :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets>`
                                
                                .. attribute:: in_pkts512_to1023_octets
                                
                                	IN PKTS 512 1023 OCTETS
                                	**type**\:   :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets>`
                                
                                .. attribute:: in_pkts65_to127_octets
                                
                                	IN PKTS 65 127OCTETS
                                	**type**\:   :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets>`
                                
                                .. attribute:: in_ucast_pkt
                                
                                	IN UCAST
                                	**type**\:   :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt>`
                                
                                .. attribute:: index
                                
                                	index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: jabber_stat
                                
                                	JABBER STATS
                                	**type**\:   :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat>`
                                
                                .. attribute:: last_clear15_min_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear24_hr_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear30_sec_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: last_clear_time
                                
                                	last clear time
                                	**type**\:  str
                                
                                .. attribute:: long_frames_stat
                                
                                	LONG FRAMES
                                	**type**\:   :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat>`
                                
                                .. attribute:: octet_stat
                                
                                	OCTET STAT
                                	**type**\:   :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat>`
                                
                                .. attribute:: out8021q_frames
                                
                                	OUT 802 1Q FRAMES
                                	**type**\:   :py:class:`Out8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021QFrames>`
                                
                                .. attribute:: out_bcast_pkt
                                
                                	OUT BCAST
                                	**type**\:   :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt>`
                                
                                .. attribute:: out_drop_abort
                                
                                	OUT DROP ABORT
                                	**type**\:   :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort>`
                                
                                .. attribute:: out_drop_other
                                
                                	OUT DROP OTHER
                                	**type**\:   :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther>`
                                
                                .. attribute:: out_drop_underrun
                                
                                	OUT DROP UNDERRUN
                                	**type**\:   :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun>`
                                
                                .. attribute:: out_error_other
                                
                                	OUT ERROR OTHER
                                	**type**\:   :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther>`
                                
                                .. attribute:: out_good_bytes
                                
                                	OUT GOOD BYTES
                                	**type**\:   :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes>`
                                
                                .. attribute:: out_good_pkts
                                
                                	OUT GOOD PKTS
                                	**type**\:   :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts>`
                                
                                .. attribute:: out_mcast_pkt
                                
                                	OUT MCAST
                                	**type**\:   :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt>`
                                
                                .. attribute:: out_octets
                                
                                	OUT OCTET
                                	**type**\:   :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets>`
                                
                                .. attribute:: out_pause_frames
                                
                                	OUT PAUSE FRAMES
                                	**type**\:   :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames>`
                                
                                .. attribute:: out_pkts10241518_octets
                                
                                	OUT PKTS 1024 1518 OCTETS
                                	**type**\:   :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets>`
                                
                                .. attribute:: out_pkts128255_octets
                                
                                	OUT PKTS 128 255 OCTETS
                                	**type**\:   :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets>`
                                
                                .. attribute:: out_pkts1519_max_octets
                                
                                	OUT PKTS 1519 MAX OCTETS
                                	**type**\:   :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets>`
                                
                                .. attribute:: out_pkts256511_octets
                                
                                	OUT PKTS 256 511 OCTETS
                                	**type**\:   :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets>`
                                
                                .. attribute:: out_pkts5121023_octets
                                
                                	OUT PKTS 512 1023 OCTETS
                                	**type**\:   :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets>`
                                
                                .. attribute:: out_pkts65127_octets
                                
                                	OUT PKTS 65 127OCTETS
                                	**type**\:   :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets>`
                                
                                .. attribute:: out_ucast_pkt
                                
                                	OUT UCAST
                                	**type**\:   :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt>`
                                
                                .. attribute:: outpkt64octet
                                
                                	OUT PKT 64 OCTET
                                	**type**\:   :py:class:`Outpkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64Octet>`
                                
                                .. attribute:: oversize_pkt_stat
                                
                                	OVERSIZE PKT
                                	**type**\:   :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat>`
                                
                                .. attribute:: rx_pkt
                                
                                	RX PKT
                                	**type**\:   :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt>`
                                
                                .. attribute:: rx_util
                                
                                	Rx Utilization in Percent
                                	**type**\:   :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil>`
                                
                                .. attribute:: sec30_support
                                
                                	30 sec support
                                	**type**\:  bool
                                
                                .. attribute:: stat_pkt
                                
                                	STAT PKT
                                	**type**\:   :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt>`
                                
                                .. attribute:: timestamp
                                
                                	timestamp
                                	**type**\:  str
                                
                                	**length:** 0..64
                                
                                .. attribute:: tx_bad_fcs
                                
                                	TX Bad Fcs
                                	**type**\:   :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs>`
                                
                                .. attribute:: tx_fragments
                                
                                	TX Fragments
                                	**type**\:   :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments>`
                                
                                .. attribute:: tx_jabber
                                
                                	TX Jabber
                                	**type**\:   :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber>`
                                
                                .. attribute:: tx_oversized_pkt
                                
                                	TX Oversized Pkt
                                	**type**\:   :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt>`
                                
                                .. attribute:: tx_pkt
                                
                                	TX PKT
                                	**type**\:   :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt>`
                                
                                .. attribute:: tx_undersized_pkt
                                
                                	TX Undersized Pkt
                                	**type**\:   :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt>`
                                
                                .. attribute:: tx_util
                                
                                	Tx Utilization in Percent
                                	**type**\:   :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil>`
                                
                                .. attribute:: valid
                                
                                	valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether, self).__init__()

                                    self.yang_name = "minute15-ether"
                                    self.yang_parent_name = "minute15-ethers"

                                    self.slot_number = YLeaf(YType.int32, "slot-number")

                                    self.index = YLeaf(YType.uint32, "index")

                                    self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                    self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                    self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                    self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                    self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                    self.timestamp = YLeaf(YType.str, "timestamp")

                                    self.valid = YLeaf(YType.boolean, "valid")

                                    self.ether10241518_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet()
                                    self.ether10241518_octet.parent = self
                                    self._children_name_map["ether10241518_octet"] = "ether10241518-octet"
                                    self._children_yang_names.add("ether10241518-octet")

                                    self.ether128255_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet()
                                    self.ether128255_octet.parent = self
                                    self._children_name_map["ether128255_octet"] = "ether128255-octet"
                                    self._children_yang_names.add("ether128255-octet")

                                    self.ether256511_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet()
                                    self.ether256511_octet.parent = self
                                    self._children_name_map["ether256511_octet"] = "ether256511-octet"
                                    self._children_yang_names.add("ether256511-octet")

                                    self.ether5121023_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet()
                                    self.ether5121023_octet.parent = self
                                    self._children_name_map["ether5121023_octet"] = "ether5121023-octet"
                                    self._children_yang_names.add("ether5121023-octet")

                                    self.ether64_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets()
                                    self.ether64_octets.parent = self
                                    self._children_name_map["ether64_octets"] = "ether64-octets"
                                    self._children_yang_names.add("ether64-octets")

                                    self.ether65127_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet()
                                    self.ether65127_octet.parent = self
                                    self._children_name_map["ether65127_octet"] = "ether65127-octet"
                                    self._children_yang_names.add("ether65127-octet")

                                    self.ether_stat_broadcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt()
                                    self.ether_stat_broadcast_pkt.parent = self
                                    self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"
                                    self._children_yang_names.add("ether-stat-broadcast-pkt")

                                    self.ether_stat_multicast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt()
                                    self.ether_stat_multicast_pkt.parent = self
                                    self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"
                                    self._children_yang_names.add("ether-stat-multicast-pkt")

                                    self.ether_stat_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt()
                                    self.ether_stat_undersized_pkt.parent = self
                                    self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"
                                    self._children_yang_names.add("ether-stat-undersized-pkt")

                                    self.fcs_errors_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat()
                                    self.fcs_errors_stat.parent = self
                                    self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"
                                    self._children_yang_names.add("fcs-errors-stat")

                                    self.if_in_errors = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors()
                                    self.if_in_errors.parent = self
                                    self._children_name_map["if_in_errors"] = "if-in-errors"
                                    self._children_yang_names.add("if-in-errors")

                                    self.if_in_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets()
                                    self.if_in_octets.parent = self
                                    self._children_name_map["if_in_octets"] = "if-in-octets"
                                    self._children_yang_names.add("if-in-octets")

                                    self.in8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021QFrames()
                                    self.in8021q_frames.parent = self
                                    self._children_name_map["in8021q_frames"] = "in8021q-frames"
                                    self._children_yang_names.add("in8021q-frames")

                                    self.in_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt()
                                    self.in_bcast_pkt.parent = self
                                    self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"
                                    self._children_yang_names.add("in-bcast-pkt")

                                    self.in_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort()
                                    self.in_drop_abort.parent = self
                                    self._children_name_map["in_drop_abort"] = "in-drop-abort"
                                    self._children_yang_names.add("in-drop-abort")

                                    self.in_drop_invalid_dmac = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac()
                                    self.in_drop_invalid_dmac.parent = self
                                    self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"
                                    self._children_yang_names.add("in-drop-invalid-dmac")

                                    self.in_drop_invalid_encap = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap()
                                    self.in_drop_invalid_encap.parent = self
                                    self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"
                                    self._children_yang_names.add("in-drop-invalid-encap")

                                    self.in_drop_invalid_vlan = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan()
                                    self.in_drop_invalid_vlan.parent = self
                                    self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"
                                    self._children_yang_names.add("in-drop-invalid-vlan")

                                    self.in_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther()
                                    self.in_drop_other.parent = self
                                    self._children_name_map["in_drop_other"] = "in-drop-other"
                                    self._children_yang_names.add("in-drop-other")

                                    self.in_drop_overrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun()
                                    self.in_drop_overrun.parent = self
                                    self._children_name_map["in_drop_overrun"] = "in-drop-overrun"
                                    self._children_yang_names.add("in-drop-overrun")

                                    self.in_error_collisions = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions()
                                    self.in_error_collisions.parent = self
                                    self._children_name_map["in_error_collisions"] = "in-error-collisions"
                                    self._children_yang_names.add("in-error-collisions")

                                    self.in_error_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments()
                                    self.in_error_fragments.parent = self
                                    self._children_name_map["in_error_fragments"] = "in-error-fragments"
                                    self._children_yang_names.add("in-error-fragments")

                                    self.in_error_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant()
                                    self.in_error_giant.parent = self
                                    self._children_name_map["in_error_giant"] = "in-error-giant"
                                    self._children_yang_names.add("in-error-giant")

                                    self.in_error_jabbers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers()
                                    self.in_error_jabbers.parent = self
                                    self._children_name_map["in_error_jabbers"] = "in-error-jabbers"
                                    self._children_yang_names.add("in-error-jabbers")

                                    self.in_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther()
                                    self.in_error_other.parent = self
                                    self._children_name_map["in_error_other"] = "in-error-other"
                                    self._children_yang_names.add("in-error-other")

                                    self.in_error_runt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt()
                                    self.in_error_runt.parent = self
                                    self._children_name_map["in_error_runt"] = "in-error-runt"
                                    self._children_yang_names.add("in-error-runt")

                                    self.in_error_symbol = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol()
                                    self.in_error_symbol.parent = self
                                    self._children_name_map["in_error_symbol"] = "in-error-symbol"
                                    self._children_yang_names.add("in-error-symbol")

                                    self.in_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes()
                                    self.in_good_bytes.parent = self
                                    self._children_name_map["in_good_bytes"] = "in-good-bytes"
                                    self._children_yang_names.add("in-good-bytes")

                                    self.in_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts()
                                    self.in_good_pkts.parent = self
                                    self._children_name_map["in_good_pkts"] = "in-good-pkts"
                                    self._children_yang_names.add("in-good-pkts")

                                    self.in_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt()
                                    self.in_mcast_pkt.parent = self
                                    self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"
                                    self._children_yang_names.add("in-mcast-pkt")

                                    self.in_mib_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant()
                                    self.in_mib_giant.parent = self
                                    self._children_name_map["in_mib_giant"] = "in-mib-giant"
                                    self._children_yang_names.add("in-mib-giant")

                                    self.in_mib_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber()
                                    self.in_mib_jabber.parent = self
                                    self._children_name_map["in_mib_jabber"] = "in-mib-jabber"
                                    self._children_yang_names.add("in-mib-jabber")

                                    self.in_mibcrc = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc()
                                    self.in_mibcrc.parent = self
                                    self._children_name_map["in_mibcrc"] = "in-mibcrc"
                                    self._children_yang_names.add("in-mibcrc")

                                    self.in_pause_frame = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame()
                                    self.in_pause_frame.parent = self
                                    self._children_name_map["in_pause_frame"] = "in-pause-frame"
                                    self._children_yang_names.add("in-pause-frame")

                                    self.in_pkt64_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet()
                                    self.in_pkt64_octet.parent = self
                                    self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"
                                    self._children_yang_names.add("in-pkt64-octet")

                                    self.in_pkts1024_to1518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets()
                                    self.in_pkts1024_to1518_octets.parent = self
                                    self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"
                                    self._children_yang_names.add("in-pkts1024-to1518-octets")

                                    self.in_pkts128_to255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets()
                                    self.in_pkts128_to255_octets.parent = self
                                    self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"
                                    self._children_yang_names.add("in-pkts128-to255-octets")

                                    self.in_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets()
                                    self.in_pkts1519_max_octets.parent = self
                                    self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"
                                    self._children_yang_names.add("in-pkts1519-max-octets")

                                    self.in_pkts256_to511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets()
                                    self.in_pkts256_to511_octets.parent = self
                                    self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"
                                    self._children_yang_names.add("in-pkts256-to511-octets")

                                    self.in_pkts512_to1023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets()
                                    self.in_pkts512_to1023_octets.parent = self
                                    self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"
                                    self._children_yang_names.add("in-pkts512-to1023-octets")

                                    self.in_pkts65_to127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets()
                                    self.in_pkts65_to127_octets.parent = self
                                    self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"
                                    self._children_yang_names.add("in-pkts65-to127-octets")

                                    self.in_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt()
                                    self.in_ucast_pkt.parent = self
                                    self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"
                                    self._children_yang_names.add("in-ucast-pkt")

                                    self.jabber_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat()
                                    self.jabber_stat.parent = self
                                    self._children_name_map["jabber_stat"] = "jabber-stat"
                                    self._children_yang_names.add("jabber-stat")

                                    self.long_frames_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat()
                                    self.long_frames_stat.parent = self
                                    self._children_name_map["long_frames_stat"] = "long-frames-stat"
                                    self._children_yang_names.add("long-frames-stat")

                                    self.octet_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat()
                                    self.octet_stat.parent = self
                                    self._children_name_map["octet_stat"] = "octet-stat"
                                    self._children_yang_names.add("octet-stat")

                                    self.out8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021QFrames()
                                    self.out8021q_frames.parent = self
                                    self._children_name_map["out8021q_frames"] = "out8021q-frames"
                                    self._children_yang_names.add("out8021q-frames")

                                    self.out_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt()
                                    self.out_bcast_pkt.parent = self
                                    self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"
                                    self._children_yang_names.add("out-bcast-pkt")

                                    self.out_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort()
                                    self.out_drop_abort.parent = self
                                    self._children_name_map["out_drop_abort"] = "out-drop-abort"
                                    self._children_yang_names.add("out-drop-abort")

                                    self.out_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther()
                                    self.out_drop_other.parent = self
                                    self._children_name_map["out_drop_other"] = "out-drop-other"
                                    self._children_yang_names.add("out-drop-other")

                                    self.out_drop_underrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun()
                                    self.out_drop_underrun.parent = self
                                    self._children_name_map["out_drop_underrun"] = "out-drop-underrun"
                                    self._children_yang_names.add("out-drop-underrun")

                                    self.out_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther()
                                    self.out_error_other.parent = self
                                    self._children_name_map["out_error_other"] = "out-error-other"
                                    self._children_yang_names.add("out-error-other")

                                    self.out_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes()
                                    self.out_good_bytes.parent = self
                                    self._children_name_map["out_good_bytes"] = "out-good-bytes"
                                    self._children_yang_names.add("out-good-bytes")

                                    self.out_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts()
                                    self.out_good_pkts.parent = self
                                    self._children_name_map["out_good_pkts"] = "out-good-pkts"
                                    self._children_yang_names.add("out-good-pkts")

                                    self.out_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt()
                                    self.out_mcast_pkt.parent = self
                                    self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"
                                    self._children_yang_names.add("out-mcast-pkt")

                                    self.out_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets()
                                    self.out_octets.parent = self
                                    self._children_name_map["out_octets"] = "out-octets"
                                    self._children_yang_names.add("out-octets")

                                    self.out_pause_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames()
                                    self.out_pause_frames.parent = self
                                    self._children_name_map["out_pause_frames"] = "out-pause-frames"
                                    self._children_yang_names.add("out-pause-frames")

                                    self.out_pkts10241518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets()
                                    self.out_pkts10241518_octets.parent = self
                                    self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"
                                    self._children_yang_names.add("out-pkts10241518-octets")

                                    self.out_pkts128255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets()
                                    self.out_pkts128255_octets.parent = self
                                    self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"
                                    self._children_yang_names.add("out-pkts128255-octets")

                                    self.out_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets()
                                    self.out_pkts1519_max_octets.parent = self
                                    self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"
                                    self._children_yang_names.add("out-pkts1519-max-octets")

                                    self.out_pkts256511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets()
                                    self.out_pkts256511_octets.parent = self
                                    self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"
                                    self._children_yang_names.add("out-pkts256511-octets")

                                    self.out_pkts5121023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets()
                                    self.out_pkts5121023_octets.parent = self
                                    self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"
                                    self._children_yang_names.add("out-pkts5121023-octets")

                                    self.out_pkts65127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets()
                                    self.out_pkts65127_octets.parent = self
                                    self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"
                                    self._children_yang_names.add("out-pkts65127-octets")

                                    self.out_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt()
                                    self.out_ucast_pkt.parent = self
                                    self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"
                                    self._children_yang_names.add("out-ucast-pkt")

                                    self.outpkt64octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64Octet()
                                    self.outpkt64octet.parent = self
                                    self._children_name_map["outpkt64octet"] = "outpkt64octet"
                                    self._children_yang_names.add("outpkt64octet")

                                    self.oversize_pkt_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat()
                                    self.oversize_pkt_stat.parent = self
                                    self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"
                                    self._children_yang_names.add("oversize-pkt-stat")

                                    self.rx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt()
                                    self.rx_pkt.parent = self
                                    self._children_name_map["rx_pkt"] = "rx-pkt"
                                    self._children_yang_names.add("rx-pkt")

                                    self.rx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil()
                                    self.rx_util.parent = self
                                    self._children_name_map["rx_util"] = "rx-util"
                                    self._children_yang_names.add("rx-util")

                                    self.stat_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt()
                                    self.stat_pkt.parent = self
                                    self._children_name_map["stat_pkt"] = "stat-pkt"
                                    self._children_yang_names.add("stat-pkt")

                                    self.tx_bad_fcs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs()
                                    self.tx_bad_fcs.parent = self
                                    self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                    self._children_yang_names.add("tx-bad-fcs")

                                    self.tx_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments()
                                    self.tx_fragments.parent = self
                                    self._children_name_map["tx_fragments"] = "tx-fragments"
                                    self._children_yang_names.add("tx-fragments")

                                    self.tx_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber()
                                    self.tx_jabber.parent = self
                                    self._children_name_map["tx_jabber"] = "tx-jabber"
                                    self._children_yang_names.add("tx-jabber")

                                    self.tx_oversized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt()
                                    self.tx_oversized_pkt.parent = self
                                    self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"
                                    self._children_yang_names.add("tx-oversized-pkt")

                                    self.tx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt()
                                    self.tx_pkt.parent = self
                                    self._children_name_map["tx_pkt"] = "tx-pkt"
                                    self._children_yang_names.add("tx-pkt")

                                    self.tx_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt()
                                    self.tx_undersized_pkt.parent = self
                                    self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"
                                    self._children_yang_names.add("tx-undersized-pkt")

                                    self.tx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil()
                                    self.tx_util.parent = self
                                    self._children_name_map["tx_util"] = "tx-util"
                                    self._children_yang_names.add("tx-util")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("slot_number",
                                                    "index",
                                                    "last_clear15_min_time",
                                                    "last_clear24_hr_time",
                                                    "last_clear30_sec_time",
                                                    "last_clear_time",
                                                    "sec30_support",
                                                    "timestamp",
                                                    "valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether, self).__setattr__(name, value)


                                class RxPkt(Entity):
                                    """
                                    RX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt, self).__init__()

                                        self.yang_name = "rx-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class StatPkt(Entity):
                                    """
                                    STAT PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt, self).__init__()

                                        self.yang_name = "stat-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "stat-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OctetStat(Entity):
                                    """
                                    OCTET STAT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat, self).__init__()

                                        self.yang_name = "octet-stat"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "octet-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OversizePktStat(Entity):
                                    """
                                    OVERSIZE PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat, self).__init__()

                                        self.yang_name = "oversize-pkt-stat"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "oversize-pkt-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class FcsErrorsStat(Entity):
                                    """
                                    FCS ERR
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat, self).__init__()

                                        self.yang_name = "fcs-errors-stat"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fcs-errors-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class LongFramesStat(Entity):
                                    """
                                    LONG FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat, self).__init__()

                                        self.yang_name = "long-frames-stat"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "long-frames-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class JabberStat(Entity):
                                    """
                                    JABBER STATS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat, self).__init__()

                                        self.yang_name = "jabber-stat"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "jabber-stat" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether64Octets(Entity):
                                    """
                                    SIXTY FOUR OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets, self).__init__()

                                        self.yang_name = "ether64-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether64-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether65127Octet(Entity):
                                    """
                                    OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet, self).__init__()

                                        self.yang_name = "ether65127-octet"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether65127-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether128255Octet(Entity):
                                    """
                                    TFF OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet, self).__init__()

                                        self.yang_name = "ether128255-octet"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether128255-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether256511Octet(Entity):
                                    """
                                    FOO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet, self).__init__()

                                        self.yang_name = "ether256511-octet"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether256511-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether5121023Octet(Entity):
                                    """
                                    OZTT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet, self).__init__()

                                        self.yang_name = "ether5121023-octet"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether5121023-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Ether10241518Octet(Entity):
                                    """
                                    OFO OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet, self).__init__()

                                        self.yang_name = "ether10241518-octet"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether10241518-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InUcastPkt(Entity):
                                    """
                                    IN UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt, self).__init__()

                                        self.yang_name = "in-ucast-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-ucast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InMcastPkt(Entity):
                                    """
                                    IN MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt, self).__init__()

                                        self.yang_name = "in-mcast-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-mcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InBcastPkt(Entity):
                                    """
                                    IN BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt, self).__init__()

                                        self.yang_name = "in-bcast-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-bcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutUcastPkt(Entity):
                                    """
                                    OUT UCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt, self).__init__()

                                        self.yang_name = "out-ucast-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-ucast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutBcastPkt(Entity):
                                    """
                                    OUT BCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt, self).__init__()

                                        self.yang_name = "out-bcast-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-bcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutMcastPkt(Entity):
                                    """
                                    OUT MCAST
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt, self).__init__()

                                        self.yang_name = "out-mcast-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-mcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxPkt(Entity):
                                    """
                                    TX PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt, self).__init__()

                                        self.yang_name = "tx-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class IfInErrors(Entity):
                                    """
                                    IFIN ERRORS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors, self).__init__()

                                        self.yang_name = "if-in-errors"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "if-in-errors" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class IfInOctets(Entity):
                                    """
                                    IFIN OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets, self).__init__()

                                        self.yang_name = "if-in-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "if-in-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class EtherStatMulticastPkt(Entity):
                                    """
                                    ETHER STAT MULTICAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt, self).__init__()

                                        self.yang_name = "ether-stat-multicast-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether-stat-multicast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class EtherStatBroadcastPkt(Entity):
                                    """
                                    ETHER STAT BROADCAST PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt, self).__init__()

                                        self.yang_name = "ether-stat-broadcast-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether-stat-broadcast-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class EtherStatUndersizedPkt(Entity):
                                    """
                                    ETHER STAT UNDERSIZED PKT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt, self).__init__()

                                        self.yang_name = "ether-stat-undersized-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ether-stat-undersized-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutOctets(Entity):
                                    """
                                    OUT OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets, self).__init__()

                                        self.yang_name = "out-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPauseFrame(Entity):
                                    """
                                    INPUT PAUSE FRAME
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame, self).__init__()

                                        self.yang_name = "in-pause-frame"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pause-frame" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InGoodBytes(Entity):
                                    """
                                    INPUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes, self).__init__()

                                        self.yang_name = "in-good-bytes"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-good-bytes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class In8021QFrames(Entity):
                                    """
                                    INPUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021QFrames, self).__init__()

                                        self.yang_name = "in8021q-frames"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021QFrames, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021QFrames, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in8021q-frames" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts1519MaxOctets(Entity):
                                    """
                                    INPUT PKTS 1519MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "in-pkts1519-max-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts1519-max-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InGoodPkts(Entity):
                                    """
                                    INPUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts, self).__init__()

                                        self.yang_name = "in-good-pkts"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-good-pkts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropOverrun(Entity):
                                    """
                                    INPUT DROP OVERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun, self).__init__()

                                        self.yang_name = "in-drop-overrun"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-overrun" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropAbort(Entity):
                                    """
                                    INPUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort, self).__init__()

                                        self.yang_name = "in-drop-abort"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-abort" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropInvalidVlan(Entity):
                                    """
                                    INPUT DROP INVALID VLAN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan, self).__init__()

                                        self.yang_name = "in-drop-invalid-vlan"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-invalid-vlan" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropInvalidDmac(Entity):
                                    """
                                    INPUT DROP INVALID DMAC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac, self).__init__()

                                        self.yang_name = "in-drop-invalid-dmac"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-invalid-dmac" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropInvalidEncap(Entity):
                                    """
                                    INPUT DROP INVALID ENCAP
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap, self).__init__()

                                        self.yang_name = "in-drop-invalid-encap"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-invalid-encap" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InDropOther(Entity):
                                    """
                                    INPUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther, self).__init__()

                                        self.yang_name = "in-drop-other"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-drop-other" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InMibGiant(Entity):
                                    """
                                    INPUT MIB GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant, self).__init__()

                                        self.yang_name = "in-mib-giant"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-mib-giant" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InMibJabber(Entity):
                                    """
                                    INPUT MIB JABBER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber, self).__init__()

                                        self.yang_name = "in-mib-jabber"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-mib-jabber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InMibcrc(Entity):
                                    """
                                    IN MIB CRC
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc, self).__init__()

                                        self.yang_name = "in-mibcrc"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-mibcrc" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorCollisions(Entity):
                                    """
                                    IN ERROR COLLISIONS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions, self).__init__()

                                        self.yang_name = "in-error-collisions"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-collisions" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorSymbol(Entity):
                                    """
                                    IN ERROR SYMBOL
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol, self).__init__()

                                        self.yang_name = "in-error-symbol"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-symbol" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutGoodBytes(Entity):
                                    """
                                    OUT GOOD BYTES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes, self).__init__()

                                        self.yang_name = "out-good-bytes"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-good-bytes" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Out8021QFrames(Entity):
                                    """
                                    OUT 802 1Q FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021QFrames, self).__init__()

                                        self.yang_name = "out8021q-frames"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021QFrames, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021QFrames, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out8021q-frames" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPauseFrames(Entity):
                                    """
                                    OUT PAUSE FRAMES
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames, self).__init__()

                                        self.yang_name = "out-pause-frames"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pause-frames" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts1519MaxOctets(Entity):
                                    """
                                    OUT PKTS 1519 MAX OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets, self).__init__()

                                        self.yang_name = "out-pkts1519-max-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts1519-max-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutGoodPkts(Entity):
                                    """
                                    OUT GOOD PKTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts, self).__init__()

                                        self.yang_name = "out-good-pkts"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-good-pkts" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutDropUnderrun(Entity):
                                    """
                                    OUT DROP UNDERRUN
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun, self).__init__()

                                        self.yang_name = "out-drop-underrun"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-drop-underrun" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutDropAbort(Entity):
                                    """
                                    OUT DROP ABORT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort, self).__init__()

                                        self.yang_name = "out-drop-abort"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-drop-abort" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutDropOther(Entity):
                                    """
                                    OUT DROP OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther, self).__init__()

                                        self.yang_name = "out-drop-other"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-drop-other" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutErrorOther(Entity):
                                    """
                                    OUT ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther, self).__init__()

                                        self.yang_name = "out-error-other"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-error-other" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorGiant(Entity):
                                    """
                                    IN ERROR GIANT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant, self).__init__()

                                        self.yang_name = "in-error-giant"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-giant" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorRunt(Entity):
                                    """
                                    IN ERROR RUNT
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt, self).__init__()

                                        self.yang_name = "in-error-runt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-runt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorJabbers(Entity):
                                    """
                                    IN ERROR JABBERS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers, self).__init__()

                                        self.yang_name = "in-error-jabbers"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-jabbers" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorFragments(Entity):
                                    """
                                    IN ERROR FRAGMENTS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments, self).__init__()

                                        self.yang_name = "in-error-fragments"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-fragments" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InErrorOther(Entity):
                                    """
                                    IN ERROR OTHER
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther, self).__init__()

                                        self.yang_name = "in-error-other"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-error-other" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkt64Octet(Entity):
                                    """
                                    IN PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet, self).__init__()

                                        self.yang_name = "in-pkt64-octet"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkt64-octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts65To127Octets(Entity):
                                    """
                                    IN PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets, self).__init__()

                                        self.yang_name = "in-pkts65-to127-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts65-to127-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts128To255Octets(Entity):
                                    """
                                    IN PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets, self).__init__()

                                        self.yang_name = "in-pkts128-to255-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts128-to255-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts256To511Octets(Entity):
                                    """
                                    IN PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets, self).__init__()

                                        self.yang_name = "in-pkts256-to511-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts256-to511-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts512To1023Octets(Entity):
                                    """
                                    IN PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets, self).__init__()

                                        self.yang_name = "in-pkts512-to1023-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts512-to1023-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class InPkts1024To1518Octets(Entity):
                                    """
                                    IN PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets, self).__init__()

                                        self.yang_name = "in-pkts1024-to1518-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "in-pkts1024-to1518-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class Outpkt64Octet(Entity):
                                    """
                                    OUT PKT 64 OCTET
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64Octet, self).__init__()

                                        self.yang_name = "outpkt64octet"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64Octet, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64Octet, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "outpkt64octet" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts65127Octets(Entity):
                                    """
                                    OUT PKTS 65 127OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets, self).__init__()

                                        self.yang_name = "out-pkts65127-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts65127-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts128255Octets(Entity):
                                    """
                                    OUT PKTS 128 255 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets, self).__init__()

                                        self.yang_name = "out-pkts128255-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts128255-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts256511Octets(Entity):
                                    """
                                    OUT PKTS 256 511 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets, self).__init__()

                                        self.yang_name = "out-pkts256511-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts256511-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts5121023Octets(Entity):
                                    """
                                    OUT PKTS 512 1023 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets, self).__init__()

                                        self.yang_name = "out-pkts5121023-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts5121023-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class OutPkts10241518Octets(Entity):
                                    """
                                    OUT PKTS 1024 1518 OCTETS
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets, self).__init__()

                                        self.yang_name = "out-pkts10241518-octets"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "out-pkts10241518-octets" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class RxUtil(Entity):
                                    """
                                    Rx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil, self).__init__()

                                        self.yang_name = "rx-util"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rx-util" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxUtil(Entity):
                                    """
                                    Tx Utilization in Percent
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  str
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  str
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil, self).__init__()

                                        self.yang_name = "tx-util"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.str, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.str, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-util" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxUndersizedPkt(Entity):
                                    """
                                    TX Undersized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt, self).__init__()

                                        self.yang_name = "tx-undersized-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-undersized-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxOversizedPkt(Entity):
                                    """
                                    TX Oversized Pkt
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt, self).__init__()

                                        self.yang_name = "tx-oversized-pkt"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-oversized-pkt" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxFragments(Entity):
                                    """
                                    TX Fragments
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments, self).__init__()

                                        self.yang_name = "tx-fragments"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-fragments" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxJabber(Entity):
                                    """
                                    TX Jabber
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber, self).__init__()

                                        self.yang_name = "tx-jabber"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-jabber" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix


                                class TxBadFcs(Entity):
                                    """
                                    TX Bad Fcs
                                    
                                    .. attribute:: data
                                    
                                    	the number in the interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tca_report
                                    
                                    	enable/disable to report TCA
                                    	**type**\:  bool
                                    
                                    .. attribute:: threshold
                                    
                                    	the threshold users set
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: valid
                                    
                                    	valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs, self).__init__()

                                        self.yang_name = "tx-bad-fcs"
                                        self.yang_parent_name = "minute15-ether"

                                        self.data = YLeaf(YType.uint64, "data")

                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                        self.threshold = YLeaf(YType.uint64, "threshold")

                                        self.valid = YLeaf(YType.boolean, "valid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("data",
                                                        "tca_report",
                                                        "threshold",
                                                        "valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.data.is_set or
                                            self.tca_report.is_set or
                                            self.threshold.is_set or
                                            self.valid.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.data.yfilter != YFilter.not_set or
                                            self.tca_report.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set or
                                            self.valid.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tx-bad-fcs" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.data.get_name_leafdata())
                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())
                                        if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "data"):
                                            self.data = value
                                            self.data.value_namespace = name_space
                                            self.data.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tca-report"):
                                            self.tca_report = value
                                            self.tca_report.value_namespace = name_space
                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix
                                        if(value_path == "valid"):
                                            self.valid = value
                                            self.valid.value_namespace = name_space
                                            self.valid.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.slot_number.is_set or
                                        self.index.is_set or
                                        self.last_clear15_min_time.is_set or
                                        self.last_clear24_hr_time.is_set or
                                        self.last_clear30_sec_time.is_set or
                                        self.last_clear_time.is_set or
                                        self.sec30_support.is_set or
                                        self.timestamp.is_set or
                                        self.valid.is_set or
                                        (self.ether10241518_octet is not None and self.ether10241518_octet.has_data()) or
                                        (self.ether128255_octet is not None and self.ether128255_octet.has_data()) or
                                        (self.ether256511_octet is not None and self.ether256511_octet.has_data()) or
                                        (self.ether5121023_octet is not None and self.ether5121023_octet.has_data()) or
                                        (self.ether64_octets is not None and self.ether64_octets.has_data()) or
                                        (self.ether65127_octet is not None and self.ether65127_octet.has_data()) or
                                        (self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt.has_data()) or
                                        (self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt.has_data()) or
                                        (self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt.has_data()) or
                                        (self.fcs_errors_stat is not None and self.fcs_errors_stat.has_data()) or
                                        (self.if_in_errors is not None and self.if_in_errors.has_data()) or
                                        (self.if_in_octets is not None and self.if_in_octets.has_data()) or
                                        (self.in8021q_frames is not None and self.in8021q_frames.has_data()) or
                                        (self.in_bcast_pkt is not None and self.in_bcast_pkt.has_data()) or
                                        (self.in_drop_abort is not None and self.in_drop_abort.has_data()) or
                                        (self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac.has_data()) or
                                        (self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap.has_data()) or
                                        (self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan.has_data()) or
                                        (self.in_drop_other is not None and self.in_drop_other.has_data()) or
                                        (self.in_drop_overrun is not None and self.in_drop_overrun.has_data()) or
                                        (self.in_error_collisions is not None and self.in_error_collisions.has_data()) or
                                        (self.in_error_fragments is not None and self.in_error_fragments.has_data()) or
                                        (self.in_error_giant is not None and self.in_error_giant.has_data()) or
                                        (self.in_error_jabbers is not None and self.in_error_jabbers.has_data()) or
                                        (self.in_error_other is not None and self.in_error_other.has_data()) or
                                        (self.in_error_runt is not None and self.in_error_runt.has_data()) or
                                        (self.in_error_symbol is not None and self.in_error_symbol.has_data()) or
                                        (self.in_good_bytes is not None and self.in_good_bytes.has_data()) or
                                        (self.in_good_pkts is not None and self.in_good_pkts.has_data()) or
                                        (self.in_mcast_pkt is not None and self.in_mcast_pkt.has_data()) or
                                        (self.in_mib_giant is not None and self.in_mib_giant.has_data()) or
                                        (self.in_mib_jabber is not None and self.in_mib_jabber.has_data()) or
                                        (self.in_mibcrc is not None and self.in_mibcrc.has_data()) or
                                        (self.in_pause_frame is not None and self.in_pause_frame.has_data()) or
                                        (self.in_pkt64_octet is not None and self.in_pkt64_octet.has_data()) or
                                        (self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets.has_data()) or
                                        (self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets.has_data()) or
                                        (self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets.has_data()) or
                                        (self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets.has_data()) or
                                        (self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets.has_data()) or
                                        (self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets.has_data()) or
                                        (self.in_ucast_pkt is not None and self.in_ucast_pkt.has_data()) or
                                        (self.jabber_stat is not None and self.jabber_stat.has_data()) or
                                        (self.long_frames_stat is not None and self.long_frames_stat.has_data()) or
                                        (self.octet_stat is not None and self.octet_stat.has_data()) or
                                        (self.out8021q_frames is not None and self.out8021q_frames.has_data()) or
                                        (self.out_bcast_pkt is not None and self.out_bcast_pkt.has_data()) or
                                        (self.out_drop_abort is not None and self.out_drop_abort.has_data()) or
                                        (self.out_drop_other is not None and self.out_drop_other.has_data()) or
                                        (self.out_drop_underrun is not None and self.out_drop_underrun.has_data()) or
                                        (self.out_error_other is not None and self.out_error_other.has_data()) or
                                        (self.out_good_bytes is not None and self.out_good_bytes.has_data()) or
                                        (self.out_good_pkts is not None and self.out_good_pkts.has_data()) or
                                        (self.out_mcast_pkt is not None and self.out_mcast_pkt.has_data()) or
                                        (self.out_octets is not None and self.out_octets.has_data()) or
                                        (self.out_pause_frames is not None and self.out_pause_frames.has_data()) or
                                        (self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets.has_data()) or
                                        (self.out_pkts128255_octets is not None and self.out_pkts128255_octets.has_data()) or
                                        (self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets.has_data()) or
                                        (self.out_pkts256511_octets is not None and self.out_pkts256511_octets.has_data()) or
                                        (self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets.has_data()) or
                                        (self.out_pkts65127_octets is not None and self.out_pkts65127_octets.has_data()) or
                                        (self.out_ucast_pkt is not None and self.out_ucast_pkt.has_data()) or
                                        (self.outpkt64octet is not None and self.outpkt64octet.has_data()) or
                                        (self.oversize_pkt_stat is not None and self.oversize_pkt_stat.has_data()) or
                                        (self.rx_pkt is not None and self.rx_pkt.has_data()) or
                                        (self.rx_util is not None and self.rx_util.has_data()) or
                                        (self.stat_pkt is not None and self.stat_pkt.has_data()) or
                                        (self.tx_bad_fcs is not None and self.tx_bad_fcs.has_data()) or
                                        (self.tx_fragments is not None and self.tx_fragments.has_data()) or
                                        (self.tx_jabber is not None and self.tx_jabber.has_data()) or
                                        (self.tx_oversized_pkt is not None and self.tx_oversized_pkt.has_data()) or
                                        (self.tx_pkt is not None and self.tx_pkt.has_data()) or
                                        (self.tx_undersized_pkt is not None and self.tx_undersized_pkt.has_data()) or
                                        (self.tx_util is not None and self.tx_util.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.slot_number.yfilter != YFilter.not_set or
                                        self.index.yfilter != YFilter.not_set or
                                        self.last_clear15_min_time.yfilter != YFilter.not_set or
                                        self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                        self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                        self.last_clear_time.yfilter != YFilter.not_set or
                                        self.sec30_support.yfilter != YFilter.not_set or
                                        self.timestamp.yfilter != YFilter.not_set or
                                        self.valid.yfilter != YFilter.not_set or
                                        (self.ether10241518_octet is not None and self.ether10241518_octet.has_operation()) or
                                        (self.ether128255_octet is not None and self.ether128255_octet.has_operation()) or
                                        (self.ether256511_octet is not None and self.ether256511_octet.has_operation()) or
                                        (self.ether5121023_octet is not None and self.ether5121023_octet.has_operation()) or
                                        (self.ether64_octets is not None and self.ether64_octets.has_operation()) or
                                        (self.ether65127_octet is not None and self.ether65127_octet.has_operation()) or
                                        (self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt.has_operation()) or
                                        (self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt.has_operation()) or
                                        (self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt.has_operation()) or
                                        (self.fcs_errors_stat is not None and self.fcs_errors_stat.has_operation()) or
                                        (self.if_in_errors is not None and self.if_in_errors.has_operation()) or
                                        (self.if_in_octets is not None and self.if_in_octets.has_operation()) or
                                        (self.in8021q_frames is not None and self.in8021q_frames.has_operation()) or
                                        (self.in_bcast_pkt is not None and self.in_bcast_pkt.has_operation()) or
                                        (self.in_drop_abort is not None and self.in_drop_abort.has_operation()) or
                                        (self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac.has_operation()) or
                                        (self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap.has_operation()) or
                                        (self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan.has_operation()) or
                                        (self.in_drop_other is not None and self.in_drop_other.has_operation()) or
                                        (self.in_drop_overrun is not None and self.in_drop_overrun.has_operation()) or
                                        (self.in_error_collisions is not None and self.in_error_collisions.has_operation()) or
                                        (self.in_error_fragments is not None and self.in_error_fragments.has_operation()) or
                                        (self.in_error_giant is not None and self.in_error_giant.has_operation()) or
                                        (self.in_error_jabbers is not None and self.in_error_jabbers.has_operation()) or
                                        (self.in_error_other is not None and self.in_error_other.has_operation()) or
                                        (self.in_error_runt is not None and self.in_error_runt.has_operation()) or
                                        (self.in_error_symbol is not None and self.in_error_symbol.has_operation()) or
                                        (self.in_good_bytes is not None and self.in_good_bytes.has_operation()) or
                                        (self.in_good_pkts is not None and self.in_good_pkts.has_operation()) or
                                        (self.in_mcast_pkt is not None and self.in_mcast_pkt.has_operation()) or
                                        (self.in_mib_giant is not None and self.in_mib_giant.has_operation()) or
                                        (self.in_mib_jabber is not None and self.in_mib_jabber.has_operation()) or
                                        (self.in_mibcrc is not None and self.in_mibcrc.has_operation()) or
                                        (self.in_pause_frame is not None and self.in_pause_frame.has_operation()) or
                                        (self.in_pkt64_octet is not None and self.in_pkt64_octet.has_operation()) or
                                        (self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets.has_operation()) or
                                        (self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets.has_operation()) or
                                        (self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets.has_operation()) or
                                        (self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets.has_operation()) or
                                        (self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets.has_operation()) or
                                        (self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets.has_operation()) or
                                        (self.in_ucast_pkt is not None and self.in_ucast_pkt.has_operation()) or
                                        (self.jabber_stat is not None and self.jabber_stat.has_operation()) or
                                        (self.long_frames_stat is not None and self.long_frames_stat.has_operation()) or
                                        (self.octet_stat is not None and self.octet_stat.has_operation()) or
                                        (self.out8021q_frames is not None and self.out8021q_frames.has_operation()) or
                                        (self.out_bcast_pkt is not None and self.out_bcast_pkt.has_operation()) or
                                        (self.out_drop_abort is not None and self.out_drop_abort.has_operation()) or
                                        (self.out_drop_other is not None and self.out_drop_other.has_operation()) or
                                        (self.out_drop_underrun is not None and self.out_drop_underrun.has_operation()) or
                                        (self.out_error_other is not None and self.out_error_other.has_operation()) or
                                        (self.out_good_bytes is not None and self.out_good_bytes.has_operation()) or
                                        (self.out_good_pkts is not None and self.out_good_pkts.has_operation()) or
                                        (self.out_mcast_pkt is not None and self.out_mcast_pkt.has_operation()) or
                                        (self.out_octets is not None and self.out_octets.has_operation()) or
                                        (self.out_pause_frames is not None and self.out_pause_frames.has_operation()) or
                                        (self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets.has_operation()) or
                                        (self.out_pkts128255_octets is not None and self.out_pkts128255_octets.has_operation()) or
                                        (self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets.has_operation()) or
                                        (self.out_pkts256511_octets is not None and self.out_pkts256511_octets.has_operation()) or
                                        (self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets.has_operation()) or
                                        (self.out_pkts65127_octets is not None and self.out_pkts65127_octets.has_operation()) or
                                        (self.out_ucast_pkt is not None and self.out_ucast_pkt.has_operation()) or
                                        (self.outpkt64octet is not None and self.outpkt64octet.has_operation()) or
                                        (self.oversize_pkt_stat is not None and self.oversize_pkt_stat.has_operation()) or
                                        (self.rx_pkt is not None and self.rx_pkt.has_operation()) or
                                        (self.rx_util is not None and self.rx_util.has_operation()) or
                                        (self.stat_pkt is not None and self.stat_pkt.has_operation()) or
                                        (self.tx_bad_fcs is not None and self.tx_bad_fcs.has_operation()) or
                                        (self.tx_fragments is not None and self.tx_fragments.has_operation()) or
                                        (self.tx_jabber is not None and self.tx_jabber.has_operation()) or
                                        (self.tx_oversized_pkt is not None and self.tx_oversized_pkt.has_operation()) or
                                        (self.tx_pkt is not None and self.tx_pkt.has_operation()) or
                                        (self.tx_undersized_pkt is not None and self.tx_undersized_pkt.has_operation()) or
                                        (self.tx_util is not None and self.tx_util.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "minute15-ether" + "[slot-number='" + self.slot_number.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.slot_number.is_set or self.slot_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.slot_number.get_name_leafdata())
                                    if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.index.get_name_leafdata())
                                    if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                    if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                    if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                    if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                    if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                    if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.timestamp.get_name_leafdata())
                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ether10241518-octet"):
                                        if (self.ether10241518_octet is None):
                                            self.ether10241518_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether10241518Octet()
                                            self.ether10241518_octet.parent = self
                                            self._children_name_map["ether10241518_octet"] = "ether10241518-octet"
                                        return self.ether10241518_octet

                                    if (child_yang_name == "ether128255-octet"):
                                        if (self.ether128255_octet is None):
                                            self.ether128255_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether128255Octet()
                                            self.ether128255_octet.parent = self
                                            self._children_name_map["ether128255_octet"] = "ether128255-octet"
                                        return self.ether128255_octet

                                    if (child_yang_name == "ether256511-octet"):
                                        if (self.ether256511_octet is None):
                                            self.ether256511_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether256511Octet()
                                            self.ether256511_octet.parent = self
                                            self._children_name_map["ether256511_octet"] = "ether256511-octet"
                                        return self.ether256511_octet

                                    if (child_yang_name == "ether5121023-octet"):
                                        if (self.ether5121023_octet is None):
                                            self.ether5121023_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether5121023Octet()
                                            self.ether5121023_octet.parent = self
                                            self._children_name_map["ether5121023_octet"] = "ether5121023-octet"
                                        return self.ether5121023_octet

                                    if (child_yang_name == "ether64-octets"):
                                        if (self.ether64_octets is None):
                                            self.ether64_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether64Octets()
                                            self.ether64_octets.parent = self
                                            self._children_name_map["ether64_octets"] = "ether64-octets"
                                        return self.ether64_octets

                                    if (child_yang_name == "ether65127-octet"):
                                        if (self.ether65127_octet is None):
                                            self.ether65127_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Ether65127Octet()
                                            self.ether65127_octet.parent = self
                                            self._children_name_map["ether65127_octet"] = "ether65127-octet"
                                        return self.ether65127_octet

                                    if (child_yang_name == "ether-stat-broadcast-pkt"):
                                        if (self.ether_stat_broadcast_pkt is None):
                                            self.ether_stat_broadcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatBroadcastPkt()
                                            self.ether_stat_broadcast_pkt.parent = self
                                            self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"
                                        return self.ether_stat_broadcast_pkt

                                    if (child_yang_name == "ether-stat-multicast-pkt"):
                                        if (self.ether_stat_multicast_pkt is None):
                                            self.ether_stat_multicast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatMulticastPkt()
                                            self.ether_stat_multicast_pkt.parent = self
                                            self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"
                                        return self.ether_stat_multicast_pkt

                                    if (child_yang_name == "ether-stat-undersized-pkt"):
                                        if (self.ether_stat_undersized_pkt is None):
                                            self.ether_stat_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.EtherStatUndersizedPkt()
                                            self.ether_stat_undersized_pkt.parent = self
                                            self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"
                                        return self.ether_stat_undersized_pkt

                                    if (child_yang_name == "fcs-errors-stat"):
                                        if (self.fcs_errors_stat is None):
                                            self.fcs_errors_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.FcsErrorsStat()
                                            self.fcs_errors_stat.parent = self
                                            self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"
                                        return self.fcs_errors_stat

                                    if (child_yang_name == "if-in-errors"):
                                        if (self.if_in_errors is None):
                                            self.if_in_errors = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInErrors()
                                            self.if_in_errors.parent = self
                                            self._children_name_map["if_in_errors"] = "if-in-errors"
                                        return self.if_in_errors

                                    if (child_yang_name == "if-in-octets"):
                                        if (self.if_in_octets is None):
                                            self.if_in_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.IfInOctets()
                                            self.if_in_octets.parent = self
                                            self._children_name_map["if_in_octets"] = "if-in-octets"
                                        return self.if_in_octets

                                    if (child_yang_name == "in8021q-frames"):
                                        if (self.in8021q_frames is None):
                                            self.in8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.In8021QFrames()
                                            self.in8021q_frames.parent = self
                                            self._children_name_map["in8021q_frames"] = "in8021q-frames"
                                        return self.in8021q_frames

                                    if (child_yang_name == "in-bcast-pkt"):
                                        if (self.in_bcast_pkt is None):
                                            self.in_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InBcastPkt()
                                            self.in_bcast_pkt.parent = self
                                            self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"
                                        return self.in_bcast_pkt

                                    if (child_yang_name == "in-drop-abort"):
                                        if (self.in_drop_abort is None):
                                            self.in_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropAbort()
                                            self.in_drop_abort.parent = self
                                            self._children_name_map["in_drop_abort"] = "in-drop-abort"
                                        return self.in_drop_abort

                                    if (child_yang_name == "in-drop-invalid-dmac"):
                                        if (self.in_drop_invalid_dmac is None):
                                            self.in_drop_invalid_dmac = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidDmac()
                                            self.in_drop_invalid_dmac.parent = self
                                            self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"
                                        return self.in_drop_invalid_dmac

                                    if (child_yang_name == "in-drop-invalid-encap"):
                                        if (self.in_drop_invalid_encap is None):
                                            self.in_drop_invalid_encap = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidEncap()
                                            self.in_drop_invalid_encap.parent = self
                                            self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"
                                        return self.in_drop_invalid_encap

                                    if (child_yang_name == "in-drop-invalid-vlan"):
                                        if (self.in_drop_invalid_vlan is None):
                                            self.in_drop_invalid_vlan = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropInvalidVlan()
                                            self.in_drop_invalid_vlan.parent = self
                                            self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"
                                        return self.in_drop_invalid_vlan

                                    if (child_yang_name == "in-drop-other"):
                                        if (self.in_drop_other is None):
                                            self.in_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOther()
                                            self.in_drop_other.parent = self
                                            self._children_name_map["in_drop_other"] = "in-drop-other"
                                        return self.in_drop_other

                                    if (child_yang_name == "in-drop-overrun"):
                                        if (self.in_drop_overrun is None):
                                            self.in_drop_overrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InDropOverrun()
                                            self.in_drop_overrun.parent = self
                                            self._children_name_map["in_drop_overrun"] = "in-drop-overrun"
                                        return self.in_drop_overrun

                                    if (child_yang_name == "in-error-collisions"):
                                        if (self.in_error_collisions is None):
                                            self.in_error_collisions = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorCollisions()
                                            self.in_error_collisions.parent = self
                                            self._children_name_map["in_error_collisions"] = "in-error-collisions"
                                        return self.in_error_collisions

                                    if (child_yang_name == "in-error-fragments"):
                                        if (self.in_error_fragments is None):
                                            self.in_error_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorFragments()
                                            self.in_error_fragments.parent = self
                                            self._children_name_map["in_error_fragments"] = "in-error-fragments"
                                        return self.in_error_fragments

                                    if (child_yang_name == "in-error-giant"):
                                        if (self.in_error_giant is None):
                                            self.in_error_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorGiant()
                                            self.in_error_giant.parent = self
                                            self._children_name_map["in_error_giant"] = "in-error-giant"
                                        return self.in_error_giant

                                    if (child_yang_name == "in-error-jabbers"):
                                        if (self.in_error_jabbers is None):
                                            self.in_error_jabbers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorJabbers()
                                            self.in_error_jabbers.parent = self
                                            self._children_name_map["in_error_jabbers"] = "in-error-jabbers"
                                        return self.in_error_jabbers

                                    if (child_yang_name == "in-error-other"):
                                        if (self.in_error_other is None):
                                            self.in_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorOther()
                                            self.in_error_other.parent = self
                                            self._children_name_map["in_error_other"] = "in-error-other"
                                        return self.in_error_other

                                    if (child_yang_name == "in-error-runt"):
                                        if (self.in_error_runt is None):
                                            self.in_error_runt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorRunt()
                                            self.in_error_runt.parent = self
                                            self._children_name_map["in_error_runt"] = "in-error-runt"
                                        return self.in_error_runt

                                    if (child_yang_name == "in-error-symbol"):
                                        if (self.in_error_symbol is None):
                                            self.in_error_symbol = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InErrorSymbol()
                                            self.in_error_symbol.parent = self
                                            self._children_name_map["in_error_symbol"] = "in-error-symbol"
                                        return self.in_error_symbol

                                    if (child_yang_name == "in-good-bytes"):
                                        if (self.in_good_bytes is None):
                                            self.in_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodBytes()
                                            self.in_good_bytes.parent = self
                                            self._children_name_map["in_good_bytes"] = "in-good-bytes"
                                        return self.in_good_bytes

                                    if (child_yang_name == "in-good-pkts"):
                                        if (self.in_good_pkts is None):
                                            self.in_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InGoodPkts()
                                            self.in_good_pkts.parent = self
                                            self._children_name_map["in_good_pkts"] = "in-good-pkts"
                                        return self.in_good_pkts

                                    if (child_yang_name == "in-mcast-pkt"):
                                        if (self.in_mcast_pkt is None):
                                            self.in_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMcastPkt()
                                            self.in_mcast_pkt.parent = self
                                            self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"
                                        return self.in_mcast_pkt

                                    if (child_yang_name == "in-mib-giant"):
                                        if (self.in_mib_giant is None):
                                            self.in_mib_giant = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibGiant()
                                            self.in_mib_giant.parent = self
                                            self._children_name_map["in_mib_giant"] = "in-mib-giant"
                                        return self.in_mib_giant

                                    if (child_yang_name == "in-mib-jabber"):
                                        if (self.in_mib_jabber is None):
                                            self.in_mib_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibJabber()
                                            self.in_mib_jabber.parent = self
                                            self._children_name_map["in_mib_jabber"] = "in-mib-jabber"
                                        return self.in_mib_jabber

                                    if (child_yang_name == "in-mibcrc"):
                                        if (self.in_mibcrc is None):
                                            self.in_mibcrc = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InMibcrc()
                                            self.in_mibcrc.parent = self
                                            self._children_name_map["in_mibcrc"] = "in-mibcrc"
                                        return self.in_mibcrc

                                    if (child_yang_name == "in-pause-frame"):
                                        if (self.in_pause_frame is None):
                                            self.in_pause_frame = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPauseFrame()
                                            self.in_pause_frame.parent = self
                                            self._children_name_map["in_pause_frame"] = "in-pause-frame"
                                        return self.in_pause_frame

                                    if (child_yang_name == "in-pkt64-octet"):
                                        if (self.in_pkt64_octet is None):
                                            self.in_pkt64_octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkt64Octet()
                                            self.in_pkt64_octet.parent = self
                                            self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"
                                        return self.in_pkt64_octet

                                    if (child_yang_name == "in-pkts1024-to1518-octets"):
                                        if (self.in_pkts1024_to1518_octets is None):
                                            self.in_pkts1024_to1518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1024To1518Octets()
                                            self.in_pkts1024_to1518_octets.parent = self
                                            self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"
                                        return self.in_pkts1024_to1518_octets

                                    if (child_yang_name == "in-pkts128-to255-octets"):
                                        if (self.in_pkts128_to255_octets is None):
                                            self.in_pkts128_to255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts128To255Octets()
                                            self.in_pkts128_to255_octets.parent = self
                                            self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"
                                        return self.in_pkts128_to255_octets

                                    if (child_yang_name == "in-pkts1519-max-octets"):
                                        if (self.in_pkts1519_max_octets is None):
                                            self.in_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts1519MaxOctets()
                                            self.in_pkts1519_max_octets.parent = self
                                            self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"
                                        return self.in_pkts1519_max_octets

                                    if (child_yang_name == "in-pkts256-to511-octets"):
                                        if (self.in_pkts256_to511_octets is None):
                                            self.in_pkts256_to511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts256To511Octets()
                                            self.in_pkts256_to511_octets.parent = self
                                            self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"
                                        return self.in_pkts256_to511_octets

                                    if (child_yang_name == "in-pkts512-to1023-octets"):
                                        if (self.in_pkts512_to1023_octets is None):
                                            self.in_pkts512_to1023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts512To1023Octets()
                                            self.in_pkts512_to1023_octets.parent = self
                                            self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"
                                        return self.in_pkts512_to1023_octets

                                    if (child_yang_name == "in-pkts65-to127-octets"):
                                        if (self.in_pkts65_to127_octets is None):
                                            self.in_pkts65_to127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InPkts65To127Octets()
                                            self.in_pkts65_to127_octets.parent = self
                                            self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"
                                        return self.in_pkts65_to127_octets

                                    if (child_yang_name == "in-ucast-pkt"):
                                        if (self.in_ucast_pkt is None):
                                            self.in_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.InUcastPkt()
                                            self.in_ucast_pkt.parent = self
                                            self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"
                                        return self.in_ucast_pkt

                                    if (child_yang_name == "jabber-stat"):
                                        if (self.jabber_stat is None):
                                            self.jabber_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.JabberStat()
                                            self.jabber_stat.parent = self
                                            self._children_name_map["jabber_stat"] = "jabber-stat"
                                        return self.jabber_stat

                                    if (child_yang_name == "long-frames-stat"):
                                        if (self.long_frames_stat is None):
                                            self.long_frames_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.LongFramesStat()
                                            self.long_frames_stat.parent = self
                                            self._children_name_map["long_frames_stat"] = "long-frames-stat"
                                        return self.long_frames_stat

                                    if (child_yang_name == "octet-stat"):
                                        if (self.octet_stat is None):
                                            self.octet_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OctetStat()
                                            self.octet_stat.parent = self
                                            self._children_name_map["octet_stat"] = "octet-stat"
                                        return self.octet_stat

                                    if (child_yang_name == "out8021q-frames"):
                                        if (self.out8021q_frames is None):
                                            self.out8021q_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Out8021QFrames()
                                            self.out8021q_frames.parent = self
                                            self._children_name_map["out8021q_frames"] = "out8021q-frames"
                                        return self.out8021q_frames

                                    if (child_yang_name == "out-bcast-pkt"):
                                        if (self.out_bcast_pkt is None):
                                            self.out_bcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutBcastPkt()
                                            self.out_bcast_pkt.parent = self
                                            self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"
                                        return self.out_bcast_pkt

                                    if (child_yang_name == "out-drop-abort"):
                                        if (self.out_drop_abort is None):
                                            self.out_drop_abort = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropAbort()
                                            self.out_drop_abort.parent = self
                                            self._children_name_map["out_drop_abort"] = "out-drop-abort"
                                        return self.out_drop_abort

                                    if (child_yang_name == "out-drop-other"):
                                        if (self.out_drop_other is None):
                                            self.out_drop_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropOther()
                                            self.out_drop_other.parent = self
                                            self._children_name_map["out_drop_other"] = "out-drop-other"
                                        return self.out_drop_other

                                    if (child_yang_name == "out-drop-underrun"):
                                        if (self.out_drop_underrun is None):
                                            self.out_drop_underrun = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutDropUnderrun()
                                            self.out_drop_underrun.parent = self
                                            self._children_name_map["out_drop_underrun"] = "out-drop-underrun"
                                        return self.out_drop_underrun

                                    if (child_yang_name == "out-error-other"):
                                        if (self.out_error_other is None):
                                            self.out_error_other = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutErrorOther()
                                            self.out_error_other.parent = self
                                            self._children_name_map["out_error_other"] = "out-error-other"
                                        return self.out_error_other

                                    if (child_yang_name == "out-good-bytes"):
                                        if (self.out_good_bytes is None):
                                            self.out_good_bytes = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodBytes()
                                            self.out_good_bytes.parent = self
                                            self._children_name_map["out_good_bytes"] = "out-good-bytes"
                                        return self.out_good_bytes

                                    if (child_yang_name == "out-good-pkts"):
                                        if (self.out_good_pkts is None):
                                            self.out_good_pkts = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutGoodPkts()
                                            self.out_good_pkts.parent = self
                                            self._children_name_map["out_good_pkts"] = "out-good-pkts"
                                        return self.out_good_pkts

                                    if (child_yang_name == "out-mcast-pkt"):
                                        if (self.out_mcast_pkt is None):
                                            self.out_mcast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutMcastPkt()
                                            self.out_mcast_pkt.parent = self
                                            self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"
                                        return self.out_mcast_pkt

                                    if (child_yang_name == "out-octets"):
                                        if (self.out_octets is None):
                                            self.out_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutOctets()
                                            self.out_octets.parent = self
                                            self._children_name_map["out_octets"] = "out-octets"
                                        return self.out_octets

                                    if (child_yang_name == "out-pause-frames"):
                                        if (self.out_pause_frames is None):
                                            self.out_pause_frames = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPauseFrames()
                                            self.out_pause_frames.parent = self
                                            self._children_name_map["out_pause_frames"] = "out-pause-frames"
                                        return self.out_pause_frames

                                    if (child_yang_name == "out-pkts10241518-octets"):
                                        if (self.out_pkts10241518_octets is None):
                                            self.out_pkts10241518_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts10241518Octets()
                                            self.out_pkts10241518_octets.parent = self
                                            self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"
                                        return self.out_pkts10241518_octets

                                    if (child_yang_name == "out-pkts128255-octets"):
                                        if (self.out_pkts128255_octets is None):
                                            self.out_pkts128255_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts128255Octets()
                                            self.out_pkts128255_octets.parent = self
                                            self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"
                                        return self.out_pkts128255_octets

                                    if (child_yang_name == "out-pkts1519-max-octets"):
                                        if (self.out_pkts1519_max_octets is None):
                                            self.out_pkts1519_max_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts1519MaxOctets()
                                            self.out_pkts1519_max_octets.parent = self
                                            self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"
                                        return self.out_pkts1519_max_octets

                                    if (child_yang_name == "out-pkts256511-octets"):
                                        if (self.out_pkts256511_octets is None):
                                            self.out_pkts256511_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts256511Octets()
                                            self.out_pkts256511_octets.parent = self
                                            self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"
                                        return self.out_pkts256511_octets

                                    if (child_yang_name == "out-pkts5121023-octets"):
                                        if (self.out_pkts5121023_octets is None):
                                            self.out_pkts5121023_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts5121023Octets()
                                            self.out_pkts5121023_octets.parent = self
                                            self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"
                                        return self.out_pkts5121023_octets

                                    if (child_yang_name == "out-pkts65127-octets"):
                                        if (self.out_pkts65127_octets is None):
                                            self.out_pkts65127_octets = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutPkts65127Octets()
                                            self.out_pkts65127_octets.parent = self
                                            self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"
                                        return self.out_pkts65127_octets

                                    if (child_yang_name == "out-ucast-pkt"):
                                        if (self.out_ucast_pkt is None):
                                            self.out_ucast_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OutUcastPkt()
                                            self.out_ucast_pkt.parent = self
                                            self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"
                                        return self.out_ucast_pkt

                                    if (child_yang_name == "outpkt64octet"):
                                        if (self.outpkt64octet is None):
                                            self.outpkt64octet = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.Outpkt64Octet()
                                            self.outpkt64octet.parent = self
                                            self._children_name_map["outpkt64octet"] = "outpkt64octet"
                                        return self.outpkt64octet

                                    if (child_yang_name == "oversize-pkt-stat"):
                                        if (self.oversize_pkt_stat is None):
                                            self.oversize_pkt_stat = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.OversizePktStat()
                                            self.oversize_pkt_stat.parent = self
                                            self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"
                                        return self.oversize_pkt_stat

                                    if (child_yang_name == "rx-pkt"):
                                        if (self.rx_pkt is None):
                                            self.rx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxPkt()
                                            self.rx_pkt.parent = self
                                            self._children_name_map["rx_pkt"] = "rx-pkt"
                                        return self.rx_pkt

                                    if (child_yang_name == "rx-util"):
                                        if (self.rx_util is None):
                                            self.rx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.RxUtil()
                                            self.rx_util.parent = self
                                            self._children_name_map["rx_util"] = "rx-util"
                                        return self.rx_util

                                    if (child_yang_name == "stat-pkt"):
                                        if (self.stat_pkt is None):
                                            self.stat_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.StatPkt()
                                            self.stat_pkt.parent = self
                                            self._children_name_map["stat_pkt"] = "stat-pkt"
                                        return self.stat_pkt

                                    if (child_yang_name == "tx-bad-fcs"):
                                        if (self.tx_bad_fcs is None):
                                            self.tx_bad_fcs = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxBadFcs()
                                            self.tx_bad_fcs.parent = self
                                            self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                        return self.tx_bad_fcs

                                    if (child_yang_name == "tx-fragments"):
                                        if (self.tx_fragments is None):
                                            self.tx_fragments = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxFragments()
                                            self.tx_fragments.parent = self
                                            self._children_name_map["tx_fragments"] = "tx-fragments"
                                        return self.tx_fragments

                                    if (child_yang_name == "tx-jabber"):
                                        if (self.tx_jabber is None):
                                            self.tx_jabber = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxJabber()
                                            self.tx_jabber.parent = self
                                            self._children_name_map["tx_jabber"] = "tx-jabber"
                                        return self.tx_jabber

                                    if (child_yang_name == "tx-oversized-pkt"):
                                        if (self.tx_oversized_pkt is None):
                                            self.tx_oversized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxOversizedPkt()
                                            self.tx_oversized_pkt.parent = self
                                            self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"
                                        return self.tx_oversized_pkt

                                    if (child_yang_name == "tx-pkt"):
                                        if (self.tx_pkt is None):
                                            self.tx_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxPkt()
                                            self.tx_pkt.parent = self
                                            self._children_name_map["tx_pkt"] = "tx-pkt"
                                        return self.tx_pkt

                                    if (child_yang_name == "tx-undersized-pkt"):
                                        if (self.tx_undersized_pkt is None):
                                            self.tx_undersized_pkt = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUndersizedPkt()
                                            self.tx_undersized_pkt.parent = self
                                            self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"
                                        return self.tx_undersized_pkt

                                    if (child_yang_name == "tx-util"):
                                        if (self.tx_util is None):
                                            self.tx_util = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether.TxUtil()
                                            self.tx_util.parent = self
                                            self._children_name_map["tx_util"] = "tx-util"
                                        return self.tx_util

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ether10241518-octet" or name == "ether128255-octet" or name == "ether256511-octet" or name == "ether5121023-octet" or name == "ether64-octets" or name == "ether65127-octet" or name == "ether-stat-broadcast-pkt" or name == "ether-stat-multicast-pkt" or name == "ether-stat-undersized-pkt" or name == "fcs-errors-stat" or name == "if-in-errors" or name == "if-in-octets" or name == "in8021q-frames" or name == "in-bcast-pkt" or name == "in-drop-abort" or name == "in-drop-invalid-dmac" or name == "in-drop-invalid-encap" or name == "in-drop-invalid-vlan" or name == "in-drop-other" or name == "in-drop-overrun" or name == "in-error-collisions" or name == "in-error-fragments" or name == "in-error-giant" or name == "in-error-jabbers" or name == "in-error-other" or name == "in-error-runt" or name == "in-error-symbol" or name == "in-good-bytes" or name == "in-good-pkts" or name == "in-mcast-pkt" or name == "in-mib-giant" or name == "in-mib-jabber" or name == "in-mibcrc" or name == "in-pause-frame" or name == "in-pkt64-octet" or name == "in-pkts1024-to1518-octets" or name == "in-pkts128-to255-octets" or name == "in-pkts1519-max-octets" or name == "in-pkts256-to511-octets" or name == "in-pkts512-to1023-octets" or name == "in-pkts65-to127-octets" or name == "in-ucast-pkt" or name == "jabber-stat" or name == "long-frames-stat" or name == "octet-stat" or name == "out8021q-frames" or name == "out-bcast-pkt" or name == "out-drop-abort" or name == "out-drop-other" or name == "out-drop-underrun" or name == "out-error-other" or name == "out-good-bytes" or name == "out-good-pkts" or name == "out-mcast-pkt" or name == "out-octets" or name == "out-pause-frames" or name == "out-pkts10241518-octets" or name == "out-pkts128255-octets" or name == "out-pkts1519-max-octets" or name == "out-pkts256511-octets" or name == "out-pkts5121023-octets" or name == "out-pkts65127-octets" or name == "out-ucast-pkt" or name == "outpkt64octet" or name == "oversize-pkt-stat" or name == "rx-pkt" or name == "rx-util" or name == "stat-pkt" or name == "tx-bad-fcs" or name == "tx-fragments" or name == "tx-jabber" or name == "tx-oversized-pkt" or name == "tx-pkt" or name == "tx-undersized-pkt" or name == "tx-util" or name == "slot-number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "slot-number"):
                                        self.slot_number = value
                                        self.slot_number.value_namespace = name_space
                                        self.slot_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "index"):
                                        self.index = value
                                        self.index.value_namespace = name_space
                                        self.index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear15-min-time"):
                                        self.last_clear15_min_time = value
                                        self.last_clear15_min_time.value_namespace = name_space
                                        self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear24-hr-time"):
                                        self.last_clear24_hr_time = value
                                        self.last_clear24_hr_time.value_namespace = name_space
                                        self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear30-sec-time"):
                                        self.last_clear30_sec_time = value
                                        self.last_clear30_sec_time.value_namespace = name_space
                                        self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-clear-time"):
                                        self.last_clear_time = value
                                        self.last_clear_time.value_namespace = name_space
                                        self.last_clear_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sec30-support"):
                                        self.sec30_support = value
                                        self.sec30_support.value_namespace = name_space
                                        self.sec30_support.value_namespace_prefix = name_space_prefix
                                    if(value_path == "timestamp"):
                                        self.timestamp = value
                                        self.timestamp.value_namespace = name_space
                                        self.timestamp.value_namespace_prefix = name_space_prefix
                                    if(value_path == "valid"):
                                        self.valid = value
                                        self.valid.value_namespace = name_space
                                        self.valid.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.minute15_ether:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.minute15_ether:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "minute15-ethers" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "minute15-ether"):
                                    for c in self.minute15_ether:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers.Minute15Ether()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.minute15_ether.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "minute15-ether"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.minute15_ethers is not None and self.minute15_ethers.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.minute15_ethers is not None and self.minute15_ethers.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "minute15" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "minute15-ethers"):
                                if (self.minute15_ethers is None):
                                    self.minute15_ethers = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15.Minute15Ethers()
                                    self.minute15_ethers.parent = self
                                    self._children_name_map["minute15_ethers"] = "minute15-ethers"
                                return self.minute15_ethers

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "minute15-ethers"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.ethernet_hour24 is not None and self.ethernet_hour24.has_data()) or
                            (self.ethernet_second30 is not None and self.ethernet_second30.has_data()) or
                            (self.minute15 is not None and self.minute15.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.ethernet_hour24 is not None and self.ethernet_hour24.has_operation()) or
                            (self.ethernet_second30 is not None and self.ethernet_second30.has_operation()) or
                            (self.minute15 is not None and self.minute15.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ethernet-current" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ethernet-hour24"):
                            if (self.ethernet_hour24 is None):
                                self.ethernet_hour24 = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetHour24()
                                self.ethernet_hour24.parent = self
                                self._children_name_map["ethernet_hour24"] = "ethernet-hour24"
                            return self.ethernet_hour24

                        if (child_yang_name == "ethernet-second30"):
                            if (self.ethernet_second30 is None):
                                self.ethernet_second30 = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.EthernetSecond30()
                                self.ethernet_second30.parent = self
                                self._children_name_map["ethernet_second30"] = "ethernet-second30"
                            return self.ethernet_second30

                        if (child_yang_name == "minute15"):
                            if (self.minute15 is None):
                                self.minute15 = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent.Minute15()
                                self.minute15.parent = self
                                self._children_name_map["minute15"] = "minute15"
                            return self.minute15

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ethernet-hour24" or name == "ethernet-second30" or name == "minute15"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.name.is_set or
                        (self.ethernet_current is not None and self.ethernet_current.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.name.yfilter != YFilter.not_set or
                        (self.ethernet_current is not None and self.ethernet_current.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ethernet-port" + "[name='" + self.name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/ethernet/ethernet-ports/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ethernet-current"):
                        if (self.ethernet_current is None):
                            self.ethernet_current = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort.EthernetCurrent()
                            self.ethernet_current.parent = self
                            self._children_name_map["ethernet_current"] = "ethernet-current"
                        return self.ethernet_current

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ethernet-current" or name == "name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "name"):
                        self.name = value
                        self.name.value_namespace = name_space
                        self.name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.ethernet_port:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.ethernet_port:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "ethernet-ports" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/ethernet/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "ethernet-port"):
                    for c in self.ethernet_port:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = PerformanceManagement.Ethernet.EthernetPorts.EthernetPort()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.ethernet_port.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "ethernet-port"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.ethernet_ports is not None and self.ethernet_ports.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.ethernet_ports is not None and self.ethernet_ports.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "ethernet" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "ethernet-ports"):
                if (self.ethernet_ports is None):
                    self.ethernet_ports = PerformanceManagement.Ethernet.EthernetPorts()
                    self.ethernet_ports.parent = self
                    self._children_name_map["ethernet_ports"] = "ethernet-ports"
                return self.ethernet_ports

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "ethernet-ports"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.dwdm is not None and self.dwdm.has_data()) or
            (self.ethernet is not None and self.ethernet.has_data()) or
            (self.ho_vc is not None and self.ho_vc.has_data()) or
            (self.oc is not None and self.oc.has_data()) or
            (self.odu is not None and self.odu.has_data()) or
            (self.optics is not None and self.optics.has_data()) or
            (self.otu is not None and self.otu.has_data()) or
            (self.sonet is not None and self.sonet.has_data()) or
            (self.stm is not None and self.stm.has_data()) or
            (self.sts is not None and self.sts.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.dwdm is not None and self.dwdm.has_operation()) or
            (self.ethernet is not None and self.ethernet.has_operation()) or
            (self.ho_vc is not None and self.ho_vc.has_operation()) or
            (self.oc is not None and self.oc.has_operation()) or
            (self.odu is not None and self.odu.has_operation()) or
            (self.optics is not None and self.optics.has_operation()) or
            (self.otu is not None and self.otu.has_operation()) or
            (self.sonet is not None and self.sonet.has_operation()) or
            (self.stm is not None and self.stm.has_operation()) or
            (self.sts is not None and self.sts.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "dwdm"):
            if (self.dwdm is None):
                self.dwdm = PerformanceManagement.Dwdm()
                self.dwdm.parent = self
                self._children_name_map["dwdm"] = "dwdm"
            return self.dwdm

        if (child_yang_name == "ethernet"):
            if (self.ethernet is None):
                self.ethernet = PerformanceManagement.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "ethernet"
            return self.ethernet

        if (child_yang_name == "ho-vc"):
            if (self.ho_vc is None):
                self.ho_vc = PerformanceManagement.HoVc()
                self.ho_vc.parent = self
                self._children_name_map["ho_vc"] = "ho-vc"
            return self.ho_vc

        if (child_yang_name == "oc"):
            if (self.oc is None):
                self.oc = PerformanceManagement.Oc()
                self.oc.parent = self
                self._children_name_map["oc"] = "oc"
            return self.oc

        if (child_yang_name == "odu"):
            if (self.odu is None):
                self.odu = PerformanceManagement.Odu()
                self.odu.parent = self
                self._children_name_map["odu"] = "odu"
            return self.odu

        if (child_yang_name == "optics"):
            if (self.optics is None):
                self.optics = PerformanceManagement.Optics()
                self.optics.parent = self
                self._children_name_map["optics"] = "optics"
            return self.optics

        if (child_yang_name == "otu"):
            if (self.otu is None):
                self.otu = PerformanceManagement.Otu()
                self.otu.parent = self
                self._children_name_map["otu"] = "otu"
            return self.otu

        if (child_yang_name == "sonet"):
            if (self.sonet is None):
                self.sonet = PerformanceManagement.Sonet()
                self.sonet.parent = self
                self._children_name_map["sonet"] = "sonet"
            return self.sonet

        if (child_yang_name == "stm"):
            if (self.stm is None):
                self.stm = PerformanceManagement.Stm()
                self.stm.parent = self
                self._children_name_map["stm"] = "stm"
            return self.stm

        if (child_yang_name == "sts"):
            if (self.sts is None):
                self.sts = PerformanceManagement.Sts()
                self.sts.parent = self
                self._children_name_map["sts"] = "sts"
            return self.sts

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "dwdm" or name == "ethernet" or name == "ho-vc" or name == "oc" or name == "odu" or name == "optics" or name == "otu" or name == "sonet" or name == "stm" or name == "sts"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = PerformanceManagement()
        return self._top_entity

class PerformanceManagementHistory(Entity):
    """
    performance management history
    
    .. attribute:: global_
    
    	global History performace data
    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_>`
    
    

    """

    _prefix = 'pmengine-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(PerformanceManagementHistory, self).__init__()
        self._top_entity = None

        self.yang_name = "performance-management-history"
        self.yang_parent_name = "Cisco-IOS-XR-pmengine-oper"

        self.global_ = PerformanceManagementHistory.Global_()
        self.global_.parent = self
        self._children_name_map["global_"] = "global"
        self._children_yang_names.add("global")


    class Global_(Entity):
        """
        global History performace data
        
        .. attribute:: periodic
        
        	History performace data
        	**type**\:   :py:class:`Periodic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic>`
        
        

        """

        _prefix = 'pmengine-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PerformanceManagementHistory.Global_, self).__init__()

            self.yang_name = "global"
            self.yang_parent_name = "performance-management-history"

            self.periodic = PerformanceManagementHistory.Global_.Periodic()
            self.periodic.parent = self
            self._children_name_map["periodic"] = "periodic"
            self._children_yang_names.add("periodic")


        class Periodic(Entity):
            """
            History performace data
            
            .. attribute:: dwdm_history
            
            	DWDM controller History performance data
            	**type**\:   :py:class:`DwdmHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory>`
            
            .. attribute:: ethernet_history
            
            	EHERNET controller History performance data
            	**type**\:   :py:class:`EthernetHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory>`
            
            .. attribute:: ho_vc_history
            
            	HO\_VC controller History performance data
            	**type**\:   :py:class:`HoVcHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory>`
            
            .. attribute:: oc_history
            
            	OC controller History performance data
            	**type**\:   :py:class:`OcHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory>`
            
            .. attribute:: odu_history
            
            	ODU controller History performance data
            	**type**\:   :py:class:`OduHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory>`
            
            .. attribute:: optics_history
            
            	OPTICS controller History performance data
            	**type**\:   :py:class:`OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory>`
            
            .. attribute:: otu_history
            
            	OTU controller History performance data
            	**type**\:   :py:class:`OtuHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory>`
            
            .. attribute:: sonet_history
            
            	SONET controller History performance data
            	**type**\:   :py:class:`SonetHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory>`
            
            .. attribute:: stm_history
            
            	STM controller History performance data
            	**type**\:   :py:class:`StmHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory>`
            
            .. attribute:: sts_history
            
            	STS controller History performance data
            	**type**\:   :py:class:`StsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory>`
            
            

            """

            _prefix = 'pmengine-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PerformanceManagementHistory.Global_.Periodic, self).__init__()

                self.yang_name = "periodic"
                self.yang_parent_name = "global"

                self.dwdm_history = PerformanceManagementHistory.Global_.Periodic.DwdmHistory()
                self.dwdm_history.parent = self
                self._children_name_map["dwdm_history"] = "dwdm-history"
                self._children_yang_names.add("dwdm-history")

                self.ethernet_history = PerformanceManagementHistory.Global_.Periodic.EthernetHistory()
                self.ethernet_history.parent = self
                self._children_name_map["ethernet_history"] = "ethernet-history"
                self._children_yang_names.add("ethernet-history")

                self.ho_vc_history = PerformanceManagementHistory.Global_.Periodic.HoVcHistory()
                self.ho_vc_history.parent = self
                self._children_name_map["ho_vc_history"] = "ho-vc-history"
                self._children_yang_names.add("ho-vc-history")

                self.oc_history = PerformanceManagementHistory.Global_.Periodic.OcHistory()
                self.oc_history.parent = self
                self._children_name_map["oc_history"] = "oc-history"
                self._children_yang_names.add("oc-history")

                self.odu_history = PerformanceManagementHistory.Global_.Periodic.OduHistory()
                self.odu_history.parent = self
                self._children_name_map["odu_history"] = "odu-history"
                self._children_yang_names.add("odu-history")

                self.optics_history = PerformanceManagementHistory.Global_.Periodic.OpticsHistory()
                self.optics_history.parent = self
                self._children_name_map["optics_history"] = "optics-history"
                self._children_yang_names.add("optics-history")

                self.otu_history = PerformanceManagementHistory.Global_.Periodic.OtuHistory()
                self.otu_history.parent = self
                self._children_name_map["otu_history"] = "otu-history"
                self._children_yang_names.add("otu-history")

                self.sonet_history = PerformanceManagementHistory.Global_.Periodic.SonetHistory()
                self.sonet_history.parent = self
                self._children_name_map["sonet_history"] = "sonet-history"
                self._children_yang_names.add("sonet-history")

                self.stm_history = PerformanceManagementHistory.Global_.Periodic.StmHistory()
                self.stm_history.parent = self
                self._children_name_map["stm_history"] = "stm-history"
                self._children_yang_names.add("stm-history")

                self.sts_history = PerformanceManagementHistory.Global_.Periodic.StsHistory()
                self.sts_history.parent = self
                self._children_name_map["sts_history"] = "sts-history"
                self._children_yang_names.add("sts-history")


            class SonetHistory(Entity):
                """
                SONET controller History performance data
                
                .. attribute:: sonet_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`SonetPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory, self).__init__()

                    self.yang_name = "sonet-history"
                    self.yang_parent_name = "periodic"

                    self.sonet_port_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories()
                    self.sonet_port_histories.parent = self
                    self._children_name_map["sonet_port_histories"] = "sonet-port-histories"
                    self._children_yang_names.add("sonet-port-histories")


                class SonetPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: sonet_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`SonetPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories, self).__init__()

                        self.yang_name = "sonet-port-histories"
                        self.yang_parent_name = "sonet-history"

                        self.sonet_port_history = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories, self).__setattr__(name, value)


                    class SonetPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: sonet_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`SonetHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History>`
                        
                        .. attribute:: sonet_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`SonetMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory, self).__init__()

                            self.yang_name = "sonet-port-history"
                            self.yang_parent_name = "sonet-port-histories"

                            self.name = YLeaf(YType.str, "name")

                            self.sonet_hour24_history = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History()
                            self.sonet_hour24_history.parent = self
                            self._children_name_map["sonet_hour24_history"] = "sonet-hour24-history"
                            self._children_yang_names.add("sonet-hour24-history")

                            self.sonet_minute15_history = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History()
                            self.sonet_minute15_history.parent = self
                            self._children_name_map["sonet_minute15_history"] = "sonet-minute15-history"
                            self._children_yang_names.add("sonet-minute15-history")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory, self).__setattr__(name, value)


                        class SonetMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_minute15_path_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`SonetMinute15PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories>`
                            
                            .. attribute:: sonet_minute15ocn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`SonetMinute15OcnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History, self).__init__()

                                self.yang_name = "sonet-minute15-history"
                                self.yang_parent_name = "sonet-port-history"

                                self.sonet_minute15_path_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories()
                                self.sonet_minute15_path_histories.parent = self
                                self._children_name_map["sonet_minute15_path_histories"] = "sonet-minute15-path-histories"
                                self._children_yang_names.add("sonet-minute15-path-histories")

                                self.sonet_minute15ocn_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories()
                                self.sonet_minute15ocn_histories.parent = self
                                self._children_name_map["sonet_minute15ocn_histories"] = "sonet-minute15ocn-histories"
                                self._children_yang_names.add("sonet-minute15ocn-histories")


                            class SonetMinute15OcnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: sonet_minute15ocn_history
                                
                                	port 15\-minute ocn performance data
                                	**type**\: list of    :py:class:`SonetMinute15OcnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories, self).__init__()

                                    self.yang_name = "sonet-minute15ocn-histories"
                                    self.yang_parent_name = "sonet-minute15-history"

                                    self.sonet_minute15ocn_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories, self).__setattr__(name, value)


                                class SonetMinute15OcnHistory(Entity):
                                    """
                                    port 15\-minute ocn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sonet_minute15ocn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`SonetMinute15OcnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory, self).__init__()

                                        self.yang_name = "sonet-minute15ocn-history"
                                        self.yang_parent_name = "sonet-minute15ocn-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.sonet_minute15ocn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances()
                                        self.sonet_minute15ocn_time_line_instances.parent = self
                                        self._children_name_map["sonet_minute15ocn_time_line_instances"] = "sonet-minute15ocn-time-line-instances"
                                        self._children_yang_names.add("sonet-minute15ocn-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory, self).__setattr__(name, value)


                                    class SonetMinute15OcnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sonet_minute15ocn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`SonetMinute15OcnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances, self).__init__()

                                            self.yang_name = "sonet-minute15ocn-time-line-instances"
                                            self.yang_parent_name = "sonet-minute15ocn-history"

                                            self.sonet_minute15ocn_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances, self).__setattr__(name, value)


                                        class SonetMinute15OcnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line>`
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance, self).__init__()

                                                self.yang_name = "sonet-minute15ocn-time-line-instance"
                                                self.yang_parent_name = "sonet-minute15ocn-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.fe_line = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self._children_name_map["fe_line"] = "fe-line"
                                                self._children_yang_names.add("fe-line")

                                                self.line = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line()
                                                self.line.parent = self
                                                self._children_name_map["line"] = "line"
                                                self._children_yang_names.add("line")

                                                self.section = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section()
                                                self.section.parent = self
                                                self._children_name_map["section"] = "section"
                                                self._children_yang_names.add("section")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance, self).__setattr__(name, value)


                                            class Section(Entity):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionCVs>`
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_sef_ss
                                                
                                                	The number of Severely Errored Framing Seconds
                                                	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSefSs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section, self).__init__()

                                                    self.yang_name = "section"
                                                    self.yang_parent_name = "sonet-minute15ocn-time-line-instance"

                                                    self.section_status = YLeaf(YType.int32, "section-status")

                                                    self.section_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionCVs()
                                                    self.section_c_vs.parent = self
                                                    self._children_name_map["section_c_vs"] = "section-c-vs"
                                                    self._children_yang_names.add("section-c-vs")

                                                    self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self._children_name_map["section_e_ss"] = "section-e-ss"
                                                    self._children_yang_names.add("section-e-ss")

                                                    self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self._children_name_map["section_se_ss"] = "section-se-ss"
                                                    self._children_yang_names.add("section-se-ss")

                                                    self.section_sef_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSefSs()
                                                    self.section_sef_ss.parent = self
                                                    self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                                    self._children_yang_names.add("section-sef-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("section_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section, self).__setattr__(name, value)


                                                class SectionESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionESs, self).__init__()

                                                        self.yang_name = "section-e-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSeSs, self).__init__()

                                                        self.yang_name = "section-se-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionSefSs(Entity):
                                                    """
                                                    The number of Severely Errored Framing Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSefSs, self).__init__()

                                                        self.yang_name = "section-sef-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSefSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSefSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-sef-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionCVs, self).__init__()

                                                        self.yang_name = "section-c-vs"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.section_status.is_set or
                                                        (self.section_c_vs is not None and self.section_c_vs.has_data()) or
                                                        (self.section_e_ss is not None and self.section_e_ss.has_data()) or
                                                        (self.section_se_ss is not None and self.section_se_ss.has_data()) or
                                                        (self.section_sef_ss is not None and self.section_sef_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.section_status.yfilter != YFilter.not_set or
                                                        (self.section_c_vs is not None and self.section_c_vs.has_operation()) or
                                                        (self.section_e_ss is not None and self.section_e_ss.has_operation()) or
                                                        (self.section_se_ss is not None and self.section_se_ss.has_operation()) or
                                                        (self.section_sef_ss is not None and self.section_sef_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "section" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.section_status.is_set or self.section_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.section_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "section-c-vs"):
                                                        if (self.section_c_vs is None):
                                                            self.section_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionCVs()
                                                            self.section_c_vs.parent = self
                                                            self._children_name_map["section_c_vs"] = "section-c-vs"
                                                        return self.section_c_vs

                                                    if (child_yang_name == "section-e-ss"):
                                                        if (self.section_e_ss is None):
                                                            self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionESs()
                                                            self.section_e_ss.parent = self
                                                            self._children_name_map["section_e_ss"] = "section-e-ss"
                                                        return self.section_e_ss

                                                    if (child_yang_name == "section-se-ss"):
                                                        if (self.section_se_ss is None):
                                                            self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSeSs()
                                                            self.section_se_ss.parent = self
                                                            self._children_name_map["section_se_ss"] = "section-se-ss"
                                                        return self.section_se_ss

                                                    if (child_yang_name == "section-sef-ss"):
                                                        if (self.section_sef_ss is None):
                                                            self.section_sef_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section.SectionSefSs()
                                                            self.section_sef_ss.parent = self
                                                            self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                                        return self.section_sef_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "section-c-vs" or name == "section-e-ss" or name == "section-se-ss" or name == "section-sef-ss" or name == "section-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "section-status"):
                                                        self.section_status = value
                                                        self.section_status.value_namespace = name_space
                                                        self.section_status.value_namespace_prefix = name_space_prefix


                                            class Line(Entity):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineCVs>`
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineFcLs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line, self).__init__()

                                                    self.yang_name = "line"
                                                    self.yang_parent_name = "sonet-minute15ocn-time-line-instance"

                                                    self.line_status = YLeaf(YType.int32, "line-status")

                                                    self.line_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineCVs()
                                                    self.line_c_vs.parent = self
                                                    self._children_name_map["line_c_vs"] = "line-c-vs"
                                                    self._children_yang_names.add("line-c-vs")

                                                    self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self._children_name_map["line_e_ss"] = "line-e-ss"
                                                    self._children_yang_names.add("line-e-ss")

                                                    self.line_fc_ls = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineFcLs()
                                                    self.line_fc_ls.parent = self
                                                    self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                                    self._children_yang_names.add("line-fc-ls")

                                                    self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self._children_name_map["line_se_ss"] = "line-se-ss"
                                                    self._children_yang_names.add("line-se-ss")

                                                    self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self
                                                    self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                                    self._children_yang_names.add("line-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("line_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line, self).__setattr__(name, value)


                                                class LineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineESs, self).__init__()

                                                        self.yang_name = "line-e-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineSeSs, self).__init__()

                                                        self.yang_name = "line-se-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineCVs, self).__init__()

                                                        self.yang_name = "line-c-vs"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineUaSs, self).__init__()

                                                        self.yang_name = "line-ua-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineFcLs, self).__init__()

                                                        self.yang_name = "line-fc-ls"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineFcLs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineFcLs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-fc-ls" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.line_status.is_set or
                                                        (self.line_c_vs is not None and self.line_c_vs.has_data()) or
                                                        (self.line_e_ss is not None and self.line_e_ss.has_data()) or
                                                        (self.line_fc_ls is not None and self.line_fc_ls.has_data()) or
                                                        (self.line_se_ss is not None and self.line_se_ss.has_data()) or
                                                        (self.line_ua_ss is not None and self.line_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.line_status.yfilter != YFilter.not_set or
                                                        (self.line_c_vs is not None and self.line_c_vs.has_operation()) or
                                                        (self.line_e_ss is not None and self.line_e_ss.has_operation()) or
                                                        (self.line_fc_ls is not None and self.line_fc_ls.has_operation()) or
                                                        (self.line_se_ss is not None and self.line_se_ss.has_operation()) or
                                                        (self.line_ua_ss is not None and self.line_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "line" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.line_status.is_set or self.line_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.line_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "line-c-vs"):
                                                        if (self.line_c_vs is None):
                                                            self.line_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineCVs()
                                                            self.line_c_vs.parent = self
                                                            self._children_name_map["line_c_vs"] = "line-c-vs"
                                                        return self.line_c_vs

                                                    if (child_yang_name == "line-e-ss"):
                                                        if (self.line_e_ss is None):
                                                            self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineESs()
                                                            self.line_e_ss.parent = self
                                                            self._children_name_map["line_e_ss"] = "line-e-ss"
                                                        return self.line_e_ss

                                                    if (child_yang_name == "line-fc-ls"):
                                                        if (self.line_fc_ls is None):
                                                            self.line_fc_ls = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineFcLs()
                                                            self.line_fc_ls.parent = self
                                                            self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                                        return self.line_fc_ls

                                                    if (child_yang_name == "line-se-ss"):
                                                        if (self.line_se_ss is None):
                                                            self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineSeSs()
                                                            self.line_se_ss.parent = self
                                                            self._children_name_map["line_se_ss"] = "line-se-ss"
                                                        return self.line_se_ss

                                                    if (child_yang_name == "line-ua-ss"):
                                                        if (self.line_ua_ss is None):
                                                            self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line.LineUaSs()
                                                            self.line_ua_ss.parent = self
                                                            self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                                        return self.line_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "line-c-vs" or name == "line-e-ss" or name == "line-fc-ls" or name == "line-se-ss" or name == "line-ua-ss" or name == "line-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "line-status"):
                                                        self.line_status = value
                                                        self.line_status.value_namespace = name_space
                                                        self.line_status.value_namespace_prefix = name_space_prefix


                                            class FeLine(Entity):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs>`
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine, self).__init__()

                                                    self.yang_name = "fe-line"
                                                    self.yang_parent_name = "sonet-minute15ocn-time-line-instance"

                                                    self.far_end_line_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs()
                                                    self.far_end_line_c_vs.parent = self
                                                    self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                                    self._children_yang_names.add("far-end-line-c-vs")

                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                                    self._children_yang_names.add("far-end-line-e-ss")

                                                    self.far_end_line_fc_ls = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                    self.far_end_line_fc_ls.parent = self
                                                    self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                                    self._children_yang_names.add("far-end-line-fc-ls")

                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                                    self._children_yang_names.add("far-end-line-se-ss")

                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self
                                                    self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                                    self._children_yang_names.add("far-end-line-ua-ss")


                                                class FarEndLineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineESs, self).__init__()

                                                        self.yang_name = "far-end-line-e-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs, self).__init__()

                                                        self.yang_name = "far-end-line-se-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs, self).__init__()

                                                        self.yang_name = "far-end-line-c-vs"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs, self).__init__()

                                                        self.yang_name = "far-end-line-ua-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs, self).__init__()

                                                        self.yang_name = "far-end-line-fc-ls"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-fc-ls" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_data()) or
                                                        (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_data()) or
                                                        (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_data()) or
                                                        (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_data()) or
                                                        (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_operation()) or
                                                        (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_operation()) or
                                                        (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_operation()) or
                                                        (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_operation()) or
                                                        (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fe-line" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "far-end-line-c-vs"):
                                                        if (self.far_end_line_c_vs is None):
                                                            self.far_end_line_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs()
                                                            self.far_end_line_c_vs.parent = self
                                                            self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                                        return self.far_end_line_c_vs

                                                    if (child_yang_name == "far-end-line-e-ss"):
                                                        if (self.far_end_line_e_ss is None):
                                                            self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineESs()
                                                            self.far_end_line_e_ss.parent = self
                                                            self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                                        return self.far_end_line_e_ss

                                                    if (child_yang_name == "far-end-line-fc-ls"):
                                                        if (self.far_end_line_fc_ls is None):
                                                            self.far_end_line_fc_ls = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                            self.far_end_line_fc_ls.parent = self
                                                            self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                                        return self.far_end_line_fc_ls

                                                    if (child_yang_name == "far-end-line-se-ss"):
                                                        if (self.far_end_line_se_ss is None):
                                                            self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                            self.far_end_line_se_ss.parent = self
                                                            self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                                        return self.far_end_line_se_ss

                                                    if (child_yang_name == "far-end-line-ua-ss"):
                                                        if (self.far_end_line_ua_ss is None):
                                                            self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                            self.far_end_line_ua_ss.parent = self
                                                            self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                                        return self.far_end_line_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "far-end-line-c-vs" or name == "far-end-line-e-ss" or name == "far-end-line-fc-ls" or name == "far-end-line-se-ss" or name == "far-end-line-ua-ss"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.fe_line is not None and self.fe_line.has_data()) or
                                                    (self.line is not None and self.line.has_data()) or
                                                    (self.section is not None and self.section.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.fe_line is not None and self.fe_line.has_operation()) or
                                                    (self.line is not None and self.line.has_operation()) or
                                                    (self.section is not None and self.section.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sonet-minute15ocn-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "fe-line"):
                                                    if (self.fe_line is None):
                                                        self.fe_line = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.FeLine()
                                                        self.fe_line.parent = self
                                                        self._children_name_map["fe_line"] = "fe-line"
                                                    return self.fe_line

                                                if (child_yang_name == "line"):
                                                    if (self.line is None):
                                                        self.line = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Line()
                                                        self.line.parent = self
                                                        self._children_name_map["line"] = "line"
                                                    return self.line

                                                if (child_yang_name == "section"):
                                                    if (self.section is None):
                                                        self.section = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance.Section()
                                                        self.section.parent = self
                                                        self._children_name_map["section"] = "section"
                                                    return self.section

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "fe-line" or name == "line" or name == "section" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.sonet_minute15ocn_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.sonet_minute15ocn_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sonet-minute15ocn-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "sonet-minute15ocn-time-line-instance"):
                                                for c in self.sonet_minute15ocn_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances.SonetMinute15OcnTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.sonet_minute15ocn_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "sonet-minute15ocn-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.sonet_minute15ocn_time_line_instances is not None and self.sonet_minute15ocn_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.sonet_minute15ocn_time_line_instances is not None and self.sonet_minute15ocn_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sonet-minute15ocn-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sonet-minute15ocn-time-line-instances"):
                                            if (self.sonet_minute15ocn_time_line_instances is None):
                                                self.sonet_minute15ocn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory.SonetMinute15OcnTimeLineInstances()
                                                self.sonet_minute15ocn_time_line_instances.parent = self
                                                self._children_name_map["sonet_minute15ocn_time_line_instances"] = "sonet-minute15ocn-time-line-instances"
                                            return self.sonet_minute15ocn_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sonet-minute15ocn-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.sonet_minute15ocn_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.sonet_minute15ocn_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sonet-minute15ocn-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sonet-minute15ocn-history"):
                                        for c in self.sonet_minute15ocn_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories.SonetMinute15OcnHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.sonet_minute15ocn_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sonet-minute15ocn-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SonetMinute15PathHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: sonet_minute15_path_history
                                
                                	port 15\-minute Path performance data
                                	**type**\: list of    :py:class:`SonetMinute15PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories, self).__init__()

                                    self.yang_name = "sonet-minute15-path-histories"
                                    self.yang_parent_name = "sonet-minute15-history"

                                    self.sonet_minute15_path_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories, self).__setattr__(name, value)


                                class SonetMinute15PathHistory(Entity):
                                    """
                                    port 15\-minute Path performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sonet_minute15_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`SonetMinute15PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory, self).__init__()

                                        self.yang_name = "sonet-minute15-path-history"
                                        self.yang_parent_name = "sonet-minute15-path-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.sonet_minute15_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances()
                                        self.sonet_minute15_path_time_line_instances.parent = self
                                        self._children_name_map["sonet_minute15_path_time_line_instances"] = "sonet-minute15-path-time-line-instances"
                                        self._children_yang_names.add("sonet-minute15-path-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory, self).__setattr__(name, value)


                                    class SonetMinute15PathTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sonet_minute15_path_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`SonetMinute15PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances, self).__init__()

                                            self.yang_name = "sonet-minute15-path-time-line-instances"
                                            self.yang_parent_name = "sonet-minute15-path-history"

                                            self.sonet_minute15_path_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances, self).__setattr__(name, value)


                                        class SonetMinute15PathTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance, self).__init__()

                                                self.yang_name = "sonet-minute15-path-time-line-instance"
                                                self.yang_parent_name = "sonet-minute15-path-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.fe_path = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self._children_name_map["fe_path"] = "fe-path"
                                                self._children_yang_names.add("fe-path")

                                                self.path = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self._children_name_map["path"] = "path"
                                                self._children_yang_names.add("path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance, self).__setattr__(name, value)


                                            class Path(Entity):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs>`
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_width
                                                
                                                	Indicates the type of the SONET/SDH Path
                                                	**type**\:   :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path, self).__init__()

                                                    self.yang_name = "path"
                                                    self.yang_parent_name = "sonet-minute15-path-time-line-instance"

                                                    self.path_status = YLeaf(YType.int32, "path-status")

                                                    self.path_width = YLeaf(YType.enumeration, "path-width")

                                                    self.path_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs()
                                                    self.path_c_vs.parent = self
                                                    self._children_name_map["path_c_vs"] = "path-c-vs"
                                                    self._children_yang_names.add("path-c-vs")

                                                    self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self._children_name_map["path_e_ss"] = "path-e-ss"
                                                    self._children_yang_names.add("path-e-ss")

                                                    self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self._children_name_map["path_se_ss"] = "path-se-ss"
                                                    self._children_yang_names.add("path-se-ss")

                                                    self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                    self._children_yang_names.add("path-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("path_status",
                                                                    "path_width") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path, self).__setattr__(name, value)


                                                class PathESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs, self).__init__()

                                                        self.yang_name = "path-e-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs, self).__init__()

                                                        self.yang_name = "path-se-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs, self).__init__()

                                                        self.yang_name = "path-c-vs"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs, self).__init__()

                                                        self.yang_name = "path-ua-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.path_status.is_set or
                                                        self.path_width.is_set or
                                                        (self.path_c_vs is not None and self.path_c_vs.has_data()) or
                                                        (self.path_e_ss is not None and self.path_e_ss.has_data()) or
                                                        (self.path_se_ss is not None and self.path_se_ss.has_data()) or
                                                        (self.path_ua_ss is not None and self.path_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.path_status.yfilter != YFilter.not_set or
                                                        self.path_width.yfilter != YFilter.not_set or
                                                        (self.path_c_vs is not None and self.path_c_vs.has_operation()) or
                                                        (self.path_e_ss is not None and self.path_e_ss.has_operation()) or
                                                        (self.path_se_ss is not None and self.path_se_ss.has_operation()) or
                                                        (self.path_ua_ss is not None and self.path_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.path_status.get_name_leafdata())
                                                    if (self.path_width.is_set or self.path_width.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.path_width.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "path-c-vs"):
                                                        if (self.path_c_vs is None):
                                                            self.path_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathCVs()
                                                            self.path_c_vs.parent = self
                                                            self._children_name_map["path_c_vs"] = "path-c-vs"
                                                        return self.path_c_vs

                                                    if (child_yang_name == "path-e-ss"):
                                                        if (self.path_e_ss is None):
                                                            self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathESs()
                                                            self.path_e_ss.parent = self
                                                            self._children_name_map["path_e_ss"] = "path-e-ss"
                                                        return self.path_e_ss

                                                    if (child_yang_name == "path-se-ss"):
                                                        if (self.path_se_ss is None):
                                                            self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathSeSs()
                                                            self.path_se_ss.parent = self
                                                            self._children_name_map["path_se_ss"] = "path-se-ss"
                                                        return self.path_se_ss

                                                    if (child_yang_name == "path-ua-ss"):
                                                        if (self.path_ua_ss is None):
                                                            self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path.PathUaSs()
                                                            self.path_ua_ss.parent = self
                                                            self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                        return self.path_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "path-c-vs" or name == "path-e-ss" or name == "path-se-ss" or name == "path-ua-ss" or name == "path-status" or name == "path-width"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "path-status"):
                                                        self.path_status = value
                                                        self.path_status.value_namespace = name_space
                                                        self.path_status.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "path-width"):
                                                        self.path_width = value
                                                        self.path_width.value_namespace = name_space
                                                        self.path_width.value_namespace_prefix = name_space_prefix


                                            class FePath(Entity):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath, self).__init__()

                                                    self.yang_name = "fe-path"
                                                    self.yang_parent_name = "sonet-minute15-path-time-line-instance"

                                                    self.far_end_path_c_vs = YLeaf(YType.uint32, "far-end-path-c-vs")

                                                    self.far_end_path_e_ss = YLeaf(YType.uint32, "far-end-path-e-ss")

                                                    self.far_end_path_se_ss = YLeaf(YType.uint32, "far-end-path-se-ss")

                                                    self.far_end_path_ua_ss = YLeaf(YType.uint32, "far-end-path-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("far_end_path_c_vs",
                                                                    "far_end_path_e_ss",
                                                                    "far_end_path_se_ss",
                                                                    "far_end_path_ua_ss") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.far_end_path_c_vs.is_set or
                                                        self.far_end_path_e_ss.is_set or
                                                        self.far_end_path_se_ss.is_set or
                                                        self.far_end_path_ua_ss.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.far_end_path_c_vs.yfilter != YFilter.not_set or
                                                        self.far_end_path_e_ss.yfilter != YFilter.not_set or
                                                        self.far_end_path_se_ss.yfilter != YFilter.not_set or
                                                        self.far_end_path_ua_ss.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fe-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.far_end_path_c_vs.is_set or self.far_end_path_c_vs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_c_vs.get_name_leafdata())
                                                    if (self.far_end_path_e_ss.is_set or self.far_end_path_e_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_e_ss.get_name_leafdata())
                                                    if (self.far_end_path_se_ss.is_set or self.far_end_path_se_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_se_ss.get_name_leafdata())
                                                    if (self.far_end_path_ua_ss.is_set or self.far_end_path_ua_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_ua_ss.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "far-end-path-c-vs" or name == "far-end-path-e-ss" or name == "far-end-path-se-ss" or name == "far-end-path-ua-ss"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "far-end-path-c-vs"):
                                                        self.far_end_path_c_vs = value
                                                        self.far_end_path_c_vs.value_namespace = name_space
                                                        self.far_end_path_c_vs.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-e-ss"):
                                                        self.far_end_path_e_ss = value
                                                        self.far_end_path_e_ss.value_namespace = name_space
                                                        self.far_end_path_e_ss.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-se-ss"):
                                                        self.far_end_path_se_ss = value
                                                        self.far_end_path_se_ss.value_namespace = name_space
                                                        self.far_end_path_se_ss.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-ua-ss"):
                                                        self.far_end_path_ua_ss = value
                                                        self.far_end_path_ua_ss.value_namespace = name_space
                                                        self.far_end_path_ua_ss.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.fe_path is not None and self.fe_path.has_data()) or
                                                    (self.path is not None and self.path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.fe_path is not None and self.fe_path.has_operation()) or
                                                    (self.path is not None and self.path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sonet-minute15-path-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "fe-path"):
                                                    if (self.fe_path is None):
                                                        self.fe_path = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.FePath()
                                                        self.fe_path.parent = self
                                                        self._children_name_map["fe_path"] = "fe-path"
                                                    return self.fe_path

                                                if (child_yang_name == "path"):
                                                    if (self.path is None):
                                                        self.path = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance.Path()
                                                        self.path.parent = self
                                                        self._children_name_map["path"] = "path"
                                                    return self.path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "fe-path" or name == "path" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.sonet_minute15_path_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.sonet_minute15_path_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sonet-minute15-path-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "sonet-minute15-path-time-line-instance"):
                                                for c in self.sonet_minute15_path_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances.SonetMinute15PathTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.sonet_minute15_path_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "sonet-minute15-path-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.sonet_minute15_path_time_line_instances is not None and self.sonet_minute15_path_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.sonet_minute15_path_time_line_instances is not None and self.sonet_minute15_path_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sonet-minute15-path-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sonet-minute15-path-time-line-instances"):
                                            if (self.sonet_minute15_path_time_line_instances is None):
                                                self.sonet_minute15_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory.SonetMinute15PathTimeLineInstances()
                                                self.sonet_minute15_path_time_line_instances.parent = self
                                                self._children_name_map["sonet_minute15_path_time_line_instances"] = "sonet-minute15-path-time-line-instances"
                                            return self.sonet_minute15_path_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sonet-minute15-path-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.sonet_minute15_path_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.sonet_minute15_path_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sonet-minute15-path-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sonet-minute15-path-history"):
                                        for c in self.sonet_minute15_path_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories.SonetMinute15PathHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.sonet_minute15_path_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sonet-minute15-path-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    (self.sonet_minute15_path_histories is not None and self.sonet_minute15_path_histories.has_data()) or
                                    (self.sonet_minute15ocn_histories is not None and self.sonet_minute15ocn_histories.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.sonet_minute15_path_histories is not None and self.sonet_minute15_path_histories.has_operation()) or
                                    (self.sonet_minute15ocn_histories is not None and self.sonet_minute15ocn_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-minute15-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sonet-minute15-path-histories"):
                                    if (self.sonet_minute15_path_histories is None):
                                        self.sonet_minute15_path_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15PathHistories()
                                        self.sonet_minute15_path_histories.parent = self
                                        self._children_name_map["sonet_minute15_path_histories"] = "sonet-minute15-path-histories"
                                    return self.sonet_minute15_path_histories

                                if (child_yang_name == "sonet-minute15ocn-histories"):
                                    if (self.sonet_minute15ocn_histories is None):
                                        self.sonet_minute15ocn_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History.SonetMinute15OcnHistories()
                                        self.sonet_minute15ocn_histories.parent = self
                                        self._children_name_map["sonet_minute15ocn_histories"] = "sonet-minute15ocn-histories"
                                    return self.sonet_minute15ocn_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sonet-minute15-path-histories" or name == "sonet-minute15ocn-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class SonetHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sonet_hour24_path_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`SonetHour24PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories>`
                            
                            .. attribute:: sonet_hour24ocn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`SonetHour24OcnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History, self).__init__()

                                self.yang_name = "sonet-hour24-history"
                                self.yang_parent_name = "sonet-port-history"

                                self.sonet_hour24_path_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories()
                                self.sonet_hour24_path_histories.parent = self
                                self._children_name_map["sonet_hour24_path_histories"] = "sonet-hour24-path-histories"
                                self._children_yang_names.add("sonet-hour24-path-histories")

                                self.sonet_hour24ocn_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories()
                                self.sonet_hour24ocn_histories.parent = self
                                self._children_name_map["sonet_hour24ocn_histories"] = "sonet-hour24ocn-histories"
                                self._children_yang_names.add("sonet-hour24ocn-histories")


                            class SonetHour24PathHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: sonet_hour24_path_history
                                
                                	port 24 hour Path performance data
                                	**type**\: list of    :py:class:`SonetHour24PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories, self).__init__()

                                    self.yang_name = "sonet-hour24-path-histories"
                                    self.yang_parent_name = "sonet-hour24-history"

                                    self.sonet_hour24_path_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories, self).__setattr__(name, value)


                                class SonetHour24PathHistory(Entity):
                                    """
                                    port 24 hour Path performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sonet_hour24_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`SonetHour24PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory, self).__init__()

                                        self.yang_name = "sonet-hour24-path-history"
                                        self.yang_parent_name = "sonet-hour24-path-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.sonet_hour24_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances()
                                        self.sonet_hour24_path_time_line_instances.parent = self
                                        self._children_name_map["sonet_hour24_path_time_line_instances"] = "sonet-hour24-path-time-line-instances"
                                        self._children_yang_names.add("sonet-hour24-path-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory, self).__setattr__(name, value)


                                    class SonetHour24PathTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sonet_hour24_path_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`SonetHour24PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances, self).__init__()

                                            self.yang_name = "sonet-hour24-path-time-line-instances"
                                            self.yang_parent_name = "sonet-hour24-path-history"

                                            self.sonet_hour24_path_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances, self).__setattr__(name, value)


                                        class SonetHour24PathTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance, self).__init__()

                                                self.yang_name = "sonet-hour24-path-time-line-instance"
                                                self.yang_parent_name = "sonet-hour24-path-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.fe_path = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self._children_name_map["fe_path"] = "fe-path"
                                                self._children_yang_names.add("fe-path")

                                                self.path = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self._children_name_map["path"] = "path"
                                                self._children_yang_names.add("path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance, self).__setattr__(name, value)


                                            class Path(Entity):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs>`
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_width
                                                
                                                	Indicates the type of the SONET/SDH Path
                                                	**type**\:   :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path, self).__init__()

                                                    self.yang_name = "path"
                                                    self.yang_parent_name = "sonet-hour24-path-time-line-instance"

                                                    self.path_status = YLeaf(YType.int32, "path-status")

                                                    self.path_width = YLeaf(YType.enumeration, "path-width")

                                                    self.path_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs()
                                                    self.path_c_vs.parent = self
                                                    self._children_name_map["path_c_vs"] = "path-c-vs"
                                                    self._children_yang_names.add("path-c-vs")

                                                    self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self._children_name_map["path_e_ss"] = "path-e-ss"
                                                    self._children_yang_names.add("path-e-ss")

                                                    self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self._children_name_map["path_se_ss"] = "path-se-ss"
                                                    self._children_yang_names.add("path-se-ss")

                                                    self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                    self._children_yang_names.add("path-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("path_status",
                                                                    "path_width") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path, self).__setattr__(name, value)


                                                class PathESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs, self).__init__()

                                                        self.yang_name = "path-e-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs, self).__init__()

                                                        self.yang_name = "path-se-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs, self).__init__()

                                                        self.yang_name = "path-c-vs"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs, self).__init__()

                                                        self.yang_name = "path-ua-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.path_status.is_set or
                                                        self.path_width.is_set or
                                                        (self.path_c_vs is not None and self.path_c_vs.has_data()) or
                                                        (self.path_e_ss is not None and self.path_e_ss.has_data()) or
                                                        (self.path_se_ss is not None and self.path_se_ss.has_data()) or
                                                        (self.path_ua_ss is not None and self.path_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.path_status.yfilter != YFilter.not_set or
                                                        self.path_width.yfilter != YFilter.not_set or
                                                        (self.path_c_vs is not None and self.path_c_vs.has_operation()) or
                                                        (self.path_e_ss is not None and self.path_e_ss.has_operation()) or
                                                        (self.path_se_ss is not None and self.path_se_ss.has_operation()) or
                                                        (self.path_ua_ss is not None and self.path_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.path_status.get_name_leafdata())
                                                    if (self.path_width.is_set or self.path_width.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.path_width.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "path-c-vs"):
                                                        if (self.path_c_vs is None):
                                                            self.path_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathCVs()
                                                            self.path_c_vs.parent = self
                                                            self._children_name_map["path_c_vs"] = "path-c-vs"
                                                        return self.path_c_vs

                                                    if (child_yang_name == "path-e-ss"):
                                                        if (self.path_e_ss is None):
                                                            self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathESs()
                                                            self.path_e_ss.parent = self
                                                            self._children_name_map["path_e_ss"] = "path-e-ss"
                                                        return self.path_e_ss

                                                    if (child_yang_name == "path-se-ss"):
                                                        if (self.path_se_ss is None):
                                                            self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathSeSs()
                                                            self.path_se_ss.parent = self
                                                            self._children_name_map["path_se_ss"] = "path-se-ss"
                                                        return self.path_se_ss

                                                    if (child_yang_name == "path-ua-ss"):
                                                        if (self.path_ua_ss is None):
                                                            self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path.PathUaSs()
                                                            self.path_ua_ss.parent = self
                                                            self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                        return self.path_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "path-c-vs" or name == "path-e-ss" or name == "path-se-ss" or name == "path-ua-ss" or name == "path-status" or name == "path-width"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "path-status"):
                                                        self.path_status = value
                                                        self.path_status.value_namespace = name_space
                                                        self.path_status.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "path-width"):
                                                        self.path_width = value
                                                        self.path_width.value_namespace = name_space
                                                        self.path_width.value_namespace_prefix = name_space_prefix


                                            class FePath(Entity):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath, self).__init__()

                                                    self.yang_name = "fe-path"
                                                    self.yang_parent_name = "sonet-hour24-path-time-line-instance"

                                                    self.far_end_path_c_vs = YLeaf(YType.uint32, "far-end-path-c-vs")

                                                    self.far_end_path_e_ss = YLeaf(YType.uint32, "far-end-path-e-ss")

                                                    self.far_end_path_se_ss = YLeaf(YType.uint32, "far-end-path-se-ss")

                                                    self.far_end_path_ua_ss = YLeaf(YType.uint32, "far-end-path-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("far_end_path_c_vs",
                                                                    "far_end_path_e_ss",
                                                                    "far_end_path_se_ss",
                                                                    "far_end_path_ua_ss") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.far_end_path_c_vs.is_set or
                                                        self.far_end_path_e_ss.is_set or
                                                        self.far_end_path_se_ss.is_set or
                                                        self.far_end_path_ua_ss.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.far_end_path_c_vs.yfilter != YFilter.not_set or
                                                        self.far_end_path_e_ss.yfilter != YFilter.not_set or
                                                        self.far_end_path_se_ss.yfilter != YFilter.not_set or
                                                        self.far_end_path_ua_ss.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fe-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.far_end_path_c_vs.is_set or self.far_end_path_c_vs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_c_vs.get_name_leafdata())
                                                    if (self.far_end_path_e_ss.is_set or self.far_end_path_e_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_e_ss.get_name_leafdata())
                                                    if (self.far_end_path_se_ss.is_set or self.far_end_path_se_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_se_ss.get_name_leafdata())
                                                    if (self.far_end_path_ua_ss.is_set or self.far_end_path_ua_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_ua_ss.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "far-end-path-c-vs" or name == "far-end-path-e-ss" or name == "far-end-path-se-ss" or name == "far-end-path-ua-ss"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "far-end-path-c-vs"):
                                                        self.far_end_path_c_vs = value
                                                        self.far_end_path_c_vs.value_namespace = name_space
                                                        self.far_end_path_c_vs.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-e-ss"):
                                                        self.far_end_path_e_ss = value
                                                        self.far_end_path_e_ss.value_namespace = name_space
                                                        self.far_end_path_e_ss.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-se-ss"):
                                                        self.far_end_path_se_ss = value
                                                        self.far_end_path_se_ss.value_namespace = name_space
                                                        self.far_end_path_se_ss.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-ua-ss"):
                                                        self.far_end_path_ua_ss = value
                                                        self.far_end_path_ua_ss.value_namespace = name_space
                                                        self.far_end_path_ua_ss.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.fe_path is not None and self.fe_path.has_data()) or
                                                    (self.path is not None and self.path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.fe_path is not None and self.fe_path.has_operation()) or
                                                    (self.path is not None and self.path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sonet-hour24-path-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "fe-path"):
                                                    if (self.fe_path is None):
                                                        self.fe_path = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.FePath()
                                                        self.fe_path.parent = self
                                                        self._children_name_map["fe_path"] = "fe-path"
                                                    return self.fe_path

                                                if (child_yang_name == "path"):
                                                    if (self.path is None):
                                                        self.path = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance.Path()
                                                        self.path.parent = self
                                                        self._children_name_map["path"] = "path"
                                                    return self.path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "fe-path" or name == "path" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.sonet_hour24_path_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.sonet_hour24_path_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sonet-hour24-path-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "sonet-hour24-path-time-line-instance"):
                                                for c in self.sonet_hour24_path_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances.SonetHour24PathTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.sonet_hour24_path_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "sonet-hour24-path-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.sonet_hour24_path_time_line_instances is not None and self.sonet_hour24_path_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.sonet_hour24_path_time_line_instances is not None and self.sonet_hour24_path_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sonet-hour24-path-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sonet-hour24-path-time-line-instances"):
                                            if (self.sonet_hour24_path_time_line_instances is None):
                                                self.sonet_hour24_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory.SonetHour24PathTimeLineInstances()
                                                self.sonet_hour24_path_time_line_instances.parent = self
                                                self._children_name_map["sonet_hour24_path_time_line_instances"] = "sonet-hour24-path-time-line-instances"
                                            return self.sonet_hour24_path_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sonet-hour24-path-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.sonet_hour24_path_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.sonet_hour24_path_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sonet-hour24-path-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sonet-hour24-path-history"):
                                        for c in self.sonet_hour24_path_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories.SonetHour24PathHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.sonet_hour24_path_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sonet-hour24-path-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SonetHour24OcnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: sonet_hour24ocn_history
                                
                                	port 24 hour ocn performance data
                                	**type**\: list of    :py:class:`SonetHour24OcnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories, self).__init__()

                                    self.yang_name = "sonet-hour24ocn-histories"
                                    self.yang_parent_name = "sonet-hour24-history"

                                    self.sonet_hour24ocn_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories, self).__setattr__(name, value)


                                class SonetHour24OcnHistory(Entity):
                                    """
                                    port 24 hour ocn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sonet_hour24ocn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`SonetHour24OcnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory, self).__init__()

                                        self.yang_name = "sonet-hour24ocn-history"
                                        self.yang_parent_name = "sonet-hour24ocn-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.sonet_hour24ocn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances()
                                        self.sonet_hour24ocn_time_line_instances.parent = self
                                        self._children_name_map["sonet_hour24ocn_time_line_instances"] = "sonet-hour24ocn-time-line-instances"
                                        self._children_yang_names.add("sonet-hour24ocn-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory, self).__setattr__(name, value)


                                    class SonetHour24OcnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sonet_hour24ocn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`SonetHour24OcnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances, self).__init__()

                                            self.yang_name = "sonet-hour24ocn-time-line-instances"
                                            self.yang_parent_name = "sonet-hour24ocn-history"

                                            self.sonet_hour24ocn_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances, self).__setattr__(name, value)


                                        class SonetHour24OcnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line>`
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance, self).__init__()

                                                self.yang_name = "sonet-hour24ocn-time-line-instance"
                                                self.yang_parent_name = "sonet-hour24ocn-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.fe_line = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self._children_name_map["fe_line"] = "fe-line"
                                                self._children_yang_names.add("fe-line")

                                                self.line = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line()
                                                self.line.parent = self
                                                self._children_name_map["line"] = "line"
                                                self._children_yang_names.add("line")

                                                self.section = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section()
                                                self.section.parent = self
                                                self._children_name_map["section"] = "section"
                                                self._children_yang_names.add("section")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance, self).__setattr__(name, value)


                                            class Section(Entity):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionCVs>`
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_sef_ss
                                                
                                                	The number of Severely Errored Framing Seconds
                                                	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSefSs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section, self).__init__()

                                                    self.yang_name = "section"
                                                    self.yang_parent_name = "sonet-hour24ocn-time-line-instance"

                                                    self.section_status = YLeaf(YType.int32, "section-status")

                                                    self.section_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionCVs()
                                                    self.section_c_vs.parent = self
                                                    self._children_name_map["section_c_vs"] = "section-c-vs"
                                                    self._children_yang_names.add("section-c-vs")

                                                    self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self._children_name_map["section_e_ss"] = "section-e-ss"
                                                    self._children_yang_names.add("section-e-ss")

                                                    self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self._children_name_map["section_se_ss"] = "section-se-ss"
                                                    self._children_yang_names.add("section-se-ss")

                                                    self.section_sef_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSefSs()
                                                    self.section_sef_ss.parent = self
                                                    self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                                    self._children_yang_names.add("section-sef-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("section_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section, self).__setattr__(name, value)


                                                class SectionESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionESs, self).__init__()

                                                        self.yang_name = "section-e-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSeSs, self).__init__()

                                                        self.yang_name = "section-se-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionSefSs(Entity):
                                                    """
                                                    The number of Severely Errored Framing Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSefSs, self).__init__()

                                                        self.yang_name = "section-sef-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSefSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSefSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-sef-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionCVs, self).__init__()

                                                        self.yang_name = "section-c-vs"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.section_status.is_set or
                                                        (self.section_c_vs is not None and self.section_c_vs.has_data()) or
                                                        (self.section_e_ss is not None and self.section_e_ss.has_data()) or
                                                        (self.section_se_ss is not None and self.section_se_ss.has_data()) or
                                                        (self.section_sef_ss is not None and self.section_sef_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.section_status.yfilter != YFilter.not_set or
                                                        (self.section_c_vs is not None and self.section_c_vs.has_operation()) or
                                                        (self.section_e_ss is not None and self.section_e_ss.has_operation()) or
                                                        (self.section_se_ss is not None and self.section_se_ss.has_operation()) or
                                                        (self.section_sef_ss is not None and self.section_sef_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "section" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.section_status.is_set or self.section_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.section_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "section-c-vs"):
                                                        if (self.section_c_vs is None):
                                                            self.section_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionCVs()
                                                            self.section_c_vs.parent = self
                                                            self._children_name_map["section_c_vs"] = "section-c-vs"
                                                        return self.section_c_vs

                                                    if (child_yang_name == "section-e-ss"):
                                                        if (self.section_e_ss is None):
                                                            self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionESs()
                                                            self.section_e_ss.parent = self
                                                            self._children_name_map["section_e_ss"] = "section-e-ss"
                                                        return self.section_e_ss

                                                    if (child_yang_name == "section-se-ss"):
                                                        if (self.section_se_ss is None):
                                                            self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSeSs()
                                                            self.section_se_ss.parent = self
                                                            self._children_name_map["section_se_ss"] = "section-se-ss"
                                                        return self.section_se_ss

                                                    if (child_yang_name == "section-sef-ss"):
                                                        if (self.section_sef_ss is None):
                                                            self.section_sef_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section.SectionSefSs()
                                                            self.section_sef_ss.parent = self
                                                            self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                                        return self.section_sef_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "section-c-vs" or name == "section-e-ss" or name == "section-se-ss" or name == "section-sef-ss" or name == "section-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "section-status"):
                                                        self.section_status = value
                                                        self.section_status.value_namespace = name_space
                                                        self.section_status.value_namespace_prefix = name_space_prefix


                                            class Line(Entity):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineCVs>`
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineFcLs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line, self).__init__()

                                                    self.yang_name = "line"
                                                    self.yang_parent_name = "sonet-hour24ocn-time-line-instance"

                                                    self.line_status = YLeaf(YType.int32, "line-status")

                                                    self.line_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineCVs()
                                                    self.line_c_vs.parent = self
                                                    self._children_name_map["line_c_vs"] = "line-c-vs"
                                                    self._children_yang_names.add("line-c-vs")

                                                    self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self._children_name_map["line_e_ss"] = "line-e-ss"
                                                    self._children_yang_names.add("line-e-ss")

                                                    self.line_fc_ls = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineFcLs()
                                                    self.line_fc_ls.parent = self
                                                    self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                                    self._children_yang_names.add("line-fc-ls")

                                                    self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self._children_name_map["line_se_ss"] = "line-se-ss"
                                                    self._children_yang_names.add("line-se-ss")

                                                    self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self
                                                    self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                                    self._children_yang_names.add("line-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("line_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line, self).__setattr__(name, value)


                                                class LineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineESs, self).__init__()

                                                        self.yang_name = "line-e-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineSeSs, self).__init__()

                                                        self.yang_name = "line-se-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineCVs, self).__init__()

                                                        self.yang_name = "line-c-vs"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineUaSs, self).__init__()

                                                        self.yang_name = "line-ua-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineFcLs, self).__init__()

                                                        self.yang_name = "line-fc-ls"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineFcLs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineFcLs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-fc-ls" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.line_status.is_set or
                                                        (self.line_c_vs is not None and self.line_c_vs.has_data()) or
                                                        (self.line_e_ss is not None and self.line_e_ss.has_data()) or
                                                        (self.line_fc_ls is not None and self.line_fc_ls.has_data()) or
                                                        (self.line_se_ss is not None and self.line_se_ss.has_data()) or
                                                        (self.line_ua_ss is not None and self.line_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.line_status.yfilter != YFilter.not_set or
                                                        (self.line_c_vs is not None and self.line_c_vs.has_operation()) or
                                                        (self.line_e_ss is not None and self.line_e_ss.has_operation()) or
                                                        (self.line_fc_ls is not None and self.line_fc_ls.has_operation()) or
                                                        (self.line_se_ss is not None and self.line_se_ss.has_operation()) or
                                                        (self.line_ua_ss is not None and self.line_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "line" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.line_status.is_set or self.line_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.line_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "line-c-vs"):
                                                        if (self.line_c_vs is None):
                                                            self.line_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineCVs()
                                                            self.line_c_vs.parent = self
                                                            self._children_name_map["line_c_vs"] = "line-c-vs"
                                                        return self.line_c_vs

                                                    if (child_yang_name == "line-e-ss"):
                                                        if (self.line_e_ss is None):
                                                            self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineESs()
                                                            self.line_e_ss.parent = self
                                                            self._children_name_map["line_e_ss"] = "line-e-ss"
                                                        return self.line_e_ss

                                                    if (child_yang_name == "line-fc-ls"):
                                                        if (self.line_fc_ls is None):
                                                            self.line_fc_ls = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineFcLs()
                                                            self.line_fc_ls.parent = self
                                                            self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                                        return self.line_fc_ls

                                                    if (child_yang_name == "line-se-ss"):
                                                        if (self.line_se_ss is None):
                                                            self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineSeSs()
                                                            self.line_se_ss.parent = self
                                                            self._children_name_map["line_se_ss"] = "line-se-ss"
                                                        return self.line_se_ss

                                                    if (child_yang_name == "line-ua-ss"):
                                                        if (self.line_ua_ss is None):
                                                            self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line.LineUaSs()
                                                            self.line_ua_ss.parent = self
                                                            self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                                        return self.line_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "line-c-vs" or name == "line-e-ss" or name == "line-fc-ls" or name == "line-se-ss" or name == "line-ua-ss" or name == "line-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "line-status"):
                                                        self.line_status = value
                                                        self.line_status.value_namespace = name_space
                                                        self.line_status.value_namespace_prefix = name_space_prefix


                                            class FeLine(Entity):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineCVs>`
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine, self).__init__()

                                                    self.yang_name = "fe-line"
                                                    self.yang_parent_name = "sonet-hour24ocn-time-line-instance"

                                                    self.far_end_line_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineCVs()
                                                    self.far_end_line_c_vs.parent = self
                                                    self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                                    self._children_yang_names.add("far-end-line-c-vs")

                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                                    self._children_yang_names.add("far-end-line-e-ss")

                                                    self.far_end_line_fc_ls = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                    self.far_end_line_fc_ls.parent = self
                                                    self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                                    self._children_yang_names.add("far-end-line-fc-ls")

                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                                    self._children_yang_names.add("far-end-line-se-ss")

                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self
                                                    self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                                    self._children_yang_names.add("far-end-line-ua-ss")


                                                class FarEndLineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineESs, self).__init__()

                                                        self.yang_name = "far-end-line-e-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs, self).__init__()

                                                        self.yang_name = "far-end-line-se-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineCVs, self).__init__()

                                                        self.yang_name = "far-end-line-c-vs"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs, self).__init__()

                                                        self.yang_name = "far-end-line-ua-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs, self).__init__()

                                                        self.yang_name = "far-end-line-fc-ls"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-fc-ls" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_data()) or
                                                        (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_data()) or
                                                        (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_data()) or
                                                        (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_data()) or
                                                        (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_operation()) or
                                                        (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_operation()) or
                                                        (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_operation()) or
                                                        (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_operation()) or
                                                        (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fe-line" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "far-end-line-c-vs"):
                                                        if (self.far_end_line_c_vs is None):
                                                            self.far_end_line_c_vs = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineCVs()
                                                            self.far_end_line_c_vs.parent = self
                                                            self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                                        return self.far_end_line_c_vs

                                                    if (child_yang_name == "far-end-line-e-ss"):
                                                        if (self.far_end_line_e_ss is None):
                                                            self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineESs()
                                                            self.far_end_line_e_ss.parent = self
                                                            self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                                        return self.far_end_line_e_ss

                                                    if (child_yang_name == "far-end-line-fc-ls"):
                                                        if (self.far_end_line_fc_ls is None):
                                                            self.far_end_line_fc_ls = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                            self.far_end_line_fc_ls.parent = self
                                                            self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                                        return self.far_end_line_fc_ls

                                                    if (child_yang_name == "far-end-line-se-ss"):
                                                        if (self.far_end_line_se_ss is None):
                                                            self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                            self.far_end_line_se_ss.parent = self
                                                            self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                                        return self.far_end_line_se_ss

                                                    if (child_yang_name == "far-end-line-ua-ss"):
                                                        if (self.far_end_line_ua_ss is None):
                                                            self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                            self.far_end_line_ua_ss.parent = self
                                                            self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                                        return self.far_end_line_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "far-end-line-c-vs" or name == "far-end-line-e-ss" or name == "far-end-line-fc-ls" or name == "far-end-line-se-ss" or name == "far-end-line-ua-ss"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.fe_line is not None and self.fe_line.has_data()) or
                                                    (self.line is not None and self.line.has_data()) or
                                                    (self.section is not None and self.section.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.fe_line is not None and self.fe_line.has_operation()) or
                                                    (self.line is not None and self.line.has_operation()) or
                                                    (self.section is not None and self.section.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sonet-hour24ocn-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "fe-line"):
                                                    if (self.fe_line is None):
                                                        self.fe_line = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.FeLine()
                                                        self.fe_line.parent = self
                                                        self._children_name_map["fe_line"] = "fe-line"
                                                    return self.fe_line

                                                if (child_yang_name == "line"):
                                                    if (self.line is None):
                                                        self.line = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Line()
                                                        self.line.parent = self
                                                        self._children_name_map["line"] = "line"
                                                    return self.line

                                                if (child_yang_name == "section"):
                                                    if (self.section is None):
                                                        self.section = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance.Section()
                                                        self.section.parent = self
                                                        self._children_name_map["section"] = "section"
                                                    return self.section

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "fe-line" or name == "line" or name == "section" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.sonet_hour24ocn_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.sonet_hour24ocn_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sonet-hour24ocn-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "sonet-hour24ocn-time-line-instance"):
                                                for c in self.sonet_hour24ocn_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances.SonetHour24OcnTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.sonet_hour24ocn_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "sonet-hour24ocn-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.sonet_hour24ocn_time_line_instances is not None and self.sonet_hour24ocn_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.sonet_hour24ocn_time_line_instances is not None and self.sonet_hour24ocn_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sonet-hour24ocn-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sonet-hour24ocn-time-line-instances"):
                                            if (self.sonet_hour24ocn_time_line_instances is None):
                                                self.sonet_hour24ocn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory.SonetHour24OcnTimeLineInstances()
                                                self.sonet_hour24ocn_time_line_instances.parent = self
                                                self._children_name_map["sonet_hour24ocn_time_line_instances"] = "sonet-hour24ocn-time-line-instances"
                                            return self.sonet_hour24ocn_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sonet-hour24ocn-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.sonet_hour24ocn_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.sonet_hour24ocn_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sonet-hour24ocn-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sonet-hour24ocn-history"):
                                        for c in self.sonet_hour24ocn_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories.SonetHour24OcnHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.sonet_hour24ocn_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sonet-hour24ocn-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    (self.sonet_hour24_path_histories is not None and self.sonet_hour24_path_histories.has_data()) or
                                    (self.sonet_hour24ocn_histories is not None and self.sonet_hour24ocn_histories.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.sonet_hour24_path_histories is not None and self.sonet_hour24_path_histories.has_operation()) or
                                    (self.sonet_hour24ocn_histories is not None and self.sonet_hour24ocn_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sonet-hour24-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sonet-hour24-path-histories"):
                                    if (self.sonet_hour24_path_histories is None):
                                        self.sonet_hour24_path_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24PathHistories()
                                        self.sonet_hour24_path_histories.parent = self
                                        self._children_name_map["sonet_hour24_path_histories"] = "sonet-hour24-path-histories"
                                    return self.sonet_hour24_path_histories

                                if (child_yang_name == "sonet-hour24ocn-histories"):
                                    if (self.sonet_hour24ocn_histories is None):
                                        self.sonet_hour24ocn_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History.SonetHour24OcnHistories()
                                        self.sonet_hour24ocn_histories.parent = self
                                        self._children_name_map["sonet_hour24ocn_histories"] = "sonet-hour24ocn-histories"
                                    return self.sonet_hour24ocn_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sonet-hour24-path-histories" or name == "sonet-hour24ocn-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.name.is_set or
                                (self.sonet_hour24_history is not None and self.sonet_hour24_history.has_data()) or
                                (self.sonet_minute15_history is not None and self.sonet_minute15_history.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                (self.sonet_hour24_history is not None and self.sonet_hour24_history.has_operation()) or
                                (self.sonet_minute15_history is not None and self.sonet_minute15_history.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sonet-port-history" + "[name='" + self.name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/sonet-history/sonet-port-histories/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sonet-hour24-history"):
                                if (self.sonet_hour24_history is None):
                                    self.sonet_hour24_history = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetHour24History()
                                    self.sonet_hour24_history.parent = self
                                    self._children_name_map["sonet_hour24_history"] = "sonet-hour24-history"
                                return self.sonet_hour24_history

                            if (child_yang_name == "sonet-minute15-history"):
                                if (self.sonet_minute15_history is None):
                                    self.sonet_minute15_history = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory.SonetMinute15History()
                                    self.sonet_minute15_history.parent = self
                                    self._children_name_map["sonet_minute15_history"] = "sonet-minute15-history"
                                return self.sonet_minute15_history

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sonet-hour24-history" or name == "sonet-minute15-history" or name == "name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.sonet_port_history:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.sonet_port_history:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sonet-port-histories" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/sonet-history/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sonet-port-history"):
                            for c in self.sonet_port_history:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories.SonetPortHistory()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.sonet_port_history.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sonet-port-history"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.sonet_port_histories is not None and self.sonet_port_histories.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.sonet_port_histories is not None and self.sonet_port_histories.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "sonet-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sonet-port-histories"):
                        if (self.sonet_port_histories is None):
                            self.sonet_port_histories = PerformanceManagementHistory.Global_.Periodic.SonetHistory.SonetPortHistories()
                            self.sonet_port_histories.parent = self
                            self._children_name_map["sonet_port_histories"] = "sonet-port-histories"
                        return self.sonet_port_histories

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sonet-port-histories"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class StsHistory(Entity):
                """
                STS controller History performance data
                
                .. attribute:: sts_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`StsPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory, self).__init__()

                    self.yang_name = "sts-history"
                    self.yang_parent_name = "periodic"

                    self.sts_port_histories = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories()
                    self.sts_port_histories.parent = self
                    self._children_name_map["sts_port_histories"] = "sts-port-histories"
                    self._children_yang_names.add("sts-port-histories")


                class StsPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: sts_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`StsPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories, self).__init__()

                        self.yang_name = "sts-port-histories"
                        self.yang_parent_name = "sts-history"

                        self.sts_port_history = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories, self).__setattr__(name, value)


                    class StsPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: sts_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`StsHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History>`
                        
                        .. attribute:: sts_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`StsMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory, self).__init__()

                            self.yang_name = "sts-port-history"
                            self.yang_parent_name = "sts-port-histories"

                            self.name = YLeaf(YType.str, "name")

                            self.sts_hour24_history = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History()
                            self.sts_hour24_history.parent = self
                            self._children_name_map["sts_hour24_history"] = "sts-hour24-history"
                            self._children_yang_names.add("sts-hour24-history")

                            self.sts_minute15_history = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History()
                            self.sts_minute15_history.parent = self
                            self._children_name_map["sts_minute15_history"] = "sts-minute15-history"
                            self._children_yang_names.add("sts-minute15-history")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory, self).__setattr__(name, value)


                        class StsMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sts_minute15_path_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`StsMinute15PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History, self).__init__()

                                self.yang_name = "sts-minute15-history"
                                self.yang_parent_name = "sts-port-history"

                                self.sts_minute15_path_histories = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories()
                                self.sts_minute15_path_histories.parent = self
                                self._children_name_map["sts_minute15_path_histories"] = "sts-minute15-path-histories"
                                self._children_yang_names.add("sts-minute15-path-histories")


                            class StsMinute15PathHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: sts_minute15_path_history
                                
                                	port 15\-minute Path performance data
                                	**type**\: list of    :py:class:`StsMinute15PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories, self).__init__()

                                    self.yang_name = "sts-minute15-path-histories"
                                    self.yang_parent_name = "sts-minute15-history"

                                    self.sts_minute15_path_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories, self).__setattr__(name, value)


                                class StsMinute15PathHistory(Entity):
                                    """
                                    port 15\-minute Path performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sts_minute15_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`StsMinute15PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory, self).__init__()

                                        self.yang_name = "sts-minute15-path-history"
                                        self.yang_parent_name = "sts-minute15-path-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.sts_minute15_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances()
                                        self.sts_minute15_path_time_line_instances.parent = self
                                        self._children_name_map["sts_minute15_path_time_line_instances"] = "sts-minute15-path-time-line-instances"
                                        self._children_yang_names.add("sts-minute15-path-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory, self).__setattr__(name, value)


                                    class StsMinute15PathTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sts_minute15_path_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`StsMinute15PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances, self).__init__()

                                            self.yang_name = "sts-minute15-path-time-line-instances"
                                            self.yang_parent_name = "sts-minute15-path-history"

                                            self.sts_minute15_path_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances, self).__setattr__(name, value)


                                        class StsMinute15PathTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance, self).__init__()

                                                self.yang_name = "sts-minute15-path-time-line-instance"
                                                self.yang_parent_name = "sts-minute15-path-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.fe_path = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self._children_name_map["fe_path"] = "fe-path"
                                                self._children_yang_names.add("fe-path")

                                                self.path = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self._children_name_map["path"] = "path"
                                                self._children_yang_names.add("path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance, self).__setattr__(name, value)


                                            class Path(Entity):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs>`
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_width
                                                
                                                	Indicates the type of the SONET/SDH Path
                                                	**type**\:   :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path, self).__init__()

                                                    self.yang_name = "path"
                                                    self.yang_parent_name = "sts-minute15-path-time-line-instance"

                                                    self.path_status = YLeaf(YType.int32, "path-status")

                                                    self.path_width = YLeaf(YType.enumeration, "path-width")

                                                    self.path_c_vs = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs()
                                                    self.path_c_vs.parent = self
                                                    self._children_name_map["path_c_vs"] = "path-c-vs"
                                                    self._children_yang_names.add("path-c-vs")

                                                    self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self._children_name_map["path_e_ss"] = "path-e-ss"
                                                    self._children_yang_names.add("path-e-ss")

                                                    self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self._children_name_map["path_se_ss"] = "path-se-ss"
                                                    self._children_yang_names.add("path-se-ss")

                                                    self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                    self._children_yang_names.add("path-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("path_status",
                                                                    "path_width") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path, self).__setattr__(name, value)


                                                class PathESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs, self).__init__()

                                                        self.yang_name = "path-e-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs, self).__init__()

                                                        self.yang_name = "path-se-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs, self).__init__()

                                                        self.yang_name = "path-c-vs"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs, self).__init__()

                                                        self.yang_name = "path-ua-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.path_status.is_set or
                                                        self.path_width.is_set or
                                                        (self.path_c_vs is not None and self.path_c_vs.has_data()) or
                                                        (self.path_e_ss is not None and self.path_e_ss.has_data()) or
                                                        (self.path_se_ss is not None and self.path_se_ss.has_data()) or
                                                        (self.path_ua_ss is not None and self.path_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.path_status.yfilter != YFilter.not_set or
                                                        self.path_width.yfilter != YFilter.not_set or
                                                        (self.path_c_vs is not None and self.path_c_vs.has_operation()) or
                                                        (self.path_e_ss is not None and self.path_e_ss.has_operation()) or
                                                        (self.path_se_ss is not None and self.path_se_ss.has_operation()) or
                                                        (self.path_ua_ss is not None and self.path_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.path_status.get_name_leafdata())
                                                    if (self.path_width.is_set or self.path_width.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.path_width.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "path-c-vs"):
                                                        if (self.path_c_vs is None):
                                                            self.path_c_vs = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathCVs()
                                                            self.path_c_vs.parent = self
                                                            self._children_name_map["path_c_vs"] = "path-c-vs"
                                                        return self.path_c_vs

                                                    if (child_yang_name == "path-e-ss"):
                                                        if (self.path_e_ss is None):
                                                            self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathESs()
                                                            self.path_e_ss.parent = self
                                                            self._children_name_map["path_e_ss"] = "path-e-ss"
                                                        return self.path_e_ss

                                                    if (child_yang_name == "path-se-ss"):
                                                        if (self.path_se_ss is None):
                                                            self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathSeSs()
                                                            self.path_se_ss.parent = self
                                                            self._children_name_map["path_se_ss"] = "path-se-ss"
                                                        return self.path_se_ss

                                                    if (child_yang_name == "path-ua-ss"):
                                                        if (self.path_ua_ss is None):
                                                            self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path.PathUaSs()
                                                            self.path_ua_ss.parent = self
                                                            self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                        return self.path_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "path-c-vs" or name == "path-e-ss" or name == "path-se-ss" or name == "path-ua-ss" or name == "path-status" or name == "path-width"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "path-status"):
                                                        self.path_status = value
                                                        self.path_status.value_namespace = name_space
                                                        self.path_status.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "path-width"):
                                                        self.path_width = value
                                                        self.path_width.value_namespace = name_space
                                                        self.path_width.value_namespace_prefix = name_space_prefix


                                            class FePath(Entity):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath, self).__init__()

                                                    self.yang_name = "fe-path"
                                                    self.yang_parent_name = "sts-minute15-path-time-line-instance"

                                                    self.far_end_path_c_vs = YLeaf(YType.uint32, "far-end-path-c-vs")

                                                    self.far_end_path_e_ss = YLeaf(YType.uint32, "far-end-path-e-ss")

                                                    self.far_end_path_se_ss = YLeaf(YType.uint32, "far-end-path-se-ss")

                                                    self.far_end_path_ua_ss = YLeaf(YType.uint32, "far-end-path-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("far_end_path_c_vs",
                                                                    "far_end_path_e_ss",
                                                                    "far_end_path_se_ss",
                                                                    "far_end_path_ua_ss") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.far_end_path_c_vs.is_set or
                                                        self.far_end_path_e_ss.is_set or
                                                        self.far_end_path_se_ss.is_set or
                                                        self.far_end_path_ua_ss.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.far_end_path_c_vs.yfilter != YFilter.not_set or
                                                        self.far_end_path_e_ss.yfilter != YFilter.not_set or
                                                        self.far_end_path_se_ss.yfilter != YFilter.not_set or
                                                        self.far_end_path_ua_ss.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fe-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.far_end_path_c_vs.is_set or self.far_end_path_c_vs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_c_vs.get_name_leafdata())
                                                    if (self.far_end_path_e_ss.is_set or self.far_end_path_e_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_e_ss.get_name_leafdata())
                                                    if (self.far_end_path_se_ss.is_set or self.far_end_path_se_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_se_ss.get_name_leafdata())
                                                    if (self.far_end_path_ua_ss.is_set or self.far_end_path_ua_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_ua_ss.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "far-end-path-c-vs" or name == "far-end-path-e-ss" or name == "far-end-path-se-ss" or name == "far-end-path-ua-ss"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "far-end-path-c-vs"):
                                                        self.far_end_path_c_vs = value
                                                        self.far_end_path_c_vs.value_namespace = name_space
                                                        self.far_end_path_c_vs.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-e-ss"):
                                                        self.far_end_path_e_ss = value
                                                        self.far_end_path_e_ss.value_namespace = name_space
                                                        self.far_end_path_e_ss.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-se-ss"):
                                                        self.far_end_path_se_ss = value
                                                        self.far_end_path_se_ss.value_namespace = name_space
                                                        self.far_end_path_se_ss.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-ua-ss"):
                                                        self.far_end_path_ua_ss = value
                                                        self.far_end_path_ua_ss.value_namespace = name_space
                                                        self.far_end_path_ua_ss.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.fe_path is not None and self.fe_path.has_data()) or
                                                    (self.path is not None and self.path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.fe_path is not None and self.fe_path.has_operation()) or
                                                    (self.path is not None and self.path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sts-minute15-path-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "fe-path"):
                                                    if (self.fe_path is None):
                                                        self.fe_path = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.FePath()
                                                        self.fe_path.parent = self
                                                        self._children_name_map["fe_path"] = "fe-path"
                                                    return self.fe_path

                                                if (child_yang_name == "path"):
                                                    if (self.path is None):
                                                        self.path = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance.Path()
                                                        self.path.parent = self
                                                        self._children_name_map["path"] = "path"
                                                    return self.path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "fe-path" or name == "path" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.sts_minute15_path_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.sts_minute15_path_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sts-minute15-path-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "sts-minute15-path-time-line-instance"):
                                                for c in self.sts_minute15_path_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances.StsMinute15PathTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.sts_minute15_path_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "sts-minute15-path-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.sts_minute15_path_time_line_instances is not None and self.sts_minute15_path_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.sts_minute15_path_time_line_instances is not None and self.sts_minute15_path_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sts-minute15-path-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sts-minute15-path-time-line-instances"):
                                            if (self.sts_minute15_path_time_line_instances is None):
                                                self.sts_minute15_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory.StsMinute15PathTimeLineInstances()
                                                self.sts_minute15_path_time_line_instances.parent = self
                                                self._children_name_map["sts_minute15_path_time_line_instances"] = "sts-minute15-path-time-line-instances"
                                            return self.sts_minute15_path_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sts-minute15-path-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.sts_minute15_path_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.sts_minute15_path_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sts-minute15-path-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sts-minute15-path-history"):
                                        for c in self.sts_minute15_path_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories.StsMinute15PathHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.sts_minute15_path_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sts-minute15-path-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.sts_minute15_path_histories is not None and self.sts_minute15_path_histories.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.sts_minute15_path_histories is not None and self.sts_minute15_path_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sts-minute15-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sts-minute15-path-histories"):
                                    if (self.sts_minute15_path_histories is None):
                                        self.sts_minute15_path_histories = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History.StsMinute15PathHistories()
                                        self.sts_minute15_path_histories.parent = self
                                        self._children_name_map["sts_minute15_path_histories"] = "sts-minute15-path-histories"
                                    return self.sts_minute15_path_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sts-minute15-path-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class StsHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: sts_hour24_path_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`StsHour24PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History, self).__init__()

                                self.yang_name = "sts-hour24-history"
                                self.yang_parent_name = "sts-port-history"

                                self.sts_hour24_path_histories = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories()
                                self.sts_hour24_path_histories.parent = self
                                self._children_name_map["sts_hour24_path_histories"] = "sts-hour24-path-histories"
                                self._children_yang_names.add("sts-hour24-path-histories")


                            class StsHour24PathHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: sts_hour24_path_history
                                
                                	port 24 hour Path performance data
                                	**type**\: list of    :py:class:`StsHour24PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories, self).__init__()

                                    self.yang_name = "sts-hour24-path-histories"
                                    self.yang_parent_name = "sts-hour24-history"

                                    self.sts_hour24_path_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories, self).__setattr__(name, value)


                                class StsHour24PathHistory(Entity):
                                    """
                                    port 24 hour Path performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sts_hour24_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`StsHour24PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory, self).__init__()

                                        self.yang_name = "sts-hour24-path-history"
                                        self.yang_parent_name = "sts-hour24-path-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.sts_hour24_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances()
                                        self.sts_hour24_path_time_line_instances.parent = self
                                        self._children_name_map["sts_hour24_path_time_line_instances"] = "sts-hour24-path-time-line-instances"
                                        self._children_yang_names.add("sts-hour24-path-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory, self).__setattr__(name, value)


                                    class StsHour24PathTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: sts_hour24_path_time_line_instance
                                        
                                        	port 15\-minute sts performance data
                                        	**type**\: list of    :py:class:`StsHour24PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances, self).__init__()

                                            self.yang_name = "sts-hour24-path-time-line-instances"
                                            self.yang_parent_name = "sts-hour24-path-history"

                                            self.sts_hour24_path_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances, self).__setattr__(name, value)


                                        class StsHour24PathTimeLineInstance(Entity):
                                            """
                                            port 15\-minute sts performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance, self).__init__()

                                                self.yang_name = "sts-hour24-path-time-line-instance"
                                                self.yang_parent_name = "sts-hour24-path-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.fe_path = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self._children_name_map["fe_path"] = "fe-path"
                                                self._children_yang_names.add("fe-path")

                                                self.path = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self._children_name_map["path"] = "path"
                                                self._children_yang_names.add("path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance, self).__setattr__(name, value)


                                            class Path(Entity):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`PathCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs>`
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                .. attribute:: path_width
                                                
                                                	Indicates the type of the SONET/SDH Path
                                                	**type**\:   :py:class:`PmSonetPathWidthEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmSonetPathWidthEnum>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path, self).__init__()

                                                    self.yang_name = "path"
                                                    self.yang_parent_name = "sts-hour24-path-time-line-instance"

                                                    self.path_status = YLeaf(YType.int32, "path-status")

                                                    self.path_width = YLeaf(YType.enumeration, "path-width")

                                                    self.path_c_vs = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs()
                                                    self.path_c_vs.parent = self
                                                    self._children_name_map["path_c_vs"] = "path-c-vs"
                                                    self._children_yang_names.add("path-c-vs")

                                                    self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self._children_name_map["path_e_ss"] = "path-e-ss"
                                                    self._children_yang_names.add("path-e-ss")

                                                    self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self._children_name_map["path_se_ss"] = "path-se-ss"
                                                    self._children_yang_names.add("path-se-ss")

                                                    self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                    self._children_yang_names.add("path-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("path_status",
                                                                    "path_width") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path, self).__setattr__(name, value)


                                                class PathESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs, self).__init__()

                                                        self.yang_name = "path-e-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs, self).__init__()

                                                        self.yang_name = "path-se-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs, self).__init__()

                                                        self.yang_name = "path-c-vs"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs, self).__init__()

                                                        self.yang_name = "path-ua-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.path_status.is_set or
                                                        self.path_width.is_set or
                                                        (self.path_c_vs is not None and self.path_c_vs.has_data()) or
                                                        (self.path_e_ss is not None and self.path_e_ss.has_data()) or
                                                        (self.path_se_ss is not None and self.path_se_ss.has_data()) or
                                                        (self.path_ua_ss is not None and self.path_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.path_status.yfilter != YFilter.not_set or
                                                        self.path_width.yfilter != YFilter.not_set or
                                                        (self.path_c_vs is not None and self.path_c_vs.has_operation()) or
                                                        (self.path_e_ss is not None and self.path_e_ss.has_operation()) or
                                                        (self.path_se_ss is not None and self.path_se_ss.has_operation()) or
                                                        (self.path_ua_ss is not None and self.path_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.path_status.get_name_leafdata())
                                                    if (self.path_width.is_set or self.path_width.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.path_width.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "path-c-vs"):
                                                        if (self.path_c_vs is None):
                                                            self.path_c_vs = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathCVs()
                                                            self.path_c_vs.parent = self
                                                            self._children_name_map["path_c_vs"] = "path-c-vs"
                                                        return self.path_c_vs

                                                    if (child_yang_name == "path-e-ss"):
                                                        if (self.path_e_ss is None):
                                                            self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathESs()
                                                            self.path_e_ss.parent = self
                                                            self._children_name_map["path_e_ss"] = "path-e-ss"
                                                        return self.path_e_ss

                                                    if (child_yang_name == "path-se-ss"):
                                                        if (self.path_se_ss is None):
                                                            self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathSeSs()
                                                            self.path_se_ss.parent = self
                                                            self._children_name_map["path_se_ss"] = "path-se-ss"
                                                        return self.path_se_ss

                                                    if (child_yang_name == "path-ua-ss"):
                                                        if (self.path_ua_ss is None):
                                                            self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path.PathUaSs()
                                                            self.path_ua_ss.parent = self
                                                            self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                        return self.path_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "path-c-vs" or name == "path-e-ss" or name == "path-se-ss" or name == "path-ua-ss" or name == "path-status" or name == "path-width"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "path-status"):
                                                        self.path_status = value
                                                        self.path_status.value_namespace = name_space
                                                        self.path_status.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "path-width"):
                                                        self.path_width = value
                                                        self.path_width.value_namespace = name_space
                                                        self.path_width.value_namespace_prefix = name_space_prefix


                                            class FePath(Entity):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath, self).__init__()

                                                    self.yang_name = "fe-path"
                                                    self.yang_parent_name = "sts-hour24-path-time-line-instance"

                                                    self.far_end_path_c_vs = YLeaf(YType.uint32, "far-end-path-c-vs")

                                                    self.far_end_path_e_ss = YLeaf(YType.uint32, "far-end-path-e-ss")

                                                    self.far_end_path_se_ss = YLeaf(YType.uint32, "far-end-path-se-ss")

                                                    self.far_end_path_ua_ss = YLeaf(YType.uint32, "far-end-path-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("far_end_path_c_vs",
                                                                    "far_end_path_e_ss",
                                                                    "far_end_path_se_ss",
                                                                    "far_end_path_ua_ss") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.far_end_path_c_vs.is_set or
                                                        self.far_end_path_e_ss.is_set or
                                                        self.far_end_path_se_ss.is_set or
                                                        self.far_end_path_ua_ss.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.far_end_path_c_vs.yfilter != YFilter.not_set or
                                                        self.far_end_path_e_ss.yfilter != YFilter.not_set or
                                                        self.far_end_path_se_ss.yfilter != YFilter.not_set or
                                                        self.far_end_path_ua_ss.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fe-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.far_end_path_c_vs.is_set or self.far_end_path_c_vs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_c_vs.get_name_leafdata())
                                                    if (self.far_end_path_e_ss.is_set or self.far_end_path_e_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_e_ss.get_name_leafdata())
                                                    if (self.far_end_path_se_ss.is_set or self.far_end_path_se_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_se_ss.get_name_leafdata())
                                                    if (self.far_end_path_ua_ss.is_set or self.far_end_path_ua_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_ua_ss.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "far-end-path-c-vs" or name == "far-end-path-e-ss" or name == "far-end-path-se-ss" or name == "far-end-path-ua-ss"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "far-end-path-c-vs"):
                                                        self.far_end_path_c_vs = value
                                                        self.far_end_path_c_vs.value_namespace = name_space
                                                        self.far_end_path_c_vs.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-e-ss"):
                                                        self.far_end_path_e_ss = value
                                                        self.far_end_path_e_ss.value_namespace = name_space
                                                        self.far_end_path_e_ss.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-se-ss"):
                                                        self.far_end_path_se_ss = value
                                                        self.far_end_path_se_ss.value_namespace = name_space
                                                        self.far_end_path_se_ss.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-ua-ss"):
                                                        self.far_end_path_ua_ss = value
                                                        self.far_end_path_ua_ss.value_namespace = name_space
                                                        self.far_end_path_ua_ss.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.fe_path is not None and self.fe_path.has_data()) or
                                                    (self.path is not None and self.path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.fe_path is not None and self.fe_path.has_operation()) or
                                                    (self.path is not None and self.path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "sts-hour24-path-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "fe-path"):
                                                    if (self.fe_path is None):
                                                        self.fe_path = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.FePath()
                                                        self.fe_path.parent = self
                                                        self._children_name_map["fe_path"] = "fe-path"
                                                    return self.fe_path

                                                if (child_yang_name == "path"):
                                                    if (self.path is None):
                                                        self.path = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance.Path()
                                                        self.path.parent = self
                                                        self._children_name_map["path"] = "path"
                                                    return self.path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "fe-path" or name == "path" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.sts_hour24_path_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.sts_hour24_path_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "sts-hour24-path-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "sts-hour24-path-time-line-instance"):
                                                for c in self.sts_hour24_path_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances.StsHour24PathTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.sts_hour24_path_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "sts-hour24-path-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.sts_hour24_path_time_line_instances is not None and self.sts_hour24_path_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.sts_hour24_path_time_line_instances is not None and self.sts_hour24_path_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sts-hour24-path-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "sts-hour24-path-time-line-instances"):
                                            if (self.sts_hour24_path_time_line_instances is None):
                                                self.sts_hour24_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory.StsHour24PathTimeLineInstances()
                                                self.sts_hour24_path_time_line_instances.parent = self
                                                self._children_name_map["sts_hour24_path_time_line_instances"] = "sts-hour24-path-time-line-instances"
                                            return self.sts_hour24_path_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "sts-hour24-path-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.sts_hour24_path_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.sts_hour24_path_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sts-hour24-path-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sts-hour24-path-history"):
                                        for c in self.sts_hour24_path_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories.StsHour24PathHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.sts_hour24_path_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sts-hour24-path-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.sts_hour24_path_histories is not None and self.sts_hour24_path_histories.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.sts_hour24_path_histories is not None and self.sts_hour24_path_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sts-hour24-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sts-hour24-path-histories"):
                                    if (self.sts_hour24_path_histories is None):
                                        self.sts_hour24_path_histories = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History.StsHour24PathHistories()
                                        self.sts_hour24_path_histories.parent = self
                                        self._children_name_map["sts_hour24_path_histories"] = "sts-hour24-path-histories"
                                    return self.sts_hour24_path_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sts-hour24-path-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.name.is_set or
                                (self.sts_hour24_history is not None and self.sts_hour24_history.has_data()) or
                                (self.sts_minute15_history is not None and self.sts_minute15_history.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                (self.sts_hour24_history is not None and self.sts_hour24_history.has_operation()) or
                                (self.sts_minute15_history is not None and self.sts_minute15_history.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sts-port-history" + "[name='" + self.name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/sts-history/sts-port-histories/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "sts-hour24-history"):
                                if (self.sts_hour24_history is None):
                                    self.sts_hour24_history = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsHour24History()
                                    self.sts_hour24_history.parent = self
                                    self._children_name_map["sts_hour24_history"] = "sts-hour24-history"
                                return self.sts_hour24_history

                            if (child_yang_name == "sts-minute15-history"):
                                if (self.sts_minute15_history is None):
                                    self.sts_minute15_history = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory.StsMinute15History()
                                    self.sts_minute15_history.parent = self
                                    self._children_name_map["sts_minute15_history"] = "sts-minute15-history"
                                return self.sts_minute15_history

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "sts-hour24-history" or name == "sts-minute15-history" or name == "name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.sts_port_history:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.sts_port_history:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sts-port-histories" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/sts-history/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sts-port-history"):
                            for c in self.sts_port_history:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories.StsPortHistory()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.sts_port_history.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sts-port-history"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.sts_port_histories is not None and self.sts_port_histories.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.sts_port_histories is not None and self.sts_port_histories.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "sts-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sts-port-histories"):
                        if (self.sts_port_histories is None):
                            self.sts_port_histories = PerformanceManagementHistory.Global_.Periodic.StsHistory.StsPortHistories()
                            self.sts_port_histories.parent = self
                            self._children_name_map["sts_port_histories"] = "sts-port-histories"
                        return self.sts_port_histories

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sts-port-histories"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class EthernetHistory(Entity):
                """
                EHERNET controller History performance data
                
                .. attribute:: ethernet_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`EthernetPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory, self).__init__()

                    self.yang_name = "ethernet-history"
                    self.yang_parent_name = "periodic"

                    self.ethernet_port_histories = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories()
                    self.ethernet_port_histories.parent = self
                    self._children_name_map["ethernet_port_histories"] = "ethernet-port-histories"
                    self._children_yang_names.add("ethernet-port-histories")


                class EthernetPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: ethernet_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`EthernetPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories, self).__init__()

                        self.yang_name = "ethernet-port-histories"
                        self.yang_parent_name = "ethernet-history"

                        self.ethernet_port_history = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories, self).__setattr__(name, value)


                    class EthernetPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: ethernet_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`EthernetHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History>`
                        
                        .. attribute:: ethernet_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`EthernetMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History>`
                        
                        .. attribute:: ethernet_second30_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`EthernetSecond30History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory, self).__init__()

                            self.yang_name = "ethernet-port-history"
                            self.yang_parent_name = "ethernet-port-histories"

                            self.name = YLeaf(YType.str, "name")

                            self.ethernet_hour24_history = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History()
                            self.ethernet_hour24_history.parent = self
                            self._children_name_map["ethernet_hour24_history"] = "ethernet-hour24-history"
                            self._children_yang_names.add("ethernet-hour24-history")

                            self.ethernet_minute15_history = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History()
                            self.ethernet_minute15_history.parent = self
                            self._children_name_map["ethernet_minute15_history"] = "ethernet-minute15-history"
                            self._children_yang_names.add("ethernet-minute15-history")

                            self.ethernet_second30_history = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History()
                            self.ethernet_second30_history.parent = self
                            self._children_name_map["ethernet_second30_history"] = "ethernet-second30-history"
                            self._children_yang_names.add("ethernet-second30-history")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory, self).__setattr__(name, value)


                        class EthernetSecond30History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: second30_ether_histories
                            
                            	ETHERNET port interval performance data
                            	**type**\:   :py:class:`Second30EtherHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History, self).__init__()

                                self.yang_name = "ethernet-second30-history"
                                self.yang_parent_name = "ethernet-port-history"

                                self.second30_ether_histories = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories()
                                self.second30_ether_histories.parent = self
                                self._children_name_map["second30_ether_histories"] = "second30-ether-histories"
                                self._children_yang_names.add("second30-ether-histories")


                            class Second30EtherHistories(Entity):
                                """
                                ETHERNET port interval performance data
                                
                                .. attribute:: second30_ether_history
                                
                                	ETHERNET port 30 sec ether performance data
                                	**type**\: list of    :py:class:`Second30EtherHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories, self).__init__()

                                    self.yang_name = "second30-ether-histories"
                                    self.yang_parent_name = "ethernet-second30-history"

                                    self.second30_ether_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories, self).__setattr__(name, value)


                                class Second30EtherHistory(Entity):
                                    """
                                    ETHERNET port 30 sec ether performance
                                    data
                                    
                                    .. attribute:: slot_number  <key>
                                    
                                    	interval slot number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: second30_ether_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`Second30EtherTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory, self).__init__()

                                        self.yang_name = "second30-ether-history"
                                        self.yang_parent_name = "second30-ether-histories"

                                        self.slot_number = YLeaf(YType.int32, "slot-number")

                                        self.second30_ether_time_line_instances = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances()
                                        self.second30_ether_time_line_instances.parent = self
                                        self._children_name_map["second30_ether_time_line_instances"] = "second30-ether-time-line-instances"
                                        self._children_yang_names.add("second30-ether-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("slot_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory, self).__setattr__(name, value)


                                    class Second30EtherTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: second30_ether_time_line_instance
                                        
                                        	port 30 sec otn performance data
                                        	**type**\: list of    :py:class:`Second30EtherTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances, self).__init__()

                                            self.yang_name = "second30-ether-time-line-instances"
                                            self.yang_parent_name = "second30-ether-history"

                                            self.second30_ether_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances, self).__setattr__(name, value)


                                        class Second30EtherTimeLineInstance(Entity):
                                            """
                                            port 30 sec otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ether10241518_octet
                                            
                                            	OFO OCTET
                                            	**type**\:   :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet>`
                                            
                                            .. attribute:: ether128255_octet
                                            
                                            	TFF OCTET
                                            	**type**\:   :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet>`
                                            
                                            .. attribute:: ether256511_octet
                                            
                                            	FOO OCTET
                                            	**type**\:   :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet>`
                                            
                                            .. attribute:: ether5121023_octet
                                            
                                            	OZTT OCTET
                                            	**type**\:   :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet>`
                                            
                                            .. attribute:: ether64_octets
                                            
                                            	SIXTY FOUR OCTET
                                            	**type**\:   :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets>`
                                            
                                            .. attribute:: ether65127_octet
                                            
                                            	OCTET
                                            	**type**\:   :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet>`
                                            
                                            .. attribute:: ether_stat_broadcast_pkt
                                            
                                            	ETHER STAT BROADCAST PKT
                                            	**type**\:   :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt>`
                                            
                                            .. attribute:: ether_stat_multicast_pkt
                                            
                                            	ETHER STAT MULTICAST PKT
                                            	**type**\:   :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt>`
                                            
                                            .. attribute:: ether_stat_undersized_pkt
                                            
                                            	ETHER STAT UNDERSIZED PKT
                                            	**type**\:   :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt>`
                                            
                                            .. attribute:: fcs_errors_stat
                                            
                                            	FCS ERR
                                            	**type**\:   :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat>`
                                            
                                            .. attribute:: if_in_errors
                                            
                                            	IFIN ERRORS
                                            	**type**\:   :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors>`
                                            
                                            .. attribute:: if_in_octets
                                            
                                            	IFIN OCTETS
                                            	**type**\:   :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets>`
                                            
                                            .. attribute:: in8021q_frames
                                            
                                            	INPUT 802 1Q FRAMES
                                            	**type**\:   :py:class:`In8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021QFrames>`
                                            
                                            .. attribute:: in_bcast_pkt
                                            
                                            	IN BCAST
                                            	**type**\:   :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt>`
                                            
                                            .. attribute:: in_drop_abort
                                            
                                            	INPUT DROP ABORT
                                            	**type**\:   :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort>`
                                            
                                            .. attribute:: in_drop_invalid_dmac
                                            
                                            	INPUT DROP INVALID DMAC
                                            	**type**\:   :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac>`
                                            
                                            .. attribute:: in_drop_invalid_encap
                                            
                                            	INPUT DROP INVALID ENCAP
                                            	**type**\:   :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap>`
                                            
                                            .. attribute:: in_drop_invalid_vlan
                                            
                                            	INPUT DROP INVALID VLAN
                                            	**type**\:   :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan>`
                                            
                                            .. attribute:: in_drop_other
                                            
                                            	INPUT DROP OTHER
                                            	**type**\:   :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther>`
                                            
                                            .. attribute:: in_drop_overrun
                                            
                                            	INPUT DROP OVERRUN
                                            	**type**\:   :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun>`
                                            
                                            .. attribute:: in_error_collisions
                                            
                                            	IN ERROR COLLISIONS
                                            	**type**\:   :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions>`
                                            
                                            .. attribute:: in_error_fragments
                                            
                                            	IN ERROR FRAGMENTS
                                            	**type**\:   :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments>`
                                            
                                            .. attribute:: in_error_giant
                                            
                                            	IN ERROR GIANT
                                            	**type**\:   :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant>`
                                            
                                            .. attribute:: in_error_jabbers
                                            
                                            	IN ERROR JABBERS
                                            	**type**\:   :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers>`
                                            
                                            .. attribute:: in_error_other
                                            
                                            	IN ERROR OTHER
                                            	**type**\:   :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther>`
                                            
                                            .. attribute:: in_error_runt
                                            
                                            	IN ERROR RUNT
                                            	**type**\:   :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt>`
                                            
                                            .. attribute:: in_error_symbol
                                            
                                            	IN ERROR SYMBOL
                                            	**type**\:   :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol>`
                                            
                                            .. attribute:: in_good_bytes
                                            
                                            	INPUT GOOD BYTES
                                            	**type**\:   :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes>`
                                            
                                            .. attribute:: in_good_pkts
                                            
                                            	INPUT GOOD PKTS
                                            	**type**\:   :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts>`
                                            
                                            .. attribute:: in_mcast_pkt
                                            
                                            	IN MCAST
                                            	**type**\:   :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt>`
                                            
                                            .. attribute:: in_mib_giant
                                            
                                            	INPUT MIB GIANT
                                            	**type**\:   :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant>`
                                            
                                            .. attribute:: in_mib_jabber
                                            
                                            	INPUT MIB JABBER
                                            	**type**\:   :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber>`
                                            
                                            .. attribute:: in_mibcrc
                                            
                                            	IN MIB CRC
                                            	**type**\:   :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc>`
                                            
                                            .. attribute:: in_pause_frame
                                            
                                            	INPUT PAUSE FRAME
                                            	**type**\:   :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame>`
                                            
                                            .. attribute:: in_pkt64_octet
                                            
                                            	IN PKT 64 OCTET
                                            	**type**\:   :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet>`
                                            
                                            .. attribute:: in_pkts1024_to1518_octets
                                            
                                            	IN PKTS 1024 1518 OCTETS
                                            	**type**\:   :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets>`
                                            
                                            .. attribute:: in_pkts128_to255_octets
                                            
                                            	IN PKTS 128 255 OCTETS
                                            	**type**\:   :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets>`
                                            
                                            .. attribute:: in_pkts1519_max_octets
                                            
                                            	INPUT PKTS 1519MAX OCTETS
                                            	**type**\:   :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets>`
                                            
                                            .. attribute:: in_pkts256_to511_octets
                                            
                                            	IN PKTS 256 511 OCTETS
                                            	**type**\:   :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets>`
                                            
                                            .. attribute:: in_pkts512_to1023_octets
                                            
                                            	IN PKTS 512 1023 OCTETS
                                            	**type**\:   :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets>`
                                            
                                            .. attribute:: in_pkts65_to127_octets
                                            
                                            	IN PKTS 65 127OCTETS
                                            	**type**\:   :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets>`
                                            
                                            .. attribute:: in_ucast_pkt
                                            
                                            	IN UCAST
                                            	**type**\:   :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: jabber_stat
                                            
                                            	JABBER STATS
                                            	**type**\:   :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat>`
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: long_frames_stat
                                            
                                            	LONG FRAMES
                                            	**type**\:   :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat>`
                                            
                                            .. attribute:: octet_stat
                                            
                                            	OCTET STAT
                                            	**type**\:   :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat>`
                                            
                                            .. attribute:: out8021q_frames
                                            
                                            	OUT 802 1Q FRAMES
                                            	**type**\:   :py:class:`Out8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021QFrames>`
                                            
                                            .. attribute:: out_bcast_pkt
                                            
                                            	OUT BCAST
                                            	**type**\:   :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt>`
                                            
                                            .. attribute:: out_drop_abort
                                            
                                            	OUT DROP ABORT
                                            	**type**\:   :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort>`
                                            
                                            .. attribute:: out_drop_other
                                            
                                            	OUT DROP OTHER
                                            	**type**\:   :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther>`
                                            
                                            .. attribute:: out_drop_underrun
                                            
                                            	OUT DROP UNDERRUN
                                            	**type**\:   :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun>`
                                            
                                            .. attribute:: out_error_other
                                            
                                            	OUT ERROR OTHER
                                            	**type**\:   :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther>`
                                            
                                            .. attribute:: out_good_bytes
                                            
                                            	OUT GOOD BYTES
                                            	**type**\:   :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes>`
                                            
                                            .. attribute:: out_good_pkts
                                            
                                            	OUT GOOD PKTS
                                            	**type**\:   :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts>`
                                            
                                            .. attribute:: out_mcast_pkt
                                            
                                            	OUT MCAST
                                            	**type**\:   :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt>`
                                            
                                            .. attribute:: out_octets
                                            
                                            	OUT OCTET
                                            	**type**\:   :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets>`
                                            
                                            .. attribute:: out_pause_frames
                                            
                                            	OUT PAUSE FRAMES
                                            	**type**\:   :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames>`
                                            
                                            .. attribute:: out_pkts10241518_octets
                                            
                                            	OUT PKTS 1024 1518 OCTETS
                                            	**type**\:   :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets>`
                                            
                                            .. attribute:: out_pkts128255_octets
                                            
                                            	OUT PKTS 128 255 OCTETS
                                            	**type**\:   :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets>`
                                            
                                            .. attribute:: out_pkts1519_max_octets
                                            
                                            	OUT PKTS 1519 MAX OCTETS
                                            	**type**\:   :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets>`
                                            
                                            .. attribute:: out_pkts256511_octets
                                            
                                            	OUT PKTS 256 511 OCTETS
                                            	**type**\:   :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets>`
                                            
                                            .. attribute:: out_pkts5121023_octets
                                            
                                            	OUT PKTS 512 1023 OCTETS
                                            	**type**\:   :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets>`
                                            
                                            .. attribute:: out_pkts65127_octets
                                            
                                            	OUT PKTS 65 127OCTETS
                                            	**type**\:   :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets>`
                                            
                                            .. attribute:: out_ucast_pkt
                                            
                                            	OUT UCAST
                                            	**type**\:   :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt>`
                                            
                                            .. attribute:: outpkt64octet
                                            
                                            	OUT PKT 64 OCTET
                                            	**type**\:   :py:class:`Outpkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64Octet>`
                                            
                                            .. attribute:: oversize_pkt_stat
                                            
                                            	OVERSIZE PKT
                                            	**type**\:   :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat>`
                                            
                                            .. attribute:: rx_pkt
                                            
                                            	RX PKT
                                            	**type**\:   :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt>`
                                            
                                            .. attribute:: rx_util
                                            
                                            	Rx Utilization in Percent
                                            	**type**\:   :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: stat_pkt
                                            
                                            	STAT PKT
                                            	**type**\:   :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: tx_bad_fcs
                                            
                                            	TX Bad Fcs
                                            	**type**\:   :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs>`
                                            
                                            .. attribute:: tx_fragments
                                            
                                            	TX Fragments
                                            	**type**\:   :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments>`
                                            
                                            .. attribute:: tx_jabber
                                            
                                            	TX Jabber
                                            	**type**\:   :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber>`
                                            
                                            .. attribute:: tx_oversized_pkt
                                            
                                            	TX Oversized Pkt
                                            	**type**\:   :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt>`
                                            
                                            .. attribute:: tx_pkt
                                            
                                            	TX PKT
                                            	**type**\:   :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt>`
                                            
                                            .. attribute:: tx_undersized_pkt
                                            
                                            	TX Undersized Pkt
                                            	**type**\:   :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt>`
                                            
                                            .. attribute:: tx_util
                                            
                                            	Tx Utilization in Percent
                                            	**type**\:   :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance, self).__init__()

                                                self.yang_name = "second30-ether-time-line-instance"
                                                self.yang_parent_name = "second30-ether-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.ether10241518_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet()
                                                self.ether10241518_octet.parent = self
                                                self._children_name_map["ether10241518_octet"] = "ether10241518-octet"
                                                self._children_yang_names.add("ether10241518-octet")

                                                self.ether128255_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet()
                                                self.ether128255_octet.parent = self
                                                self._children_name_map["ether128255_octet"] = "ether128255-octet"
                                                self._children_yang_names.add("ether128255-octet")

                                                self.ether256511_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet()
                                                self.ether256511_octet.parent = self
                                                self._children_name_map["ether256511_octet"] = "ether256511-octet"
                                                self._children_yang_names.add("ether256511-octet")

                                                self.ether5121023_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet()
                                                self.ether5121023_octet.parent = self
                                                self._children_name_map["ether5121023_octet"] = "ether5121023-octet"
                                                self._children_yang_names.add("ether5121023-octet")

                                                self.ether64_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets()
                                                self.ether64_octets.parent = self
                                                self._children_name_map["ether64_octets"] = "ether64-octets"
                                                self._children_yang_names.add("ether64-octets")

                                                self.ether65127_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet()
                                                self.ether65127_octet.parent = self
                                                self._children_name_map["ether65127_octet"] = "ether65127-octet"
                                                self._children_yang_names.add("ether65127-octet")

                                                self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                self.ether_stat_broadcast_pkt.parent = self
                                                self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"
                                                self._children_yang_names.add("ether-stat-broadcast-pkt")

                                                self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt()
                                                self.ether_stat_multicast_pkt.parent = self
                                                self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"
                                                self._children_yang_names.add("ether-stat-multicast-pkt")

                                                self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                self.ether_stat_undersized_pkt.parent = self
                                                self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"
                                                self._children_yang_names.add("ether-stat-undersized-pkt")

                                                self.fcs_errors_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat()
                                                self.fcs_errors_stat.parent = self
                                                self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"
                                                self._children_yang_names.add("fcs-errors-stat")

                                                self.if_in_errors = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors()
                                                self.if_in_errors.parent = self
                                                self._children_name_map["if_in_errors"] = "if-in-errors"
                                                self._children_yang_names.add("if-in-errors")

                                                self.if_in_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets()
                                                self.if_in_octets.parent = self
                                                self._children_name_map["if_in_octets"] = "if-in-octets"
                                                self._children_yang_names.add("if-in-octets")

                                                self.in8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021QFrames()
                                                self.in8021q_frames.parent = self
                                                self._children_name_map["in8021q_frames"] = "in8021q-frames"
                                                self._children_yang_names.add("in8021q-frames")

                                                self.in_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt()
                                                self.in_bcast_pkt.parent = self
                                                self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"
                                                self._children_yang_names.add("in-bcast-pkt")

                                                self.in_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort()
                                                self.in_drop_abort.parent = self
                                                self._children_name_map["in_drop_abort"] = "in-drop-abort"
                                                self._children_yang_names.add("in-drop-abort")

                                                self.in_drop_invalid_dmac = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac()
                                                self.in_drop_invalid_dmac.parent = self
                                                self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"
                                                self._children_yang_names.add("in-drop-invalid-dmac")

                                                self.in_drop_invalid_encap = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap()
                                                self.in_drop_invalid_encap.parent = self
                                                self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"
                                                self._children_yang_names.add("in-drop-invalid-encap")

                                                self.in_drop_invalid_vlan = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan()
                                                self.in_drop_invalid_vlan.parent = self
                                                self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"
                                                self._children_yang_names.add("in-drop-invalid-vlan")

                                                self.in_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther()
                                                self.in_drop_other.parent = self
                                                self._children_name_map["in_drop_other"] = "in-drop-other"
                                                self._children_yang_names.add("in-drop-other")

                                                self.in_drop_overrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun()
                                                self.in_drop_overrun.parent = self
                                                self._children_name_map["in_drop_overrun"] = "in-drop-overrun"
                                                self._children_yang_names.add("in-drop-overrun")

                                                self.in_error_collisions = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions()
                                                self.in_error_collisions.parent = self
                                                self._children_name_map["in_error_collisions"] = "in-error-collisions"
                                                self._children_yang_names.add("in-error-collisions")

                                                self.in_error_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments()
                                                self.in_error_fragments.parent = self
                                                self._children_name_map["in_error_fragments"] = "in-error-fragments"
                                                self._children_yang_names.add("in-error-fragments")

                                                self.in_error_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant()
                                                self.in_error_giant.parent = self
                                                self._children_name_map["in_error_giant"] = "in-error-giant"
                                                self._children_yang_names.add("in-error-giant")

                                                self.in_error_jabbers = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers()
                                                self.in_error_jabbers.parent = self
                                                self._children_name_map["in_error_jabbers"] = "in-error-jabbers"
                                                self._children_yang_names.add("in-error-jabbers")

                                                self.in_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther()
                                                self.in_error_other.parent = self
                                                self._children_name_map["in_error_other"] = "in-error-other"
                                                self._children_yang_names.add("in-error-other")

                                                self.in_error_runt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt()
                                                self.in_error_runt.parent = self
                                                self._children_name_map["in_error_runt"] = "in-error-runt"
                                                self._children_yang_names.add("in-error-runt")

                                                self.in_error_symbol = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol()
                                                self.in_error_symbol.parent = self
                                                self._children_name_map["in_error_symbol"] = "in-error-symbol"
                                                self._children_yang_names.add("in-error-symbol")

                                                self.in_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes()
                                                self.in_good_bytes.parent = self
                                                self._children_name_map["in_good_bytes"] = "in-good-bytes"
                                                self._children_yang_names.add("in-good-bytes")

                                                self.in_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts()
                                                self.in_good_pkts.parent = self
                                                self._children_name_map["in_good_pkts"] = "in-good-pkts"
                                                self._children_yang_names.add("in-good-pkts")

                                                self.in_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt()
                                                self.in_mcast_pkt.parent = self
                                                self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"
                                                self._children_yang_names.add("in-mcast-pkt")

                                                self.in_mib_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant()
                                                self.in_mib_giant.parent = self
                                                self._children_name_map["in_mib_giant"] = "in-mib-giant"
                                                self._children_yang_names.add("in-mib-giant")

                                                self.in_mib_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber()
                                                self.in_mib_jabber.parent = self
                                                self._children_name_map["in_mib_jabber"] = "in-mib-jabber"
                                                self._children_yang_names.add("in-mib-jabber")

                                                self.in_mibcrc = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc()
                                                self.in_mibcrc.parent = self
                                                self._children_name_map["in_mibcrc"] = "in-mibcrc"
                                                self._children_yang_names.add("in-mibcrc")

                                                self.in_pause_frame = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame()
                                                self.in_pause_frame.parent = self
                                                self._children_name_map["in_pause_frame"] = "in-pause-frame"
                                                self._children_yang_names.add("in-pause-frame")

                                                self.in_pkt64_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet()
                                                self.in_pkt64_octet.parent = self
                                                self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"
                                                self._children_yang_names.add("in-pkt64-octet")

                                                self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets()
                                                self.in_pkts1024_to1518_octets.parent = self
                                                self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"
                                                self._children_yang_names.add("in-pkts1024-to1518-octets")

                                                self.in_pkts128_to255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets()
                                                self.in_pkts128_to255_octets.parent = self
                                                self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"
                                                self._children_yang_names.add("in-pkts128-to255-octets")

                                                self.in_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets()
                                                self.in_pkts1519_max_octets.parent = self
                                                self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"
                                                self._children_yang_names.add("in-pkts1519-max-octets")

                                                self.in_pkts256_to511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets()
                                                self.in_pkts256_to511_octets.parent = self
                                                self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"
                                                self._children_yang_names.add("in-pkts256-to511-octets")

                                                self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets()
                                                self.in_pkts512_to1023_octets.parent = self
                                                self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"
                                                self._children_yang_names.add("in-pkts512-to1023-octets")

                                                self.in_pkts65_to127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets()
                                                self.in_pkts65_to127_octets.parent = self
                                                self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"
                                                self._children_yang_names.add("in-pkts65-to127-octets")

                                                self.in_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt()
                                                self.in_ucast_pkt.parent = self
                                                self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"
                                                self._children_yang_names.add("in-ucast-pkt")

                                                self.jabber_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat()
                                                self.jabber_stat.parent = self
                                                self._children_name_map["jabber_stat"] = "jabber-stat"
                                                self._children_yang_names.add("jabber-stat")

                                                self.long_frames_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat()
                                                self.long_frames_stat.parent = self
                                                self._children_name_map["long_frames_stat"] = "long-frames-stat"
                                                self._children_yang_names.add("long-frames-stat")

                                                self.octet_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat()
                                                self.octet_stat.parent = self
                                                self._children_name_map["octet_stat"] = "octet-stat"
                                                self._children_yang_names.add("octet-stat")

                                                self.out8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021QFrames()
                                                self.out8021q_frames.parent = self
                                                self._children_name_map["out8021q_frames"] = "out8021q-frames"
                                                self._children_yang_names.add("out8021q-frames")

                                                self.out_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt()
                                                self.out_bcast_pkt.parent = self
                                                self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"
                                                self._children_yang_names.add("out-bcast-pkt")

                                                self.out_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort()
                                                self.out_drop_abort.parent = self
                                                self._children_name_map["out_drop_abort"] = "out-drop-abort"
                                                self._children_yang_names.add("out-drop-abort")

                                                self.out_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther()
                                                self.out_drop_other.parent = self
                                                self._children_name_map["out_drop_other"] = "out-drop-other"
                                                self._children_yang_names.add("out-drop-other")

                                                self.out_drop_underrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun()
                                                self.out_drop_underrun.parent = self
                                                self._children_name_map["out_drop_underrun"] = "out-drop-underrun"
                                                self._children_yang_names.add("out-drop-underrun")

                                                self.out_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther()
                                                self.out_error_other.parent = self
                                                self._children_name_map["out_error_other"] = "out-error-other"
                                                self._children_yang_names.add("out-error-other")

                                                self.out_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes()
                                                self.out_good_bytes.parent = self
                                                self._children_name_map["out_good_bytes"] = "out-good-bytes"
                                                self._children_yang_names.add("out-good-bytes")

                                                self.out_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts()
                                                self.out_good_pkts.parent = self
                                                self._children_name_map["out_good_pkts"] = "out-good-pkts"
                                                self._children_yang_names.add("out-good-pkts")

                                                self.out_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt()
                                                self.out_mcast_pkt.parent = self
                                                self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"
                                                self._children_yang_names.add("out-mcast-pkt")

                                                self.out_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets()
                                                self.out_octets.parent = self
                                                self._children_name_map["out_octets"] = "out-octets"
                                                self._children_yang_names.add("out-octets")

                                                self.out_pause_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames()
                                                self.out_pause_frames.parent = self
                                                self._children_name_map["out_pause_frames"] = "out-pause-frames"
                                                self._children_yang_names.add("out-pause-frames")

                                                self.out_pkts10241518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets()
                                                self.out_pkts10241518_octets.parent = self
                                                self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"
                                                self._children_yang_names.add("out-pkts10241518-octets")

                                                self.out_pkts128255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets()
                                                self.out_pkts128255_octets.parent = self
                                                self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"
                                                self._children_yang_names.add("out-pkts128255-octets")

                                                self.out_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                self.out_pkts1519_max_octets.parent = self
                                                self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"
                                                self._children_yang_names.add("out-pkts1519-max-octets")

                                                self.out_pkts256511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets()
                                                self.out_pkts256511_octets.parent = self
                                                self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"
                                                self._children_yang_names.add("out-pkts256511-octets")

                                                self.out_pkts5121023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets()
                                                self.out_pkts5121023_octets.parent = self
                                                self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"
                                                self._children_yang_names.add("out-pkts5121023-octets")

                                                self.out_pkts65127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets()
                                                self.out_pkts65127_octets.parent = self
                                                self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"
                                                self._children_yang_names.add("out-pkts65127-octets")

                                                self.out_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt()
                                                self.out_ucast_pkt.parent = self
                                                self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"
                                                self._children_yang_names.add("out-ucast-pkt")

                                                self.outpkt64octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64Octet()
                                                self.outpkt64octet.parent = self
                                                self._children_name_map["outpkt64octet"] = "outpkt64octet"
                                                self._children_yang_names.add("outpkt64octet")

                                                self.oversize_pkt_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat()
                                                self.oversize_pkt_stat.parent = self
                                                self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"
                                                self._children_yang_names.add("oversize-pkt-stat")

                                                self.rx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt()
                                                self.rx_pkt.parent = self
                                                self._children_name_map["rx_pkt"] = "rx-pkt"
                                                self._children_yang_names.add("rx-pkt")

                                                self.rx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil()
                                                self.rx_util.parent = self
                                                self._children_name_map["rx_util"] = "rx-util"
                                                self._children_yang_names.add("rx-util")

                                                self.stat_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt()
                                                self.stat_pkt.parent = self
                                                self._children_name_map["stat_pkt"] = "stat-pkt"
                                                self._children_yang_names.add("stat-pkt")

                                                self.tx_bad_fcs = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs()
                                                self.tx_bad_fcs.parent = self
                                                self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                                self._children_yang_names.add("tx-bad-fcs")

                                                self.tx_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments()
                                                self.tx_fragments.parent = self
                                                self._children_name_map["tx_fragments"] = "tx-fragments"
                                                self._children_yang_names.add("tx-fragments")

                                                self.tx_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber()
                                                self.tx_jabber.parent = self
                                                self._children_name_map["tx_jabber"] = "tx-jabber"
                                                self._children_yang_names.add("tx-jabber")

                                                self.tx_oversized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt()
                                                self.tx_oversized_pkt.parent = self
                                                self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"
                                                self._children_yang_names.add("tx-oversized-pkt")

                                                self.tx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt()
                                                self.tx_pkt.parent = self
                                                self._children_name_map["tx_pkt"] = "tx-pkt"
                                                self._children_yang_names.add("tx-pkt")

                                                self.tx_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt()
                                                self.tx_undersized_pkt.parent = self
                                                self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"
                                                self._children_yang_names.add("tx-undersized-pkt")

                                                self.tx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil()
                                                self.tx_util.parent = self
                                                self._children_name_map["tx_util"] = "tx-util"
                                                self._children_yang_names.add("tx-util")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance, self).__setattr__(name, value)


                                            class RxPkt(Entity):
                                                """
                                                RX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt, self).__init__()

                                                    self.yang_name = "rx-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class StatPkt(Entity):
                                                """
                                                STAT PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt, self).__init__()

                                                    self.yang_name = "stat-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "stat-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OctetStat(Entity):
                                                """
                                                OCTET STAT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat, self).__init__()

                                                    self.yang_name = "octet-stat"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "octet-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OversizePktStat(Entity):
                                                """
                                                OVERSIZE PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat, self).__init__()

                                                    self.yang_name = "oversize-pkt-stat"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "oversize-pkt-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class FcsErrorsStat(Entity):
                                                """
                                                FCS ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat, self).__init__()

                                                    self.yang_name = "fcs-errors-stat"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fcs-errors-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LongFramesStat(Entity):
                                                """
                                                LONG FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat, self).__init__()

                                                    self.yang_name = "long-frames-stat"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "long-frames-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class JabberStat(Entity):
                                                """
                                                JABBER STATS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat, self).__init__()

                                                    self.yang_name = "jabber-stat"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "jabber-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether64Octets(Entity):
                                                """
                                                SIXTY FOUR OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets, self).__init__()

                                                    self.yang_name = "ether64-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether64-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether65127Octet(Entity):
                                                """
                                                OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet, self).__init__()

                                                    self.yang_name = "ether65127-octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether65127-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether128255Octet(Entity):
                                                """
                                                TFF OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet, self).__init__()

                                                    self.yang_name = "ether128255-octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether128255-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether256511Octet(Entity):
                                                """
                                                FOO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet, self).__init__()

                                                    self.yang_name = "ether256511-octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether256511-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether5121023Octet(Entity):
                                                """
                                                OZTT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet, self).__init__()

                                                    self.yang_name = "ether5121023-octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether5121023-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether10241518Octet(Entity):
                                                """
                                                OFO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet, self).__init__()

                                                    self.yang_name = "ether10241518-octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether10241518-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InUcastPkt(Entity):
                                                """
                                                IN UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt, self).__init__()

                                                    self.yang_name = "in-ucast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-ucast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InMcastPkt(Entity):
                                                """
                                                IN MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt, self).__init__()

                                                    self.yang_name = "in-mcast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-mcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InBcastPkt(Entity):
                                                """
                                                IN BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt, self).__init__()

                                                    self.yang_name = "in-bcast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-bcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutUcastPkt(Entity):
                                                """
                                                OUT UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt, self).__init__()

                                                    self.yang_name = "out-ucast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-ucast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutBcastPkt(Entity):
                                                """
                                                OUT BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt, self).__init__()

                                                    self.yang_name = "out-bcast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-bcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutMcastPkt(Entity):
                                                """
                                                OUT MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt, self).__init__()

                                                    self.yang_name = "out-mcast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-mcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxPkt(Entity):
                                                """
                                                TX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt, self).__init__()

                                                    self.yang_name = "tx-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class IfInErrors(Entity):
                                                """
                                                IFIN ERRORS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors, self).__init__()

                                                    self.yang_name = "if-in-errors"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "if-in-errors" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class IfInOctets(Entity):
                                                """
                                                IFIN OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets, self).__init__()

                                                    self.yang_name = "if-in-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "if-in-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class EtherStatMulticastPkt(Entity):
                                                """
                                                ETHER STAT MULTICAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-multicast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether-stat-multicast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class EtherStatBroadcastPkt(Entity):
                                                """
                                                ETHER STAT BROADCAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-broadcast-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether-stat-broadcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class EtherStatUndersizedPkt(Entity):
                                                """
                                                ETHER STAT UNDERSIZED PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt, self).__init__()

                                                    self.yang_name = "ether-stat-undersized-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether-stat-undersized-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutOctets(Entity):
                                                """
                                                OUT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets, self).__init__()

                                                    self.yang_name = "out-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPauseFrame(Entity):
                                                """
                                                INPUT PAUSE FRAME
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame, self).__init__()

                                                    self.yang_name = "in-pause-frame"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pause-frame" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InGoodBytes(Entity):
                                                """
                                                INPUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes, self).__init__()

                                                    self.yang_name = "in-good-bytes"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-good-bytes" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class In8021QFrames(Entity):
                                                """
                                                INPUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021QFrames, self).__init__()

                                                    self.yang_name = "in8021q-frames"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021QFrames, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021QFrames, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in8021q-frames" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts1519MaxOctets(Entity):
                                                """
                                                INPUT PKTS 1519MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "in-pkts1519-max-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts1519-max-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InGoodPkts(Entity):
                                                """
                                                INPUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts, self).__init__()

                                                    self.yang_name = "in-good-pkts"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-good-pkts" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropOverrun(Entity):
                                                """
                                                INPUT DROP OVERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun, self).__init__()

                                                    self.yang_name = "in-drop-overrun"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-overrun" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropAbort(Entity):
                                                """
                                                INPUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort, self).__init__()

                                                    self.yang_name = "in-drop-abort"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-abort" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropInvalidVlan(Entity):
                                                """
                                                INPUT DROP INVALID VLAN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan, self).__init__()

                                                    self.yang_name = "in-drop-invalid-vlan"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-invalid-vlan" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropInvalidDmac(Entity):
                                                """
                                                INPUT DROP INVALID DMAC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac, self).__init__()

                                                    self.yang_name = "in-drop-invalid-dmac"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-invalid-dmac" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropInvalidEncap(Entity):
                                                """
                                                INPUT DROP INVALID ENCAP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap, self).__init__()

                                                    self.yang_name = "in-drop-invalid-encap"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-invalid-encap" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropOther(Entity):
                                                """
                                                INPUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther, self).__init__()

                                                    self.yang_name = "in-drop-other"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-other" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InMibGiant(Entity):
                                                """
                                                INPUT MIB GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant, self).__init__()

                                                    self.yang_name = "in-mib-giant"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-mib-giant" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InMibJabber(Entity):
                                                """
                                                INPUT MIB JABBER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber, self).__init__()

                                                    self.yang_name = "in-mib-jabber"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-mib-jabber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InMibcrc(Entity):
                                                """
                                                IN MIB CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc, self).__init__()

                                                    self.yang_name = "in-mibcrc"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-mibcrc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorCollisions(Entity):
                                                """
                                                IN ERROR COLLISIONS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions, self).__init__()

                                                    self.yang_name = "in-error-collisions"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-collisions" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorSymbol(Entity):
                                                """
                                                IN ERROR SYMBOL
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol, self).__init__()

                                                    self.yang_name = "in-error-symbol"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-symbol" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutGoodBytes(Entity):
                                                """
                                                OUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes, self).__init__()

                                                    self.yang_name = "out-good-bytes"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-good-bytes" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Out8021QFrames(Entity):
                                                """
                                                OUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021QFrames, self).__init__()

                                                    self.yang_name = "out8021q-frames"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021QFrames, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021QFrames, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out8021q-frames" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPauseFrames(Entity):
                                                """
                                                OUT PAUSE FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames, self).__init__()

                                                    self.yang_name = "out-pause-frames"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pause-frames" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts1519MaxOctets(Entity):
                                                """
                                                OUT PKTS 1519 MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "out-pkts1519-max-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts1519-max-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutGoodPkts(Entity):
                                                """
                                                OUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts, self).__init__()

                                                    self.yang_name = "out-good-pkts"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-good-pkts" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutDropUnderrun(Entity):
                                                """
                                                OUT DROP UNDERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun, self).__init__()

                                                    self.yang_name = "out-drop-underrun"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-drop-underrun" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutDropAbort(Entity):
                                                """
                                                OUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort, self).__init__()

                                                    self.yang_name = "out-drop-abort"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-drop-abort" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutDropOther(Entity):
                                                """
                                                OUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther, self).__init__()

                                                    self.yang_name = "out-drop-other"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-drop-other" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutErrorOther(Entity):
                                                """
                                                OUT ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther, self).__init__()

                                                    self.yang_name = "out-error-other"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-error-other" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorGiant(Entity):
                                                """
                                                IN ERROR GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant, self).__init__()

                                                    self.yang_name = "in-error-giant"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-giant" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorRunt(Entity):
                                                """
                                                IN ERROR RUNT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt, self).__init__()

                                                    self.yang_name = "in-error-runt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-runt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorJabbers(Entity):
                                                """
                                                IN ERROR JABBERS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers, self).__init__()

                                                    self.yang_name = "in-error-jabbers"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-jabbers" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorFragments(Entity):
                                                """
                                                IN ERROR FRAGMENTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments, self).__init__()

                                                    self.yang_name = "in-error-fragments"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-fragments" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorOther(Entity):
                                                """
                                                IN ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther, self).__init__()

                                                    self.yang_name = "in-error-other"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-other" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkt64Octet(Entity):
                                                """
                                                IN PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet, self).__init__()

                                                    self.yang_name = "in-pkt64-octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkt64-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts65To127Octets(Entity):
                                                """
                                                IN PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets, self).__init__()

                                                    self.yang_name = "in-pkts65-to127-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts65-to127-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts128To255Octets(Entity):
                                                """
                                                IN PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets, self).__init__()

                                                    self.yang_name = "in-pkts128-to255-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts128-to255-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts256To511Octets(Entity):
                                                """
                                                IN PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets, self).__init__()

                                                    self.yang_name = "in-pkts256-to511-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts256-to511-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts512To1023Octets(Entity):
                                                """
                                                IN PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets, self).__init__()

                                                    self.yang_name = "in-pkts512-to1023-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts512-to1023-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts1024To1518Octets(Entity):
                                                """
                                                IN PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets, self).__init__()

                                                    self.yang_name = "in-pkts1024-to1518-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts1024-to1518-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Outpkt64Octet(Entity):
                                                """
                                                OUT PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64Octet, self).__init__()

                                                    self.yang_name = "outpkt64octet"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "outpkt64octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts65127Octets(Entity):
                                                """
                                                OUT PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets, self).__init__()

                                                    self.yang_name = "out-pkts65127-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts65127-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts128255Octets(Entity):
                                                """
                                                OUT PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets, self).__init__()

                                                    self.yang_name = "out-pkts128255-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts128255-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts256511Octets(Entity):
                                                """
                                                OUT PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets, self).__init__()

                                                    self.yang_name = "out-pkts256511-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts256511-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts5121023Octets(Entity):
                                                """
                                                OUT PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets, self).__init__()

                                                    self.yang_name = "out-pkts5121023-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts5121023-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts10241518Octets(Entity):
                                                """
                                                OUT PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets, self).__init__()

                                                    self.yang_name = "out-pkts10241518-octets"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts10241518-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class RxUtil(Entity):
                                                """
                                                Rx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil, self).__init__()

                                                    self.yang_name = "rx-util"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-util" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxUtil(Entity):
                                                """
                                                Tx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil, self).__init__()

                                                    self.yang_name = "tx-util"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-util" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxUndersizedPkt(Entity):
                                                """
                                                TX Undersized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt, self).__init__()

                                                    self.yang_name = "tx-undersized-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-undersized-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxOversizedPkt(Entity):
                                                """
                                                TX Oversized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt, self).__init__()

                                                    self.yang_name = "tx-oversized-pkt"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-oversized-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxFragments(Entity):
                                                """
                                                TX Fragments
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments, self).__init__()

                                                    self.yang_name = "tx-fragments"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-fragments" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxJabber(Entity):
                                                """
                                                TX Jabber
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber, self).__init__()

                                                    self.yang_name = "tx-jabber"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-jabber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxBadFcs(Entity):
                                                """
                                                TX Bad Fcs
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs, self).__init__()

                                                    self.yang_name = "tx-bad-fcs"
                                                    self.yang_parent_name = "second30-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-bad-fcs" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.ether10241518_octet is not None and self.ether10241518_octet.has_data()) or
                                                    (self.ether128255_octet is not None and self.ether128255_octet.has_data()) or
                                                    (self.ether256511_octet is not None and self.ether256511_octet.has_data()) or
                                                    (self.ether5121023_octet is not None and self.ether5121023_octet.has_data()) or
                                                    (self.ether64_octets is not None and self.ether64_octets.has_data()) or
                                                    (self.ether65127_octet is not None and self.ether65127_octet.has_data()) or
                                                    (self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt.has_data()) or
                                                    (self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt.has_data()) or
                                                    (self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt.has_data()) or
                                                    (self.fcs_errors_stat is not None and self.fcs_errors_stat.has_data()) or
                                                    (self.if_in_errors is not None and self.if_in_errors.has_data()) or
                                                    (self.if_in_octets is not None and self.if_in_octets.has_data()) or
                                                    (self.in8021q_frames is not None and self.in8021q_frames.has_data()) or
                                                    (self.in_bcast_pkt is not None and self.in_bcast_pkt.has_data()) or
                                                    (self.in_drop_abort is not None and self.in_drop_abort.has_data()) or
                                                    (self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac.has_data()) or
                                                    (self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap.has_data()) or
                                                    (self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan.has_data()) or
                                                    (self.in_drop_other is not None and self.in_drop_other.has_data()) or
                                                    (self.in_drop_overrun is not None and self.in_drop_overrun.has_data()) or
                                                    (self.in_error_collisions is not None and self.in_error_collisions.has_data()) or
                                                    (self.in_error_fragments is not None and self.in_error_fragments.has_data()) or
                                                    (self.in_error_giant is not None and self.in_error_giant.has_data()) or
                                                    (self.in_error_jabbers is not None and self.in_error_jabbers.has_data()) or
                                                    (self.in_error_other is not None and self.in_error_other.has_data()) or
                                                    (self.in_error_runt is not None and self.in_error_runt.has_data()) or
                                                    (self.in_error_symbol is not None and self.in_error_symbol.has_data()) or
                                                    (self.in_good_bytes is not None and self.in_good_bytes.has_data()) or
                                                    (self.in_good_pkts is not None and self.in_good_pkts.has_data()) or
                                                    (self.in_mcast_pkt is not None and self.in_mcast_pkt.has_data()) or
                                                    (self.in_mib_giant is not None and self.in_mib_giant.has_data()) or
                                                    (self.in_mib_jabber is not None and self.in_mib_jabber.has_data()) or
                                                    (self.in_mibcrc is not None and self.in_mibcrc.has_data()) or
                                                    (self.in_pause_frame is not None and self.in_pause_frame.has_data()) or
                                                    (self.in_pkt64_octet is not None and self.in_pkt64_octet.has_data()) or
                                                    (self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets.has_data()) or
                                                    (self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets.has_data()) or
                                                    (self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets.has_data()) or
                                                    (self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets.has_data()) or
                                                    (self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets.has_data()) or
                                                    (self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets.has_data()) or
                                                    (self.in_ucast_pkt is not None and self.in_ucast_pkt.has_data()) or
                                                    (self.jabber_stat is not None and self.jabber_stat.has_data()) or
                                                    (self.long_frames_stat is not None and self.long_frames_stat.has_data()) or
                                                    (self.octet_stat is not None and self.octet_stat.has_data()) or
                                                    (self.out8021q_frames is not None and self.out8021q_frames.has_data()) or
                                                    (self.out_bcast_pkt is not None and self.out_bcast_pkt.has_data()) or
                                                    (self.out_drop_abort is not None and self.out_drop_abort.has_data()) or
                                                    (self.out_drop_other is not None and self.out_drop_other.has_data()) or
                                                    (self.out_drop_underrun is not None and self.out_drop_underrun.has_data()) or
                                                    (self.out_error_other is not None and self.out_error_other.has_data()) or
                                                    (self.out_good_bytes is not None and self.out_good_bytes.has_data()) or
                                                    (self.out_good_pkts is not None and self.out_good_pkts.has_data()) or
                                                    (self.out_mcast_pkt is not None and self.out_mcast_pkt.has_data()) or
                                                    (self.out_octets is not None and self.out_octets.has_data()) or
                                                    (self.out_pause_frames is not None and self.out_pause_frames.has_data()) or
                                                    (self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets.has_data()) or
                                                    (self.out_pkts128255_octets is not None and self.out_pkts128255_octets.has_data()) or
                                                    (self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets.has_data()) or
                                                    (self.out_pkts256511_octets is not None and self.out_pkts256511_octets.has_data()) or
                                                    (self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets.has_data()) or
                                                    (self.out_pkts65127_octets is not None and self.out_pkts65127_octets.has_data()) or
                                                    (self.out_ucast_pkt is not None and self.out_ucast_pkt.has_data()) or
                                                    (self.outpkt64octet is not None and self.outpkt64octet.has_data()) or
                                                    (self.oversize_pkt_stat is not None and self.oversize_pkt_stat.has_data()) or
                                                    (self.rx_pkt is not None and self.rx_pkt.has_data()) or
                                                    (self.rx_util is not None and self.rx_util.has_data()) or
                                                    (self.stat_pkt is not None and self.stat_pkt.has_data()) or
                                                    (self.tx_bad_fcs is not None and self.tx_bad_fcs.has_data()) or
                                                    (self.tx_fragments is not None and self.tx_fragments.has_data()) or
                                                    (self.tx_jabber is not None and self.tx_jabber.has_data()) or
                                                    (self.tx_oversized_pkt is not None and self.tx_oversized_pkt.has_data()) or
                                                    (self.tx_pkt is not None and self.tx_pkt.has_data()) or
                                                    (self.tx_undersized_pkt is not None and self.tx_undersized_pkt.has_data()) or
                                                    (self.tx_util is not None and self.tx_util.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.ether10241518_octet is not None and self.ether10241518_octet.has_operation()) or
                                                    (self.ether128255_octet is not None and self.ether128255_octet.has_operation()) or
                                                    (self.ether256511_octet is not None and self.ether256511_octet.has_operation()) or
                                                    (self.ether5121023_octet is not None and self.ether5121023_octet.has_operation()) or
                                                    (self.ether64_octets is not None and self.ether64_octets.has_operation()) or
                                                    (self.ether65127_octet is not None and self.ether65127_octet.has_operation()) or
                                                    (self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt.has_operation()) or
                                                    (self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt.has_operation()) or
                                                    (self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt.has_operation()) or
                                                    (self.fcs_errors_stat is not None and self.fcs_errors_stat.has_operation()) or
                                                    (self.if_in_errors is not None and self.if_in_errors.has_operation()) or
                                                    (self.if_in_octets is not None and self.if_in_octets.has_operation()) or
                                                    (self.in8021q_frames is not None and self.in8021q_frames.has_operation()) or
                                                    (self.in_bcast_pkt is not None and self.in_bcast_pkt.has_operation()) or
                                                    (self.in_drop_abort is not None and self.in_drop_abort.has_operation()) or
                                                    (self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac.has_operation()) or
                                                    (self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap.has_operation()) or
                                                    (self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan.has_operation()) or
                                                    (self.in_drop_other is not None and self.in_drop_other.has_operation()) or
                                                    (self.in_drop_overrun is not None and self.in_drop_overrun.has_operation()) or
                                                    (self.in_error_collisions is not None and self.in_error_collisions.has_operation()) or
                                                    (self.in_error_fragments is not None and self.in_error_fragments.has_operation()) or
                                                    (self.in_error_giant is not None and self.in_error_giant.has_operation()) or
                                                    (self.in_error_jabbers is not None and self.in_error_jabbers.has_operation()) or
                                                    (self.in_error_other is not None and self.in_error_other.has_operation()) or
                                                    (self.in_error_runt is not None and self.in_error_runt.has_operation()) or
                                                    (self.in_error_symbol is not None and self.in_error_symbol.has_operation()) or
                                                    (self.in_good_bytes is not None and self.in_good_bytes.has_operation()) or
                                                    (self.in_good_pkts is not None and self.in_good_pkts.has_operation()) or
                                                    (self.in_mcast_pkt is not None and self.in_mcast_pkt.has_operation()) or
                                                    (self.in_mib_giant is not None and self.in_mib_giant.has_operation()) or
                                                    (self.in_mib_jabber is not None and self.in_mib_jabber.has_operation()) or
                                                    (self.in_mibcrc is not None and self.in_mibcrc.has_operation()) or
                                                    (self.in_pause_frame is not None and self.in_pause_frame.has_operation()) or
                                                    (self.in_pkt64_octet is not None and self.in_pkt64_octet.has_operation()) or
                                                    (self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets.has_operation()) or
                                                    (self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets.has_operation()) or
                                                    (self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets.has_operation()) or
                                                    (self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets.has_operation()) or
                                                    (self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets.has_operation()) or
                                                    (self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets.has_operation()) or
                                                    (self.in_ucast_pkt is not None and self.in_ucast_pkt.has_operation()) or
                                                    (self.jabber_stat is not None and self.jabber_stat.has_operation()) or
                                                    (self.long_frames_stat is not None and self.long_frames_stat.has_operation()) or
                                                    (self.octet_stat is not None and self.octet_stat.has_operation()) or
                                                    (self.out8021q_frames is not None and self.out8021q_frames.has_operation()) or
                                                    (self.out_bcast_pkt is not None and self.out_bcast_pkt.has_operation()) or
                                                    (self.out_drop_abort is not None and self.out_drop_abort.has_operation()) or
                                                    (self.out_drop_other is not None and self.out_drop_other.has_operation()) or
                                                    (self.out_drop_underrun is not None and self.out_drop_underrun.has_operation()) or
                                                    (self.out_error_other is not None and self.out_error_other.has_operation()) or
                                                    (self.out_good_bytes is not None and self.out_good_bytes.has_operation()) or
                                                    (self.out_good_pkts is not None and self.out_good_pkts.has_operation()) or
                                                    (self.out_mcast_pkt is not None and self.out_mcast_pkt.has_operation()) or
                                                    (self.out_octets is not None and self.out_octets.has_operation()) or
                                                    (self.out_pause_frames is not None and self.out_pause_frames.has_operation()) or
                                                    (self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets.has_operation()) or
                                                    (self.out_pkts128255_octets is not None and self.out_pkts128255_octets.has_operation()) or
                                                    (self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets.has_operation()) or
                                                    (self.out_pkts256511_octets is not None and self.out_pkts256511_octets.has_operation()) or
                                                    (self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets.has_operation()) or
                                                    (self.out_pkts65127_octets is not None and self.out_pkts65127_octets.has_operation()) or
                                                    (self.out_ucast_pkt is not None and self.out_ucast_pkt.has_operation()) or
                                                    (self.outpkt64octet is not None and self.outpkt64octet.has_operation()) or
                                                    (self.oversize_pkt_stat is not None and self.oversize_pkt_stat.has_operation()) or
                                                    (self.rx_pkt is not None and self.rx_pkt.has_operation()) or
                                                    (self.rx_util is not None and self.rx_util.has_operation()) or
                                                    (self.stat_pkt is not None and self.stat_pkt.has_operation()) or
                                                    (self.tx_bad_fcs is not None and self.tx_bad_fcs.has_operation()) or
                                                    (self.tx_fragments is not None and self.tx_fragments.has_operation()) or
                                                    (self.tx_jabber is not None and self.tx_jabber.has_operation()) or
                                                    (self.tx_oversized_pkt is not None and self.tx_oversized_pkt.has_operation()) or
                                                    (self.tx_pkt is not None and self.tx_pkt.has_operation()) or
                                                    (self.tx_undersized_pkt is not None and self.tx_undersized_pkt.has_operation()) or
                                                    (self.tx_util is not None and self.tx_util.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "second30-ether-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ether10241518-octet"):
                                                    if (self.ether10241518_octet is None):
                                                        self.ether10241518_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether10241518Octet()
                                                        self.ether10241518_octet.parent = self
                                                        self._children_name_map["ether10241518_octet"] = "ether10241518-octet"
                                                    return self.ether10241518_octet

                                                if (child_yang_name == "ether128255-octet"):
                                                    if (self.ether128255_octet is None):
                                                        self.ether128255_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether128255Octet()
                                                        self.ether128255_octet.parent = self
                                                        self._children_name_map["ether128255_octet"] = "ether128255-octet"
                                                    return self.ether128255_octet

                                                if (child_yang_name == "ether256511-octet"):
                                                    if (self.ether256511_octet is None):
                                                        self.ether256511_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether256511Octet()
                                                        self.ether256511_octet.parent = self
                                                        self._children_name_map["ether256511_octet"] = "ether256511-octet"
                                                    return self.ether256511_octet

                                                if (child_yang_name == "ether5121023-octet"):
                                                    if (self.ether5121023_octet is None):
                                                        self.ether5121023_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether5121023Octet()
                                                        self.ether5121023_octet.parent = self
                                                        self._children_name_map["ether5121023_octet"] = "ether5121023-octet"
                                                    return self.ether5121023_octet

                                                if (child_yang_name == "ether64-octets"):
                                                    if (self.ether64_octets is None):
                                                        self.ether64_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether64Octets()
                                                        self.ether64_octets.parent = self
                                                        self._children_name_map["ether64_octets"] = "ether64-octets"
                                                    return self.ether64_octets

                                                if (child_yang_name == "ether65127-octet"):
                                                    if (self.ether65127_octet is None):
                                                        self.ether65127_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Ether65127Octet()
                                                        self.ether65127_octet.parent = self
                                                        self._children_name_map["ether65127_octet"] = "ether65127-octet"
                                                    return self.ether65127_octet

                                                if (child_yang_name == "ether-stat-broadcast-pkt"):
                                                    if (self.ether_stat_broadcast_pkt is None):
                                                        self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                        self.ether_stat_broadcast_pkt.parent = self
                                                        self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"
                                                    return self.ether_stat_broadcast_pkt

                                                if (child_yang_name == "ether-stat-multicast-pkt"):
                                                    if (self.ether_stat_multicast_pkt is None):
                                                        self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatMulticastPkt()
                                                        self.ether_stat_multicast_pkt.parent = self
                                                        self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"
                                                    return self.ether_stat_multicast_pkt

                                                if (child_yang_name == "ether-stat-undersized-pkt"):
                                                    if (self.ether_stat_undersized_pkt is None):
                                                        self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                        self.ether_stat_undersized_pkt.parent = self
                                                        self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"
                                                    return self.ether_stat_undersized_pkt

                                                if (child_yang_name == "fcs-errors-stat"):
                                                    if (self.fcs_errors_stat is None):
                                                        self.fcs_errors_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.FcsErrorsStat()
                                                        self.fcs_errors_stat.parent = self
                                                        self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"
                                                    return self.fcs_errors_stat

                                                if (child_yang_name == "if-in-errors"):
                                                    if (self.if_in_errors is None):
                                                        self.if_in_errors = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInErrors()
                                                        self.if_in_errors.parent = self
                                                        self._children_name_map["if_in_errors"] = "if-in-errors"
                                                    return self.if_in_errors

                                                if (child_yang_name == "if-in-octets"):
                                                    if (self.if_in_octets is None):
                                                        self.if_in_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.IfInOctets()
                                                        self.if_in_octets.parent = self
                                                        self._children_name_map["if_in_octets"] = "if-in-octets"
                                                    return self.if_in_octets

                                                if (child_yang_name == "in8021q-frames"):
                                                    if (self.in8021q_frames is None):
                                                        self.in8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.In8021QFrames()
                                                        self.in8021q_frames.parent = self
                                                        self._children_name_map["in8021q_frames"] = "in8021q-frames"
                                                    return self.in8021q_frames

                                                if (child_yang_name == "in-bcast-pkt"):
                                                    if (self.in_bcast_pkt is None):
                                                        self.in_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InBcastPkt()
                                                        self.in_bcast_pkt.parent = self
                                                        self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"
                                                    return self.in_bcast_pkt

                                                if (child_yang_name == "in-drop-abort"):
                                                    if (self.in_drop_abort is None):
                                                        self.in_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropAbort()
                                                        self.in_drop_abort.parent = self
                                                        self._children_name_map["in_drop_abort"] = "in-drop-abort"
                                                    return self.in_drop_abort

                                                if (child_yang_name == "in-drop-invalid-dmac"):
                                                    if (self.in_drop_invalid_dmac is None):
                                                        self.in_drop_invalid_dmac = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidDmac()
                                                        self.in_drop_invalid_dmac.parent = self
                                                        self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"
                                                    return self.in_drop_invalid_dmac

                                                if (child_yang_name == "in-drop-invalid-encap"):
                                                    if (self.in_drop_invalid_encap is None):
                                                        self.in_drop_invalid_encap = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidEncap()
                                                        self.in_drop_invalid_encap.parent = self
                                                        self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"
                                                    return self.in_drop_invalid_encap

                                                if (child_yang_name == "in-drop-invalid-vlan"):
                                                    if (self.in_drop_invalid_vlan is None):
                                                        self.in_drop_invalid_vlan = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropInvalidVlan()
                                                        self.in_drop_invalid_vlan.parent = self
                                                        self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"
                                                    return self.in_drop_invalid_vlan

                                                if (child_yang_name == "in-drop-other"):
                                                    if (self.in_drop_other is None):
                                                        self.in_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOther()
                                                        self.in_drop_other.parent = self
                                                        self._children_name_map["in_drop_other"] = "in-drop-other"
                                                    return self.in_drop_other

                                                if (child_yang_name == "in-drop-overrun"):
                                                    if (self.in_drop_overrun is None):
                                                        self.in_drop_overrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InDropOverrun()
                                                        self.in_drop_overrun.parent = self
                                                        self._children_name_map["in_drop_overrun"] = "in-drop-overrun"
                                                    return self.in_drop_overrun

                                                if (child_yang_name == "in-error-collisions"):
                                                    if (self.in_error_collisions is None):
                                                        self.in_error_collisions = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorCollisions()
                                                        self.in_error_collisions.parent = self
                                                        self._children_name_map["in_error_collisions"] = "in-error-collisions"
                                                    return self.in_error_collisions

                                                if (child_yang_name == "in-error-fragments"):
                                                    if (self.in_error_fragments is None):
                                                        self.in_error_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorFragments()
                                                        self.in_error_fragments.parent = self
                                                        self._children_name_map["in_error_fragments"] = "in-error-fragments"
                                                    return self.in_error_fragments

                                                if (child_yang_name == "in-error-giant"):
                                                    if (self.in_error_giant is None):
                                                        self.in_error_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorGiant()
                                                        self.in_error_giant.parent = self
                                                        self._children_name_map["in_error_giant"] = "in-error-giant"
                                                    return self.in_error_giant

                                                if (child_yang_name == "in-error-jabbers"):
                                                    if (self.in_error_jabbers is None):
                                                        self.in_error_jabbers = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorJabbers()
                                                        self.in_error_jabbers.parent = self
                                                        self._children_name_map["in_error_jabbers"] = "in-error-jabbers"
                                                    return self.in_error_jabbers

                                                if (child_yang_name == "in-error-other"):
                                                    if (self.in_error_other is None):
                                                        self.in_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorOther()
                                                        self.in_error_other.parent = self
                                                        self._children_name_map["in_error_other"] = "in-error-other"
                                                    return self.in_error_other

                                                if (child_yang_name == "in-error-runt"):
                                                    if (self.in_error_runt is None):
                                                        self.in_error_runt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorRunt()
                                                        self.in_error_runt.parent = self
                                                        self._children_name_map["in_error_runt"] = "in-error-runt"
                                                    return self.in_error_runt

                                                if (child_yang_name == "in-error-symbol"):
                                                    if (self.in_error_symbol is None):
                                                        self.in_error_symbol = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InErrorSymbol()
                                                        self.in_error_symbol.parent = self
                                                        self._children_name_map["in_error_symbol"] = "in-error-symbol"
                                                    return self.in_error_symbol

                                                if (child_yang_name == "in-good-bytes"):
                                                    if (self.in_good_bytes is None):
                                                        self.in_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodBytes()
                                                        self.in_good_bytes.parent = self
                                                        self._children_name_map["in_good_bytes"] = "in-good-bytes"
                                                    return self.in_good_bytes

                                                if (child_yang_name == "in-good-pkts"):
                                                    if (self.in_good_pkts is None):
                                                        self.in_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InGoodPkts()
                                                        self.in_good_pkts.parent = self
                                                        self._children_name_map["in_good_pkts"] = "in-good-pkts"
                                                    return self.in_good_pkts

                                                if (child_yang_name == "in-mcast-pkt"):
                                                    if (self.in_mcast_pkt is None):
                                                        self.in_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMcastPkt()
                                                        self.in_mcast_pkt.parent = self
                                                        self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"
                                                    return self.in_mcast_pkt

                                                if (child_yang_name == "in-mib-giant"):
                                                    if (self.in_mib_giant is None):
                                                        self.in_mib_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibGiant()
                                                        self.in_mib_giant.parent = self
                                                        self._children_name_map["in_mib_giant"] = "in-mib-giant"
                                                    return self.in_mib_giant

                                                if (child_yang_name == "in-mib-jabber"):
                                                    if (self.in_mib_jabber is None):
                                                        self.in_mib_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibJabber()
                                                        self.in_mib_jabber.parent = self
                                                        self._children_name_map["in_mib_jabber"] = "in-mib-jabber"
                                                    return self.in_mib_jabber

                                                if (child_yang_name == "in-mibcrc"):
                                                    if (self.in_mibcrc is None):
                                                        self.in_mibcrc = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InMibcrc()
                                                        self.in_mibcrc.parent = self
                                                        self._children_name_map["in_mibcrc"] = "in-mibcrc"
                                                    return self.in_mibcrc

                                                if (child_yang_name == "in-pause-frame"):
                                                    if (self.in_pause_frame is None):
                                                        self.in_pause_frame = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPauseFrame()
                                                        self.in_pause_frame.parent = self
                                                        self._children_name_map["in_pause_frame"] = "in-pause-frame"
                                                    return self.in_pause_frame

                                                if (child_yang_name == "in-pkt64-octet"):
                                                    if (self.in_pkt64_octet is None):
                                                        self.in_pkt64_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkt64Octet()
                                                        self.in_pkt64_octet.parent = self
                                                        self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"
                                                    return self.in_pkt64_octet

                                                if (child_yang_name == "in-pkts1024-to1518-octets"):
                                                    if (self.in_pkts1024_to1518_octets is None):
                                                        self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1024To1518Octets()
                                                        self.in_pkts1024_to1518_octets.parent = self
                                                        self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"
                                                    return self.in_pkts1024_to1518_octets

                                                if (child_yang_name == "in-pkts128-to255-octets"):
                                                    if (self.in_pkts128_to255_octets is None):
                                                        self.in_pkts128_to255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts128To255Octets()
                                                        self.in_pkts128_to255_octets.parent = self
                                                        self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"
                                                    return self.in_pkts128_to255_octets

                                                if (child_yang_name == "in-pkts1519-max-octets"):
                                                    if (self.in_pkts1519_max_octets is None):
                                                        self.in_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts1519MaxOctets()
                                                        self.in_pkts1519_max_octets.parent = self
                                                        self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"
                                                    return self.in_pkts1519_max_octets

                                                if (child_yang_name == "in-pkts256-to511-octets"):
                                                    if (self.in_pkts256_to511_octets is None):
                                                        self.in_pkts256_to511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts256To511Octets()
                                                        self.in_pkts256_to511_octets.parent = self
                                                        self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"
                                                    return self.in_pkts256_to511_octets

                                                if (child_yang_name == "in-pkts512-to1023-octets"):
                                                    if (self.in_pkts512_to1023_octets is None):
                                                        self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts512To1023Octets()
                                                        self.in_pkts512_to1023_octets.parent = self
                                                        self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"
                                                    return self.in_pkts512_to1023_octets

                                                if (child_yang_name == "in-pkts65-to127-octets"):
                                                    if (self.in_pkts65_to127_octets is None):
                                                        self.in_pkts65_to127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InPkts65To127Octets()
                                                        self.in_pkts65_to127_octets.parent = self
                                                        self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"
                                                    return self.in_pkts65_to127_octets

                                                if (child_yang_name == "in-ucast-pkt"):
                                                    if (self.in_ucast_pkt is None):
                                                        self.in_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.InUcastPkt()
                                                        self.in_ucast_pkt.parent = self
                                                        self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"
                                                    return self.in_ucast_pkt

                                                if (child_yang_name == "jabber-stat"):
                                                    if (self.jabber_stat is None):
                                                        self.jabber_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.JabberStat()
                                                        self.jabber_stat.parent = self
                                                        self._children_name_map["jabber_stat"] = "jabber-stat"
                                                    return self.jabber_stat

                                                if (child_yang_name == "long-frames-stat"):
                                                    if (self.long_frames_stat is None):
                                                        self.long_frames_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.LongFramesStat()
                                                        self.long_frames_stat.parent = self
                                                        self._children_name_map["long_frames_stat"] = "long-frames-stat"
                                                    return self.long_frames_stat

                                                if (child_yang_name == "octet-stat"):
                                                    if (self.octet_stat is None):
                                                        self.octet_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OctetStat()
                                                        self.octet_stat.parent = self
                                                        self._children_name_map["octet_stat"] = "octet-stat"
                                                    return self.octet_stat

                                                if (child_yang_name == "out8021q-frames"):
                                                    if (self.out8021q_frames is None):
                                                        self.out8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Out8021QFrames()
                                                        self.out8021q_frames.parent = self
                                                        self._children_name_map["out8021q_frames"] = "out8021q-frames"
                                                    return self.out8021q_frames

                                                if (child_yang_name == "out-bcast-pkt"):
                                                    if (self.out_bcast_pkt is None):
                                                        self.out_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutBcastPkt()
                                                        self.out_bcast_pkt.parent = self
                                                        self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"
                                                    return self.out_bcast_pkt

                                                if (child_yang_name == "out-drop-abort"):
                                                    if (self.out_drop_abort is None):
                                                        self.out_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropAbort()
                                                        self.out_drop_abort.parent = self
                                                        self._children_name_map["out_drop_abort"] = "out-drop-abort"
                                                    return self.out_drop_abort

                                                if (child_yang_name == "out-drop-other"):
                                                    if (self.out_drop_other is None):
                                                        self.out_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropOther()
                                                        self.out_drop_other.parent = self
                                                        self._children_name_map["out_drop_other"] = "out-drop-other"
                                                    return self.out_drop_other

                                                if (child_yang_name == "out-drop-underrun"):
                                                    if (self.out_drop_underrun is None):
                                                        self.out_drop_underrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutDropUnderrun()
                                                        self.out_drop_underrun.parent = self
                                                        self._children_name_map["out_drop_underrun"] = "out-drop-underrun"
                                                    return self.out_drop_underrun

                                                if (child_yang_name == "out-error-other"):
                                                    if (self.out_error_other is None):
                                                        self.out_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutErrorOther()
                                                        self.out_error_other.parent = self
                                                        self._children_name_map["out_error_other"] = "out-error-other"
                                                    return self.out_error_other

                                                if (child_yang_name == "out-good-bytes"):
                                                    if (self.out_good_bytes is None):
                                                        self.out_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodBytes()
                                                        self.out_good_bytes.parent = self
                                                        self._children_name_map["out_good_bytes"] = "out-good-bytes"
                                                    return self.out_good_bytes

                                                if (child_yang_name == "out-good-pkts"):
                                                    if (self.out_good_pkts is None):
                                                        self.out_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutGoodPkts()
                                                        self.out_good_pkts.parent = self
                                                        self._children_name_map["out_good_pkts"] = "out-good-pkts"
                                                    return self.out_good_pkts

                                                if (child_yang_name == "out-mcast-pkt"):
                                                    if (self.out_mcast_pkt is None):
                                                        self.out_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutMcastPkt()
                                                        self.out_mcast_pkt.parent = self
                                                        self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"
                                                    return self.out_mcast_pkt

                                                if (child_yang_name == "out-octets"):
                                                    if (self.out_octets is None):
                                                        self.out_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutOctets()
                                                        self.out_octets.parent = self
                                                        self._children_name_map["out_octets"] = "out-octets"
                                                    return self.out_octets

                                                if (child_yang_name == "out-pause-frames"):
                                                    if (self.out_pause_frames is None):
                                                        self.out_pause_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPauseFrames()
                                                        self.out_pause_frames.parent = self
                                                        self._children_name_map["out_pause_frames"] = "out-pause-frames"
                                                    return self.out_pause_frames

                                                if (child_yang_name == "out-pkts10241518-octets"):
                                                    if (self.out_pkts10241518_octets is None):
                                                        self.out_pkts10241518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts10241518Octets()
                                                        self.out_pkts10241518_octets.parent = self
                                                        self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"
                                                    return self.out_pkts10241518_octets

                                                if (child_yang_name == "out-pkts128255-octets"):
                                                    if (self.out_pkts128255_octets is None):
                                                        self.out_pkts128255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts128255Octets()
                                                        self.out_pkts128255_octets.parent = self
                                                        self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"
                                                    return self.out_pkts128255_octets

                                                if (child_yang_name == "out-pkts1519-max-octets"):
                                                    if (self.out_pkts1519_max_octets is None):
                                                        self.out_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                        self.out_pkts1519_max_octets.parent = self
                                                        self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"
                                                    return self.out_pkts1519_max_octets

                                                if (child_yang_name == "out-pkts256511-octets"):
                                                    if (self.out_pkts256511_octets is None):
                                                        self.out_pkts256511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts256511Octets()
                                                        self.out_pkts256511_octets.parent = self
                                                        self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"
                                                    return self.out_pkts256511_octets

                                                if (child_yang_name == "out-pkts5121023-octets"):
                                                    if (self.out_pkts5121023_octets is None):
                                                        self.out_pkts5121023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts5121023Octets()
                                                        self.out_pkts5121023_octets.parent = self
                                                        self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"
                                                    return self.out_pkts5121023_octets

                                                if (child_yang_name == "out-pkts65127-octets"):
                                                    if (self.out_pkts65127_octets is None):
                                                        self.out_pkts65127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutPkts65127Octets()
                                                        self.out_pkts65127_octets.parent = self
                                                        self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"
                                                    return self.out_pkts65127_octets

                                                if (child_yang_name == "out-ucast-pkt"):
                                                    if (self.out_ucast_pkt is None):
                                                        self.out_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OutUcastPkt()
                                                        self.out_ucast_pkt.parent = self
                                                        self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"
                                                    return self.out_ucast_pkt

                                                if (child_yang_name == "outpkt64octet"):
                                                    if (self.outpkt64octet is None):
                                                        self.outpkt64octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.Outpkt64Octet()
                                                        self.outpkt64octet.parent = self
                                                        self._children_name_map["outpkt64octet"] = "outpkt64octet"
                                                    return self.outpkt64octet

                                                if (child_yang_name == "oversize-pkt-stat"):
                                                    if (self.oversize_pkt_stat is None):
                                                        self.oversize_pkt_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.OversizePktStat()
                                                        self.oversize_pkt_stat.parent = self
                                                        self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"
                                                    return self.oversize_pkt_stat

                                                if (child_yang_name == "rx-pkt"):
                                                    if (self.rx_pkt is None):
                                                        self.rx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxPkt()
                                                        self.rx_pkt.parent = self
                                                        self._children_name_map["rx_pkt"] = "rx-pkt"
                                                    return self.rx_pkt

                                                if (child_yang_name == "rx-util"):
                                                    if (self.rx_util is None):
                                                        self.rx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.RxUtil()
                                                        self.rx_util.parent = self
                                                        self._children_name_map["rx_util"] = "rx-util"
                                                    return self.rx_util

                                                if (child_yang_name == "stat-pkt"):
                                                    if (self.stat_pkt is None):
                                                        self.stat_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.StatPkt()
                                                        self.stat_pkt.parent = self
                                                        self._children_name_map["stat_pkt"] = "stat-pkt"
                                                    return self.stat_pkt

                                                if (child_yang_name == "tx-bad-fcs"):
                                                    if (self.tx_bad_fcs is None):
                                                        self.tx_bad_fcs = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxBadFcs()
                                                        self.tx_bad_fcs.parent = self
                                                        self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                                    return self.tx_bad_fcs

                                                if (child_yang_name == "tx-fragments"):
                                                    if (self.tx_fragments is None):
                                                        self.tx_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxFragments()
                                                        self.tx_fragments.parent = self
                                                        self._children_name_map["tx_fragments"] = "tx-fragments"
                                                    return self.tx_fragments

                                                if (child_yang_name == "tx-jabber"):
                                                    if (self.tx_jabber is None):
                                                        self.tx_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxJabber()
                                                        self.tx_jabber.parent = self
                                                        self._children_name_map["tx_jabber"] = "tx-jabber"
                                                    return self.tx_jabber

                                                if (child_yang_name == "tx-oversized-pkt"):
                                                    if (self.tx_oversized_pkt is None):
                                                        self.tx_oversized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxOversizedPkt()
                                                        self.tx_oversized_pkt.parent = self
                                                        self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"
                                                    return self.tx_oversized_pkt

                                                if (child_yang_name == "tx-pkt"):
                                                    if (self.tx_pkt is None):
                                                        self.tx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxPkt()
                                                        self.tx_pkt.parent = self
                                                        self._children_name_map["tx_pkt"] = "tx-pkt"
                                                    return self.tx_pkt

                                                if (child_yang_name == "tx-undersized-pkt"):
                                                    if (self.tx_undersized_pkt is None):
                                                        self.tx_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUndersizedPkt()
                                                        self.tx_undersized_pkt.parent = self
                                                        self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"
                                                    return self.tx_undersized_pkt

                                                if (child_yang_name == "tx-util"):
                                                    if (self.tx_util is None):
                                                        self.tx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance.TxUtil()
                                                        self.tx_util.parent = self
                                                        self._children_name_map["tx_util"] = "tx-util"
                                                    return self.tx_util

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ether10241518-octet" or name == "ether128255-octet" or name == "ether256511-octet" or name == "ether5121023-octet" or name == "ether64-octets" or name == "ether65127-octet" or name == "ether-stat-broadcast-pkt" or name == "ether-stat-multicast-pkt" or name == "ether-stat-undersized-pkt" or name == "fcs-errors-stat" or name == "if-in-errors" or name == "if-in-octets" or name == "in8021q-frames" or name == "in-bcast-pkt" or name == "in-drop-abort" or name == "in-drop-invalid-dmac" or name == "in-drop-invalid-encap" or name == "in-drop-invalid-vlan" or name == "in-drop-other" or name == "in-drop-overrun" or name == "in-error-collisions" or name == "in-error-fragments" or name == "in-error-giant" or name == "in-error-jabbers" or name == "in-error-other" or name == "in-error-runt" or name == "in-error-symbol" or name == "in-good-bytes" or name == "in-good-pkts" or name == "in-mcast-pkt" or name == "in-mib-giant" or name == "in-mib-jabber" or name == "in-mibcrc" or name == "in-pause-frame" or name == "in-pkt64-octet" or name == "in-pkts1024-to1518-octets" or name == "in-pkts128-to255-octets" or name == "in-pkts1519-max-octets" or name == "in-pkts256-to511-octets" or name == "in-pkts512-to1023-octets" or name == "in-pkts65-to127-octets" or name == "in-ucast-pkt" or name == "jabber-stat" or name == "long-frames-stat" or name == "octet-stat" or name == "out8021q-frames" or name == "out-bcast-pkt" or name == "out-drop-abort" or name == "out-drop-other" or name == "out-drop-underrun" or name == "out-error-other" or name == "out-good-bytes" or name == "out-good-pkts" or name == "out-mcast-pkt" or name == "out-octets" or name == "out-pause-frames" or name == "out-pkts10241518-octets" or name == "out-pkts128255-octets" or name == "out-pkts1519-max-octets" or name == "out-pkts256511-octets" or name == "out-pkts5121023-octets" or name == "out-pkts65127-octets" or name == "out-ucast-pkt" or name == "outpkt64octet" or name == "oversize-pkt-stat" or name == "rx-pkt" or name == "rx-util" or name == "stat-pkt" or name == "tx-bad-fcs" or name == "tx-fragments" or name == "tx-jabber" or name == "tx-oversized-pkt" or name == "tx-pkt" or name == "tx-undersized-pkt" or name == "tx-util" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.second30_ether_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.second30_ether_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "second30-ether-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "second30-ether-time-line-instance"):
                                                for c in self.second30_ether_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances.Second30EtherTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.second30_ether_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "second30-ether-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.slot_number.is_set or
                                            (self.second30_ether_time_line_instances is not None and self.second30_ether_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.slot_number.yfilter != YFilter.not_set or
                                            (self.second30_ether_time_line_instances is not None and self.second30_ether_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "second30-ether-history" + "[slot-number='" + self.slot_number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.slot_number.is_set or self.slot_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.slot_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "second30-ether-time-line-instances"):
                                            if (self.second30_ether_time_line_instances is None):
                                                self.second30_ether_time_line_instances = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory.Second30EtherTimeLineInstances()
                                                self.second30_ether_time_line_instances.parent = self
                                                self._children_name_map["second30_ether_time_line_instances"] = "second30-ether-time-line-instances"
                                            return self.second30_ether_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "second30-ether-time-line-instances" or name == "slot-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "slot-number"):
                                            self.slot_number = value
                                            self.slot_number.value_namespace = name_space
                                            self.slot_number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.second30_ether_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.second30_ether_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "second30-ether-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "second30-ether-history"):
                                        for c in self.second30_ether_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories.Second30EtherHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.second30_ether_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "second30-ether-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.second30_ether_histories is not None and self.second30_ether_histories.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.second30_ether_histories is not None and self.second30_ether_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ethernet-second30-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "second30-ether-histories"):
                                    if (self.second30_ether_histories is None):
                                        self.second30_ether_histories = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History.Second30EtherHistories()
                                        self.second30_ether_histories.parent = self
                                        self._children_name_map["second30_ether_histories"] = "second30-ether-histories"
                                    return self.second30_ether_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "second30-ether-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class EthernetHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: ethernet_hour24_ether_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`EthernetHour24EtherHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History, self).__init__()

                                self.yang_name = "ethernet-hour24-history"
                                self.yang_parent_name = "ethernet-port-history"

                                self.ethernet_hour24_ether_histories = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories()
                                self.ethernet_hour24_ether_histories.parent = self
                                self._children_name_map["ethernet_hour24_ether_histories"] = "ethernet-hour24-ether-histories"
                                self._children_yang_names.add("ethernet-hour24-ether-histories")


                            class EthernetHour24EtherHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: ethernet_hour24_ether_history
                                
                                	port 24 hour ethernet performance data
                                	**type**\: list of    :py:class:`EthernetHour24EtherHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories, self).__init__()

                                    self.yang_name = "ethernet-hour24-ether-histories"
                                    self.yang_parent_name = "ethernet-hour24-history"

                                    self.ethernet_hour24_ether_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories, self).__setattr__(name, value)


                                class EthernetHour24EtherHistory(Entity):
                                    """
                                    port 24 hour ethernet performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ethernet_hour24_ether_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`EthernetHour24EtherTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory, self).__init__()

                                        self.yang_name = "ethernet-hour24-ether-history"
                                        self.yang_parent_name = "ethernet-hour24-ether-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.ethernet_hour24_ether_time_line_instances = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances()
                                        self.ethernet_hour24_ether_time_line_instances.parent = self
                                        self._children_name_map["ethernet_hour24_ether_time_line_instances"] = "ethernet-hour24-ether-time-line-instances"
                                        self._children_yang_names.add("ethernet-hour24-ether-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory, self).__setattr__(name, value)


                                    class EthernetHour24EtherTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: ethernet_hour24_ether_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`EthernetHour24EtherTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances, self).__init__()

                                            self.yang_name = "ethernet-hour24-ether-time-line-instances"
                                            self.yang_parent_name = "ethernet-hour24-ether-history"

                                            self.ethernet_hour24_ether_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances, self).__setattr__(name, value)


                                        class EthernetHour24EtherTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ether10241518_octet
                                            
                                            	OFO OCTET
                                            	**type**\:   :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet>`
                                            
                                            .. attribute:: ether128255_octet
                                            
                                            	TFF OCTET
                                            	**type**\:   :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet>`
                                            
                                            .. attribute:: ether256511_octet
                                            
                                            	FOO OCTET
                                            	**type**\:   :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet>`
                                            
                                            .. attribute:: ether5121023_octet
                                            
                                            	OZTT OCTET
                                            	**type**\:   :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet>`
                                            
                                            .. attribute:: ether64_octets
                                            
                                            	SIXTY FOUR OCTET
                                            	**type**\:   :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets>`
                                            
                                            .. attribute:: ether65127_octet
                                            
                                            	OCTET
                                            	**type**\:   :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet>`
                                            
                                            .. attribute:: ether_stat_broadcast_pkt
                                            
                                            	ETHER STAT BROADCAST PKT
                                            	**type**\:   :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt>`
                                            
                                            .. attribute:: ether_stat_multicast_pkt
                                            
                                            	ETHER STAT MULTICAST PKT
                                            	**type**\:   :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt>`
                                            
                                            .. attribute:: ether_stat_undersized_pkt
                                            
                                            	ETHER STAT UNDERSIZED PKT
                                            	**type**\:   :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt>`
                                            
                                            .. attribute:: fcs_errors_stat
                                            
                                            	FCS ERR
                                            	**type**\:   :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat>`
                                            
                                            .. attribute:: if_in_errors
                                            
                                            	IFIN ERRORS
                                            	**type**\:   :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors>`
                                            
                                            .. attribute:: if_in_octets
                                            
                                            	IFIN OCTETS
                                            	**type**\:   :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets>`
                                            
                                            .. attribute:: in8021q_frames
                                            
                                            	INPUT 802 1Q FRAMES
                                            	**type**\:   :py:class:`In8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021QFrames>`
                                            
                                            .. attribute:: in_bcast_pkt
                                            
                                            	IN BCAST
                                            	**type**\:   :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt>`
                                            
                                            .. attribute:: in_drop_abort
                                            
                                            	INPUT DROP ABORT
                                            	**type**\:   :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort>`
                                            
                                            .. attribute:: in_drop_invalid_dmac
                                            
                                            	INPUT DROP INVALID DMAC
                                            	**type**\:   :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac>`
                                            
                                            .. attribute:: in_drop_invalid_encap
                                            
                                            	INPUT DROP INVALID ENCAP
                                            	**type**\:   :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap>`
                                            
                                            .. attribute:: in_drop_invalid_vlan
                                            
                                            	INPUT DROP INVALID VLAN
                                            	**type**\:   :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan>`
                                            
                                            .. attribute:: in_drop_other
                                            
                                            	INPUT DROP OTHER
                                            	**type**\:   :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther>`
                                            
                                            .. attribute:: in_drop_overrun
                                            
                                            	INPUT DROP OVERRUN
                                            	**type**\:   :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun>`
                                            
                                            .. attribute:: in_error_collisions
                                            
                                            	IN ERROR COLLISIONS
                                            	**type**\:   :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions>`
                                            
                                            .. attribute:: in_error_fragments
                                            
                                            	IN ERROR FRAGMENTS
                                            	**type**\:   :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments>`
                                            
                                            .. attribute:: in_error_giant
                                            
                                            	IN ERROR GIANT
                                            	**type**\:   :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant>`
                                            
                                            .. attribute:: in_error_jabbers
                                            
                                            	IN ERROR JABBERS
                                            	**type**\:   :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers>`
                                            
                                            .. attribute:: in_error_other
                                            
                                            	IN ERROR OTHER
                                            	**type**\:   :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther>`
                                            
                                            .. attribute:: in_error_runt
                                            
                                            	IN ERROR RUNT
                                            	**type**\:   :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt>`
                                            
                                            .. attribute:: in_error_symbol
                                            
                                            	IN ERROR SYMBOL
                                            	**type**\:   :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol>`
                                            
                                            .. attribute:: in_good_bytes
                                            
                                            	INPUT GOOD BYTES
                                            	**type**\:   :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes>`
                                            
                                            .. attribute:: in_good_pkts
                                            
                                            	INPUT GOOD PKTS
                                            	**type**\:   :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts>`
                                            
                                            .. attribute:: in_mcast_pkt
                                            
                                            	IN MCAST
                                            	**type**\:   :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt>`
                                            
                                            .. attribute:: in_mib_giant
                                            
                                            	INPUT MIB GIANT
                                            	**type**\:   :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant>`
                                            
                                            .. attribute:: in_mib_jabber
                                            
                                            	INPUT MIB JABBER
                                            	**type**\:   :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber>`
                                            
                                            .. attribute:: in_mibcrc
                                            
                                            	IN MIB CRC
                                            	**type**\:   :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc>`
                                            
                                            .. attribute:: in_pause_frame
                                            
                                            	INPUT PAUSE FRAME
                                            	**type**\:   :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame>`
                                            
                                            .. attribute:: in_pkt64_octet
                                            
                                            	IN PKT 64 OCTET
                                            	**type**\:   :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet>`
                                            
                                            .. attribute:: in_pkts1024_to1518_octets
                                            
                                            	IN PKTS 1024 1518 OCTETS
                                            	**type**\:   :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets>`
                                            
                                            .. attribute:: in_pkts128_to255_octets
                                            
                                            	IN PKTS 128 255 OCTETS
                                            	**type**\:   :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets>`
                                            
                                            .. attribute:: in_pkts1519_max_octets
                                            
                                            	INPUT PKTS 1519MAX OCTETS
                                            	**type**\:   :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets>`
                                            
                                            .. attribute:: in_pkts256_to511_octets
                                            
                                            	IN PKTS 256 511 OCTETS
                                            	**type**\:   :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets>`
                                            
                                            .. attribute:: in_pkts512_to1023_octets
                                            
                                            	IN PKTS 512 1023 OCTETS
                                            	**type**\:   :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets>`
                                            
                                            .. attribute:: in_pkts65_to127_octets
                                            
                                            	IN PKTS 65 127OCTETS
                                            	**type**\:   :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets>`
                                            
                                            .. attribute:: in_ucast_pkt
                                            
                                            	IN UCAST
                                            	**type**\:   :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: jabber_stat
                                            
                                            	JABBER STATS
                                            	**type**\:   :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat>`
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: long_frames_stat
                                            
                                            	LONG FRAMES
                                            	**type**\:   :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat>`
                                            
                                            .. attribute:: octet_stat
                                            
                                            	OCTET STAT
                                            	**type**\:   :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat>`
                                            
                                            .. attribute:: out8021q_frames
                                            
                                            	OUT 802 1Q FRAMES
                                            	**type**\:   :py:class:`Out8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021QFrames>`
                                            
                                            .. attribute:: out_bcast_pkt
                                            
                                            	OUT BCAST
                                            	**type**\:   :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt>`
                                            
                                            .. attribute:: out_drop_abort
                                            
                                            	OUT DROP ABORT
                                            	**type**\:   :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort>`
                                            
                                            .. attribute:: out_drop_other
                                            
                                            	OUT DROP OTHER
                                            	**type**\:   :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther>`
                                            
                                            .. attribute:: out_drop_underrun
                                            
                                            	OUT DROP UNDERRUN
                                            	**type**\:   :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun>`
                                            
                                            .. attribute:: out_error_other
                                            
                                            	OUT ERROR OTHER
                                            	**type**\:   :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther>`
                                            
                                            .. attribute:: out_good_bytes
                                            
                                            	OUT GOOD BYTES
                                            	**type**\:   :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes>`
                                            
                                            .. attribute:: out_good_pkts
                                            
                                            	OUT GOOD PKTS
                                            	**type**\:   :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts>`
                                            
                                            .. attribute:: out_mcast_pkt
                                            
                                            	OUT MCAST
                                            	**type**\:   :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt>`
                                            
                                            .. attribute:: out_octets
                                            
                                            	OUT OCTET
                                            	**type**\:   :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets>`
                                            
                                            .. attribute:: out_pause_frames
                                            
                                            	OUT PAUSE FRAMES
                                            	**type**\:   :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames>`
                                            
                                            .. attribute:: out_pkts10241518_octets
                                            
                                            	OUT PKTS 1024 1518 OCTETS
                                            	**type**\:   :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets>`
                                            
                                            .. attribute:: out_pkts128255_octets
                                            
                                            	OUT PKTS 128 255 OCTETS
                                            	**type**\:   :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets>`
                                            
                                            .. attribute:: out_pkts1519_max_octets
                                            
                                            	OUT PKTS 1519 MAX OCTETS
                                            	**type**\:   :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets>`
                                            
                                            .. attribute:: out_pkts256511_octets
                                            
                                            	OUT PKTS 256 511 OCTETS
                                            	**type**\:   :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets>`
                                            
                                            .. attribute:: out_pkts5121023_octets
                                            
                                            	OUT PKTS 512 1023 OCTETS
                                            	**type**\:   :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets>`
                                            
                                            .. attribute:: out_pkts65127_octets
                                            
                                            	OUT PKTS 65 127OCTETS
                                            	**type**\:   :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets>`
                                            
                                            .. attribute:: out_ucast_pkt
                                            
                                            	OUT UCAST
                                            	**type**\:   :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt>`
                                            
                                            .. attribute:: outpkt64octet
                                            
                                            	OUT PKT 64 OCTET
                                            	**type**\:   :py:class:`Outpkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64Octet>`
                                            
                                            .. attribute:: oversize_pkt_stat
                                            
                                            	OVERSIZE PKT
                                            	**type**\:   :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat>`
                                            
                                            .. attribute:: rx_pkt
                                            
                                            	RX PKT
                                            	**type**\:   :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt>`
                                            
                                            .. attribute:: rx_util
                                            
                                            	Rx Utilization in Percent
                                            	**type**\:   :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: stat_pkt
                                            
                                            	STAT PKT
                                            	**type**\:   :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: tx_bad_fcs
                                            
                                            	TX Bad Fcs
                                            	**type**\:   :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs>`
                                            
                                            .. attribute:: tx_fragments
                                            
                                            	TX Fragments
                                            	**type**\:   :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments>`
                                            
                                            .. attribute:: tx_jabber
                                            
                                            	TX Jabber
                                            	**type**\:   :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber>`
                                            
                                            .. attribute:: tx_oversized_pkt
                                            
                                            	TX Oversized Pkt
                                            	**type**\:   :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt>`
                                            
                                            .. attribute:: tx_pkt
                                            
                                            	TX PKT
                                            	**type**\:   :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt>`
                                            
                                            .. attribute:: tx_undersized_pkt
                                            
                                            	TX Undersized Pkt
                                            	**type**\:   :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt>`
                                            
                                            .. attribute:: tx_util
                                            
                                            	Tx Utilization in Percent
                                            	**type**\:   :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance, self).__init__()

                                                self.yang_name = "ethernet-hour24-ether-time-line-instance"
                                                self.yang_parent_name = "ethernet-hour24-ether-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.ether10241518_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet()
                                                self.ether10241518_octet.parent = self
                                                self._children_name_map["ether10241518_octet"] = "ether10241518-octet"
                                                self._children_yang_names.add("ether10241518-octet")

                                                self.ether128255_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet()
                                                self.ether128255_octet.parent = self
                                                self._children_name_map["ether128255_octet"] = "ether128255-octet"
                                                self._children_yang_names.add("ether128255-octet")

                                                self.ether256511_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet()
                                                self.ether256511_octet.parent = self
                                                self._children_name_map["ether256511_octet"] = "ether256511-octet"
                                                self._children_yang_names.add("ether256511-octet")

                                                self.ether5121023_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet()
                                                self.ether5121023_octet.parent = self
                                                self._children_name_map["ether5121023_octet"] = "ether5121023-octet"
                                                self._children_yang_names.add("ether5121023-octet")

                                                self.ether64_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets()
                                                self.ether64_octets.parent = self
                                                self._children_name_map["ether64_octets"] = "ether64-octets"
                                                self._children_yang_names.add("ether64-octets")

                                                self.ether65127_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet()
                                                self.ether65127_octet.parent = self
                                                self._children_name_map["ether65127_octet"] = "ether65127-octet"
                                                self._children_yang_names.add("ether65127-octet")

                                                self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                self.ether_stat_broadcast_pkt.parent = self
                                                self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"
                                                self._children_yang_names.add("ether-stat-broadcast-pkt")

                                                self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt()
                                                self.ether_stat_multicast_pkt.parent = self
                                                self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"
                                                self._children_yang_names.add("ether-stat-multicast-pkt")

                                                self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                self.ether_stat_undersized_pkt.parent = self
                                                self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"
                                                self._children_yang_names.add("ether-stat-undersized-pkt")

                                                self.fcs_errors_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat()
                                                self.fcs_errors_stat.parent = self
                                                self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"
                                                self._children_yang_names.add("fcs-errors-stat")

                                                self.if_in_errors = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors()
                                                self.if_in_errors.parent = self
                                                self._children_name_map["if_in_errors"] = "if-in-errors"
                                                self._children_yang_names.add("if-in-errors")

                                                self.if_in_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets()
                                                self.if_in_octets.parent = self
                                                self._children_name_map["if_in_octets"] = "if-in-octets"
                                                self._children_yang_names.add("if-in-octets")

                                                self.in8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021QFrames()
                                                self.in8021q_frames.parent = self
                                                self._children_name_map["in8021q_frames"] = "in8021q-frames"
                                                self._children_yang_names.add("in8021q-frames")

                                                self.in_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt()
                                                self.in_bcast_pkt.parent = self
                                                self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"
                                                self._children_yang_names.add("in-bcast-pkt")

                                                self.in_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort()
                                                self.in_drop_abort.parent = self
                                                self._children_name_map["in_drop_abort"] = "in-drop-abort"
                                                self._children_yang_names.add("in-drop-abort")

                                                self.in_drop_invalid_dmac = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac()
                                                self.in_drop_invalid_dmac.parent = self
                                                self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"
                                                self._children_yang_names.add("in-drop-invalid-dmac")

                                                self.in_drop_invalid_encap = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap()
                                                self.in_drop_invalid_encap.parent = self
                                                self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"
                                                self._children_yang_names.add("in-drop-invalid-encap")

                                                self.in_drop_invalid_vlan = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan()
                                                self.in_drop_invalid_vlan.parent = self
                                                self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"
                                                self._children_yang_names.add("in-drop-invalid-vlan")

                                                self.in_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther()
                                                self.in_drop_other.parent = self
                                                self._children_name_map["in_drop_other"] = "in-drop-other"
                                                self._children_yang_names.add("in-drop-other")

                                                self.in_drop_overrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun()
                                                self.in_drop_overrun.parent = self
                                                self._children_name_map["in_drop_overrun"] = "in-drop-overrun"
                                                self._children_yang_names.add("in-drop-overrun")

                                                self.in_error_collisions = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions()
                                                self.in_error_collisions.parent = self
                                                self._children_name_map["in_error_collisions"] = "in-error-collisions"
                                                self._children_yang_names.add("in-error-collisions")

                                                self.in_error_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments()
                                                self.in_error_fragments.parent = self
                                                self._children_name_map["in_error_fragments"] = "in-error-fragments"
                                                self._children_yang_names.add("in-error-fragments")

                                                self.in_error_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant()
                                                self.in_error_giant.parent = self
                                                self._children_name_map["in_error_giant"] = "in-error-giant"
                                                self._children_yang_names.add("in-error-giant")

                                                self.in_error_jabbers = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers()
                                                self.in_error_jabbers.parent = self
                                                self._children_name_map["in_error_jabbers"] = "in-error-jabbers"
                                                self._children_yang_names.add("in-error-jabbers")

                                                self.in_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther()
                                                self.in_error_other.parent = self
                                                self._children_name_map["in_error_other"] = "in-error-other"
                                                self._children_yang_names.add("in-error-other")

                                                self.in_error_runt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt()
                                                self.in_error_runt.parent = self
                                                self._children_name_map["in_error_runt"] = "in-error-runt"
                                                self._children_yang_names.add("in-error-runt")

                                                self.in_error_symbol = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol()
                                                self.in_error_symbol.parent = self
                                                self._children_name_map["in_error_symbol"] = "in-error-symbol"
                                                self._children_yang_names.add("in-error-symbol")

                                                self.in_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes()
                                                self.in_good_bytes.parent = self
                                                self._children_name_map["in_good_bytes"] = "in-good-bytes"
                                                self._children_yang_names.add("in-good-bytes")

                                                self.in_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts()
                                                self.in_good_pkts.parent = self
                                                self._children_name_map["in_good_pkts"] = "in-good-pkts"
                                                self._children_yang_names.add("in-good-pkts")

                                                self.in_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt()
                                                self.in_mcast_pkt.parent = self
                                                self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"
                                                self._children_yang_names.add("in-mcast-pkt")

                                                self.in_mib_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant()
                                                self.in_mib_giant.parent = self
                                                self._children_name_map["in_mib_giant"] = "in-mib-giant"
                                                self._children_yang_names.add("in-mib-giant")

                                                self.in_mib_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber()
                                                self.in_mib_jabber.parent = self
                                                self._children_name_map["in_mib_jabber"] = "in-mib-jabber"
                                                self._children_yang_names.add("in-mib-jabber")

                                                self.in_mibcrc = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc()
                                                self.in_mibcrc.parent = self
                                                self._children_name_map["in_mibcrc"] = "in-mibcrc"
                                                self._children_yang_names.add("in-mibcrc")

                                                self.in_pause_frame = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame()
                                                self.in_pause_frame.parent = self
                                                self._children_name_map["in_pause_frame"] = "in-pause-frame"
                                                self._children_yang_names.add("in-pause-frame")

                                                self.in_pkt64_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet()
                                                self.in_pkt64_octet.parent = self
                                                self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"
                                                self._children_yang_names.add("in-pkt64-octet")

                                                self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets()
                                                self.in_pkts1024_to1518_octets.parent = self
                                                self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"
                                                self._children_yang_names.add("in-pkts1024-to1518-octets")

                                                self.in_pkts128_to255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets()
                                                self.in_pkts128_to255_octets.parent = self
                                                self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"
                                                self._children_yang_names.add("in-pkts128-to255-octets")

                                                self.in_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets()
                                                self.in_pkts1519_max_octets.parent = self
                                                self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"
                                                self._children_yang_names.add("in-pkts1519-max-octets")

                                                self.in_pkts256_to511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets()
                                                self.in_pkts256_to511_octets.parent = self
                                                self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"
                                                self._children_yang_names.add("in-pkts256-to511-octets")

                                                self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets()
                                                self.in_pkts512_to1023_octets.parent = self
                                                self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"
                                                self._children_yang_names.add("in-pkts512-to1023-octets")

                                                self.in_pkts65_to127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets()
                                                self.in_pkts65_to127_octets.parent = self
                                                self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"
                                                self._children_yang_names.add("in-pkts65-to127-octets")

                                                self.in_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt()
                                                self.in_ucast_pkt.parent = self
                                                self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"
                                                self._children_yang_names.add("in-ucast-pkt")

                                                self.jabber_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat()
                                                self.jabber_stat.parent = self
                                                self._children_name_map["jabber_stat"] = "jabber-stat"
                                                self._children_yang_names.add("jabber-stat")

                                                self.long_frames_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat()
                                                self.long_frames_stat.parent = self
                                                self._children_name_map["long_frames_stat"] = "long-frames-stat"
                                                self._children_yang_names.add("long-frames-stat")

                                                self.octet_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat()
                                                self.octet_stat.parent = self
                                                self._children_name_map["octet_stat"] = "octet-stat"
                                                self._children_yang_names.add("octet-stat")

                                                self.out8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021QFrames()
                                                self.out8021q_frames.parent = self
                                                self._children_name_map["out8021q_frames"] = "out8021q-frames"
                                                self._children_yang_names.add("out8021q-frames")

                                                self.out_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt()
                                                self.out_bcast_pkt.parent = self
                                                self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"
                                                self._children_yang_names.add("out-bcast-pkt")

                                                self.out_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort()
                                                self.out_drop_abort.parent = self
                                                self._children_name_map["out_drop_abort"] = "out-drop-abort"
                                                self._children_yang_names.add("out-drop-abort")

                                                self.out_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther()
                                                self.out_drop_other.parent = self
                                                self._children_name_map["out_drop_other"] = "out-drop-other"
                                                self._children_yang_names.add("out-drop-other")

                                                self.out_drop_underrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun()
                                                self.out_drop_underrun.parent = self
                                                self._children_name_map["out_drop_underrun"] = "out-drop-underrun"
                                                self._children_yang_names.add("out-drop-underrun")

                                                self.out_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther()
                                                self.out_error_other.parent = self
                                                self._children_name_map["out_error_other"] = "out-error-other"
                                                self._children_yang_names.add("out-error-other")

                                                self.out_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes()
                                                self.out_good_bytes.parent = self
                                                self._children_name_map["out_good_bytes"] = "out-good-bytes"
                                                self._children_yang_names.add("out-good-bytes")

                                                self.out_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts()
                                                self.out_good_pkts.parent = self
                                                self._children_name_map["out_good_pkts"] = "out-good-pkts"
                                                self._children_yang_names.add("out-good-pkts")

                                                self.out_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt()
                                                self.out_mcast_pkt.parent = self
                                                self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"
                                                self._children_yang_names.add("out-mcast-pkt")

                                                self.out_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets()
                                                self.out_octets.parent = self
                                                self._children_name_map["out_octets"] = "out-octets"
                                                self._children_yang_names.add("out-octets")

                                                self.out_pause_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames()
                                                self.out_pause_frames.parent = self
                                                self._children_name_map["out_pause_frames"] = "out-pause-frames"
                                                self._children_yang_names.add("out-pause-frames")

                                                self.out_pkts10241518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets()
                                                self.out_pkts10241518_octets.parent = self
                                                self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"
                                                self._children_yang_names.add("out-pkts10241518-octets")

                                                self.out_pkts128255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets()
                                                self.out_pkts128255_octets.parent = self
                                                self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"
                                                self._children_yang_names.add("out-pkts128255-octets")

                                                self.out_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                self.out_pkts1519_max_octets.parent = self
                                                self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"
                                                self._children_yang_names.add("out-pkts1519-max-octets")

                                                self.out_pkts256511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets()
                                                self.out_pkts256511_octets.parent = self
                                                self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"
                                                self._children_yang_names.add("out-pkts256511-octets")

                                                self.out_pkts5121023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets()
                                                self.out_pkts5121023_octets.parent = self
                                                self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"
                                                self._children_yang_names.add("out-pkts5121023-octets")

                                                self.out_pkts65127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets()
                                                self.out_pkts65127_octets.parent = self
                                                self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"
                                                self._children_yang_names.add("out-pkts65127-octets")

                                                self.out_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt()
                                                self.out_ucast_pkt.parent = self
                                                self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"
                                                self._children_yang_names.add("out-ucast-pkt")

                                                self.outpkt64octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64Octet()
                                                self.outpkt64octet.parent = self
                                                self._children_name_map["outpkt64octet"] = "outpkt64octet"
                                                self._children_yang_names.add("outpkt64octet")

                                                self.oversize_pkt_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat()
                                                self.oversize_pkt_stat.parent = self
                                                self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"
                                                self._children_yang_names.add("oversize-pkt-stat")

                                                self.rx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt()
                                                self.rx_pkt.parent = self
                                                self._children_name_map["rx_pkt"] = "rx-pkt"
                                                self._children_yang_names.add("rx-pkt")

                                                self.rx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil()
                                                self.rx_util.parent = self
                                                self._children_name_map["rx_util"] = "rx-util"
                                                self._children_yang_names.add("rx-util")

                                                self.stat_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt()
                                                self.stat_pkt.parent = self
                                                self._children_name_map["stat_pkt"] = "stat-pkt"
                                                self._children_yang_names.add("stat-pkt")

                                                self.tx_bad_fcs = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs()
                                                self.tx_bad_fcs.parent = self
                                                self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                                self._children_yang_names.add("tx-bad-fcs")

                                                self.tx_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments()
                                                self.tx_fragments.parent = self
                                                self._children_name_map["tx_fragments"] = "tx-fragments"
                                                self._children_yang_names.add("tx-fragments")

                                                self.tx_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber()
                                                self.tx_jabber.parent = self
                                                self._children_name_map["tx_jabber"] = "tx-jabber"
                                                self._children_yang_names.add("tx-jabber")

                                                self.tx_oversized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt()
                                                self.tx_oversized_pkt.parent = self
                                                self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"
                                                self._children_yang_names.add("tx-oversized-pkt")

                                                self.tx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt()
                                                self.tx_pkt.parent = self
                                                self._children_name_map["tx_pkt"] = "tx-pkt"
                                                self._children_yang_names.add("tx-pkt")

                                                self.tx_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt()
                                                self.tx_undersized_pkt.parent = self
                                                self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"
                                                self._children_yang_names.add("tx-undersized-pkt")

                                                self.tx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil()
                                                self.tx_util.parent = self
                                                self._children_name_map["tx_util"] = "tx-util"
                                                self._children_yang_names.add("tx-util")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance, self).__setattr__(name, value)


                                            class RxPkt(Entity):
                                                """
                                                RX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt, self).__init__()

                                                    self.yang_name = "rx-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class StatPkt(Entity):
                                                """
                                                STAT PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt, self).__init__()

                                                    self.yang_name = "stat-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "stat-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OctetStat(Entity):
                                                """
                                                OCTET STAT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat, self).__init__()

                                                    self.yang_name = "octet-stat"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "octet-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OversizePktStat(Entity):
                                                """
                                                OVERSIZE PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat, self).__init__()

                                                    self.yang_name = "oversize-pkt-stat"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "oversize-pkt-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class FcsErrorsStat(Entity):
                                                """
                                                FCS ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat, self).__init__()

                                                    self.yang_name = "fcs-errors-stat"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fcs-errors-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LongFramesStat(Entity):
                                                """
                                                LONG FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat, self).__init__()

                                                    self.yang_name = "long-frames-stat"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "long-frames-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class JabberStat(Entity):
                                                """
                                                JABBER STATS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat, self).__init__()

                                                    self.yang_name = "jabber-stat"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "jabber-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether64Octets(Entity):
                                                """
                                                SIXTY FOUR OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets, self).__init__()

                                                    self.yang_name = "ether64-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether64-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether65127Octet(Entity):
                                                """
                                                OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet, self).__init__()

                                                    self.yang_name = "ether65127-octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether65127-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether128255Octet(Entity):
                                                """
                                                TFF OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet, self).__init__()

                                                    self.yang_name = "ether128255-octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether128255-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether256511Octet(Entity):
                                                """
                                                FOO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet, self).__init__()

                                                    self.yang_name = "ether256511-octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether256511-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether5121023Octet(Entity):
                                                """
                                                OZTT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet, self).__init__()

                                                    self.yang_name = "ether5121023-octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether5121023-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether10241518Octet(Entity):
                                                """
                                                OFO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet, self).__init__()

                                                    self.yang_name = "ether10241518-octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether10241518-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InUcastPkt(Entity):
                                                """
                                                IN UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt, self).__init__()

                                                    self.yang_name = "in-ucast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-ucast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InMcastPkt(Entity):
                                                """
                                                IN MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt, self).__init__()

                                                    self.yang_name = "in-mcast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-mcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InBcastPkt(Entity):
                                                """
                                                IN BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt, self).__init__()

                                                    self.yang_name = "in-bcast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-bcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutUcastPkt(Entity):
                                                """
                                                OUT UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt, self).__init__()

                                                    self.yang_name = "out-ucast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-ucast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutBcastPkt(Entity):
                                                """
                                                OUT BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt, self).__init__()

                                                    self.yang_name = "out-bcast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-bcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutMcastPkt(Entity):
                                                """
                                                OUT MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt, self).__init__()

                                                    self.yang_name = "out-mcast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-mcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxPkt(Entity):
                                                """
                                                TX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt, self).__init__()

                                                    self.yang_name = "tx-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class IfInErrors(Entity):
                                                """
                                                IFIN ERRORS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors, self).__init__()

                                                    self.yang_name = "if-in-errors"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "if-in-errors" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class IfInOctets(Entity):
                                                """
                                                IFIN OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets, self).__init__()

                                                    self.yang_name = "if-in-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "if-in-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class EtherStatMulticastPkt(Entity):
                                                """
                                                ETHER STAT MULTICAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-multicast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether-stat-multicast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class EtherStatBroadcastPkt(Entity):
                                                """
                                                ETHER STAT BROADCAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-broadcast-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether-stat-broadcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class EtherStatUndersizedPkt(Entity):
                                                """
                                                ETHER STAT UNDERSIZED PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt, self).__init__()

                                                    self.yang_name = "ether-stat-undersized-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether-stat-undersized-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutOctets(Entity):
                                                """
                                                OUT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets, self).__init__()

                                                    self.yang_name = "out-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPauseFrame(Entity):
                                                """
                                                INPUT PAUSE FRAME
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame, self).__init__()

                                                    self.yang_name = "in-pause-frame"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pause-frame" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InGoodBytes(Entity):
                                                """
                                                INPUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes, self).__init__()

                                                    self.yang_name = "in-good-bytes"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-good-bytes" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class In8021QFrames(Entity):
                                                """
                                                INPUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021QFrames, self).__init__()

                                                    self.yang_name = "in8021q-frames"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021QFrames, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021QFrames, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in8021q-frames" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts1519MaxOctets(Entity):
                                                """
                                                INPUT PKTS 1519MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "in-pkts1519-max-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts1519-max-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InGoodPkts(Entity):
                                                """
                                                INPUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts, self).__init__()

                                                    self.yang_name = "in-good-pkts"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-good-pkts" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropOverrun(Entity):
                                                """
                                                INPUT DROP OVERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun, self).__init__()

                                                    self.yang_name = "in-drop-overrun"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-overrun" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropAbort(Entity):
                                                """
                                                INPUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort, self).__init__()

                                                    self.yang_name = "in-drop-abort"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-abort" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropInvalidVlan(Entity):
                                                """
                                                INPUT DROP INVALID VLAN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan, self).__init__()

                                                    self.yang_name = "in-drop-invalid-vlan"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-invalid-vlan" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropInvalidDmac(Entity):
                                                """
                                                INPUT DROP INVALID DMAC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac, self).__init__()

                                                    self.yang_name = "in-drop-invalid-dmac"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-invalid-dmac" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropInvalidEncap(Entity):
                                                """
                                                INPUT DROP INVALID ENCAP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap, self).__init__()

                                                    self.yang_name = "in-drop-invalid-encap"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-invalid-encap" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropOther(Entity):
                                                """
                                                INPUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther, self).__init__()

                                                    self.yang_name = "in-drop-other"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-other" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InMibGiant(Entity):
                                                """
                                                INPUT MIB GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant, self).__init__()

                                                    self.yang_name = "in-mib-giant"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-mib-giant" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InMibJabber(Entity):
                                                """
                                                INPUT MIB JABBER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber, self).__init__()

                                                    self.yang_name = "in-mib-jabber"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-mib-jabber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InMibcrc(Entity):
                                                """
                                                IN MIB CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc, self).__init__()

                                                    self.yang_name = "in-mibcrc"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-mibcrc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorCollisions(Entity):
                                                """
                                                IN ERROR COLLISIONS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions, self).__init__()

                                                    self.yang_name = "in-error-collisions"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-collisions" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorSymbol(Entity):
                                                """
                                                IN ERROR SYMBOL
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol, self).__init__()

                                                    self.yang_name = "in-error-symbol"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-symbol" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutGoodBytes(Entity):
                                                """
                                                OUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes, self).__init__()

                                                    self.yang_name = "out-good-bytes"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-good-bytes" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Out8021QFrames(Entity):
                                                """
                                                OUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021QFrames, self).__init__()

                                                    self.yang_name = "out8021q-frames"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021QFrames, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021QFrames, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out8021q-frames" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPauseFrames(Entity):
                                                """
                                                OUT PAUSE FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames, self).__init__()

                                                    self.yang_name = "out-pause-frames"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pause-frames" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts1519MaxOctets(Entity):
                                                """
                                                OUT PKTS 1519 MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "out-pkts1519-max-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts1519-max-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutGoodPkts(Entity):
                                                """
                                                OUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts, self).__init__()

                                                    self.yang_name = "out-good-pkts"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-good-pkts" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutDropUnderrun(Entity):
                                                """
                                                OUT DROP UNDERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun, self).__init__()

                                                    self.yang_name = "out-drop-underrun"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-drop-underrun" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutDropAbort(Entity):
                                                """
                                                OUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort, self).__init__()

                                                    self.yang_name = "out-drop-abort"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-drop-abort" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutDropOther(Entity):
                                                """
                                                OUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther, self).__init__()

                                                    self.yang_name = "out-drop-other"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-drop-other" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutErrorOther(Entity):
                                                """
                                                OUT ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther, self).__init__()

                                                    self.yang_name = "out-error-other"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-error-other" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorGiant(Entity):
                                                """
                                                IN ERROR GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant, self).__init__()

                                                    self.yang_name = "in-error-giant"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-giant" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorRunt(Entity):
                                                """
                                                IN ERROR RUNT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt, self).__init__()

                                                    self.yang_name = "in-error-runt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-runt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorJabbers(Entity):
                                                """
                                                IN ERROR JABBERS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers, self).__init__()

                                                    self.yang_name = "in-error-jabbers"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-jabbers" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorFragments(Entity):
                                                """
                                                IN ERROR FRAGMENTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments, self).__init__()

                                                    self.yang_name = "in-error-fragments"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-fragments" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorOther(Entity):
                                                """
                                                IN ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther, self).__init__()

                                                    self.yang_name = "in-error-other"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-other" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkt64Octet(Entity):
                                                """
                                                IN PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet, self).__init__()

                                                    self.yang_name = "in-pkt64-octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkt64-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts65To127Octets(Entity):
                                                """
                                                IN PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets, self).__init__()

                                                    self.yang_name = "in-pkts65-to127-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts65-to127-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts128To255Octets(Entity):
                                                """
                                                IN PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets, self).__init__()

                                                    self.yang_name = "in-pkts128-to255-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts128-to255-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts256To511Octets(Entity):
                                                """
                                                IN PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets, self).__init__()

                                                    self.yang_name = "in-pkts256-to511-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts256-to511-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts512To1023Octets(Entity):
                                                """
                                                IN PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets, self).__init__()

                                                    self.yang_name = "in-pkts512-to1023-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts512-to1023-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts1024To1518Octets(Entity):
                                                """
                                                IN PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets, self).__init__()

                                                    self.yang_name = "in-pkts1024-to1518-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts1024-to1518-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Outpkt64Octet(Entity):
                                                """
                                                OUT PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64Octet, self).__init__()

                                                    self.yang_name = "outpkt64octet"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "outpkt64octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts65127Octets(Entity):
                                                """
                                                OUT PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets, self).__init__()

                                                    self.yang_name = "out-pkts65127-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts65127-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts128255Octets(Entity):
                                                """
                                                OUT PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets, self).__init__()

                                                    self.yang_name = "out-pkts128255-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts128255-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts256511Octets(Entity):
                                                """
                                                OUT PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets, self).__init__()

                                                    self.yang_name = "out-pkts256511-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts256511-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts5121023Octets(Entity):
                                                """
                                                OUT PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets, self).__init__()

                                                    self.yang_name = "out-pkts5121023-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts5121023-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts10241518Octets(Entity):
                                                """
                                                OUT PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets, self).__init__()

                                                    self.yang_name = "out-pkts10241518-octets"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts10241518-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class RxUtil(Entity):
                                                """
                                                Rx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil, self).__init__()

                                                    self.yang_name = "rx-util"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-util" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxUtil(Entity):
                                                """
                                                Tx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil, self).__init__()

                                                    self.yang_name = "tx-util"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-util" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxUndersizedPkt(Entity):
                                                """
                                                TX Undersized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt, self).__init__()

                                                    self.yang_name = "tx-undersized-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-undersized-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxOversizedPkt(Entity):
                                                """
                                                TX Oversized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt, self).__init__()

                                                    self.yang_name = "tx-oversized-pkt"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-oversized-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxFragments(Entity):
                                                """
                                                TX Fragments
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments, self).__init__()

                                                    self.yang_name = "tx-fragments"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-fragments" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxJabber(Entity):
                                                """
                                                TX Jabber
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber, self).__init__()

                                                    self.yang_name = "tx-jabber"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-jabber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxBadFcs(Entity):
                                                """
                                                TX Bad Fcs
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs, self).__init__()

                                                    self.yang_name = "tx-bad-fcs"
                                                    self.yang_parent_name = "ethernet-hour24-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-bad-fcs" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.ether10241518_octet is not None and self.ether10241518_octet.has_data()) or
                                                    (self.ether128255_octet is not None and self.ether128255_octet.has_data()) or
                                                    (self.ether256511_octet is not None and self.ether256511_octet.has_data()) or
                                                    (self.ether5121023_octet is not None and self.ether5121023_octet.has_data()) or
                                                    (self.ether64_octets is not None and self.ether64_octets.has_data()) or
                                                    (self.ether65127_octet is not None and self.ether65127_octet.has_data()) or
                                                    (self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt.has_data()) or
                                                    (self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt.has_data()) or
                                                    (self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt.has_data()) or
                                                    (self.fcs_errors_stat is not None and self.fcs_errors_stat.has_data()) or
                                                    (self.if_in_errors is not None and self.if_in_errors.has_data()) or
                                                    (self.if_in_octets is not None and self.if_in_octets.has_data()) or
                                                    (self.in8021q_frames is not None and self.in8021q_frames.has_data()) or
                                                    (self.in_bcast_pkt is not None and self.in_bcast_pkt.has_data()) or
                                                    (self.in_drop_abort is not None and self.in_drop_abort.has_data()) or
                                                    (self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac.has_data()) or
                                                    (self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap.has_data()) or
                                                    (self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan.has_data()) or
                                                    (self.in_drop_other is not None and self.in_drop_other.has_data()) or
                                                    (self.in_drop_overrun is not None and self.in_drop_overrun.has_data()) or
                                                    (self.in_error_collisions is not None and self.in_error_collisions.has_data()) or
                                                    (self.in_error_fragments is not None and self.in_error_fragments.has_data()) or
                                                    (self.in_error_giant is not None and self.in_error_giant.has_data()) or
                                                    (self.in_error_jabbers is not None and self.in_error_jabbers.has_data()) or
                                                    (self.in_error_other is not None and self.in_error_other.has_data()) or
                                                    (self.in_error_runt is not None and self.in_error_runt.has_data()) or
                                                    (self.in_error_symbol is not None and self.in_error_symbol.has_data()) or
                                                    (self.in_good_bytes is not None and self.in_good_bytes.has_data()) or
                                                    (self.in_good_pkts is not None and self.in_good_pkts.has_data()) or
                                                    (self.in_mcast_pkt is not None and self.in_mcast_pkt.has_data()) or
                                                    (self.in_mib_giant is not None and self.in_mib_giant.has_data()) or
                                                    (self.in_mib_jabber is not None and self.in_mib_jabber.has_data()) or
                                                    (self.in_mibcrc is not None and self.in_mibcrc.has_data()) or
                                                    (self.in_pause_frame is not None and self.in_pause_frame.has_data()) or
                                                    (self.in_pkt64_octet is not None and self.in_pkt64_octet.has_data()) or
                                                    (self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets.has_data()) or
                                                    (self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets.has_data()) or
                                                    (self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets.has_data()) or
                                                    (self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets.has_data()) or
                                                    (self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets.has_data()) or
                                                    (self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets.has_data()) or
                                                    (self.in_ucast_pkt is not None and self.in_ucast_pkt.has_data()) or
                                                    (self.jabber_stat is not None and self.jabber_stat.has_data()) or
                                                    (self.long_frames_stat is not None and self.long_frames_stat.has_data()) or
                                                    (self.octet_stat is not None and self.octet_stat.has_data()) or
                                                    (self.out8021q_frames is not None and self.out8021q_frames.has_data()) or
                                                    (self.out_bcast_pkt is not None and self.out_bcast_pkt.has_data()) or
                                                    (self.out_drop_abort is not None and self.out_drop_abort.has_data()) or
                                                    (self.out_drop_other is not None and self.out_drop_other.has_data()) or
                                                    (self.out_drop_underrun is not None and self.out_drop_underrun.has_data()) or
                                                    (self.out_error_other is not None and self.out_error_other.has_data()) or
                                                    (self.out_good_bytes is not None and self.out_good_bytes.has_data()) or
                                                    (self.out_good_pkts is not None and self.out_good_pkts.has_data()) or
                                                    (self.out_mcast_pkt is not None and self.out_mcast_pkt.has_data()) or
                                                    (self.out_octets is not None and self.out_octets.has_data()) or
                                                    (self.out_pause_frames is not None and self.out_pause_frames.has_data()) or
                                                    (self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets.has_data()) or
                                                    (self.out_pkts128255_octets is not None and self.out_pkts128255_octets.has_data()) or
                                                    (self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets.has_data()) or
                                                    (self.out_pkts256511_octets is not None and self.out_pkts256511_octets.has_data()) or
                                                    (self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets.has_data()) or
                                                    (self.out_pkts65127_octets is not None and self.out_pkts65127_octets.has_data()) or
                                                    (self.out_ucast_pkt is not None and self.out_ucast_pkt.has_data()) or
                                                    (self.outpkt64octet is not None and self.outpkt64octet.has_data()) or
                                                    (self.oversize_pkt_stat is not None and self.oversize_pkt_stat.has_data()) or
                                                    (self.rx_pkt is not None and self.rx_pkt.has_data()) or
                                                    (self.rx_util is not None and self.rx_util.has_data()) or
                                                    (self.stat_pkt is not None and self.stat_pkt.has_data()) or
                                                    (self.tx_bad_fcs is not None and self.tx_bad_fcs.has_data()) or
                                                    (self.tx_fragments is not None and self.tx_fragments.has_data()) or
                                                    (self.tx_jabber is not None and self.tx_jabber.has_data()) or
                                                    (self.tx_oversized_pkt is not None and self.tx_oversized_pkt.has_data()) or
                                                    (self.tx_pkt is not None and self.tx_pkt.has_data()) or
                                                    (self.tx_undersized_pkt is not None and self.tx_undersized_pkt.has_data()) or
                                                    (self.tx_util is not None and self.tx_util.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.ether10241518_octet is not None and self.ether10241518_octet.has_operation()) or
                                                    (self.ether128255_octet is not None and self.ether128255_octet.has_operation()) or
                                                    (self.ether256511_octet is not None and self.ether256511_octet.has_operation()) or
                                                    (self.ether5121023_octet is not None and self.ether5121023_octet.has_operation()) or
                                                    (self.ether64_octets is not None and self.ether64_octets.has_operation()) or
                                                    (self.ether65127_octet is not None and self.ether65127_octet.has_operation()) or
                                                    (self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt.has_operation()) or
                                                    (self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt.has_operation()) or
                                                    (self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt.has_operation()) or
                                                    (self.fcs_errors_stat is not None and self.fcs_errors_stat.has_operation()) or
                                                    (self.if_in_errors is not None and self.if_in_errors.has_operation()) or
                                                    (self.if_in_octets is not None and self.if_in_octets.has_operation()) or
                                                    (self.in8021q_frames is not None and self.in8021q_frames.has_operation()) or
                                                    (self.in_bcast_pkt is not None and self.in_bcast_pkt.has_operation()) or
                                                    (self.in_drop_abort is not None and self.in_drop_abort.has_operation()) or
                                                    (self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac.has_operation()) or
                                                    (self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap.has_operation()) or
                                                    (self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan.has_operation()) or
                                                    (self.in_drop_other is not None and self.in_drop_other.has_operation()) or
                                                    (self.in_drop_overrun is not None and self.in_drop_overrun.has_operation()) or
                                                    (self.in_error_collisions is not None and self.in_error_collisions.has_operation()) or
                                                    (self.in_error_fragments is not None and self.in_error_fragments.has_operation()) or
                                                    (self.in_error_giant is not None and self.in_error_giant.has_operation()) or
                                                    (self.in_error_jabbers is not None and self.in_error_jabbers.has_operation()) or
                                                    (self.in_error_other is not None and self.in_error_other.has_operation()) or
                                                    (self.in_error_runt is not None and self.in_error_runt.has_operation()) or
                                                    (self.in_error_symbol is not None and self.in_error_symbol.has_operation()) or
                                                    (self.in_good_bytes is not None and self.in_good_bytes.has_operation()) or
                                                    (self.in_good_pkts is not None and self.in_good_pkts.has_operation()) or
                                                    (self.in_mcast_pkt is not None and self.in_mcast_pkt.has_operation()) or
                                                    (self.in_mib_giant is not None and self.in_mib_giant.has_operation()) or
                                                    (self.in_mib_jabber is not None and self.in_mib_jabber.has_operation()) or
                                                    (self.in_mibcrc is not None and self.in_mibcrc.has_operation()) or
                                                    (self.in_pause_frame is not None and self.in_pause_frame.has_operation()) or
                                                    (self.in_pkt64_octet is not None and self.in_pkt64_octet.has_operation()) or
                                                    (self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets.has_operation()) or
                                                    (self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets.has_operation()) or
                                                    (self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets.has_operation()) or
                                                    (self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets.has_operation()) or
                                                    (self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets.has_operation()) or
                                                    (self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets.has_operation()) or
                                                    (self.in_ucast_pkt is not None and self.in_ucast_pkt.has_operation()) or
                                                    (self.jabber_stat is not None and self.jabber_stat.has_operation()) or
                                                    (self.long_frames_stat is not None and self.long_frames_stat.has_operation()) or
                                                    (self.octet_stat is not None and self.octet_stat.has_operation()) or
                                                    (self.out8021q_frames is not None and self.out8021q_frames.has_operation()) or
                                                    (self.out_bcast_pkt is not None and self.out_bcast_pkt.has_operation()) or
                                                    (self.out_drop_abort is not None and self.out_drop_abort.has_operation()) or
                                                    (self.out_drop_other is not None and self.out_drop_other.has_operation()) or
                                                    (self.out_drop_underrun is not None and self.out_drop_underrun.has_operation()) or
                                                    (self.out_error_other is not None and self.out_error_other.has_operation()) or
                                                    (self.out_good_bytes is not None and self.out_good_bytes.has_operation()) or
                                                    (self.out_good_pkts is not None and self.out_good_pkts.has_operation()) or
                                                    (self.out_mcast_pkt is not None and self.out_mcast_pkt.has_operation()) or
                                                    (self.out_octets is not None and self.out_octets.has_operation()) or
                                                    (self.out_pause_frames is not None and self.out_pause_frames.has_operation()) or
                                                    (self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets.has_operation()) or
                                                    (self.out_pkts128255_octets is not None and self.out_pkts128255_octets.has_operation()) or
                                                    (self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets.has_operation()) or
                                                    (self.out_pkts256511_octets is not None and self.out_pkts256511_octets.has_operation()) or
                                                    (self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets.has_operation()) or
                                                    (self.out_pkts65127_octets is not None and self.out_pkts65127_octets.has_operation()) or
                                                    (self.out_ucast_pkt is not None and self.out_ucast_pkt.has_operation()) or
                                                    (self.outpkt64octet is not None and self.outpkt64octet.has_operation()) or
                                                    (self.oversize_pkt_stat is not None and self.oversize_pkt_stat.has_operation()) or
                                                    (self.rx_pkt is not None and self.rx_pkt.has_operation()) or
                                                    (self.rx_util is not None and self.rx_util.has_operation()) or
                                                    (self.stat_pkt is not None and self.stat_pkt.has_operation()) or
                                                    (self.tx_bad_fcs is not None and self.tx_bad_fcs.has_operation()) or
                                                    (self.tx_fragments is not None and self.tx_fragments.has_operation()) or
                                                    (self.tx_jabber is not None and self.tx_jabber.has_operation()) or
                                                    (self.tx_oversized_pkt is not None and self.tx_oversized_pkt.has_operation()) or
                                                    (self.tx_pkt is not None and self.tx_pkt.has_operation()) or
                                                    (self.tx_undersized_pkt is not None and self.tx_undersized_pkt.has_operation()) or
                                                    (self.tx_util is not None and self.tx_util.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ethernet-hour24-ether-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ether10241518-octet"):
                                                    if (self.ether10241518_octet is None):
                                                        self.ether10241518_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether10241518Octet()
                                                        self.ether10241518_octet.parent = self
                                                        self._children_name_map["ether10241518_octet"] = "ether10241518-octet"
                                                    return self.ether10241518_octet

                                                if (child_yang_name == "ether128255-octet"):
                                                    if (self.ether128255_octet is None):
                                                        self.ether128255_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether128255Octet()
                                                        self.ether128255_octet.parent = self
                                                        self._children_name_map["ether128255_octet"] = "ether128255-octet"
                                                    return self.ether128255_octet

                                                if (child_yang_name == "ether256511-octet"):
                                                    if (self.ether256511_octet is None):
                                                        self.ether256511_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether256511Octet()
                                                        self.ether256511_octet.parent = self
                                                        self._children_name_map["ether256511_octet"] = "ether256511-octet"
                                                    return self.ether256511_octet

                                                if (child_yang_name == "ether5121023-octet"):
                                                    if (self.ether5121023_octet is None):
                                                        self.ether5121023_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether5121023Octet()
                                                        self.ether5121023_octet.parent = self
                                                        self._children_name_map["ether5121023_octet"] = "ether5121023-octet"
                                                    return self.ether5121023_octet

                                                if (child_yang_name == "ether64-octets"):
                                                    if (self.ether64_octets is None):
                                                        self.ether64_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether64Octets()
                                                        self.ether64_octets.parent = self
                                                        self._children_name_map["ether64_octets"] = "ether64-octets"
                                                    return self.ether64_octets

                                                if (child_yang_name == "ether65127-octet"):
                                                    if (self.ether65127_octet is None):
                                                        self.ether65127_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Ether65127Octet()
                                                        self.ether65127_octet.parent = self
                                                        self._children_name_map["ether65127_octet"] = "ether65127-octet"
                                                    return self.ether65127_octet

                                                if (child_yang_name == "ether-stat-broadcast-pkt"):
                                                    if (self.ether_stat_broadcast_pkt is None):
                                                        self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                        self.ether_stat_broadcast_pkt.parent = self
                                                        self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"
                                                    return self.ether_stat_broadcast_pkt

                                                if (child_yang_name == "ether-stat-multicast-pkt"):
                                                    if (self.ether_stat_multicast_pkt is None):
                                                        self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatMulticastPkt()
                                                        self.ether_stat_multicast_pkt.parent = self
                                                        self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"
                                                    return self.ether_stat_multicast_pkt

                                                if (child_yang_name == "ether-stat-undersized-pkt"):
                                                    if (self.ether_stat_undersized_pkt is None):
                                                        self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                        self.ether_stat_undersized_pkt.parent = self
                                                        self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"
                                                    return self.ether_stat_undersized_pkt

                                                if (child_yang_name == "fcs-errors-stat"):
                                                    if (self.fcs_errors_stat is None):
                                                        self.fcs_errors_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.FcsErrorsStat()
                                                        self.fcs_errors_stat.parent = self
                                                        self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"
                                                    return self.fcs_errors_stat

                                                if (child_yang_name == "if-in-errors"):
                                                    if (self.if_in_errors is None):
                                                        self.if_in_errors = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInErrors()
                                                        self.if_in_errors.parent = self
                                                        self._children_name_map["if_in_errors"] = "if-in-errors"
                                                    return self.if_in_errors

                                                if (child_yang_name == "if-in-octets"):
                                                    if (self.if_in_octets is None):
                                                        self.if_in_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.IfInOctets()
                                                        self.if_in_octets.parent = self
                                                        self._children_name_map["if_in_octets"] = "if-in-octets"
                                                    return self.if_in_octets

                                                if (child_yang_name == "in8021q-frames"):
                                                    if (self.in8021q_frames is None):
                                                        self.in8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.In8021QFrames()
                                                        self.in8021q_frames.parent = self
                                                        self._children_name_map["in8021q_frames"] = "in8021q-frames"
                                                    return self.in8021q_frames

                                                if (child_yang_name == "in-bcast-pkt"):
                                                    if (self.in_bcast_pkt is None):
                                                        self.in_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InBcastPkt()
                                                        self.in_bcast_pkt.parent = self
                                                        self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"
                                                    return self.in_bcast_pkt

                                                if (child_yang_name == "in-drop-abort"):
                                                    if (self.in_drop_abort is None):
                                                        self.in_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropAbort()
                                                        self.in_drop_abort.parent = self
                                                        self._children_name_map["in_drop_abort"] = "in-drop-abort"
                                                    return self.in_drop_abort

                                                if (child_yang_name == "in-drop-invalid-dmac"):
                                                    if (self.in_drop_invalid_dmac is None):
                                                        self.in_drop_invalid_dmac = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidDmac()
                                                        self.in_drop_invalid_dmac.parent = self
                                                        self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"
                                                    return self.in_drop_invalid_dmac

                                                if (child_yang_name == "in-drop-invalid-encap"):
                                                    if (self.in_drop_invalid_encap is None):
                                                        self.in_drop_invalid_encap = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidEncap()
                                                        self.in_drop_invalid_encap.parent = self
                                                        self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"
                                                    return self.in_drop_invalid_encap

                                                if (child_yang_name == "in-drop-invalid-vlan"):
                                                    if (self.in_drop_invalid_vlan is None):
                                                        self.in_drop_invalid_vlan = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropInvalidVlan()
                                                        self.in_drop_invalid_vlan.parent = self
                                                        self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"
                                                    return self.in_drop_invalid_vlan

                                                if (child_yang_name == "in-drop-other"):
                                                    if (self.in_drop_other is None):
                                                        self.in_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOther()
                                                        self.in_drop_other.parent = self
                                                        self._children_name_map["in_drop_other"] = "in-drop-other"
                                                    return self.in_drop_other

                                                if (child_yang_name == "in-drop-overrun"):
                                                    if (self.in_drop_overrun is None):
                                                        self.in_drop_overrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InDropOverrun()
                                                        self.in_drop_overrun.parent = self
                                                        self._children_name_map["in_drop_overrun"] = "in-drop-overrun"
                                                    return self.in_drop_overrun

                                                if (child_yang_name == "in-error-collisions"):
                                                    if (self.in_error_collisions is None):
                                                        self.in_error_collisions = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorCollisions()
                                                        self.in_error_collisions.parent = self
                                                        self._children_name_map["in_error_collisions"] = "in-error-collisions"
                                                    return self.in_error_collisions

                                                if (child_yang_name == "in-error-fragments"):
                                                    if (self.in_error_fragments is None):
                                                        self.in_error_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorFragments()
                                                        self.in_error_fragments.parent = self
                                                        self._children_name_map["in_error_fragments"] = "in-error-fragments"
                                                    return self.in_error_fragments

                                                if (child_yang_name == "in-error-giant"):
                                                    if (self.in_error_giant is None):
                                                        self.in_error_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorGiant()
                                                        self.in_error_giant.parent = self
                                                        self._children_name_map["in_error_giant"] = "in-error-giant"
                                                    return self.in_error_giant

                                                if (child_yang_name == "in-error-jabbers"):
                                                    if (self.in_error_jabbers is None):
                                                        self.in_error_jabbers = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorJabbers()
                                                        self.in_error_jabbers.parent = self
                                                        self._children_name_map["in_error_jabbers"] = "in-error-jabbers"
                                                    return self.in_error_jabbers

                                                if (child_yang_name == "in-error-other"):
                                                    if (self.in_error_other is None):
                                                        self.in_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorOther()
                                                        self.in_error_other.parent = self
                                                        self._children_name_map["in_error_other"] = "in-error-other"
                                                    return self.in_error_other

                                                if (child_yang_name == "in-error-runt"):
                                                    if (self.in_error_runt is None):
                                                        self.in_error_runt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorRunt()
                                                        self.in_error_runt.parent = self
                                                        self._children_name_map["in_error_runt"] = "in-error-runt"
                                                    return self.in_error_runt

                                                if (child_yang_name == "in-error-symbol"):
                                                    if (self.in_error_symbol is None):
                                                        self.in_error_symbol = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InErrorSymbol()
                                                        self.in_error_symbol.parent = self
                                                        self._children_name_map["in_error_symbol"] = "in-error-symbol"
                                                    return self.in_error_symbol

                                                if (child_yang_name == "in-good-bytes"):
                                                    if (self.in_good_bytes is None):
                                                        self.in_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodBytes()
                                                        self.in_good_bytes.parent = self
                                                        self._children_name_map["in_good_bytes"] = "in-good-bytes"
                                                    return self.in_good_bytes

                                                if (child_yang_name == "in-good-pkts"):
                                                    if (self.in_good_pkts is None):
                                                        self.in_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InGoodPkts()
                                                        self.in_good_pkts.parent = self
                                                        self._children_name_map["in_good_pkts"] = "in-good-pkts"
                                                    return self.in_good_pkts

                                                if (child_yang_name == "in-mcast-pkt"):
                                                    if (self.in_mcast_pkt is None):
                                                        self.in_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMcastPkt()
                                                        self.in_mcast_pkt.parent = self
                                                        self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"
                                                    return self.in_mcast_pkt

                                                if (child_yang_name == "in-mib-giant"):
                                                    if (self.in_mib_giant is None):
                                                        self.in_mib_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibGiant()
                                                        self.in_mib_giant.parent = self
                                                        self._children_name_map["in_mib_giant"] = "in-mib-giant"
                                                    return self.in_mib_giant

                                                if (child_yang_name == "in-mib-jabber"):
                                                    if (self.in_mib_jabber is None):
                                                        self.in_mib_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibJabber()
                                                        self.in_mib_jabber.parent = self
                                                        self._children_name_map["in_mib_jabber"] = "in-mib-jabber"
                                                    return self.in_mib_jabber

                                                if (child_yang_name == "in-mibcrc"):
                                                    if (self.in_mibcrc is None):
                                                        self.in_mibcrc = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InMibcrc()
                                                        self.in_mibcrc.parent = self
                                                        self._children_name_map["in_mibcrc"] = "in-mibcrc"
                                                    return self.in_mibcrc

                                                if (child_yang_name == "in-pause-frame"):
                                                    if (self.in_pause_frame is None):
                                                        self.in_pause_frame = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPauseFrame()
                                                        self.in_pause_frame.parent = self
                                                        self._children_name_map["in_pause_frame"] = "in-pause-frame"
                                                    return self.in_pause_frame

                                                if (child_yang_name == "in-pkt64-octet"):
                                                    if (self.in_pkt64_octet is None):
                                                        self.in_pkt64_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkt64Octet()
                                                        self.in_pkt64_octet.parent = self
                                                        self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"
                                                    return self.in_pkt64_octet

                                                if (child_yang_name == "in-pkts1024-to1518-octets"):
                                                    if (self.in_pkts1024_to1518_octets is None):
                                                        self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1024To1518Octets()
                                                        self.in_pkts1024_to1518_octets.parent = self
                                                        self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"
                                                    return self.in_pkts1024_to1518_octets

                                                if (child_yang_name == "in-pkts128-to255-octets"):
                                                    if (self.in_pkts128_to255_octets is None):
                                                        self.in_pkts128_to255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts128To255Octets()
                                                        self.in_pkts128_to255_octets.parent = self
                                                        self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"
                                                    return self.in_pkts128_to255_octets

                                                if (child_yang_name == "in-pkts1519-max-octets"):
                                                    if (self.in_pkts1519_max_octets is None):
                                                        self.in_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts1519MaxOctets()
                                                        self.in_pkts1519_max_octets.parent = self
                                                        self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"
                                                    return self.in_pkts1519_max_octets

                                                if (child_yang_name == "in-pkts256-to511-octets"):
                                                    if (self.in_pkts256_to511_octets is None):
                                                        self.in_pkts256_to511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts256To511Octets()
                                                        self.in_pkts256_to511_octets.parent = self
                                                        self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"
                                                    return self.in_pkts256_to511_octets

                                                if (child_yang_name == "in-pkts512-to1023-octets"):
                                                    if (self.in_pkts512_to1023_octets is None):
                                                        self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts512To1023Octets()
                                                        self.in_pkts512_to1023_octets.parent = self
                                                        self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"
                                                    return self.in_pkts512_to1023_octets

                                                if (child_yang_name == "in-pkts65-to127-octets"):
                                                    if (self.in_pkts65_to127_octets is None):
                                                        self.in_pkts65_to127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InPkts65To127Octets()
                                                        self.in_pkts65_to127_octets.parent = self
                                                        self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"
                                                    return self.in_pkts65_to127_octets

                                                if (child_yang_name == "in-ucast-pkt"):
                                                    if (self.in_ucast_pkt is None):
                                                        self.in_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.InUcastPkt()
                                                        self.in_ucast_pkt.parent = self
                                                        self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"
                                                    return self.in_ucast_pkt

                                                if (child_yang_name == "jabber-stat"):
                                                    if (self.jabber_stat is None):
                                                        self.jabber_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.JabberStat()
                                                        self.jabber_stat.parent = self
                                                        self._children_name_map["jabber_stat"] = "jabber-stat"
                                                    return self.jabber_stat

                                                if (child_yang_name == "long-frames-stat"):
                                                    if (self.long_frames_stat is None):
                                                        self.long_frames_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.LongFramesStat()
                                                        self.long_frames_stat.parent = self
                                                        self._children_name_map["long_frames_stat"] = "long-frames-stat"
                                                    return self.long_frames_stat

                                                if (child_yang_name == "octet-stat"):
                                                    if (self.octet_stat is None):
                                                        self.octet_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OctetStat()
                                                        self.octet_stat.parent = self
                                                        self._children_name_map["octet_stat"] = "octet-stat"
                                                    return self.octet_stat

                                                if (child_yang_name == "out8021q-frames"):
                                                    if (self.out8021q_frames is None):
                                                        self.out8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Out8021QFrames()
                                                        self.out8021q_frames.parent = self
                                                        self._children_name_map["out8021q_frames"] = "out8021q-frames"
                                                    return self.out8021q_frames

                                                if (child_yang_name == "out-bcast-pkt"):
                                                    if (self.out_bcast_pkt is None):
                                                        self.out_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutBcastPkt()
                                                        self.out_bcast_pkt.parent = self
                                                        self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"
                                                    return self.out_bcast_pkt

                                                if (child_yang_name == "out-drop-abort"):
                                                    if (self.out_drop_abort is None):
                                                        self.out_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropAbort()
                                                        self.out_drop_abort.parent = self
                                                        self._children_name_map["out_drop_abort"] = "out-drop-abort"
                                                    return self.out_drop_abort

                                                if (child_yang_name == "out-drop-other"):
                                                    if (self.out_drop_other is None):
                                                        self.out_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropOther()
                                                        self.out_drop_other.parent = self
                                                        self._children_name_map["out_drop_other"] = "out-drop-other"
                                                    return self.out_drop_other

                                                if (child_yang_name == "out-drop-underrun"):
                                                    if (self.out_drop_underrun is None):
                                                        self.out_drop_underrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutDropUnderrun()
                                                        self.out_drop_underrun.parent = self
                                                        self._children_name_map["out_drop_underrun"] = "out-drop-underrun"
                                                    return self.out_drop_underrun

                                                if (child_yang_name == "out-error-other"):
                                                    if (self.out_error_other is None):
                                                        self.out_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutErrorOther()
                                                        self.out_error_other.parent = self
                                                        self._children_name_map["out_error_other"] = "out-error-other"
                                                    return self.out_error_other

                                                if (child_yang_name == "out-good-bytes"):
                                                    if (self.out_good_bytes is None):
                                                        self.out_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodBytes()
                                                        self.out_good_bytes.parent = self
                                                        self._children_name_map["out_good_bytes"] = "out-good-bytes"
                                                    return self.out_good_bytes

                                                if (child_yang_name == "out-good-pkts"):
                                                    if (self.out_good_pkts is None):
                                                        self.out_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutGoodPkts()
                                                        self.out_good_pkts.parent = self
                                                        self._children_name_map["out_good_pkts"] = "out-good-pkts"
                                                    return self.out_good_pkts

                                                if (child_yang_name == "out-mcast-pkt"):
                                                    if (self.out_mcast_pkt is None):
                                                        self.out_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutMcastPkt()
                                                        self.out_mcast_pkt.parent = self
                                                        self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"
                                                    return self.out_mcast_pkt

                                                if (child_yang_name == "out-octets"):
                                                    if (self.out_octets is None):
                                                        self.out_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutOctets()
                                                        self.out_octets.parent = self
                                                        self._children_name_map["out_octets"] = "out-octets"
                                                    return self.out_octets

                                                if (child_yang_name == "out-pause-frames"):
                                                    if (self.out_pause_frames is None):
                                                        self.out_pause_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPauseFrames()
                                                        self.out_pause_frames.parent = self
                                                        self._children_name_map["out_pause_frames"] = "out-pause-frames"
                                                    return self.out_pause_frames

                                                if (child_yang_name == "out-pkts10241518-octets"):
                                                    if (self.out_pkts10241518_octets is None):
                                                        self.out_pkts10241518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts10241518Octets()
                                                        self.out_pkts10241518_octets.parent = self
                                                        self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"
                                                    return self.out_pkts10241518_octets

                                                if (child_yang_name == "out-pkts128255-octets"):
                                                    if (self.out_pkts128255_octets is None):
                                                        self.out_pkts128255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts128255Octets()
                                                        self.out_pkts128255_octets.parent = self
                                                        self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"
                                                    return self.out_pkts128255_octets

                                                if (child_yang_name == "out-pkts1519-max-octets"):
                                                    if (self.out_pkts1519_max_octets is None):
                                                        self.out_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                        self.out_pkts1519_max_octets.parent = self
                                                        self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"
                                                    return self.out_pkts1519_max_octets

                                                if (child_yang_name == "out-pkts256511-octets"):
                                                    if (self.out_pkts256511_octets is None):
                                                        self.out_pkts256511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts256511Octets()
                                                        self.out_pkts256511_octets.parent = self
                                                        self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"
                                                    return self.out_pkts256511_octets

                                                if (child_yang_name == "out-pkts5121023-octets"):
                                                    if (self.out_pkts5121023_octets is None):
                                                        self.out_pkts5121023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts5121023Octets()
                                                        self.out_pkts5121023_octets.parent = self
                                                        self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"
                                                    return self.out_pkts5121023_octets

                                                if (child_yang_name == "out-pkts65127-octets"):
                                                    if (self.out_pkts65127_octets is None):
                                                        self.out_pkts65127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutPkts65127Octets()
                                                        self.out_pkts65127_octets.parent = self
                                                        self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"
                                                    return self.out_pkts65127_octets

                                                if (child_yang_name == "out-ucast-pkt"):
                                                    if (self.out_ucast_pkt is None):
                                                        self.out_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OutUcastPkt()
                                                        self.out_ucast_pkt.parent = self
                                                        self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"
                                                    return self.out_ucast_pkt

                                                if (child_yang_name == "outpkt64octet"):
                                                    if (self.outpkt64octet is None):
                                                        self.outpkt64octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.Outpkt64Octet()
                                                        self.outpkt64octet.parent = self
                                                        self._children_name_map["outpkt64octet"] = "outpkt64octet"
                                                    return self.outpkt64octet

                                                if (child_yang_name == "oversize-pkt-stat"):
                                                    if (self.oversize_pkt_stat is None):
                                                        self.oversize_pkt_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.OversizePktStat()
                                                        self.oversize_pkt_stat.parent = self
                                                        self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"
                                                    return self.oversize_pkt_stat

                                                if (child_yang_name == "rx-pkt"):
                                                    if (self.rx_pkt is None):
                                                        self.rx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxPkt()
                                                        self.rx_pkt.parent = self
                                                        self._children_name_map["rx_pkt"] = "rx-pkt"
                                                    return self.rx_pkt

                                                if (child_yang_name == "rx-util"):
                                                    if (self.rx_util is None):
                                                        self.rx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.RxUtil()
                                                        self.rx_util.parent = self
                                                        self._children_name_map["rx_util"] = "rx-util"
                                                    return self.rx_util

                                                if (child_yang_name == "stat-pkt"):
                                                    if (self.stat_pkt is None):
                                                        self.stat_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.StatPkt()
                                                        self.stat_pkt.parent = self
                                                        self._children_name_map["stat_pkt"] = "stat-pkt"
                                                    return self.stat_pkt

                                                if (child_yang_name == "tx-bad-fcs"):
                                                    if (self.tx_bad_fcs is None):
                                                        self.tx_bad_fcs = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxBadFcs()
                                                        self.tx_bad_fcs.parent = self
                                                        self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                                    return self.tx_bad_fcs

                                                if (child_yang_name == "tx-fragments"):
                                                    if (self.tx_fragments is None):
                                                        self.tx_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxFragments()
                                                        self.tx_fragments.parent = self
                                                        self._children_name_map["tx_fragments"] = "tx-fragments"
                                                    return self.tx_fragments

                                                if (child_yang_name == "tx-jabber"):
                                                    if (self.tx_jabber is None):
                                                        self.tx_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxJabber()
                                                        self.tx_jabber.parent = self
                                                        self._children_name_map["tx_jabber"] = "tx-jabber"
                                                    return self.tx_jabber

                                                if (child_yang_name == "tx-oversized-pkt"):
                                                    if (self.tx_oversized_pkt is None):
                                                        self.tx_oversized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxOversizedPkt()
                                                        self.tx_oversized_pkt.parent = self
                                                        self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"
                                                    return self.tx_oversized_pkt

                                                if (child_yang_name == "tx-pkt"):
                                                    if (self.tx_pkt is None):
                                                        self.tx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxPkt()
                                                        self.tx_pkt.parent = self
                                                        self._children_name_map["tx_pkt"] = "tx-pkt"
                                                    return self.tx_pkt

                                                if (child_yang_name == "tx-undersized-pkt"):
                                                    if (self.tx_undersized_pkt is None):
                                                        self.tx_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUndersizedPkt()
                                                        self.tx_undersized_pkt.parent = self
                                                        self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"
                                                    return self.tx_undersized_pkt

                                                if (child_yang_name == "tx-util"):
                                                    if (self.tx_util is None):
                                                        self.tx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance.TxUtil()
                                                        self.tx_util.parent = self
                                                        self._children_name_map["tx_util"] = "tx-util"
                                                    return self.tx_util

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ether10241518-octet" or name == "ether128255-octet" or name == "ether256511-octet" or name == "ether5121023-octet" or name == "ether64-octets" or name == "ether65127-octet" or name == "ether-stat-broadcast-pkt" or name == "ether-stat-multicast-pkt" or name == "ether-stat-undersized-pkt" or name == "fcs-errors-stat" or name == "if-in-errors" or name == "if-in-octets" or name == "in8021q-frames" or name == "in-bcast-pkt" or name == "in-drop-abort" or name == "in-drop-invalid-dmac" or name == "in-drop-invalid-encap" or name == "in-drop-invalid-vlan" or name == "in-drop-other" or name == "in-drop-overrun" or name == "in-error-collisions" or name == "in-error-fragments" or name == "in-error-giant" or name == "in-error-jabbers" or name == "in-error-other" or name == "in-error-runt" or name == "in-error-symbol" or name == "in-good-bytes" or name == "in-good-pkts" or name == "in-mcast-pkt" or name == "in-mib-giant" or name == "in-mib-jabber" or name == "in-mibcrc" or name == "in-pause-frame" or name == "in-pkt64-octet" or name == "in-pkts1024-to1518-octets" or name == "in-pkts128-to255-octets" or name == "in-pkts1519-max-octets" or name == "in-pkts256-to511-octets" or name == "in-pkts512-to1023-octets" or name == "in-pkts65-to127-octets" or name == "in-ucast-pkt" or name == "jabber-stat" or name == "long-frames-stat" or name == "octet-stat" or name == "out8021q-frames" or name == "out-bcast-pkt" or name == "out-drop-abort" or name == "out-drop-other" or name == "out-drop-underrun" or name == "out-error-other" or name == "out-good-bytes" or name == "out-good-pkts" or name == "out-mcast-pkt" or name == "out-octets" or name == "out-pause-frames" or name == "out-pkts10241518-octets" or name == "out-pkts128255-octets" or name == "out-pkts1519-max-octets" or name == "out-pkts256511-octets" or name == "out-pkts5121023-octets" or name == "out-pkts65127-octets" or name == "out-ucast-pkt" or name == "outpkt64octet" or name == "oversize-pkt-stat" or name == "rx-pkt" or name == "rx-util" or name == "stat-pkt" or name == "tx-bad-fcs" or name == "tx-fragments" or name == "tx-jabber" or name == "tx-oversized-pkt" or name == "tx-pkt" or name == "tx-undersized-pkt" or name == "tx-util" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.ethernet_hour24_ether_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.ethernet_hour24_ether_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ethernet-hour24-ether-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "ethernet-hour24-ether-time-line-instance"):
                                                for c in self.ethernet_hour24_ether_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances.EthernetHour24EtherTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ethernet_hour24_ether_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ethernet-hour24-ether-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.ethernet_hour24_ether_time_line_instances is not None and self.ethernet_hour24_ether_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.ethernet_hour24_ether_time_line_instances is not None and self.ethernet_hour24_ether_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ethernet-hour24-ether-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "ethernet-hour24-ether-time-line-instances"):
                                            if (self.ethernet_hour24_ether_time_line_instances is None):
                                                self.ethernet_hour24_ether_time_line_instances = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory.EthernetHour24EtherTimeLineInstances()
                                                self.ethernet_hour24_ether_time_line_instances.parent = self
                                                self._children_name_map["ethernet_hour24_ether_time_line_instances"] = "ethernet-hour24-ether-time-line-instances"
                                            return self.ethernet_hour24_ether_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ethernet-hour24-ether-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.ethernet_hour24_ether_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.ethernet_hour24_ether_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ethernet-hour24-ether-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ethernet-hour24-ether-history"):
                                        for c in self.ethernet_hour24_ether_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories.EthernetHour24EtherHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.ethernet_hour24_ether_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ethernet-hour24-ether-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.ethernet_hour24_ether_histories is not None and self.ethernet_hour24_ether_histories.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.ethernet_hour24_ether_histories is not None and self.ethernet_hour24_ether_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ethernet-hour24-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ethernet-hour24-ether-histories"):
                                    if (self.ethernet_hour24_ether_histories is None):
                                        self.ethernet_hour24_ether_histories = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History.EthernetHour24EtherHistories()
                                        self.ethernet_hour24_ether_histories.parent = self
                                        self._children_name_map["ethernet_hour24_ether_histories"] = "ethernet-hour24-ether-histories"
                                    return self.ethernet_hour24_ether_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ethernet-hour24-ether-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class EthernetMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: minute15_ether_histories
                            
                            	ETHERNET port interval performance data
                            	**type**\:   :py:class:`Minute15EtherHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History, self).__init__()

                                self.yang_name = "ethernet-minute15-history"
                                self.yang_parent_name = "ethernet-port-history"

                                self.minute15_ether_histories = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories()
                                self.minute15_ether_histories.parent = self
                                self._children_name_map["minute15_ether_histories"] = "minute15-ether-histories"
                                self._children_yang_names.add("minute15-ether-histories")


                            class Minute15EtherHistories(Entity):
                                """
                                ETHERNET port interval performance data
                                
                                .. attribute:: minute15_ether_history
                                
                                	ETHERNET port 15\-minute ether performance data
                                	**type**\: list of    :py:class:`Minute15EtherHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories, self).__init__()

                                    self.yang_name = "minute15-ether-histories"
                                    self.yang_parent_name = "ethernet-minute15-history"

                                    self.minute15_ether_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories, self).__setattr__(name, value)


                                class Minute15EtherHistory(Entity):
                                    """
                                    ETHERNET port 15\-minute ether performance
                                    data
                                    
                                    .. attribute:: slot_number  <key>
                                    
                                    	interval slot number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: minute15_ether_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`Minute15EtherTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory, self).__init__()

                                        self.yang_name = "minute15-ether-history"
                                        self.yang_parent_name = "minute15-ether-histories"

                                        self.slot_number = YLeaf(YType.int32, "slot-number")

                                        self.minute15_ether_time_line_instances = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances()
                                        self.minute15_ether_time_line_instances.parent = self
                                        self._children_name_map["minute15_ether_time_line_instances"] = "minute15-ether-time-line-instances"
                                        self._children_yang_names.add("minute15-ether-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("slot_number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory, self).__setattr__(name, value)


                                    class Minute15EtherTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: minute15_ether_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`Minute15EtherTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances, self).__init__()

                                            self.yang_name = "minute15-ether-time-line-instances"
                                            self.yang_parent_name = "minute15-ether-history"

                                            self.minute15_ether_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances, self).__setattr__(name, value)


                                        class Minute15EtherTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ether10241518_octet
                                            
                                            	OFO OCTET
                                            	**type**\:   :py:class:`Ether10241518Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet>`
                                            
                                            .. attribute:: ether128255_octet
                                            
                                            	TFF OCTET
                                            	**type**\:   :py:class:`Ether128255Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet>`
                                            
                                            .. attribute:: ether256511_octet
                                            
                                            	FOO OCTET
                                            	**type**\:   :py:class:`Ether256511Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet>`
                                            
                                            .. attribute:: ether5121023_octet
                                            
                                            	OZTT OCTET
                                            	**type**\:   :py:class:`Ether5121023Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet>`
                                            
                                            .. attribute:: ether64_octets
                                            
                                            	SIXTY FOUR OCTET
                                            	**type**\:   :py:class:`Ether64Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets>`
                                            
                                            .. attribute:: ether65127_octet
                                            
                                            	OCTET
                                            	**type**\:   :py:class:`Ether65127Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet>`
                                            
                                            .. attribute:: ether_stat_broadcast_pkt
                                            
                                            	ETHER STAT BROADCAST PKT
                                            	**type**\:   :py:class:`EtherStatBroadcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt>`
                                            
                                            .. attribute:: ether_stat_multicast_pkt
                                            
                                            	ETHER STAT MULTICAST PKT
                                            	**type**\:   :py:class:`EtherStatMulticastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt>`
                                            
                                            .. attribute:: ether_stat_undersized_pkt
                                            
                                            	ETHER STAT UNDERSIZED PKT
                                            	**type**\:   :py:class:`EtherStatUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt>`
                                            
                                            .. attribute:: fcs_errors_stat
                                            
                                            	FCS ERR
                                            	**type**\:   :py:class:`FcsErrorsStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat>`
                                            
                                            .. attribute:: if_in_errors
                                            
                                            	IFIN ERRORS
                                            	**type**\:   :py:class:`IfInErrors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors>`
                                            
                                            .. attribute:: if_in_octets
                                            
                                            	IFIN OCTETS
                                            	**type**\:   :py:class:`IfInOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets>`
                                            
                                            .. attribute:: in8021q_frames
                                            
                                            	INPUT 802 1Q FRAMES
                                            	**type**\:   :py:class:`In8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021QFrames>`
                                            
                                            .. attribute:: in_bcast_pkt
                                            
                                            	IN BCAST
                                            	**type**\:   :py:class:`InBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt>`
                                            
                                            .. attribute:: in_drop_abort
                                            
                                            	INPUT DROP ABORT
                                            	**type**\:   :py:class:`InDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort>`
                                            
                                            .. attribute:: in_drop_invalid_dmac
                                            
                                            	INPUT DROP INVALID DMAC
                                            	**type**\:   :py:class:`InDropInvalidDmac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac>`
                                            
                                            .. attribute:: in_drop_invalid_encap
                                            
                                            	INPUT DROP INVALID ENCAP
                                            	**type**\:   :py:class:`InDropInvalidEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap>`
                                            
                                            .. attribute:: in_drop_invalid_vlan
                                            
                                            	INPUT DROP INVALID VLAN
                                            	**type**\:   :py:class:`InDropInvalidVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan>`
                                            
                                            .. attribute:: in_drop_other
                                            
                                            	INPUT DROP OTHER
                                            	**type**\:   :py:class:`InDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther>`
                                            
                                            .. attribute:: in_drop_overrun
                                            
                                            	INPUT DROP OVERRUN
                                            	**type**\:   :py:class:`InDropOverrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun>`
                                            
                                            .. attribute:: in_error_collisions
                                            
                                            	IN ERROR COLLISIONS
                                            	**type**\:   :py:class:`InErrorCollisions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions>`
                                            
                                            .. attribute:: in_error_fragments
                                            
                                            	IN ERROR FRAGMENTS
                                            	**type**\:   :py:class:`InErrorFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments>`
                                            
                                            .. attribute:: in_error_giant
                                            
                                            	IN ERROR GIANT
                                            	**type**\:   :py:class:`InErrorGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant>`
                                            
                                            .. attribute:: in_error_jabbers
                                            
                                            	IN ERROR JABBERS
                                            	**type**\:   :py:class:`InErrorJabbers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers>`
                                            
                                            .. attribute:: in_error_other
                                            
                                            	IN ERROR OTHER
                                            	**type**\:   :py:class:`InErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther>`
                                            
                                            .. attribute:: in_error_runt
                                            
                                            	IN ERROR RUNT
                                            	**type**\:   :py:class:`InErrorRunt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt>`
                                            
                                            .. attribute:: in_error_symbol
                                            
                                            	IN ERROR SYMBOL
                                            	**type**\:   :py:class:`InErrorSymbol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol>`
                                            
                                            .. attribute:: in_good_bytes
                                            
                                            	INPUT GOOD BYTES
                                            	**type**\:   :py:class:`InGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes>`
                                            
                                            .. attribute:: in_good_pkts
                                            
                                            	INPUT GOOD PKTS
                                            	**type**\:   :py:class:`InGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts>`
                                            
                                            .. attribute:: in_mcast_pkt
                                            
                                            	IN MCAST
                                            	**type**\:   :py:class:`InMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt>`
                                            
                                            .. attribute:: in_mib_giant
                                            
                                            	INPUT MIB GIANT
                                            	**type**\:   :py:class:`InMibGiant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant>`
                                            
                                            .. attribute:: in_mib_jabber
                                            
                                            	INPUT MIB JABBER
                                            	**type**\:   :py:class:`InMibJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber>`
                                            
                                            .. attribute:: in_mibcrc
                                            
                                            	IN MIB CRC
                                            	**type**\:   :py:class:`InMibcrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc>`
                                            
                                            .. attribute:: in_pause_frame
                                            
                                            	INPUT PAUSE FRAME
                                            	**type**\:   :py:class:`InPauseFrame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame>`
                                            
                                            .. attribute:: in_pkt64_octet
                                            
                                            	IN PKT 64 OCTET
                                            	**type**\:   :py:class:`InPkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet>`
                                            
                                            .. attribute:: in_pkts1024_to1518_octets
                                            
                                            	IN PKTS 1024 1518 OCTETS
                                            	**type**\:   :py:class:`InPkts1024To1518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets>`
                                            
                                            .. attribute:: in_pkts128_to255_octets
                                            
                                            	IN PKTS 128 255 OCTETS
                                            	**type**\:   :py:class:`InPkts128To255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets>`
                                            
                                            .. attribute:: in_pkts1519_max_octets
                                            
                                            	INPUT PKTS 1519MAX OCTETS
                                            	**type**\:   :py:class:`InPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets>`
                                            
                                            .. attribute:: in_pkts256_to511_octets
                                            
                                            	IN PKTS 256 511 OCTETS
                                            	**type**\:   :py:class:`InPkts256To511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets>`
                                            
                                            .. attribute:: in_pkts512_to1023_octets
                                            
                                            	IN PKTS 512 1023 OCTETS
                                            	**type**\:   :py:class:`InPkts512To1023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets>`
                                            
                                            .. attribute:: in_pkts65_to127_octets
                                            
                                            	IN PKTS 65 127OCTETS
                                            	**type**\:   :py:class:`InPkts65To127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets>`
                                            
                                            .. attribute:: in_ucast_pkt
                                            
                                            	IN UCAST
                                            	**type**\:   :py:class:`InUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: jabber_stat
                                            
                                            	JABBER STATS
                                            	**type**\:   :py:class:`JabberStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat>`
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: long_frames_stat
                                            
                                            	LONG FRAMES
                                            	**type**\:   :py:class:`LongFramesStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat>`
                                            
                                            .. attribute:: octet_stat
                                            
                                            	OCTET STAT
                                            	**type**\:   :py:class:`OctetStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat>`
                                            
                                            .. attribute:: out8021q_frames
                                            
                                            	OUT 802 1Q FRAMES
                                            	**type**\:   :py:class:`Out8021QFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021QFrames>`
                                            
                                            .. attribute:: out_bcast_pkt
                                            
                                            	OUT BCAST
                                            	**type**\:   :py:class:`OutBcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt>`
                                            
                                            .. attribute:: out_drop_abort
                                            
                                            	OUT DROP ABORT
                                            	**type**\:   :py:class:`OutDropAbort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort>`
                                            
                                            .. attribute:: out_drop_other
                                            
                                            	OUT DROP OTHER
                                            	**type**\:   :py:class:`OutDropOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther>`
                                            
                                            .. attribute:: out_drop_underrun
                                            
                                            	OUT DROP UNDERRUN
                                            	**type**\:   :py:class:`OutDropUnderrun <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun>`
                                            
                                            .. attribute:: out_error_other
                                            
                                            	OUT ERROR OTHER
                                            	**type**\:   :py:class:`OutErrorOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther>`
                                            
                                            .. attribute:: out_good_bytes
                                            
                                            	OUT GOOD BYTES
                                            	**type**\:   :py:class:`OutGoodBytes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes>`
                                            
                                            .. attribute:: out_good_pkts
                                            
                                            	OUT GOOD PKTS
                                            	**type**\:   :py:class:`OutGoodPkts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts>`
                                            
                                            .. attribute:: out_mcast_pkt
                                            
                                            	OUT MCAST
                                            	**type**\:   :py:class:`OutMcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt>`
                                            
                                            .. attribute:: out_octets
                                            
                                            	OUT OCTET
                                            	**type**\:   :py:class:`OutOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets>`
                                            
                                            .. attribute:: out_pause_frames
                                            
                                            	OUT PAUSE FRAMES
                                            	**type**\:   :py:class:`OutPauseFrames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames>`
                                            
                                            .. attribute:: out_pkts10241518_octets
                                            
                                            	OUT PKTS 1024 1518 OCTETS
                                            	**type**\:   :py:class:`OutPkts10241518Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets>`
                                            
                                            .. attribute:: out_pkts128255_octets
                                            
                                            	OUT PKTS 128 255 OCTETS
                                            	**type**\:   :py:class:`OutPkts128255Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets>`
                                            
                                            .. attribute:: out_pkts1519_max_octets
                                            
                                            	OUT PKTS 1519 MAX OCTETS
                                            	**type**\:   :py:class:`OutPkts1519MaxOctets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets>`
                                            
                                            .. attribute:: out_pkts256511_octets
                                            
                                            	OUT PKTS 256 511 OCTETS
                                            	**type**\:   :py:class:`OutPkts256511Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets>`
                                            
                                            .. attribute:: out_pkts5121023_octets
                                            
                                            	OUT PKTS 512 1023 OCTETS
                                            	**type**\:   :py:class:`OutPkts5121023Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets>`
                                            
                                            .. attribute:: out_pkts65127_octets
                                            
                                            	OUT PKTS 65 127OCTETS
                                            	**type**\:   :py:class:`OutPkts65127Octets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets>`
                                            
                                            .. attribute:: out_ucast_pkt
                                            
                                            	OUT UCAST
                                            	**type**\:   :py:class:`OutUcastPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt>`
                                            
                                            .. attribute:: outpkt64octet
                                            
                                            	OUT PKT 64 OCTET
                                            	**type**\:   :py:class:`Outpkt64Octet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64Octet>`
                                            
                                            .. attribute:: oversize_pkt_stat
                                            
                                            	OVERSIZE PKT
                                            	**type**\:   :py:class:`OversizePktStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat>`
                                            
                                            .. attribute:: rx_pkt
                                            
                                            	RX PKT
                                            	**type**\:   :py:class:`RxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt>`
                                            
                                            .. attribute:: rx_util
                                            
                                            	Rx Utilization in Percent
                                            	**type**\:   :py:class:`RxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: stat_pkt
                                            
                                            	STAT PKT
                                            	**type**\:   :py:class:`StatPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: tx_bad_fcs
                                            
                                            	TX Bad Fcs
                                            	**type**\:   :py:class:`TxBadFcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs>`
                                            
                                            .. attribute:: tx_fragments
                                            
                                            	TX Fragments
                                            	**type**\:   :py:class:`TxFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments>`
                                            
                                            .. attribute:: tx_jabber
                                            
                                            	TX Jabber
                                            	**type**\:   :py:class:`TxJabber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber>`
                                            
                                            .. attribute:: tx_oversized_pkt
                                            
                                            	TX Oversized Pkt
                                            	**type**\:   :py:class:`TxOversizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt>`
                                            
                                            .. attribute:: tx_pkt
                                            
                                            	TX PKT
                                            	**type**\:   :py:class:`TxPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt>`
                                            
                                            .. attribute:: tx_undersized_pkt
                                            
                                            	TX Undersized Pkt
                                            	**type**\:   :py:class:`TxUndersizedPkt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt>`
                                            
                                            .. attribute:: tx_util
                                            
                                            	Tx Utilization in Percent
                                            	**type**\:   :py:class:`TxUtil <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance, self).__init__()

                                                self.yang_name = "minute15-ether-time-line-instance"
                                                self.yang_parent_name = "minute15-ether-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.ether10241518_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet()
                                                self.ether10241518_octet.parent = self
                                                self._children_name_map["ether10241518_octet"] = "ether10241518-octet"
                                                self._children_yang_names.add("ether10241518-octet")

                                                self.ether128255_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet()
                                                self.ether128255_octet.parent = self
                                                self._children_name_map["ether128255_octet"] = "ether128255-octet"
                                                self._children_yang_names.add("ether128255-octet")

                                                self.ether256511_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet()
                                                self.ether256511_octet.parent = self
                                                self._children_name_map["ether256511_octet"] = "ether256511-octet"
                                                self._children_yang_names.add("ether256511-octet")

                                                self.ether5121023_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet()
                                                self.ether5121023_octet.parent = self
                                                self._children_name_map["ether5121023_octet"] = "ether5121023-octet"
                                                self._children_yang_names.add("ether5121023-octet")

                                                self.ether64_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets()
                                                self.ether64_octets.parent = self
                                                self._children_name_map["ether64_octets"] = "ether64-octets"
                                                self._children_yang_names.add("ether64-octets")

                                                self.ether65127_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet()
                                                self.ether65127_octet.parent = self
                                                self._children_name_map["ether65127_octet"] = "ether65127-octet"
                                                self._children_yang_names.add("ether65127-octet")

                                                self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                self.ether_stat_broadcast_pkt.parent = self
                                                self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"
                                                self._children_yang_names.add("ether-stat-broadcast-pkt")

                                                self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt()
                                                self.ether_stat_multicast_pkt.parent = self
                                                self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"
                                                self._children_yang_names.add("ether-stat-multicast-pkt")

                                                self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                self.ether_stat_undersized_pkt.parent = self
                                                self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"
                                                self._children_yang_names.add("ether-stat-undersized-pkt")

                                                self.fcs_errors_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat()
                                                self.fcs_errors_stat.parent = self
                                                self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"
                                                self._children_yang_names.add("fcs-errors-stat")

                                                self.if_in_errors = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors()
                                                self.if_in_errors.parent = self
                                                self._children_name_map["if_in_errors"] = "if-in-errors"
                                                self._children_yang_names.add("if-in-errors")

                                                self.if_in_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets()
                                                self.if_in_octets.parent = self
                                                self._children_name_map["if_in_octets"] = "if-in-octets"
                                                self._children_yang_names.add("if-in-octets")

                                                self.in8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021QFrames()
                                                self.in8021q_frames.parent = self
                                                self._children_name_map["in8021q_frames"] = "in8021q-frames"
                                                self._children_yang_names.add("in8021q-frames")

                                                self.in_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt()
                                                self.in_bcast_pkt.parent = self
                                                self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"
                                                self._children_yang_names.add("in-bcast-pkt")

                                                self.in_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort()
                                                self.in_drop_abort.parent = self
                                                self._children_name_map["in_drop_abort"] = "in-drop-abort"
                                                self._children_yang_names.add("in-drop-abort")

                                                self.in_drop_invalid_dmac = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac()
                                                self.in_drop_invalid_dmac.parent = self
                                                self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"
                                                self._children_yang_names.add("in-drop-invalid-dmac")

                                                self.in_drop_invalid_encap = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap()
                                                self.in_drop_invalid_encap.parent = self
                                                self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"
                                                self._children_yang_names.add("in-drop-invalid-encap")

                                                self.in_drop_invalid_vlan = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan()
                                                self.in_drop_invalid_vlan.parent = self
                                                self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"
                                                self._children_yang_names.add("in-drop-invalid-vlan")

                                                self.in_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther()
                                                self.in_drop_other.parent = self
                                                self._children_name_map["in_drop_other"] = "in-drop-other"
                                                self._children_yang_names.add("in-drop-other")

                                                self.in_drop_overrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun()
                                                self.in_drop_overrun.parent = self
                                                self._children_name_map["in_drop_overrun"] = "in-drop-overrun"
                                                self._children_yang_names.add("in-drop-overrun")

                                                self.in_error_collisions = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions()
                                                self.in_error_collisions.parent = self
                                                self._children_name_map["in_error_collisions"] = "in-error-collisions"
                                                self._children_yang_names.add("in-error-collisions")

                                                self.in_error_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments()
                                                self.in_error_fragments.parent = self
                                                self._children_name_map["in_error_fragments"] = "in-error-fragments"
                                                self._children_yang_names.add("in-error-fragments")

                                                self.in_error_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant()
                                                self.in_error_giant.parent = self
                                                self._children_name_map["in_error_giant"] = "in-error-giant"
                                                self._children_yang_names.add("in-error-giant")

                                                self.in_error_jabbers = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers()
                                                self.in_error_jabbers.parent = self
                                                self._children_name_map["in_error_jabbers"] = "in-error-jabbers"
                                                self._children_yang_names.add("in-error-jabbers")

                                                self.in_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther()
                                                self.in_error_other.parent = self
                                                self._children_name_map["in_error_other"] = "in-error-other"
                                                self._children_yang_names.add("in-error-other")

                                                self.in_error_runt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt()
                                                self.in_error_runt.parent = self
                                                self._children_name_map["in_error_runt"] = "in-error-runt"
                                                self._children_yang_names.add("in-error-runt")

                                                self.in_error_symbol = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol()
                                                self.in_error_symbol.parent = self
                                                self._children_name_map["in_error_symbol"] = "in-error-symbol"
                                                self._children_yang_names.add("in-error-symbol")

                                                self.in_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes()
                                                self.in_good_bytes.parent = self
                                                self._children_name_map["in_good_bytes"] = "in-good-bytes"
                                                self._children_yang_names.add("in-good-bytes")

                                                self.in_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts()
                                                self.in_good_pkts.parent = self
                                                self._children_name_map["in_good_pkts"] = "in-good-pkts"
                                                self._children_yang_names.add("in-good-pkts")

                                                self.in_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt()
                                                self.in_mcast_pkt.parent = self
                                                self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"
                                                self._children_yang_names.add("in-mcast-pkt")

                                                self.in_mib_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant()
                                                self.in_mib_giant.parent = self
                                                self._children_name_map["in_mib_giant"] = "in-mib-giant"
                                                self._children_yang_names.add("in-mib-giant")

                                                self.in_mib_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber()
                                                self.in_mib_jabber.parent = self
                                                self._children_name_map["in_mib_jabber"] = "in-mib-jabber"
                                                self._children_yang_names.add("in-mib-jabber")

                                                self.in_mibcrc = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc()
                                                self.in_mibcrc.parent = self
                                                self._children_name_map["in_mibcrc"] = "in-mibcrc"
                                                self._children_yang_names.add("in-mibcrc")

                                                self.in_pause_frame = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame()
                                                self.in_pause_frame.parent = self
                                                self._children_name_map["in_pause_frame"] = "in-pause-frame"
                                                self._children_yang_names.add("in-pause-frame")

                                                self.in_pkt64_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet()
                                                self.in_pkt64_octet.parent = self
                                                self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"
                                                self._children_yang_names.add("in-pkt64-octet")

                                                self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets()
                                                self.in_pkts1024_to1518_octets.parent = self
                                                self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"
                                                self._children_yang_names.add("in-pkts1024-to1518-octets")

                                                self.in_pkts128_to255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets()
                                                self.in_pkts128_to255_octets.parent = self
                                                self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"
                                                self._children_yang_names.add("in-pkts128-to255-octets")

                                                self.in_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets()
                                                self.in_pkts1519_max_octets.parent = self
                                                self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"
                                                self._children_yang_names.add("in-pkts1519-max-octets")

                                                self.in_pkts256_to511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets()
                                                self.in_pkts256_to511_octets.parent = self
                                                self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"
                                                self._children_yang_names.add("in-pkts256-to511-octets")

                                                self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets()
                                                self.in_pkts512_to1023_octets.parent = self
                                                self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"
                                                self._children_yang_names.add("in-pkts512-to1023-octets")

                                                self.in_pkts65_to127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets()
                                                self.in_pkts65_to127_octets.parent = self
                                                self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"
                                                self._children_yang_names.add("in-pkts65-to127-octets")

                                                self.in_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt()
                                                self.in_ucast_pkt.parent = self
                                                self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"
                                                self._children_yang_names.add("in-ucast-pkt")

                                                self.jabber_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat()
                                                self.jabber_stat.parent = self
                                                self._children_name_map["jabber_stat"] = "jabber-stat"
                                                self._children_yang_names.add("jabber-stat")

                                                self.long_frames_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat()
                                                self.long_frames_stat.parent = self
                                                self._children_name_map["long_frames_stat"] = "long-frames-stat"
                                                self._children_yang_names.add("long-frames-stat")

                                                self.octet_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat()
                                                self.octet_stat.parent = self
                                                self._children_name_map["octet_stat"] = "octet-stat"
                                                self._children_yang_names.add("octet-stat")

                                                self.out8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021QFrames()
                                                self.out8021q_frames.parent = self
                                                self._children_name_map["out8021q_frames"] = "out8021q-frames"
                                                self._children_yang_names.add("out8021q-frames")

                                                self.out_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt()
                                                self.out_bcast_pkt.parent = self
                                                self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"
                                                self._children_yang_names.add("out-bcast-pkt")

                                                self.out_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort()
                                                self.out_drop_abort.parent = self
                                                self._children_name_map["out_drop_abort"] = "out-drop-abort"
                                                self._children_yang_names.add("out-drop-abort")

                                                self.out_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther()
                                                self.out_drop_other.parent = self
                                                self._children_name_map["out_drop_other"] = "out-drop-other"
                                                self._children_yang_names.add("out-drop-other")

                                                self.out_drop_underrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun()
                                                self.out_drop_underrun.parent = self
                                                self._children_name_map["out_drop_underrun"] = "out-drop-underrun"
                                                self._children_yang_names.add("out-drop-underrun")

                                                self.out_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther()
                                                self.out_error_other.parent = self
                                                self._children_name_map["out_error_other"] = "out-error-other"
                                                self._children_yang_names.add("out-error-other")

                                                self.out_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes()
                                                self.out_good_bytes.parent = self
                                                self._children_name_map["out_good_bytes"] = "out-good-bytes"
                                                self._children_yang_names.add("out-good-bytes")

                                                self.out_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts()
                                                self.out_good_pkts.parent = self
                                                self._children_name_map["out_good_pkts"] = "out-good-pkts"
                                                self._children_yang_names.add("out-good-pkts")

                                                self.out_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt()
                                                self.out_mcast_pkt.parent = self
                                                self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"
                                                self._children_yang_names.add("out-mcast-pkt")

                                                self.out_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets()
                                                self.out_octets.parent = self
                                                self._children_name_map["out_octets"] = "out-octets"
                                                self._children_yang_names.add("out-octets")

                                                self.out_pause_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames()
                                                self.out_pause_frames.parent = self
                                                self._children_name_map["out_pause_frames"] = "out-pause-frames"
                                                self._children_yang_names.add("out-pause-frames")

                                                self.out_pkts10241518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets()
                                                self.out_pkts10241518_octets.parent = self
                                                self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"
                                                self._children_yang_names.add("out-pkts10241518-octets")

                                                self.out_pkts128255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets()
                                                self.out_pkts128255_octets.parent = self
                                                self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"
                                                self._children_yang_names.add("out-pkts128255-octets")

                                                self.out_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                self.out_pkts1519_max_octets.parent = self
                                                self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"
                                                self._children_yang_names.add("out-pkts1519-max-octets")

                                                self.out_pkts256511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets()
                                                self.out_pkts256511_octets.parent = self
                                                self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"
                                                self._children_yang_names.add("out-pkts256511-octets")

                                                self.out_pkts5121023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets()
                                                self.out_pkts5121023_octets.parent = self
                                                self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"
                                                self._children_yang_names.add("out-pkts5121023-octets")

                                                self.out_pkts65127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets()
                                                self.out_pkts65127_octets.parent = self
                                                self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"
                                                self._children_yang_names.add("out-pkts65127-octets")

                                                self.out_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt()
                                                self.out_ucast_pkt.parent = self
                                                self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"
                                                self._children_yang_names.add("out-ucast-pkt")

                                                self.outpkt64octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64Octet()
                                                self.outpkt64octet.parent = self
                                                self._children_name_map["outpkt64octet"] = "outpkt64octet"
                                                self._children_yang_names.add("outpkt64octet")

                                                self.oversize_pkt_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat()
                                                self.oversize_pkt_stat.parent = self
                                                self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"
                                                self._children_yang_names.add("oversize-pkt-stat")

                                                self.rx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt()
                                                self.rx_pkt.parent = self
                                                self._children_name_map["rx_pkt"] = "rx-pkt"
                                                self._children_yang_names.add("rx-pkt")

                                                self.rx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil()
                                                self.rx_util.parent = self
                                                self._children_name_map["rx_util"] = "rx-util"
                                                self._children_yang_names.add("rx-util")

                                                self.stat_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt()
                                                self.stat_pkt.parent = self
                                                self._children_name_map["stat_pkt"] = "stat-pkt"
                                                self._children_yang_names.add("stat-pkt")

                                                self.tx_bad_fcs = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs()
                                                self.tx_bad_fcs.parent = self
                                                self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                                self._children_yang_names.add("tx-bad-fcs")

                                                self.tx_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments()
                                                self.tx_fragments.parent = self
                                                self._children_name_map["tx_fragments"] = "tx-fragments"
                                                self._children_yang_names.add("tx-fragments")

                                                self.tx_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber()
                                                self.tx_jabber.parent = self
                                                self._children_name_map["tx_jabber"] = "tx-jabber"
                                                self._children_yang_names.add("tx-jabber")

                                                self.tx_oversized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt()
                                                self.tx_oversized_pkt.parent = self
                                                self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"
                                                self._children_yang_names.add("tx-oversized-pkt")

                                                self.tx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt()
                                                self.tx_pkt.parent = self
                                                self._children_name_map["tx_pkt"] = "tx-pkt"
                                                self._children_yang_names.add("tx-pkt")

                                                self.tx_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt()
                                                self.tx_undersized_pkt.parent = self
                                                self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"
                                                self._children_yang_names.add("tx-undersized-pkt")

                                                self.tx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil()
                                                self.tx_util.parent = self
                                                self._children_name_map["tx_util"] = "tx-util"
                                                self._children_yang_names.add("tx-util")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance, self).__setattr__(name, value)


                                            class RxPkt(Entity):
                                                """
                                                RX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt, self).__init__()

                                                    self.yang_name = "rx-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class StatPkt(Entity):
                                                """
                                                STAT PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt, self).__init__()

                                                    self.yang_name = "stat-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "stat-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OctetStat(Entity):
                                                """
                                                OCTET STAT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat, self).__init__()

                                                    self.yang_name = "octet-stat"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "octet-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OversizePktStat(Entity):
                                                """
                                                OVERSIZE PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat, self).__init__()

                                                    self.yang_name = "oversize-pkt-stat"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "oversize-pkt-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class FcsErrorsStat(Entity):
                                                """
                                                FCS ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat, self).__init__()

                                                    self.yang_name = "fcs-errors-stat"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fcs-errors-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LongFramesStat(Entity):
                                                """
                                                LONG FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat, self).__init__()

                                                    self.yang_name = "long-frames-stat"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "long-frames-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class JabberStat(Entity):
                                                """
                                                JABBER STATS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat, self).__init__()

                                                    self.yang_name = "jabber-stat"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "jabber-stat" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether64Octets(Entity):
                                                """
                                                SIXTY FOUR OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets, self).__init__()

                                                    self.yang_name = "ether64-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether64-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether65127Octet(Entity):
                                                """
                                                OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet, self).__init__()

                                                    self.yang_name = "ether65127-octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether65127-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether128255Octet(Entity):
                                                """
                                                TFF OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet, self).__init__()

                                                    self.yang_name = "ether128255-octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether128255-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether256511Octet(Entity):
                                                """
                                                FOO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet, self).__init__()

                                                    self.yang_name = "ether256511-octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether256511-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether5121023Octet(Entity):
                                                """
                                                OZTT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet, self).__init__()

                                                    self.yang_name = "ether5121023-octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether5121023-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Ether10241518Octet(Entity):
                                                """
                                                OFO OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet, self).__init__()

                                                    self.yang_name = "ether10241518-octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether10241518-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InUcastPkt(Entity):
                                                """
                                                IN UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt, self).__init__()

                                                    self.yang_name = "in-ucast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-ucast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InMcastPkt(Entity):
                                                """
                                                IN MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt, self).__init__()

                                                    self.yang_name = "in-mcast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-mcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InBcastPkt(Entity):
                                                """
                                                IN BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt, self).__init__()

                                                    self.yang_name = "in-bcast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-bcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutUcastPkt(Entity):
                                                """
                                                OUT UCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt, self).__init__()

                                                    self.yang_name = "out-ucast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-ucast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutBcastPkt(Entity):
                                                """
                                                OUT BCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt, self).__init__()

                                                    self.yang_name = "out-bcast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-bcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutMcastPkt(Entity):
                                                """
                                                OUT MCAST
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt, self).__init__()

                                                    self.yang_name = "out-mcast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-mcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxPkt(Entity):
                                                """
                                                TX PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt, self).__init__()

                                                    self.yang_name = "tx-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class IfInErrors(Entity):
                                                """
                                                IFIN ERRORS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors, self).__init__()

                                                    self.yang_name = "if-in-errors"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "if-in-errors" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class IfInOctets(Entity):
                                                """
                                                IFIN OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets, self).__init__()

                                                    self.yang_name = "if-in-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "if-in-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class EtherStatMulticastPkt(Entity):
                                                """
                                                ETHER STAT MULTICAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-multicast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether-stat-multicast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class EtherStatBroadcastPkt(Entity):
                                                """
                                                ETHER STAT BROADCAST PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt, self).__init__()

                                                    self.yang_name = "ether-stat-broadcast-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether-stat-broadcast-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class EtherStatUndersizedPkt(Entity):
                                                """
                                                ETHER STAT UNDERSIZED PKT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt, self).__init__()

                                                    self.yang_name = "ether-stat-undersized-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ether-stat-undersized-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutOctets(Entity):
                                                """
                                                OUT OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets, self).__init__()

                                                    self.yang_name = "out-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPauseFrame(Entity):
                                                """
                                                INPUT PAUSE FRAME
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame, self).__init__()

                                                    self.yang_name = "in-pause-frame"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pause-frame" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InGoodBytes(Entity):
                                                """
                                                INPUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes, self).__init__()

                                                    self.yang_name = "in-good-bytes"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-good-bytes" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class In8021QFrames(Entity):
                                                """
                                                INPUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021QFrames, self).__init__()

                                                    self.yang_name = "in8021q-frames"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021QFrames, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021QFrames, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in8021q-frames" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts1519MaxOctets(Entity):
                                                """
                                                INPUT PKTS 1519MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "in-pkts1519-max-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts1519-max-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InGoodPkts(Entity):
                                                """
                                                INPUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts, self).__init__()

                                                    self.yang_name = "in-good-pkts"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-good-pkts" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropOverrun(Entity):
                                                """
                                                INPUT DROP OVERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun, self).__init__()

                                                    self.yang_name = "in-drop-overrun"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-overrun" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropAbort(Entity):
                                                """
                                                INPUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort, self).__init__()

                                                    self.yang_name = "in-drop-abort"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-abort" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropInvalidVlan(Entity):
                                                """
                                                INPUT DROP INVALID VLAN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan, self).__init__()

                                                    self.yang_name = "in-drop-invalid-vlan"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-invalid-vlan" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropInvalidDmac(Entity):
                                                """
                                                INPUT DROP INVALID DMAC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac, self).__init__()

                                                    self.yang_name = "in-drop-invalid-dmac"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-invalid-dmac" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropInvalidEncap(Entity):
                                                """
                                                INPUT DROP INVALID ENCAP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap, self).__init__()

                                                    self.yang_name = "in-drop-invalid-encap"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-invalid-encap" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InDropOther(Entity):
                                                """
                                                INPUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther, self).__init__()

                                                    self.yang_name = "in-drop-other"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-drop-other" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InMibGiant(Entity):
                                                """
                                                INPUT MIB GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant, self).__init__()

                                                    self.yang_name = "in-mib-giant"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-mib-giant" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InMibJabber(Entity):
                                                """
                                                INPUT MIB JABBER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber, self).__init__()

                                                    self.yang_name = "in-mib-jabber"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-mib-jabber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InMibcrc(Entity):
                                                """
                                                IN MIB CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc, self).__init__()

                                                    self.yang_name = "in-mibcrc"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-mibcrc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorCollisions(Entity):
                                                """
                                                IN ERROR COLLISIONS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions, self).__init__()

                                                    self.yang_name = "in-error-collisions"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-collisions" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorSymbol(Entity):
                                                """
                                                IN ERROR SYMBOL
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol, self).__init__()

                                                    self.yang_name = "in-error-symbol"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-symbol" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutGoodBytes(Entity):
                                                """
                                                OUT GOOD BYTES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes, self).__init__()

                                                    self.yang_name = "out-good-bytes"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-good-bytes" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Out8021QFrames(Entity):
                                                """
                                                OUT 802 1Q FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021QFrames, self).__init__()

                                                    self.yang_name = "out8021q-frames"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021QFrames, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021QFrames, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out8021q-frames" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPauseFrames(Entity):
                                                """
                                                OUT PAUSE FRAMES
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames, self).__init__()

                                                    self.yang_name = "out-pause-frames"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pause-frames" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts1519MaxOctets(Entity):
                                                """
                                                OUT PKTS 1519 MAX OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets, self).__init__()

                                                    self.yang_name = "out-pkts1519-max-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts1519-max-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutGoodPkts(Entity):
                                                """
                                                OUT GOOD PKTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts, self).__init__()

                                                    self.yang_name = "out-good-pkts"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-good-pkts" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutDropUnderrun(Entity):
                                                """
                                                OUT DROP UNDERRUN
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun, self).__init__()

                                                    self.yang_name = "out-drop-underrun"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-drop-underrun" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutDropAbort(Entity):
                                                """
                                                OUT DROP ABORT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort, self).__init__()

                                                    self.yang_name = "out-drop-abort"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-drop-abort" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutDropOther(Entity):
                                                """
                                                OUT DROP OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther, self).__init__()

                                                    self.yang_name = "out-drop-other"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-drop-other" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutErrorOther(Entity):
                                                """
                                                OUT ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther, self).__init__()

                                                    self.yang_name = "out-error-other"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-error-other" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorGiant(Entity):
                                                """
                                                IN ERROR GIANT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant, self).__init__()

                                                    self.yang_name = "in-error-giant"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-giant" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorRunt(Entity):
                                                """
                                                IN ERROR RUNT
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt, self).__init__()

                                                    self.yang_name = "in-error-runt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-runt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorJabbers(Entity):
                                                """
                                                IN ERROR JABBERS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers, self).__init__()

                                                    self.yang_name = "in-error-jabbers"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-jabbers" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorFragments(Entity):
                                                """
                                                IN ERROR FRAGMENTS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments, self).__init__()

                                                    self.yang_name = "in-error-fragments"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-fragments" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InErrorOther(Entity):
                                                """
                                                IN ERROR OTHER
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther, self).__init__()

                                                    self.yang_name = "in-error-other"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-error-other" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkt64Octet(Entity):
                                                """
                                                IN PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet, self).__init__()

                                                    self.yang_name = "in-pkt64-octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkt64-octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts65To127Octets(Entity):
                                                """
                                                IN PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets, self).__init__()

                                                    self.yang_name = "in-pkts65-to127-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts65-to127-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts128To255Octets(Entity):
                                                """
                                                IN PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets, self).__init__()

                                                    self.yang_name = "in-pkts128-to255-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts128-to255-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts256To511Octets(Entity):
                                                """
                                                IN PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets, self).__init__()

                                                    self.yang_name = "in-pkts256-to511-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts256-to511-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts512To1023Octets(Entity):
                                                """
                                                IN PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets, self).__init__()

                                                    self.yang_name = "in-pkts512-to1023-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts512-to1023-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class InPkts1024To1518Octets(Entity):
                                                """
                                                IN PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets, self).__init__()

                                                    self.yang_name = "in-pkts1024-to1518-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "in-pkts1024-to1518-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Outpkt64Octet(Entity):
                                                """
                                                OUT PKT 64 OCTET
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64Octet, self).__init__()

                                                    self.yang_name = "outpkt64octet"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64Octet, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64Octet, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "outpkt64octet" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts65127Octets(Entity):
                                                """
                                                OUT PKTS 65 127OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets, self).__init__()

                                                    self.yang_name = "out-pkts65127-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts65127-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts128255Octets(Entity):
                                                """
                                                OUT PKTS 128 255 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets, self).__init__()

                                                    self.yang_name = "out-pkts128255-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts128255-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts256511Octets(Entity):
                                                """
                                                OUT PKTS 256 511 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets, self).__init__()

                                                    self.yang_name = "out-pkts256511-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts256511-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts5121023Octets(Entity):
                                                """
                                                OUT PKTS 512 1023 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets, self).__init__()

                                                    self.yang_name = "out-pkts5121023-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts5121023-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class OutPkts10241518Octets(Entity):
                                                """
                                                OUT PKTS 1024 1518 OCTETS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets, self).__init__()

                                                    self.yang_name = "out-pkts10241518-octets"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "out-pkts10241518-octets" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class RxUtil(Entity):
                                                """
                                                Rx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil, self).__init__()

                                                    self.yang_name = "rx-util"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-util" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxUtil(Entity):
                                                """
                                                Tx Utilization in Percent
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil, self).__init__()

                                                    self.yang_name = "tx-util"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-util" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxUndersizedPkt(Entity):
                                                """
                                                TX Undersized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt, self).__init__()

                                                    self.yang_name = "tx-undersized-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-undersized-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxOversizedPkt(Entity):
                                                """
                                                TX Oversized Pkt
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt, self).__init__()

                                                    self.yang_name = "tx-oversized-pkt"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-oversized-pkt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxFragments(Entity):
                                                """
                                                TX Fragments
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments, self).__init__()

                                                    self.yang_name = "tx-fragments"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-fragments" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxJabber(Entity):
                                                """
                                                TX Jabber
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber, self).__init__()

                                                    self.yang_name = "tx-jabber"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-jabber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class TxBadFcs(Entity):
                                                """
                                                TX Bad Fcs
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs, self).__init__()

                                                    self.yang_name = "tx-bad-fcs"
                                                    self.yang_parent_name = "minute15-ether-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tx-bad-fcs" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.ether10241518_octet is not None and self.ether10241518_octet.has_data()) or
                                                    (self.ether128255_octet is not None and self.ether128255_octet.has_data()) or
                                                    (self.ether256511_octet is not None and self.ether256511_octet.has_data()) or
                                                    (self.ether5121023_octet is not None and self.ether5121023_octet.has_data()) or
                                                    (self.ether64_octets is not None and self.ether64_octets.has_data()) or
                                                    (self.ether65127_octet is not None and self.ether65127_octet.has_data()) or
                                                    (self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt.has_data()) or
                                                    (self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt.has_data()) or
                                                    (self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt.has_data()) or
                                                    (self.fcs_errors_stat is not None and self.fcs_errors_stat.has_data()) or
                                                    (self.if_in_errors is not None and self.if_in_errors.has_data()) or
                                                    (self.if_in_octets is not None and self.if_in_octets.has_data()) or
                                                    (self.in8021q_frames is not None and self.in8021q_frames.has_data()) or
                                                    (self.in_bcast_pkt is not None and self.in_bcast_pkt.has_data()) or
                                                    (self.in_drop_abort is not None and self.in_drop_abort.has_data()) or
                                                    (self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac.has_data()) or
                                                    (self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap.has_data()) or
                                                    (self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan.has_data()) or
                                                    (self.in_drop_other is not None and self.in_drop_other.has_data()) or
                                                    (self.in_drop_overrun is not None and self.in_drop_overrun.has_data()) or
                                                    (self.in_error_collisions is not None and self.in_error_collisions.has_data()) or
                                                    (self.in_error_fragments is not None and self.in_error_fragments.has_data()) or
                                                    (self.in_error_giant is not None and self.in_error_giant.has_data()) or
                                                    (self.in_error_jabbers is not None and self.in_error_jabbers.has_data()) or
                                                    (self.in_error_other is not None and self.in_error_other.has_data()) or
                                                    (self.in_error_runt is not None and self.in_error_runt.has_data()) or
                                                    (self.in_error_symbol is not None and self.in_error_symbol.has_data()) or
                                                    (self.in_good_bytes is not None and self.in_good_bytes.has_data()) or
                                                    (self.in_good_pkts is not None and self.in_good_pkts.has_data()) or
                                                    (self.in_mcast_pkt is not None and self.in_mcast_pkt.has_data()) or
                                                    (self.in_mib_giant is not None and self.in_mib_giant.has_data()) or
                                                    (self.in_mib_jabber is not None and self.in_mib_jabber.has_data()) or
                                                    (self.in_mibcrc is not None and self.in_mibcrc.has_data()) or
                                                    (self.in_pause_frame is not None and self.in_pause_frame.has_data()) or
                                                    (self.in_pkt64_octet is not None and self.in_pkt64_octet.has_data()) or
                                                    (self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets.has_data()) or
                                                    (self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets.has_data()) or
                                                    (self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets.has_data()) or
                                                    (self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets.has_data()) or
                                                    (self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets.has_data()) or
                                                    (self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets.has_data()) or
                                                    (self.in_ucast_pkt is not None and self.in_ucast_pkt.has_data()) or
                                                    (self.jabber_stat is not None and self.jabber_stat.has_data()) or
                                                    (self.long_frames_stat is not None and self.long_frames_stat.has_data()) or
                                                    (self.octet_stat is not None and self.octet_stat.has_data()) or
                                                    (self.out8021q_frames is not None and self.out8021q_frames.has_data()) or
                                                    (self.out_bcast_pkt is not None and self.out_bcast_pkt.has_data()) or
                                                    (self.out_drop_abort is not None and self.out_drop_abort.has_data()) or
                                                    (self.out_drop_other is not None and self.out_drop_other.has_data()) or
                                                    (self.out_drop_underrun is not None and self.out_drop_underrun.has_data()) or
                                                    (self.out_error_other is not None and self.out_error_other.has_data()) or
                                                    (self.out_good_bytes is not None and self.out_good_bytes.has_data()) or
                                                    (self.out_good_pkts is not None and self.out_good_pkts.has_data()) or
                                                    (self.out_mcast_pkt is not None and self.out_mcast_pkt.has_data()) or
                                                    (self.out_octets is not None and self.out_octets.has_data()) or
                                                    (self.out_pause_frames is not None and self.out_pause_frames.has_data()) or
                                                    (self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets.has_data()) or
                                                    (self.out_pkts128255_octets is not None and self.out_pkts128255_octets.has_data()) or
                                                    (self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets.has_data()) or
                                                    (self.out_pkts256511_octets is not None and self.out_pkts256511_octets.has_data()) or
                                                    (self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets.has_data()) or
                                                    (self.out_pkts65127_octets is not None and self.out_pkts65127_octets.has_data()) or
                                                    (self.out_ucast_pkt is not None and self.out_ucast_pkt.has_data()) or
                                                    (self.outpkt64octet is not None and self.outpkt64octet.has_data()) or
                                                    (self.oversize_pkt_stat is not None and self.oversize_pkt_stat.has_data()) or
                                                    (self.rx_pkt is not None and self.rx_pkt.has_data()) or
                                                    (self.rx_util is not None and self.rx_util.has_data()) or
                                                    (self.stat_pkt is not None and self.stat_pkt.has_data()) or
                                                    (self.tx_bad_fcs is not None and self.tx_bad_fcs.has_data()) or
                                                    (self.tx_fragments is not None and self.tx_fragments.has_data()) or
                                                    (self.tx_jabber is not None and self.tx_jabber.has_data()) or
                                                    (self.tx_oversized_pkt is not None and self.tx_oversized_pkt.has_data()) or
                                                    (self.tx_pkt is not None and self.tx_pkt.has_data()) or
                                                    (self.tx_undersized_pkt is not None and self.tx_undersized_pkt.has_data()) or
                                                    (self.tx_util is not None and self.tx_util.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.ether10241518_octet is not None and self.ether10241518_octet.has_operation()) or
                                                    (self.ether128255_octet is not None and self.ether128255_octet.has_operation()) or
                                                    (self.ether256511_octet is not None and self.ether256511_octet.has_operation()) or
                                                    (self.ether5121023_octet is not None and self.ether5121023_octet.has_operation()) or
                                                    (self.ether64_octets is not None and self.ether64_octets.has_operation()) or
                                                    (self.ether65127_octet is not None and self.ether65127_octet.has_operation()) or
                                                    (self.ether_stat_broadcast_pkt is not None and self.ether_stat_broadcast_pkt.has_operation()) or
                                                    (self.ether_stat_multicast_pkt is not None and self.ether_stat_multicast_pkt.has_operation()) or
                                                    (self.ether_stat_undersized_pkt is not None and self.ether_stat_undersized_pkt.has_operation()) or
                                                    (self.fcs_errors_stat is not None and self.fcs_errors_stat.has_operation()) or
                                                    (self.if_in_errors is not None and self.if_in_errors.has_operation()) or
                                                    (self.if_in_octets is not None and self.if_in_octets.has_operation()) or
                                                    (self.in8021q_frames is not None and self.in8021q_frames.has_operation()) or
                                                    (self.in_bcast_pkt is not None and self.in_bcast_pkt.has_operation()) or
                                                    (self.in_drop_abort is not None and self.in_drop_abort.has_operation()) or
                                                    (self.in_drop_invalid_dmac is not None and self.in_drop_invalid_dmac.has_operation()) or
                                                    (self.in_drop_invalid_encap is not None and self.in_drop_invalid_encap.has_operation()) or
                                                    (self.in_drop_invalid_vlan is not None and self.in_drop_invalid_vlan.has_operation()) or
                                                    (self.in_drop_other is not None and self.in_drop_other.has_operation()) or
                                                    (self.in_drop_overrun is not None and self.in_drop_overrun.has_operation()) or
                                                    (self.in_error_collisions is not None and self.in_error_collisions.has_operation()) or
                                                    (self.in_error_fragments is not None and self.in_error_fragments.has_operation()) or
                                                    (self.in_error_giant is not None and self.in_error_giant.has_operation()) or
                                                    (self.in_error_jabbers is not None and self.in_error_jabbers.has_operation()) or
                                                    (self.in_error_other is not None and self.in_error_other.has_operation()) or
                                                    (self.in_error_runt is not None and self.in_error_runt.has_operation()) or
                                                    (self.in_error_symbol is not None and self.in_error_symbol.has_operation()) or
                                                    (self.in_good_bytes is not None and self.in_good_bytes.has_operation()) or
                                                    (self.in_good_pkts is not None and self.in_good_pkts.has_operation()) or
                                                    (self.in_mcast_pkt is not None and self.in_mcast_pkt.has_operation()) or
                                                    (self.in_mib_giant is not None and self.in_mib_giant.has_operation()) or
                                                    (self.in_mib_jabber is not None and self.in_mib_jabber.has_operation()) or
                                                    (self.in_mibcrc is not None and self.in_mibcrc.has_operation()) or
                                                    (self.in_pause_frame is not None and self.in_pause_frame.has_operation()) or
                                                    (self.in_pkt64_octet is not None and self.in_pkt64_octet.has_operation()) or
                                                    (self.in_pkts1024_to1518_octets is not None and self.in_pkts1024_to1518_octets.has_operation()) or
                                                    (self.in_pkts128_to255_octets is not None and self.in_pkts128_to255_octets.has_operation()) or
                                                    (self.in_pkts1519_max_octets is not None and self.in_pkts1519_max_octets.has_operation()) or
                                                    (self.in_pkts256_to511_octets is not None and self.in_pkts256_to511_octets.has_operation()) or
                                                    (self.in_pkts512_to1023_octets is not None and self.in_pkts512_to1023_octets.has_operation()) or
                                                    (self.in_pkts65_to127_octets is not None and self.in_pkts65_to127_octets.has_operation()) or
                                                    (self.in_ucast_pkt is not None and self.in_ucast_pkt.has_operation()) or
                                                    (self.jabber_stat is not None and self.jabber_stat.has_operation()) or
                                                    (self.long_frames_stat is not None and self.long_frames_stat.has_operation()) or
                                                    (self.octet_stat is not None and self.octet_stat.has_operation()) or
                                                    (self.out8021q_frames is not None and self.out8021q_frames.has_operation()) or
                                                    (self.out_bcast_pkt is not None and self.out_bcast_pkt.has_operation()) or
                                                    (self.out_drop_abort is not None and self.out_drop_abort.has_operation()) or
                                                    (self.out_drop_other is not None and self.out_drop_other.has_operation()) or
                                                    (self.out_drop_underrun is not None and self.out_drop_underrun.has_operation()) or
                                                    (self.out_error_other is not None and self.out_error_other.has_operation()) or
                                                    (self.out_good_bytes is not None and self.out_good_bytes.has_operation()) or
                                                    (self.out_good_pkts is not None and self.out_good_pkts.has_operation()) or
                                                    (self.out_mcast_pkt is not None and self.out_mcast_pkt.has_operation()) or
                                                    (self.out_octets is not None and self.out_octets.has_operation()) or
                                                    (self.out_pause_frames is not None and self.out_pause_frames.has_operation()) or
                                                    (self.out_pkts10241518_octets is not None and self.out_pkts10241518_octets.has_operation()) or
                                                    (self.out_pkts128255_octets is not None and self.out_pkts128255_octets.has_operation()) or
                                                    (self.out_pkts1519_max_octets is not None and self.out_pkts1519_max_octets.has_operation()) or
                                                    (self.out_pkts256511_octets is not None and self.out_pkts256511_octets.has_operation()) or
                                                    (self.out_pkts5121023_octets is not None and self.out_pkts5121023_octets.has_operation()) or
                                                    (self.out_pkts65127_octets is not None and self.out_pkts65127_octets.has_operation()) or
                                                    (self.out_ucast_pkt is not None and self.out_ucast_pkt.has_operation()) or
                                                    (self.outpkt64octet is not None and self.outpkt64octet.has_operation()) or
                                                    (self.oversize_pkt_stat is not None and self.oversize_pkt_stat.has_operation()) or
                                                    (self.rx_pkt is not None and self.rx_pkt.has_operation()) or
                                                    (self.rx_util is not None and self.rx_util.has_operation()) or
                                                    (self.stat_pkt is not None and self.stat_pkt.has_operation()) or
                                                    (self.tx_bad_fcs is not None and self.tx_bad_fcs.has_operation()) or
                                                    (self.tx_fragments is not None and self.tx_fragments.has_operation()) or
                                                    (self.tx_jabber is not None and self.tx_jabber.has_operation()) or
                                                    (self.tx_oversized_pkt is not None and self.tx_oversized_pkt.has_operation()) or
                                                    (self.tx_pkt is not None and self.tx_pkt.has_operation()) or
                                                    (self.tx_undersized_pkt is not None and self.tx_undersized_pkt.has_operation()) or
                                                    (self.tx_util is not None and self.tx_util.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "minute15-ether-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ether10241518-octet"):
                                                    if (self.ether10241518_octet is None):
                                                        self.ether10241518_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether10241518Octet()
                                                        self.ether10241518_octet.parent = self
                                                        self._children_name_map["ether10241518_octet"] = "ether10241518-octet"
                                                    return self.ether10241518_octet

                                                if (child_yang_name == "ether128255-octet"):
                                                    if (self.ether128255_octet is None):
                                                        self.ether128255_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether128255Octet()
                                                        self.ether128255_octet.parent = self
                                                        self._children_name_map["ether128255_octet"] = "ether128255-octet"
                                                    return self.ether128255_octet

                                                if (child_yang_name == "ether256511-octet"):
                                                    if (self.ether256511_octet is None):
                                                        self.ether256511_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether256511Octet()
                                                        self.ether256511_octet.parent = self
                                                        self._children_name_map["ether256511_octet"] = "ether256511-octet"
                                                    return self.ether256511_octet

                                                if (child_yang_name == "ether5121023-octet"):
                                                    if (self.ether5121023_octet is None):
                                                        self.ether5121023_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether5121023Octet()
                                                        self.ether5121023_octet.parent = self
                                                        self._children_name_map["ether5121023_octet"] = "ether5121023-octet"
                                                    return self.ether5121023_octet

                                                if (child_yang_name == "ether64-octets"):
                                                    if (self.ether64_octets is None):
                                                        self.ether64_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether64Octets()
                                                        self.ether64_octets.parent = self
                                                        self._children_name_map["ether64_octets"] = "ether64-octets"
                                                    return self.ether64_octets

                                                if (child_yang_name == "ether65127-octet"):
                                                    if (self.ether65127_octet is None):
                                                        self.ether65127_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Ether65127Octet()
                                                        self.ether65127_octet.parent = self
                                                        self._children_name_map["ether65127_octet"] = "ether65127-octet"
                                                    return self.ether65127_octet

                                                if (child_yang_name == "ether-stat-broadcast-pkt"):
                                                    if (self.ether_stat_broadcast_pkt is None):
                                                        self.ether_stat_broadcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatBroadcastPkt()
                                                        self.ether_stat_broadcast_pkt.parent = self
                                                        self._children_name_map["ether_stat_broadcast_pkt"] = "ether-stat-broadcast-pkt"
                                                    return self.ether_stat_broadcast_pkt

                                                if (child_yang_name == "ether-stat-multicast-pkt"):
                                                    if (self.ether_stat_multicast_pkt is None):
                                                        self.ether_stat_multicast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatMulticastPkt()
                                                        self.ether_stat_multicast_pkt.parent = self
                                                        self._children_name_map["ether_stat_multicast_pkt"] = "ether-stat-multicast-pkt"
                                                    return self.ether_stat_multicast_pkt

                                                if (child_yang_name == "ether-stat-undersized-pkt"):
                                                    if (self.ether_stat_undersized_pkt is None):
                                                        self.ether_stat_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.EtherStatUndersizedPkt()
                                                        self.ether_stat_undersized_pkt.parent = self
                                                        self._children_name_map["ether_stat_undersized_pkt"] = "ether-stat-undersized-pkt"
                                                    return self.ether_stat_undersized_pkt

                                                if (child_yang_name == "fcs-errors-stat"):
                                                    if (self.fcs_errors_stat is None):
                                                        self.fcs_errors_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.FcsErrorsStat()
                                                        self.fcs_errors_stat.parent = self
                                                        self._children_name_map["fcs_errors_stat"] = "fcs-errors-stat"
                                                    return self.fcs_errors_stat

                                                if (child_yang_name == "if-in-errors"):
                                                    if (self.if_in_errors is None):
                                                        self.if_in_errors = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInErrors()
                                                        self.if_in_errors.parent = self
                                                        self._children_name_map["if_in_errors"] = "if-in-errors"
                                                    return self.if_in_errors

                                                if (child_yang_name == "if-in-octets"):
                                                    if (self.if_in_octets is None):
                                                        self.if_in_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.IfInOctets()
                                                        self.if_in_octets.parent = self
                                                        self._children_name_map["if_in_octets"] = "if-in-octets"
                                                    return self.if_in_octets

                                                if (child_yang_name == "in8021q-frames"):
                                                    if (self.in8021q_frames is None):
                                                        self.in8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.In8021QFrames()
                                                        self.in8021q_frames.parent = self
                                                        self._children_name_map["in8021q_frames"] = "in8021q-frames"
                                                    return self.in8021q_frames

                                                if (child_yang_name == "in-bcast-pkt"):
                                                    if (self.in_bcast_pkt is None):
                                                        self.in_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InBcastPkt()
                                                        self.in_bcast_pkt.parent = self
                                                        self._children_name_map["in_bcast_pkt"] = "in-bcast-pkt"
                                                    return self.in_bcast_pkt

                                                if (child_yang_name == "in-drop-abort"):
                                                    if (self.in_drop_abort is None):
                                                        self.in_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropAbort()
                                                        self.in_drop_abort.parent = self
                                                        self._children_name_map["in_drop_abort"] = "in-drop-abort"
                                                    return self.in_drop_abort

                                                if (child_yang_name == "in-drop-invalid-dmac"):
                                                    if (self.in_drop_invalid_dmac is None):
                                                        self.in_drop_invalid_dmac = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidDmac()
                                                        self.in_drop_invalid_dmac.parent = self
                                                        self._children_name_map["in_drop_invalid_dmac"] = "in-drop-invalid-dmac"
                                                    return self.in_drop_invalid_dmac

                                                if (child_yang_name == "in-drop-invalid-encap"):
                                                    if (self.in_drop_invalid_encap is None):
                                                        self.in_drop_invalid_encap = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidEncap()
                                                        self.in_drop_invalid_encap.parent = self
                                                        self._children_name_map["in_drop_invalid_encap"] = "in-drop-invalid-encap"
                                                    return self.in_drop_invalid_encap

                                                if (child_yang_name == "in-drop-invalid-vlan"):
                                                    if (self.in_drop_invalid_vlan is None):
                                                        self.in_drop_invalid_vlan = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropInvalidVlan()
                                                        self.in_drop_invalid_vlan.parent = self
                                                        self._children_name_map["in_drop_invalid_vlan"] = "in-drop-invalid-vlan"
                                                    return self.in_drop_invalid_vlan

                                                if (child_yang_name == "in-drop-other"):
                                                    if (self.in_drop_other is None):
                                                        self.in_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOther()
                                                        self.in_drop_other.parent = self
                                                        self._children_name_map["in_drop_other"] = "in-drop-other"
                                                    return self.in_drop_other

                                                if (child_yang_name == "in-drop-overrun"):
                                                    if (self.in_drop_overrun is None):
                                                        self.in_drop_overrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InDropOverrun()
                                                        self.in_drop_overrun.parent = self
                                                        self._children_name_map["in_drop_overrun"] = "in-drop-overrun"
                                                    return self.in_drop_overrun

                                                if (child_yang_name == "in-error-collisions"):
                                                    if (self.in_error_collisions is None):
                                                        self.in_error_collisions = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorCollisions()
                                                        self.in_error_collisions.parent = self
                                                        self._children_name_map["in_error_collisions"] = "in-error-collisions"
                                                    return self.in_error_collisions

                                                if (child_yang_name == "in-error-fragments"):
                                                    if (self.in_error_fragments is None):
                                                        self.in_error_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorFragments()
                                                        self.in_error_fragments.parent = self
                                                        self._children_name_map["in_error_fragments"] = "in-error-fragments"
                                                    return self.in_error_fragments

                                                if (child_yang_name == "in-error-giant"):
                                                    if (self.in_error_giant is None):
                                                        self.in_error_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorGiant()
                                                        self.in_error_giant.parent = self
                                                        self._children_name_map["in_error_giant"] = "in-error-giant"
                                                    return self.in_error_giant

                                                if (child_yang_name == "in-error-jabbers"):
                                                    if (self.in_error_jabbers is None):
                                                        self.in_error_jabbers = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorJabbers()
                                                        self.in_error_jabbers.parent = self
                                                        self._children_name_map["in_error_jabbers"] = "in-error-jabbers"
                                                    return self.in_error_jabbers

                                                if (child_yang_name == "in-error-other"):
                                                    if (self.in_error_other is None):
                                                        self.in_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorOther()
                                                        self.in_error_other.parent = self
                                                        self._children_name_map["in_error_other"] = "in-error-other"
                                                    return self.in_error_other

                                                if (child_yang_name == "in-error-runt"):
                                                    if (self.in_error_runt is None):
                                                        self.in_error_runt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorRunt()
                                                        self.in_error_runt.parent = self
                                                        self._children_name_map["in_error_runt"] = "in-error-runt"
                                                    return self.in_error_runt

                                                if (child_yang_name == "in-error-symbol"):
                                                    if (self.in_error_symbol is None):
                                                        self.in_error_symbol = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InErrorSymbol()
                                                        self.in_error_symbol.parent = self
                                                        self._children_name_map["in_error_symbol"] = "in-error-symbol"
                                                    return self.in_error_symbol

                                                if (child_yang_name == "in-good-bytes"):
                                                    if (self.in_good_bytes is None):
                                                        self.in_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodBytes()
                                                        self.in_good_bytes.parent = self
                                                        self._children_name_map["in_good_bytes"] = "in-good-bytes"
                                                    return self.in_good_bytes

                                                if (child_yang_name == "in-good-pkts"):
                                                    if (self.in_good_pkts is None):
                                                        self.in_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InGoodPkts()
                                                        self.in_good_pkts.parent = self
                                                        self._children_name_map["in_good_pkts"] = "in-good-pkts"
                                                    return self.in_good_pkts

                                                if (child_yang_name == "in-mcast-pkt"):
                                                    if (self.in_mcast_pkt is None):
                                                        self.in_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMcastPkt()
                                                        self.in_mcast_pkt.parent = self
                                                        self._children_name_map["in_mcast_pkt"] = "in-mcast-pkt"
                                                    return self.in_mcast_pkt

                                                if (child_yang_name == "in-mib-giant"):
                                                    if (self.in_mib_giant is None):
                                                        self.in_mib_giant = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibGiant()
                                                        self.in_mib_giant.parent = self
                                                        self._children_name_map["in_mib_giant"] = "in-mib-giant"
                                                    return self.in_mib_giant

                                                if (child_yang_name == "in-mib-jabber"):
                                                    if (self.in_mib_jabber is None):
                                                        self.in_mib_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibJabber()
                                                        self.in_mib_jabber.parent = self
                                                        self._children_name_map["in_mib_jabber"] = "in-mib-jabber"
                                                    return self.in_mib_jabber

                                                if (child_yang_name == "in-mibcrc"):
                                                    if (self.in_mibcrc is None):
                                                        self.in_mibcrc = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InMibcrc()
                                                        self.in_mibcrc.parent = self
                                                        self._children_name_map["in_mibcrc"] = "in-mibcrc"
                                                    return self.in_mibcrc

                                                if (child_yang_name == "in-pause-frame"):
                                                    if (self.in_pause_frame is None):
                                                        self.in_pause_frame = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPauseFrame()
                                                        self.in_pause_frame.parent = self
                                                        self._children_name_map["in_pause_frame"] = "in-pause-frame"
                                                    return self.in_pause_frame

                                                if (child_yang_name == "in-pkt64-octet"):
                                                    if (self.in_pkt64_octet is None):
                                                        self.in_pkt64_octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkt64Octet()
                                                        self.in_pkt64_octet.parent = self
                                                        self._children_name_map["in_pkt64_octet"] = "in-pkt64-octet"
                                                    return self.in_pkt64_octet

                                                if (child_yang_name == "in-pkts1024-to1518-octets"):
                                                    if (self.in_pkts1024_to1518_octets is None):
                                                        self.in_pkts1024_to1518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1024To1518Octets()
                                                        self.in_pkts1024_to1518_octets.parent = self
                                                        self._children_name_map["in_pkts1024_to1518_octets"] = "in-pkts1024-to1518-octets"
                                                    return self.in_pkts1024_to1518_octets

                                                if (child_yang_name == "in-pkts128-to255-octets"):
                                                    if (self.in_pkts128_to255_octets is None):
                                                        self.in_pkts128_to255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts128To255Octets()
                                                        self.in_pkts128_to255_octets.parent = self
                                                        self._children_name_map["in_pkts128_to255_octets"] = "in-pkts128-to255-octets"
                                                    return self.in_pkts128_to255_octets

                                                if (child_yang_name == "in-pkts1519-max-octets"):
                                                    if (self.in_pkts1519_max_octets is None):
                                                        self.in_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts1519MaxOctets()
                                                        self.in_pkts1519_max_octets.parent = self
                                                        self._children_name_map["in_pkts1519_max_octets"] = "in-pkts1519-max-octets"
                                                    return self.in_pkts1519_max_octets

                                                if (child_yang_name == "in-pkts256-to511-octets"):
                                                    if (self.in_pkts256_to511_octets is None):
                                                        self.in_pkts256_to511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts256To511Octets()
                                                        self.in_pkts256_to511_octets.parent = self
                                                        self._children_name_map["in_pkts256_to511_octets"] = "in-pkts256-to511-octets"
                                                    return self.in_pkts256_to511_octets

                                                if (child_yang_name == "in-pkts512-to1023-octets"):
                                                    if (self.in_pkts512_to1023_octets is None):
                                                        self.in_pkts512_to1023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts512To1023Octets()
                                                        self.in_pkts512_to1023_octets.parent = self
                                                        self._children_name_map["in_pkts512_to1023_octets"] = "in-pkts512-to1023-octets"
                                                    return self.in_pkts512_to1023_octets

                                                if (child_yang_name == "in-pkts65-to127-octets"):
                                                    if (self.in_pkts65_to127_octets is None):
                                                        self.in_pkts65_to127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InPkts65To127Octets()
                                                        self.in_pkts65_to127_octets.parent = self
                                                        self._children_name_map["in_pkts65_to127_octets"] = "in-pkts65-to127-octets"
                                                    return self.in_pkts65_to127_octets

                                                if (child_yang_name == "in-ucast-pkt"):
                                                    if (self.in_ucast_pkt is None):
                                                        self.in_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.InUcastPkt()
                                                        self.in_ucast_pkt.parent = self
                                                        self._children_name_map["in_ucast_pkt"] = "in-ucast-pkt"
                                                    return self.in_ucast_pkt

                                                if (child_yang_name == "jabber-stat"):
                                                    if (self.jabber_stat is None):
                                                        self.jabber_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.JabberStat()
                                                        self.jabber_stat.parent = self
                                                        self._children_name_map["jabber_stat"] = "jabber-stat"
                                                    return self.jabber_stat

                                                if (child_yang_name == "long-frames-stat"):
                                                    if (self.long_frames_stat is None):
                                                        self.long_frames_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.LongFramesStat()
                                                        self.long_frames_stat.parent = self
                                                        self._children_name_map["long_frames_stat"] = "long-frames-stat"
                                                    return self.long_frames_stat

                                                if (child_yang_name == "octet-stat"):
                                                    if (self.octet_stat is None):
                                                        self.octet_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OctetStat()
                                                        self.octet_stat.parent = self
                                                        self._children_name_map["octet_stat"] = "octet-stat"
                                                    return self.octet_stat

                                                if (child_yang_name == "out8021q-frames"):
                                                    if (self.out8021q_frames is None):
                                                        self.out8021q_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Out8021QFrames()
                                                        self.out8021q_frames.parent = self
                                                        self._children_name_map["out8021q_frames"] = "out8021q-frames"
                                                    return self.out8021q_frames

                                                if (child_yang_name == "out-bcast-pkt"):
                                                    if (self.out_bcast_pkt is None):
                                                        self.out_bcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutBcastPkt()
                                                        self.out_bcast_pkt.parent = self
                                                        self._children_name_map["out_bcast_pkt"] = "out-bcast-pkt"
                                                    return self.out_bcast_pkt

                                                if (child_yang_name == "out-drop-abort"):
                                                    if (self.out_drop_abort is None):
                                                        self.out_drop_abort = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropAbort()
                                                        self.out_drop_abort.parent = self
                                                        self._children_name_map["out_drop_abort"] = "out-drop-abort"
                                                    return self.out_drop_abort

                                                if (child_yang_name == "out-drop-other"):
                                                    if (self.out_drop_other is None):
                                                        self.out_drop_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropOther()
                                                        self.out_drop_other.parent = self
                                                        self._children_name_map["out_drop_other"] = "out-drop-other"
                                                    return self.out_drop_other

                                                if (child_yang_name == "out-drop-underrun"):
                                                    if (self.out_drop_underrun is None):
                                                        self.out_drop_underrun = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutDropUnderrun()
                                                        self.out_drop_underrun.parent = self
                                                        self._children_name_map["out_drop_underrun"] = "out-drop-underrun"
                                                    return self.out_drop_underrun

                                                if (child_yang_name == "out-error-other"):
                                                    if (self.out_error_other is None):
                                                        self.out_error_other = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutErrorOther()
                                                        self.out_error_other.parent = self
                                                        self._children_name_map["out_error_other"] = "out-error-other"
                                                    return self.out_error_other

                                                if (child_yang_name == "out-good-bytes"):
                                                    if (self.out_good_bytes is None):
                                                        self.out_good_bytes = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodBytes()
                                                        self.out_good_bytes.parent = self
                                                        self._children_name_map["out_good_bytes"] = "out-good-bytes"
                                                    return self.out_good_bytes

                                                if (child_yang_name == "out-good-pkts"):
                                                    if (self.out_good_pkts is None):
                                                        self.out_good_pkts = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutGoodPkts()
                                                        self.out_good_pkts.parent = self
                                                        self._children_name_map["out_good_pkts"] = "out-good-pkts"
                                                    return self.out_good_pkts

                                                if (child_yang_name == "out-mcast-pkt"):
                                                    if (self.out_mcast_pkt is None):
                                                        self.out_mcast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutMcastPkt()
                                                        self.out_mcast_pkt.parent = self
                                                        self._children_name_map["out_mcast_pkt"] = "out-mcast-pkt"
                                                    return self.out_mcast_pkt

                                                if (child_yang_name == "out-octets"):
                                                    if (self.out_octets is None):
                                                        self.out_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutOctets()
                                                        self.out_octets.parent = self
                                                        self._children_name_map["out_octets"] = "out-octets"
                                                    return self.out_octets

                                                if (child_yang_name == "out-pause-frames"):
                                                    if (self.out_pause_frames is None):
                                                        self.out_pause_frames = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPauseFrames()
                                                        self.out_pause_frames.parent = self
                                                        self._children_name_map["out_pause_frames"] = "out-pause-frames"
                                                    return self.out_pause_frames

                                                if (child_yang_name == "out-pkts10241518-octets"):
                                                    if (self.out_pkts10241518_octets is None):
                                                        self.out_pkts10241518_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts10241518Octets()
                                                        self.out_pkts10241518_octets.parent = self
                                                        self._children_name_map["out_pkts10241518_octets"] = "out-pkts10241518-octets"
                                                    return self.out_pkts10241518_octets

                                                if (child_yang_name == "out-pkts128255-octets"):
                                                    if (self.out_pkts128255_octets is None):
                                                        self.out_pkts128255_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts128255Octets()
                                                        self.out_pkts128255_octets.parent = self
                                                        self._children_name_map["out_pkts128255_octets"] = "out-pkts128255-octets"
                                                    return self.out_pkts128255_octets

                                                if (child_yang_name == "out-pkts1519-max-octets"):
                                                    if (self.out_pkts1519_max_octets is None):
                                                        self.out_pkts1519_max_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts1519MaxOctets()
                                                        self.out_pkts1519_max_octets.parent = self
                                                        self._children_name_map["out_pkts1519_max_octets"] = "out-pkts1519-max-octets"
                                                    return self.out_pkts1519_max_octets

                                                if (child_yang_name == "out-pkts256511-octets"):
                                                    if (self.out_pkts256511_octets is None):
                                                        self.out_pkts256511_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts256511Octets()
                                                        self.out_pkts256511_octets.parent = self
                                                        self._children_name_map["out_pkts256511_octets"] = "out-pkts256511-octets"
                                                    return self.out_pkts256511_octets

                                                if (child_yang_name == "out-pkts5121023-octets"):
                                                    if (self.out_pkts5121023_octets is None):
                                                        self.out_pkts5121023_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts5121023Octets()
                                                        self.out_pkts5121023_octets.parent = self
                                                        self._children_name_map["out_pkts5121023_octets"] = "out-pkts5121023-octets"
                                                    return self.out_pkts5121023_octets

                                                if (child_yang_name == "out-pkts65127-octets"):
                                                    if (self.out_pkts65127_octets is None):
                                                        self.out_pkts65127_octets = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutPkts65127Octets()
                                                        self.out_pkts65127_octets.parent = self
                                                        self._children_name_map["out_pkts65127_octets"] = "out-pkts65127-octets"
                                                    return self.out_pkts65127_octets

                                                if (child_yang_name == "out-ucast-pkt"):
                                                    if (self.out_ucast_pkt is None):
                                                        self.out_ucast_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OutUcastPkt()
                                                        self.out_ucast_pkt.parent = self
                                                        self._children_name_map["out_ucast_pkt"] = "out-ucast-pkt"
                                                    return self.out_ucast_pkt

                                                if (child_yang_name == "outpkt64octet"):
                                                    if (self.outpkt64octet is None):
                                                        self.outpkt64octet = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.Outpkt64Octet()
                                                        self.outpkt64octet.parent = self
                                                        self._children_name_map["outpkt64octet"] = "outpkt64octet"
                                                    return self.outpkt64octet

                                                if (child_yang_name == "oversize-pkt-stat"):
                                                    if (self.oversize_pkt_stat is None):
                                                        self.oversize_pkt_stat = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.OversizePktStat()
                                                        self.oversize_pkt_stat.parent = self
                                                        self._children_name_map["oversize_pkt_stat"] = "oversize-pkt-stat"
                                                    return self.oversize_pkt_stat

                                                if (child_yang_name == "rx-pkt"):
                                                    if (self.rx_pkt is None):
                                                        self.rx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxPkt()
                                                        self.rx_pkt.parent = self
                                                        self._children_name_map["rx_pkt"] = "rx-pkt"
                                                    return self.rx_pkt

                                                if (child_yang_name == "rx-util"):
                                                    if (self.rx_util is None):
                                                        self.rx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.RxUtil()
                                                        self.rx_util.parent = self
                                                        self._children_name_map["rx_util"] = "rx-util"
                                                    return self.rx_util

                                                if (child_yang_name == "stat-pkt"):
                                                    if (self.stat_pkt is None):
                                                        self.stat_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.StatPkt()
                                                        self.stat_pkt.parent = self
                                                        self._children_name_map["stat_pkt"] = "stat-pkt"
                                                    return self.stat_pkt

                                                if (child_yang_name == "tx-bad-fcs"):
                                                    if (self.tx_bad_fcs is None):
                                                        self.tx_bad_fcs = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxBadFcs()
                                                        self.tx_bad_fcs.parent = self
                                                        self._children_name_map["tx_bad_fcs"] = "tx-bad-fcs"
                                                    return self.tx_bad_fcs

                                                if (child_yang_name == "tx-fragments"):
                                                    if (self.tx_fragments is None):
                                                        self.tx_fragments = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxFragments()
                                                        self.tx_fragments.parent = self
                                                        self._children_name_map["tx_fragments"] = "tx-fragments"
                                                    return self.tx_fragments

                                                if (child_yang_name == "tx-jabber"):
                                                    if (self.tx_jabber is None):
                                                        self.tx_jabber = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxJabber()
                                                        self.tx_jabber.parent = self
                                                        self._children_name_map["tx_jabber"] = "tx-jabber"
                                                    return self.tx_jabber

                                                if (child_yang_name == "tx-oversized-pkt"):
                                                    if (self.tx_oversized_pkt is None):
                                                        self.tx_oversized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxOversizedPkt()
                                                        self.tx_oversized_pkt.parent = self
                                                        self._children_name_map["tx_oversized_pkt"] = "tx-oversized-pkt"
                                                    return self.tx_oversized_pkt

                                                if (child_yang_name == "tx-pkt"):
                                                    if (self.tx_pkt is None):
                                                        self.tx_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxPkt()
                                                        self.tx_pkt.parent = self
                                                        self._children_name_map["tx_pkt"] = "tx-pkt"
                                                    return self.tx_pkt

                                                if (child_yang_name == "tx-undersized-pkt"):
                                                    if (self.tx_undersized_pkt is None):
                                                        self.tx_undersized_pkt = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUndersizedPkt()
                                                        self.tx_undersized_pkt.parent = self
                                                        self._children_name_map["tx_undersized_pkt"] = "tx-undersized-pkt"
                                                    return self.tx_undersized_pkt

                                                if (child_yang_name == "tx-util"):
                                                    if (self.tx_util is None):
                                                        self.tx_util = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance.TxUtil()
                                                        self.tx_util.parent = self
                                                        self._children_name_map["tx_util"] = "tx-util"
                                                    return self.tx_util

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ether10241518-octet" or name == "ether128255-octet" or name == "ether256511-octet" or name == "ether5121023-octet" or name == "ether64-octets" or name == "ether65127-octet" or name == "ether-stat-broadcast-pkt" or name == "ether-stat-multicast-pkt" or name == "ether-stat-undersized-pkt" or name == "fcs-errors-stat" or name == "if-in-errors" or name == "if-in-octets" or name == "in8021q-frames" or name == "in-bcast-pkt" or name == "in-drop-abort" or name == "in-drop-invalid-dmac" or name == "in-drop-invalid-encap" or name == "in-drop-invalid-vlan" or name == "in-drop-other" or name == "in-drop-overrun" or name == "in-error-collisions" or name == "in-error-fragments" or name == "in-error-giant" or name == "in-error-jabbers" or name == "in-error-other" or name == "in-error-runt" or name == "in-error-symbol" or name == "in-good-bytes" or name == "in-good-pkts" or name == "in-mcast-pkt" or name == "in-mib-giant" or name == "in-mib-jabber" or name == "in-mibcrc" or name == "in-pause-frame" or name == "in-pkt64-octet" or name == "in-pkts1024-to1518-octets" or name == "in-pkts128-to255-octets" or name == "in-pkts1519-max-octets" or name == "in-pkts256-to511-octets" or name == "in-pkts512-to1023-octets" or name == "in-pkts65-to127-octets" or name == "in-ucast-pkt" or name == "jabber-stat" or name == "long-frames-stat" or name == "octet-stat" or name == "out8021q-frames" or name == "out-bcast-pkt" or name == "out-drop-abort" or name == "out-drop-other" or name == "out-drop-underrun" or name == "out-error-other" or name == "out-good-bytes" or name == "out-good-pkts" or name == "out-mcast-pkt" or name == "out-octets" or name == "out-pause-frames" or name == "out-pkts10241518-octets" or name == "out-pkts128255-octets" or name == "out-pkts1519-max-octets" or name == "out-pkts256511-octets" or name == "out-pkts5121023-octets" or name == "out-pkts65127-octets" or name == "out-ucast-pkt" or name == "outpkt64octet" or name == "oversize-pkt-stat" or name == "rx-pkt" or name == "rx-util" or name == "stat-pkt" or name == "tx-bad-fcs" or name == "tx-fragments" or name == "tx-jabber" or name == "tx-oversized-pkt" or name == "tx-pkt" or name == "tx-undersized-pkt" or name == "tx-util" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.minute15_ether_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.minute15_ether_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "minute15-ether-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "minute15-ether-time-line-instance"):
                                                for c in self.minute15_ether_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances.Minute15EtherTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.minute15_ether_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "minute15-ether-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.slot_number.is_set or
                                            (self.minute15_ether_time_line_instances is not None and self.minute15_ether_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.slot_number.yfilter != YFilter.not_set or
                                            (self.minute15_ether_time_line_instances is not None and self.minute15_ether_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "minute15-ether-history" + "[slot-number='" + self.slot_number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.slot_number.is_set or self.slot_number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.slot_number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "minute15-ether-time-line-instances"):
                                            if (self.minute15_ether_time_line_instances is None):
                                                self.minute15_ether_time_line_instances = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory.Minute15EtherTimeLineInstances()
                                                self.minute15_ether_time_line_instances.parent = self
                                                self._children_name_map["minute15_ether_time_line_instances"] = "minute15-ether-time-line-instances"
                                            return self.minute15_ether_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "minute15-ether-time-line-instances" or name == "slot-number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "slot-number"):
                                            self.slot_number = value
                                            self.slot_number.value_namespace = name_space
                                            self.slot_number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.minute15_ether_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.minute15_ether_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "minute15-ether-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "minute15-ether-history"):
                                        for c in self.minute15_ether_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories.Minute15EtherHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.minute15_ether_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "minute15-ether-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.minute15_ether_histories is not None and self.minute15_ether_histories.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.minute15_ether_histories is not None and self.minute15_ether_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ethernet-minute15-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "minute15-ether-histories"):
                                    if (self.minute15_ether_histories is None):
                                        self.minute15_ether_histories = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History.Minute15EtherHistories()
                                        self.minute15_ether_histories.parent = self
                                        self._children_name_map["minute15_ether_histories"] = "minute15-ether-histories"
                                    return self.minute15_ether_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "minute15-ether-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.name.is_set or
                                (self.ethernet_hour24_history is not None and self.ethernet_hour24_history.has_data()) or
                                (self.ethernet_minute15_history is not None and self.ethernet_minute15_history.has_data()) or
                                (self.ethernet_second30_history is not None and self.ethernet_second30_history.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                (self.ethernet_hour24_history is not None and self.ethernet_hour24_history.has_operation()) or
                                (self.ethernet_minute15_history is not None and self.ethernet_minute15_history.has_operation()) or
                                (self.ethernet_second30_history is not None and self.ethernet_second30_history.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ethernet-port-history" + "[name='" + self.name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/ethernet-history/ethernet-port-histories/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ethernet-hour24-history"):
                                if (self.ethernet_hour24_history is None):
                                    self.ethernet_hour24_history = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetHour24History()
                                    self.ethernet_hour24_history.parent = self
                                    self._children_name_map["ethernet_hour24_history"] = "ethernet-hour24-history"
                                return self.ethernet_hour24_history

                            if (child_yang_name == "ethernet-minute15-history"):
                                if (self.ethernet_minute15_history is None):
                                    self.ethernet_minute15_history = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetMinute15History()
                                    self.ethernet_minute15_history.parent = self
                                    self._children_name_map["ethernet_minute15_history"] = "ethernet-minute15-history"
                                return self.ethernet_minute15_history

                            if (child_yang_name == "ethernet-second30-history"):
                                if (self.ethernet_second30_history is None):
                                    self.ethernet_second30_history = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory.EthernetSecond30History()
                                    self.ethernet_second30_history.parent = self
                                    self._children_name_map["ethernet_second30_history"] = "ethernet-second30-history"
                                return self.ethernet_second30_history

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ethernet-hour24-history" or name == "ethernet-minute15-history" or name == "ethernet-second30-history" or name == "name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ethernet_port_history:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ethernet_port_history:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ethernet-port-histories" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/ethernet-history/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ethernet-port-history"):
                            for c in self.ethernet_port_history:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories.EthernetPortHistory()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ethernet_port_history.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ethernet-port-history"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.ethernet_port_histories is not None and self.ethernet_port_histories.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.ethernet_port_histories is not None and self.ethernet_port_histories.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ethernet-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ethernet-port-histories"):
                        if (self.ethernet_port_histories is None):
                            self.ethernet_port_histories = PerformanceManagementHistory.Global_.Periodic.EthernetHistory.EthernetPortHistories()
                            self.ethernet_port_histories.parent = self
                            self._children_name_map["ethernet_port_histories"] = "ethernet-port-histories"
                        return self.ethernet_port_histories

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ethernet-port-histories"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class DwdmHistory(Entity):
                """
                DWDM controller History performance data
                
                .. attribute:: dwdm_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`DwdmPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory, self).__init__()

                    self.yang_name = "dwdm-history"
                    self.yang_parent_name = "periodic"

                    self.dwdm_port_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories()
                    self.dwdm_port_histories.parent = self
                    self._children_name_map["dwdm_port_histories"] = "dwdm-port-histories"
                    self._children_yang_names.add("dwdm-port-histories")


                class DwdmPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: dwdm_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`DwdmPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories, self).__init__()

                        self.yang_name = "dwdm-port-histories"
                        self.yang_parent_name = "dwdm-history"

                        self.dwdm_port_history = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories, self).__setattr__(name, value)


                    class DwdmPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: dwdm_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`DwdmHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History>`
                        
                        .. attribute:: dwdm_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`DwdmMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory, self).__init__()

                            self.yang_name = "dwdm-port-history"
                            self.yang_parent_name = "dwdm-port-histories"

                            self.name = YLeaf(YType.str, "name")

                            self.dwdm_hour24_history = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History()
                            self.dwdm_hour24_history.parent = self
                            self._children_name_map["dwdm_hour24_history"] = "dwdm-hour24-history"
                            self._children_yang_names.add("dwdm-hour24-history")

                            self.dwdm_minute15_history = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History()
                            self.dwdm_minute15_history.parent = self
                            self._children_name_map["dwdm_minute15_history"] = "dwdm-minute15-history"
                            self._children_yang_names.add("dwdm-minute15-history")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory, self).__setattr__(name, value)


                        class DwdmMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_minute15_optics_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`DwdmMinute15OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories>`
                            
                            .. attribute:: dwdm_minute15fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`DwdmMinute15FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories>`
                            
                            .. attribute:: dwdm_minute15otn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`DwdmMinute15OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History, self).__init__()

                                self.yang_name = "dwdm-minute15-history"
                                self.yang_parent_name = "dwdm-port-history"

                                self.dwdm_minute15_optics_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories()
                                self.dwdm_minute15_optics_histories.parent = self
                                self._children_name_map["dwdm_minute15_optics_histories"] = "dwdm-minute15-optics-histories"
                                self._children_yang_names.add("dwdm-minute15-optics-histories")

                                self.dwdm_minute15fec_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories()
                                self.dwdm_minute15fec_histories.parent = self
                                self._children_name_map["dwdm_minute15fec_histories"] = "dwdm-minute15fec-histories"
                                self._children_yang_names.add("dwdm-minute15fec-histories")

                                self.dwdm_minute15otn_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories()
                                self.dwdm_minute15otn_histories.parent = self
                                self._children_name_map["dwdm_minute15otn_histories"] = "dwdm-minute15otn-histories"
                                self._children_yang_names.add("dwdm-minute15otn-histories")


                            class DwdmMinute15OtnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: dwdm_minute15otn_history
                                
                                	port 15\-minute otn performance data
                                	**type**\: list of    :py:class:`DwdmMinute15OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories, self).__init__()

                                    self.yang_name = "dwdm-minute15otn-histories"
                                    self.yang_parent_name = "dwdm-minute15-history"

                                    self.dwdm_minute15otn_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories, self).__setattr__(name, value)


                                class DwdmMinute15OtnHistory(Entity):
                                    """
                                    port 15\-minute otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: dwdm_minute15otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`DwdmMinute15OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory, self).__init__()

                                        self.yang_name = "dwdm-minute15otn-history"
                                        self.yang_parent_name = "dwdm-minute15otn-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.dwdm_minute15otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances()
                                        self.dwdm_minute15otn_time_line_instances.parent = self
                                        self._children_name_map["dwdm_minute15otn_time_line_instances"] = "dwdm-minute15otn-time-line-instances"
                                        self._children_yang_names.add("dwdm-minute15otn-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory, self).__setattr__(name, value)


                                    class DwdmMinute15OtnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_minute15otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`DwdmMinute15OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances, self).__init__()

                                            self.yang_name = "dwdm-minute15otn-time-line-instances"
                                            self.yang_parent_name = "dwdm-minute15otn-history"

                                            self.dwdm_minute15otn_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances, self).__setattr__(name, value)


                                        class DwdmMinute15OtnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance, self).__init__()

                                                self.yang_name = "dwdm-minute15otn-time-line-instance"
                                                self.yang_parent_name = "dwdm-minute15otn-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"
                                                self._children_yang_names.add("bbe-fe")

                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"
                                                self._children_yang_names.add("bbe-ne")

                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"
                                                self._children_yang_names.add("bber-fe")

                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"
                                                self._children_yang_names.add("bber-ne")

                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"
                                                self._children_yang_names.add("es-fe")

                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"
                                                self._children_yang_names.add("es-ne")

                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"
                                                self._children_yang_names.add("esr-fe")

                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"
                                                self._children_yang_names.add("esr-ne")

                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._children_yang_names.add("fc-fe")

                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"
                                                self._children_yang_names.add("fc-ne")

                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"
                                                self._children_yang_names.add("lbc")

                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"
                                                self._children_yang_names.add("ses-fe")

                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"
                                                self._children_yang_names.add("ses-ne")

                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"
                                                self._children_yang_names.add("sesr-fe")

                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"
                                                self._children_yang_names.add("sesr-ne")

                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"
                                                self._children_yang_names.add("uas-fe")

                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"
                                                self._children_yang_names.add("uas-ne")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance, self).__setattr__(name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.Lbc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.Lbc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "dwdm-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_data()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_data()) or
                                                    (self.es_fe is not None and self.es_fe.has_data()) or
                                                    (self.es_ne is not None and self.es_ne.has_data()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_data()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_data()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_data()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_data()) or
                                                    (self.lbc is not None and self.lbc.has_data()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_data()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_data()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_data()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                                    (self.es_fe is not None and self.es_fe.has_operation()) or
                                                    (self.es_ne is not None and self.es_ne.has_operation()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                                    (self.lbc is not None and self.lbc.has_operation()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dwdm-minute15otn-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bbe-fe"):
                                                    if (self.bbe_fe is None):
                                                        self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeFe()
                                                        self.bbe_fe.parent = self
                                                        self._children_name_map["bbe_fe"] = "bbe-fe"
                                                    return self.bbe_fe

                                                if (child_yang_name == "bbe-ne"):
                                                    if (self.bbe_ne is None):
                                                        self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BbeNe()
                                                        self.bbe_ne.parent = self
                                                        self._children_name_map["bbe_ne"] = "bbe-ne"
                                                    return self.bbe_ne

                                                if (child_yang_name == "bber-fe"):
                                                    if (self.bber_fe is None):
                                                        self.bber_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberFe()
                                                        self.bber_fe.parent = self
                                                        self._children_name_map["bber_fe"] = "bber-fe"
                                                    return self.bber_fe

                                                if (child_yang_name == "bber-ne"):
                                                    if (self.bber_ne is None):
                                                        self.bber_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.BberNe()
                                                        self.bber_ne.parent = self
                                                        self._children_name_map["bber_ne"] = "bber-ne"
                                                    return self.bber_ne

                                                if (child_yang_name == "es-fe"):
                                                    if (self.es_fe is None):
                                                        self.es_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsFe()
                                                        self.es_fe.parent = self
                                                        self._children_name_map["es_fe"] = "es-fe"
                                                    return self.es_fe

                                                if (child_yang_name == "es-ne"):
                                                    if (self.es_ne is None):
                                                        self.es_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsNe()
                                                        self.es_ne.parent = self
                                                        self._children_name_map["es_ne"] = "es-ne"
                                                    return self.es_ne

                                                if (child_yang_name == "esr-fe"):
                                                    if (self.esr_fe is None):
                                                        self.esr_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrFe()
                                                        self.esr_fe.parent = self
                                                        self._children_name_map["esr_fe"] = "esr-fe"
                                                    return self.esr_fe

                                                if (child_yang_name == "esr-ne"):
                                                    if (self.esr_ne is None):
                                                        self.esr_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.EsrNe()
                                                        self.esr_ne.parent = self
                                                        self._children_name_map["esr_ne"] = "esr-ne"
                                                    return self.esr_ne

                                                if (child_yang_name == "fc-fe"):
                                                    if (self.fc_fe is None):
                                                        self.fc_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcFe()
                                                        self.fc_fe.parent = self
                                                        self._children_name_map["fc_fe"] = "fc-fe"
                                                    return self.fc_fe

                                                if (child_yang_name == "fc-ne"):
                                                    if (self.fc_ne is None):
                                                        self.fc_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.FcNe()
                                                        self.fc_ne.parent = self
                                                        self._children_name_map["fc_ne"] = "fc-ne"
                                                    return self.fc_ne

                                                if (child_yang_name == "lbc"):
                                                    if (self.lbc is None):
                                                        self.lbc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.Lbc()
                                                        self.lbc.parent = self
                                                        self._children_name_map["lbc"] = "lbc"
                                                    return self.lbc

                                                if (child_yang_name == "ses-fe"):
                                                    if (self.ses_fe is None):
                                                        self.ses_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesFe()
                                                        self.ses_fe.parent = self
                                                        self._children_name_map["ses_fe"] = "ses-fe"
                                                    return self.ses_fe

                                                if (child_yang_name == "ses-ne"):
                                                    if (self.ses_ne is None):
                                                        self.ses_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesNe()
                                                        self.ses_ne.parent = self
                                                        self._children_name_map["ses_ne"] = "ses-ne"
                                                    return self.ses_ne

                                                if (child_yang_name == "sesr-fe"):
                                                    if (self.sesr_fe is None):
                                                        self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrFe()
                                                        self.sesr_fe.parent = self
                                                        self._children_name_map["sesr_fe"] = "sesr-fe"
                                                    return self.sesr_fe

                                                if (child_yang_name == "sesr-ne"):
                                                    if (self.sesr_ne is None):
                                                        self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.SesrNe()
                                                        self.sesr_ne.parent = self
                                                        self._children_name_map["sesr_ne"] = "sesr-ne"
                                                    return self.sesr_ne

                                                if (child_yang_name == "uas-fe"):
                                                    if (self.uas_fe is None):
                                                        self.uas_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasFe()
                                                        self.uas_fe.parent = self
                                                        self._children_name_map["uas_fe"] = "uas-fe"
                                                    return self.uas_fe

                                                if (child_yang_name == "uas-ne"):
                                                    if (self.uas_ne is None):
                                                        self.uas_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance.UasNe()
                                                        self.uas_ne.parent = self
                                                        self._children_name_map["uas_ne"] = "uas-ne"
                                                    return self.uas_ne

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.dwdm_minute15otn_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.dwdm_minute15otn_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dwdm-minute15otn-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dwdm-minute15otn-time-line-instance"):
                                                for c in self.dwdm_minute15otn_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances.DwdmMinute15OtnTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.dwdm_minute15otn_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dwdm-minute15otn-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.dwdm_minute15otn_time_line_instances is not None and self.dwdm_minute15otn_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.dwdm_minute15otn_time_line_instances is not None and self.dwdm_minute15otn_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dwdm-minute15otn-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dwdm-minute15otn-time-line-instances"):
                                            if (self.dwdm_minute15otn_time_line_instances is None):
                                                self.dwdm_minute15otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory.DwdmMinute15OtnTimeLineInstances()
                                                self.dwdm_minute15otn_time_line_instances.parent = self
                                                self._children_name_map["dwdm_minute15otn_time_line_instances"] = "dwdm-minute15otn-time-line-instances"
                                            return self.dwdm_minute15otn_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dwdm-minute15otn-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.dwdm_minute15otn_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.dwdm_minute15otn_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dwdm-minute15otn-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dwdm-minute15otn-history"):
                                        for c in self.dwdm_minute15otn_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories.DwdmMinute15OtnHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.dwdm_minute15otn_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dwdm-minute15otn-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DwdmMinute15FecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: dwdm_minute15fec_history
                                
                                	port 15\-minute fec performance data
                                	**type**\: list of    :py:class:`DwdmMinute15FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories, self).__init__()

                                    self.yang_name = "dwdm-minute15fec-histories"
                                    self.yang_parent_name = "dwdm-minute15-history"

                                    self.dwdm_minute15fec_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories, self).__setattr__(name, value)


                                class DwdmMinute15FecHistory(Entity):
                                    """
                                    port 15\-minute fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: dwdm_minute15fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`DwdmMinute15FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory, self).__init__()

                                        self.yang_name = "dwdm-minute15fec-history"
                                        self.yang_parent_name = "dwdm-minute15fec-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.dwdm_minute15fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances()
                                        self.dwdm_minute15fec_time_line_instances.parent = self
                                        self._children_name_map["dwdm_minute15fec_time_line_instances"] = "dwdm-minute15fec-time-line-instances"
                                        self._children_yang_names.add("dwdm-minute15fec-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory, self).__setattr__(name, value)


                                    class DwdmMinute15FecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_minute15fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data by index
                                        	**type**\: list of    :py:class:`DwdmMinute15FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances, self).__init__()

                                            self.yang_name = "dwdm-minute15fec-time-line-instances"
                                            self.yang_parent_name = "dwdm-minute15fec-history"

                                            self.dwdm_minute15fec_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances, self).__setattr__(name, value)


                                        class DwdmMinute15FecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data by
                                            index
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance, self).__init__()

                                                self.yang_name = "dwdm-minute15fec-time-line-instance"
                                                self.yang_parent_name = "dwdm-minute15fec-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"
                                                self._children_yang_names.add("ec-bits")

                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                self._children_yang_names.add("post-fec-ber")

                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                self._children_yang_names.add("pre-fec-ber")

                                                self.q = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"
                                                self._children_yang_names.add("q")

                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._children_yang_names.add("qmargin")

                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"
                                                self._children_yang_names.add("uc-words")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance, self).__setattr__(name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "dwdm-minute15fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.EcBits, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.EcBits, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ec-bits" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "dwdm-minute15fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.UcWords, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.UcWords, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uc-words" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "dwdm-minute15fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pre-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "dwdm-minute15fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "post-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "dwdm-minute15fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Q, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Q, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "q" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "dwdm-minute15fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Qmargin, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Qmargin, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "qmargin" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_data()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                                    (self.q is not None and self.q.has_data()) or
                                                    (self.qmargin is not None and self.qmargin.has_data()) or
                                                    (self.uc_words is not None and self.uc_words.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                                    (self.q is not None and self.q.has_operation()) or
                                                    (self.qmargin is not None and self.qmargin.has_operation()) or
                                                    (self.uc_words is not None and self.uc_words.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dwdm-minute15fec-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ec-bits"):
                                                    if (self.ec_bits is None):
                                                        self.ec_bits = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.EcBits()
                                                        self.ec_bits.parent = self
                                                        self._children_name_map["ec_bits"] = "ec-bits"
                                                    return self.ec_bits

                                                if (child_yang_name == "post-fec-ber"):
                                                    if (self.post_fec_ber is None):
                                                        self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PostFecBer()
                                                        self.post_fec_ber.parent = self
                                                        self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                    return self.post_fec_ber

                                                if (child_yang_name == "pre-fec-ber"):
                                                    if (self.pre_fec_ber is None):
                                                        self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.PreFecBer()
                                                        self.pre_fec_ber.parent = self
                                                        self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                    return self.pre_fec_ber

                                                if (child_yang_name == "q"):
                                                    if (self.q is None):
                                                        self.q = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Q()
                                                        self.q.parent = self
                                                        self._children_name_map["q"] = "q"
                                                    return self.q

                                                if (child_yang_name == "qmargin"):
                                                    if (self.qmargin is None):
                                                        self.qmargin = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.Qmargin()
                                                        self.qmargin.parent = self
                                                        self._children_name_map["qmargin"] = "qmargin"
                                                    return self.qmargin

                                                if (child_yang_name == "uc-words"):
                                                    if (self.uc_words is None):
                                                        self.uc_words = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance.UcWords()
                                                        self.uc_words.parent = self
                                                        self._children_name_map["uc_words"] = "uc-words"
                                                    return self.uc_words

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.dwdm_minute15fec_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.dwdm_minute15fec_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dwdm-minute15fec-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dwdm-minute15fec-time-line-instance"):
                                                for c in self.dwdm_minute15fec_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances.DwdmMinute15FecTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.dwdm_minute15fec_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dwdm-minute15fec-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.dwdm_minute15fec_time_line_instances is not None and self.dwdm_minute15fec_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.dwdm_minute15fec_time_line_instances is not None and self.dwdm_minute15fec_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dwdm-minute15fec-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dwdm-minute15fec-time-line-instances"):
                                            if (self.dwdm_minute15fec_time_line_instances is None):
                                                self.dwdm_minute15fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory.DwdmMinute15FecTimeLineInstances()
                                                self.dwdm_minute15fec_time_line_instances.parent = self
                                                self._children_name_map["dwdm_minute15fec_time_line_instances"] = "dwdm-minute15fec-time-line-instances"
                                            return self.dwdm_minute15fec_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dwdm-minute15fec-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.dwdm_minute15fec_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.dwdm_minute15fec_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dwdm-minute15fec-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dwdm-minute15fec-history"):
                                        for c in self.dwdm_minute15fec_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories.DwdmMinute15FecHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.dwdm_minute15fec_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dwdm-minute15fec-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DwdmMinute15OpticsHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: dwdm_minute15_optics_history
                                
                                	port 15\-minute optics performance data
                                	**type**\: list of    :py:class:`DwdmMinute15OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories, self).__init__()

                                    self.yang_name = "dwdm-minute15-optics-histories"
                                    self.yang_parent_name = "dwdm-minute15-history"

                                    self.dwdm_minute15_optics_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories, self).__setattr__(name, value)


                                class DwdmMinute15OpticsHistory(Entity):
                                    """
                                    port 15\-minute optics performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: dwdm_minute15_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`DwdmMinute15OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory, self).__init__()

                                        self.yang_name = "dwdm-minute15-optics-history"
                                        self.yang_parent_name = "dwdm-minute15-optics-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.dwdm_minute15_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances()
                                        self.dwdm_minute15_optics_time_line_instances.parent = self
                                        self._children_name_map["dwdm_minute15_optics_time_line_instances"] = "dwdm-minute15-optics-time-line-instances"
                                        self._children_yang_names.add("dwdm-minute15-optics-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory, self).__setattr__(name, value)


                                    class DwdmMinute15OpticsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_minute15_optics_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`DwdmMinute15OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances, self).__init__()

                                            self.yang_name = "dwdm-minute15-optics-time-line-instances"
                                            self.yang_parent_name = "dwdm-minute15-optics-history"

                                            self.dwdm_minute15_optics_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances, self).__setattr__(name, value)


                                        class DwdmMinute15OpticsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance, self).__init__()

                                                self.yang_name = "dwdm-minute15-optics-time-line-instance"
                                                self.yang_parent_name = "dwdm-minute15-optics-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.cd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self._children_name_map["cd"] = "cd"
                                                self._children_yang_names.add("cd")

                                                self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self._children_name_map["center_wavelength"] = "center-wavelength"
                                                self._children_yang_names.add("center-wavelength")

                                                self.dgd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self._children_name_map["dgd"] = "dgd"
                                                self._children_yang_names.add("dgd")

                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"
                                                self._children_yang_names.add("lbc")

                                                self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self._children_name_map["lbc_pc"] = "lbc-pc"
                                                self._children_yang_names.add("lbc-pc")

                                                self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                                self._children_yang_names.add("low-sig-freq-off")

                                                self.opr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self._children_name_map["opr"] = "opr"
                                                self._children_yang_names.add("opr")

                                                self.opt = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self._children_name_map["opt"] = "opt"
                                                self._children_yang_names.add("opt")

                                                self.osnr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self._children_name_map["osnr"] = "osnr"
                                                self._children_yang_names.add("osnr")

                                                self.pcr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self._children_name_map["pcr"] = "pcr"
                                                self._children_yang_names.add("pcr")

                                                self.pdl = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self._children_name_map["pdl"] = "pdl"
                                                self._children_yang_names.add("pdl")

                                                self.pmd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self._children_name_map["pmd"] = "pmd"
                                                self._children_yang_names.add("pmd")

                                                self.pn = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self._children_name_map["pn"] = "pn"
                                                self._children_yang_names.add("pn")

                                                self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                                self._children_yang_names.add("rx-sig-pow")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance, self).__setattr__(name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LbcPc(Entity):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc, self).__init__()

                                                    self.yang_name = "lbc-pc"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc-pc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Opt(Entity):
                                                """
                                                OPT
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt, self).__init__()

                                                    self.yang_name = "opt"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Opr(Entity):
                                                """
                                                OPR
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr, self).__init__()

                                                    self.yang_name = "opr"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Cd(Entity):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd, self).__init__()

                                                    self.yang_name = "cd"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "cd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Dgd(Entity):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd, self).__init__()

                                                    self.yang_name = "dgd"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dgd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pmd(Entity):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd, self).__init__()

                                                    self.yang_name = "pmd"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pmd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Osnr(Entity):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr, self).__init__()

                                                    self.yang_name = "osnr"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "osnr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class CenterWavelength(Entity):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength, self).__init__()

                                                    self.yang_name = "center-wavelength"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "center-wavelength" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pdl(Entity):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl, self).__init__()

                                                    self.yang_name = "pdl"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pdl" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pcr(Entity):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr, self).__init__()

                                                    self.yang_name = "pcr"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pcr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pn(Entity):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn, self).__init__()

                                                    self.yang_name = "pn"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pn" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class RxSigPow(Entity):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow, self).__init__()

                                                    self.yang_name = "rx-sig-pow"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-sig-pow" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LowSigFreqOff(Entity):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff, self).__init__()

                                                    self.yang_name = "low-sig-freq-off"
                                                    self.yang_parent_name = "dwdm-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "low-sig-freq-off" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.cd is not None and self.cd.has_data()) or
                                                    (self.center_wavelength is not None and self.center_wavelength.has_data()) or
                                                    (self.dgd is not None and self.dgd.has_data()) or
                                                    (self.lbc is not None and self.lbc.has_data()) or
                                                    (self.lbc_pc is not None and self.lbc_pc.has_data()) or
                                                    (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_data()) or
                                                    (self.opr is not None and self.opr.has_data()) or
                                                    (self.opt is not None and self.opt.has_data()) or
                                                    (self.osnr is not None and self.osnr.has_data()) or
                                                    (self.pcr is not None and self.pcr.has_data()) or
                                                    (self.pdl is not None and self.pdl.has_data()) or
                                                    (self.pmd is not None and self.pmd.has_data()) or
                                                    (self.pn is not None and self.pn.has_data()) or
                                                    (self.rx_sig_pow is not None and self.rx_sig_pow.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.cd is not None and self.cd.has_operation()) or
                                                    (self.center_wavelength is not None and self.center_wavelength.has_operation()) or
                                                    (self.dgd is not None and self.dgd.has_operation()) or
                                                    (self.lbc is not None and self.lbc.has_operation()) or
                                                    (self.lbc_pc is not None and self.lbc_pc.has_operation()) or
                                                    (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_operation()) or
                                                    (self.opr is not None and self.opr.has_operation()) or
                                                    (self.opt is not None and self.opt.has_operation()) or
                                                    (self.osnr is not None and self.osnr.has_operation()) or
                                                    (self.pcr is not None and self.pcr.has_operation()) or
                                                    (self.pdl is not None and self.pdl.has_operation()) or
                                                    (self.pmd is not None and self.pmd.has_operation()) or
                                                    (self.pn is not None and self.pn.has_operation()) or
                                                    (self.rx_sig_pow is not None and self.rx_sig_pow.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dwdm-minute15-optics-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "cd"):
                                                    if (self.cd is None):
                                                        self.cd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Cd()
                                                        self.cd.parent = self
                                                        self._children_name_map["cd"] = "cd"
                                                    return self.cd

                                                if (child_yang_name == "center-wavelength"):
                                                    if (self.center_wavelength is None):
                                                        self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.CenterWavelength()
                                                        self.center_wavelength.parent = self
                                                        self._children_name_map["center_wavelength"] = "center-wavelength"
                                                    return self.center_wavelength

                                                if (child_yang_name == "dgd"):
                                                    if (self.dgd is None):
                                                        self.dgd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Dgd()
                                                        self.dgd.parent = self
                                                        self._children_name_map["dgd"] = "dgd"
                                                    return self.dgd

                                                if (child_yang_name == "lbc"):
                                                    if (self.lbc is None):
                                                        self.lbc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Lbc()
                                                        self.lbc.parent = self
                                                        self._children_name_map["lbc"] = "lbc"
                                                    return self.lbc

                                                if (child_yang_name == "lbc-pc"):
                                                    if (self.lbc_pc is None):
                                                        self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LbcPc()
                                                        self.lbc_pc.parent = self
                                                        self._children_name_map["lbc_pc"] = "lbc-pc"
                                                    return self.lbc_pc

                                                if (child_yang_name == "low-sig-freq-off"):
                                                    if (self.low_sig_freq_off is None):
                                                        self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.LowSigFreqOff()
                                                        self.low_sig_freq_off.parent = self
                                                        self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                                    return self.low_sig_freq_off

                                                if (child_yang_name == "opr"):
                                                    if (self.opr is None):
                                                        self.opr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opr()
                                                        self.opr.parent = self
                                                        self._children_name_map["opr"] = "opr"
                                                    return self.opr

                                                if (child_yang_name == "opt"):
                                                    if (self.opt is None):
                                                        self.opt = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Opt()
                                                        self.opt.parent = self
                                                        self._children_name_map["opt"] = "opt"
                                                    return self.opt

                                                if (child_yang_name == "osnr"):
                                                    if (self.osnr is None):
                                                        self.osnr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Osnr()
                                                        self.osnr.parent = self
                                                        self._children_name_map["osnr"] = "osnr"
                                                    return self.osnr

                                                if (child_yang_name == "pcr"):
                                                    if (self.pcr is None):
                                                        self.pcr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pcr()
                                                        self.pcr.parent = self
                                                        self._children_name_map["pcr"] = "pcr"
                                                    return self.pcr

                                                if (child_yang_name == "pdl"):
                                                    if (self.pdl is None):
                                                        self.pdl = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pdl()
                                                        self.pdl.parent = self
                                                        self._children_name_map["pdl"] = "pdl"
                                                    return self.pdl

                                                if (child_yang_name == "pmd"):
                                                    if (self.pmd is None):
                                                        self.pmd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pmd()
                                                        self.pmd.parent = self
                                                        self._children_name_map["pmd"] = "pmd"
                                                    return self.pmd

                                                if (child_yang_name == "pn"):
                                                    if (self.pn is None):
                                                        self.pn = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.Pn()
                                                        self.pn.parent = self
                                                        self._children_name_map["pn"] = "pn"
                                                    return self.pn

                                                if (child_yang_name == "rx-sig-pow"):
                                                    if (self.rx_sig_pow is None):
                                                        self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance.RxSigPow()
                                                        self.rx_sig_pow.parent = self
                                                        self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                                    return self.rx_sig_pow

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cd" or name == "center-wavelength" or name == "dgd" or name == "lbc" or name == "lbc-pc" or name == "low-sig-freq-off" or name == "opr" or name == "opt" or name == "osnr" or name == "pcr" or name == "pdl" or name == "pmd" or name == "pn" or name == "rx-sig-pow" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.dwdm_minute15_optics_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.dwdm_minute15_optics_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dwdm-minute15-optics-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dwdm-minute15-optics-time-line-instance"):
                                                for c in self.dwdm_minute15_optics_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances.DwdmMinute15OpticsTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.dwdm_minute15_optics_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dwdm-minute15-optics-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.dwdm_minute15_optics_time_line_instances is not None and self.dwdm_minute15_optics_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.dwdm_minute15_optics_time_line_instances is not None and self.dwdm_minute15_optics_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dwdm-minute15-optics-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dwdm-minute15-optics-time-line-instances"):
                                            if (self.dwdm_minute15_optics_time_line_instances is None):
                                                self.dwdm_minute15_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory.DwdmMinute15OpticsTimeLineInstances()
                                                self.dwdm_minute15_optics_time_line_instances.parent = self
                                                self._children_name_map["dwdm_minute15_optics_time_line_instances"] = "dwdm-minute15-optics-time-line-instances"
                                            return self.dwdm_minute15_optics_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dwdm-minute15-optics-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.dwdm_minute15_optics_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.dwdm_minute15_optics_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dwdm-minute15-optics-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dwdm-minute15-optics-history"):
                                        for c in self.dwdm_minute15_optics_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories.DwdmMinute15OpticsHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.dwdm_minute15_optics_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dwdm-minute15-optics-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    (self.dwdm_minute15_optics_histories is not None and self.dwdm_minute15_optics_histories.has_data()) or
                                    (self.dwdm_minute15fec_histories is not None and self.dwdm_minute15fec_histories.has_data()) or
                                    (self.dwdm_minute15otn_histories is not None and self.dwdm_minute15otn_histories.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dwdm_minute15_optics_histories is not None and self.dwdm_minute15_optics_histories.has_operation()) or
                                    (self.dwdm_minute15fec_histories is not None and self.dwdm_minute15fec_histories.has_operation()) or
                                    (self.dwdm_minute15otn_histories is not None and self.dwdm_minute15otn_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dwdm-minute15-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dwdm-minute15-optics-histories"):
                                    if (self.dwdm_minute15_optics_histories is None):
                                        self.dwdm_minute15_optics_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OpticsHistories()
                                        self.dwdm_minute15_optics_histories.parent = self
                                        self._children_name_map["dwdm_minute15_optics_histories"] = "dwdm-minute15-optics-histories"
                                    return self.dwdm_minute15_optics_histories

                                if (child_yang_name == "dwdm-minute15fec-histories"):
                                    if (self.dwdm_minute15fec_histories is None):
                                        self.dwdm_minute15fec_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15FecHistories()
                                        self.dwdm_minute15fec_histories.parent = self
                                        self._children_name_map["dwdm_minute15fec_histories"] = "dwdm-minute15fec-histories"
                                    return self.dwdm_minute15fec_histories

                                if (child_yang_name == "dwdm-minute15otn-histories"):
                                    if (self.dwdm_minute15otn_histories is None):
                                        self.dwdm_minute15otn_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History.DwdmMinute15OtnHistories()
                                        self.dwdm_minute15otn_histories.parent = self
                                        self._children_name_map["dwdm_minute15otn_histories"] = "dwdm-minute15otn-histories"
                                    return self.dwdm_minute15otn_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dwdm-minute15-optics-histories" or name == "dwdm-minute15fec-histories" or name == "dwdm-minute15otn-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DwdmHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: dwdm_hour24_optics_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`DwdmHour24OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories>`
                            
                            .. attribute:: dwdm_hour24fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`DwdmHour24FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories>`
                            
                            .. attribute:: dwdm_hour24otn_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`DwdmHour24OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History, self).__init__()

                                self.yang_name = "dwdm-hour24-history"
                                self.yang_parent_name = "dwdm-port-history"

                                self.dwdm_hour24_optics_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories()
                                self.dwdm_hour24_optics_histories.parent = self
                                self._children_name_map["dwdm_hour24_optics_histories"] = "dwdm-hour24-optics-histories"
                                self._children_yang_names.add("dwdm-hour24-optics-histories")

                                self.dwdm_hour24fec_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories()
                                self.dwdm_hour24fec_histories.parent = self
                                self._children_name_map["dwdm_hour24fec_histories"] = "dwdm-hour24fec-histories"
                                self._children_yang_names.add("dwdm-hour24fec-histories")

                                self.dwdm_hour24otn_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories()
                                self.dwdm_hour24otn_histories.parent = self
                                self._children_name_map["dwdm_hour24otn_histories"] = "dwdm-hour24otn-histories"
                                self._children_yang_names.add("dwdm-hour24otn-histories")


                            class DwdmHour24OtnHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: dwdm_hour24otn_history
                                
                                	port 24 hour otn performance data
                                	**type**\: list of    :py:class:`DwdmHour24OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories, self).__init__()

                                    self.yang_name = "dwdm-hour24otn-histories"
                                    self.yang_parent_name = "dwdm-hour24-history"

                                    self.dwdm_hour24otn_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories, self).__setattr__(name, value)


                                class DwdmHour24OtnHistory(Entity):
                                    """
                                    port 24 hour otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: dwdm_hour24otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`DwdmHour24OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory, self).__init__()

                                        self.yang_name = "dwdm-hour24otn-history"
                                        self.yang_parent_name = "dwdm-hour24otn-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.dwdm_hour24otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances()
                                        self.dwdm_hour24otn_time_line_instances.parent = self
                                        self._children_name_map["dwdm_hour24otn_time_line_instances"] = "dwdm-hour24otn-time-line-instances"
                                        self._children_yang_names.add("dwdm-hour24otn-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory, self).__setattr__(name, value)


                                    class DwdmHour24OtnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_hour24otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`DwdmHour24OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances, self).__init__()

                                            self.yang_name = "dwdm-hour24otn-time-line-instances"
                                            self.yang_parent_name = "dwdm-hour24otn-history"

                                            self.dwdm_hour24otn_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances, self).__setattr__(name, value)


                                        class DwdmHour24OtnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance, self).__init__()

                                                self.yang_name = "dwdm-hour24otn-time-line-instance"
                                                self.yang_parent_name = "dwdm-hour24otn-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"
                                                self._children_yang_names.add("bbe-fe")

                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"
                                                self._children_yang_names.add("bbe-ne")

                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"
                                                self._children_yang_names.add("bber-fe")

                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"
                                                self._children_yang_names.add("bber-ne")

                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"
                                                self._children_yang_names.add("es-fe")

                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"
                                                self._children_yang_names.add("es-ne")

                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"
                                                self._children_yang_names.add("esr-fe")

                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"
                                                self._children_yang_names.add("esr-ne")

                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._children_yang_names.add("fc-fe")

                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"
                                                self._children_yang_names.add("fc-ne")

                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"
                                                self._children_yang_names.add("lbc")

                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"
                                                self._children_yang_names.add("ses-fe")

                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"
                                                self._children_yang_names.add("ses-ne")

                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"
                                                self._children_yang_names.add("sesr-fe")

                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"
                                                self._children_yang_names.add("sesr-ne")

                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"
                                                self._children_yang_names.add("uas-fe")

                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"
                                                self._children_yang_names.add("uas-ne")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance, self).__setattr__(name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.Lbc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.Lbc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "dwdm-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_data()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_data()) or
                                                    (self.es_fe is not None and self.es_fe.has_data()) or
                                                    (self.es_ne is not None and self.es_ne.has_data()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_data()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_data()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_data()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_data()) or
                                                    (self.lbc is not None and self.lbc.has_data()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_data()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_data()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_data()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                                    (self.es_fe is not None and self.es_fe.has_operation()) or
                                                    (self.es_ne is not None and self.es_ne.has_operation()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                                    (self.lbc is not None and self.lbc.has_operation()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dwdm-hour24otn-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bbe-fe"):
                                                    if (self.bbe_fe is None):
                                                        self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeFe()
                                                        self.bbe_fe.parent = self
                                                        self._children_name_map["bbe_fe"] = "bbe-fe"
                                                    return self.bbe_fe

                                                if (child_yang_name == "bbe-ne"):
                                                    if (self.bbe_ne is None):
                                                        self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BbeNe()
                                                        self.bbe_ne.parent = self
                                                        self._children_name_map["bbe_ne"] = "bbe-ne"
                                                    return self.bbe_ne

                                                if (child_yang_name == "bber-fe"):
                                                    if (self.bber_fe is None):
                                                        self.bber_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberFe()
                                                        self.bber_fe.parent = self
                                                        self._children_name_map["bber_fe"] = "bber-fe"
                                                    return self.bber_fe

                                                if (child_yang_name == "bber-ne"):
                                                    if (self.bber_ne is None):
                                                        self.bber_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.BberNe()
                                                        self.bber_ne.parent = self
                                                        self._children_name_map["bber_ne"] = "bber-ne"
                                                    return self.bber_ne

                                                if (child_yang_name == "es-fe"):
                                                    if (self.es_fe is None):
                                                        self.es_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsFe()
                                                        self.es_fe.parent = self
                                                        self._children_name_map["es_fe"] = "es-fe"
                                                    return self.es_fe

                                                if (child_yang_name == "es-ne"):
                                                    if (self.es_ne is None):
                                                        self.es_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsNe()
                                                        self.es_ne.parent = self
                                                        self._children_name_map["es_ne"] = "es-ne"
                                                    return self.es_ne

                                                if (child_yang_name == "esr-fe"):
                                                    if (self.esr_fe is None):
                                                        self.esr_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrFe()
                                                        self.esr_fe.parent = self
                                                        self._children_name_map["esr_fe"] = "esr-fe"
                                                    return self.esr_fe

                                                if (child_yang_name == "esr-ne"):
                                                    if (self.esr_ne is None):
                                                        self.esr_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.EsrNe()
                                                        self.esr_ne.parent = self
                                                        self._children_name_map["esr_ne"] = "esr-ne"
                                                    return self.esr_ne

                                                if (child_yang_name == "fc-fe"):
                                                    if (self.fc_fe is None):
                                                        self.fc_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcFe()
                                                        self.fc_fe.parent = self
                                                        self._children_name_map["fc_fe"] = "fc-fe"
                                                    return self.fc_fe

                                                if (child_yang_name == "fc-ne"):
                                                    if (self.fc_ne is None):
                                                        self.fc_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.FcNe()
                                                        self.fc_ne.parent = self
                                                        self._children_name_map["fc_ne"] = "fc-ne"
                                                    return self.fc_ne

                                                if (child_yang_name == "lbc"):
                                                    if (self.lbc is None):
                                                        self.lbc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.Lbc()
                                                        self.lbc.parent = self
                                                        self._children_name_map["lbc"] = "lbc"
                                                    return self.lbc

                                                if (child_yang_name == "ses-fe"):
                                                    if (self.ses_fe is None):
                                                        self.ses_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesFe()
                                                        self.ses_fe.parent = self
                                                        self._children_name_map["ses_fe"] = "ses-fe"
                                                    return self.ses_fe

                                                if (child_yang_name == "ses-ne"):
                                                    if (self.ses_ne is None):
                                                        self.ses_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesNe()
                                                        self.ses_ne.parent = self
                                                        self._children_name_map["ses_ne"] = "ses-ne"
                                                    return self.ses_ne

                                                if (child_yang_name == "sesr-fe"):
                                                    if (self.sesr_fe is None):
                                                        self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrFe()
                                                        self.sesr_fe.parent = self
                                                        self._children_name_map["sesr_fe"] = "sesr-fe"
                                                    return self.sesr_fe

                                                if (child_yang_name == "sesr-ne"):
                                                    if (self.sesr_ne is None):
                                                        self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.SesrNe()
                                                        self.sesr_ne.parent = self
                                                        self._children_name_map["sesr_ne"] = "sesr-ne"
                                                    return self.sesr_ne

                                                if (child_yang_name == "uas-fe"):
                                                    if (self.uas_fe is None):
                                                        self.uas_fe = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasFe()
                                                        self.uas_fe.parent = self
                                                        self._children_name_map["uas_fe"] = "uas-fe"
                                                    return self.uas_fe

                                                if (child_yang_name == "uas-ne"):
                                                    if (self.uas_ne is None):
                                                        self.uas_ne = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance.UasNe()
                                                        self.uas_ne.parent = self
                                                        self._children_name_map["uas_ne"] = "uas-ne"
                                                    return self.uas_ne

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.dwdm_hour24otn_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.dwdm_hour24otn_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dwdm-hour24otn-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dwdm-hour24otn-time-line-instance"):
                                                for c in self.dwdm_hour24otn_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances.DwdmHour24OtnTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.dwdm_hour24otn_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dwdm-hour24otn-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.dwdm_hour24otn_time_line_instances is not None and self.dwdm_hour24otn_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.dwdm_hour24otn_time_line_instances is not None and self.dwdm_hour24otn_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dwdm-hour24otn-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dwdm-hour24otn-time-line-instances"):
                                            if (self.dwdm_hour24otn_time_line_instances is None):
                                                self.dwdm_hour24otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory.DwdmHour24OtnTimeLineInstances()
                                                self.dwdm_hour24otn_time_line_instances.parent = self
                                                self._children_name_map["dwdm_hour24otn_time_line_instances"] = "dwdm-hour24otn-time-line-instances"
                                            return self.dwdm_hour24otn_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dwdm-hour24otn-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.dwdm_hour24otn_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.dwdm_hour24otn_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dwdm-hour24otn-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dwdm-hour24otn-history"):
                                        for c in self.dwdm_hour24otn_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories.DwdmHour24OtnHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.dwdm_hour24otn_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dwdm-hour24otn-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DwdmHour24FecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: dwdm_hour24fec_history
                                
                                	port 24 hour fec performance data
                                	**type**\: list of    :py:class:`DwdmHour24FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories, self).__init__()

                                    self.yang_name = "dwdm-hour24fec-histories"
                                    self.yang_parent_name = "dwdm-hour24-history"

                                    self.dwdm_hour24fec_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories, self).__setattr__(name, value)


                                class DwdmHour24FecHistory(Entity):
                                    """
                                    port 24 hour fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: dwdm_hour24fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`DwdmHour24FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory, self).__init__()

                                        self.yang_name = "dwdm-hour24fec-history"
                                        self.yang_parent_name = "dwdm-hour24fec-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.dwdm_hour24fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances()
                                        self.dwdm_hour24fec_time_line_instances.parent = self
                                        self._children_name_map["dwdm_hour24fec_time_line_instances"] = "dwdm-hour24fec-time-line-instances"
                                        self._children_yang_names.add("dwdm-hour24fec-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory, self).__setattr__(name, value)


                                    class DwdmHour24FecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_hour24fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data by index
                                        	**type**\: list of    :py:class:`DwdmHour24FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances, self).__init__()

                                            self.yang_name = "dwdm-hour24fec-time-line-instances"
                                            self.yang_parent_name = "dwdm-hour24fec-history"

                                            self.dwdm_hour24fec_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances, self).__setattr__(name, value)


                                        class DwdmHour24FecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data by
                                            index
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance, self).__init__()

                                                self.yang_name = "dwdm-hour24fec-time-line-instance"
                                                self.yang_parent_name = "dwdm-hour24fec-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"
                                                self._children_yang_names.add("ec-bits")

                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                self._children_yang_names.add("post-fec-ber")

                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                self._children_yang_names.add("pre-fec-ber")

                                                self.q = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"
                                                self._children_yang_names.add("q")

                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._children_yang_names.add("qmargin")

                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"
                                                self._children_yang_names.add("uc-words")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance, self).__setattr__(name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "dwdm-hour24fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.EcBits, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.EcBits, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ec-bits" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "dwdm-hour24fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.UcWords, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.UcWords, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uc-words" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "dwdm-hour24fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pre-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "dwdm-hour24fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "post-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "dwdm-hour24fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Q, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Q, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "q" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "dwdm-hour24fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Qmargin, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Qmargin, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "qmargin" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_data()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                                    (self.q is not None and self.q.has_data()) or
                                                    (self.qmargin is not None and self.qmargin.has_data()) or
                                                    (self.uc_words is not None and self.uc_words.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                                    (self.q is not None and self.q.has_operation()) or
                                                    (self.qmargin is not None and self.qmargin.has_operation()) or
                                                    (self.uc_words is not None and self.uc_words.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dwdm-hour24fec-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ec-bits"):
                                                    if (self.ec_bits is None):
                                                        self.ec_bits = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.EcBits()
                                                        self.ec_bits.parent = self
                                                        self._children_name_map["ec_bits"] = "ec-bits"
                                                    return self.ec_bits

                                                if (child_yang_name == "post-fec-ber"):
                                                    if (self.post_fec_ber is None):
                                                        self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PostFecBer()
                                                        self.post_fec_ber.parent = self
                                                        self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                    return self.post_fec_ber

                                                if (child_yang_name == "pre-fec-ber"):
                                                    if (self.pre_fec_ber is None):
                                                        self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.PreFecBer()
                                                        self.pre_fec_ber.parent = self
                                                        self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                    return self.pre_fec_ber

                                                if (child_yang_name == "q"):
                                                    if (self.q is None):
                                                        self.q = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Q()
                                                        self.q.parent = self
                                                        self._children_name_map["q"] = "q"
                                                    return self.q

                                                if (child_yang_name == "qmargin"):
                                                    if (self.qmargin is None):
                                                        self.qmargin = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.Qmargin()
                                                        self.qmargin.parent = self
                                                        self._children_name_map["qmargin"] = "qmargin"
                                                    return self.qmargin

                                                if (child_yang_name == "uc-words"):
                                                    if (self.uc_words is None):
                                                        self.uc_words = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance.UcWords()
                                                        self.uc_words.parent = self
                                                        self._children_name_map["uc_words"] = "uc-words"
                                                    return self.uc_words

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.dwdm_hour24fec_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.dwdm_hour24fec_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dwdm-hour24fec-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dwdm-hour24fec-time-line-instance"):
                                                for c in self.dwdm_hour24fec_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances.DwdmHour24FecTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.dwdm_hour24fec_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dwdm-hour24fec-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.dwdm_hour24fec_time_line_instances is not None and self.dwdm_hour24fec_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.dwdm_hour24fec_time_line_instances is not None and self.dwdm_hour24fec_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dwdm-hour24fec-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dwdm-hour24fec-time-line-instances"):
                                            if (self.dwdm_hour24fec_time_line_instances is None):
                                                self.dwdm_hour24fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory.DwdmHour24FecTimeLineInstances()
                                                self.dwdm_hour24fec_time_line_instances.parent = self
                                                self._children_name_map["dwdm_hour24fec_time_line_instances"] = "dwdm-hour24fec-time-line-instances"
                                            return self.dwdm_hour24fec_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dwdm-hour24fec-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.dwdm_hour24fec_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.dwdm_hour24fec_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dwdm-hour24fec-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dwdm-hour24fec-history"):
                                        for c in self.dwdm_hour24fec_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories.DwdmHour24FecHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.dwdm_hour24fec_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dwdm-hour24fec-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DwdmHour24OpticsHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: dwdm_hour24_optics_history
                                
                                	port 24 hour optics performance data
                                	**type**\: list of    :py:class:`DwdmHour24OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories, self).__init__()

                                    self.yang_name = "dwdm-hour24-optics-histories"
                                    self.yang_parent_name = "dwdm-hour24-history"

                                    self.dwdm_hour24_optics_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories, self).__setattr__(name, value)


                                class DwdmHour24OpticsHistory(Entity):
                                    """
                                    port 24 hour optics performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: dwdm_hour24_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`DwdmHour24OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory, self).__init__()

                                        self.yang_name = "dwdm-hour24-optics-history"
                                        self.yang_parent_name = "dwdm-hour24-optics-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.dwdm_hour24_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances()
                                        self.dwdm_hour24_optics_time_line_instances.parent = self
                                        self._children_name_map["dwdm_hour24_optics_time_line_instances"] = "dwdm-hour24-optics-time-line-instances"
                                        self._children_yang_names.add("dwdm-hour24-optics-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory, self).__setattr__(name, value)


                                    class DwdmHour24OpticsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: dwdm_hour24_optics_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`DwdmHour24OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances, self).__init__()

                                            self.yang_name = "dwdm-hour24-optics-time-line-instances"
                                            self.yang_parent_name = "dwdm-hour24-optics-history"

                                            self.dwdm_hour24_optics_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances, self).__setattr__(name, value)


                                        class DwdmHour24OpticsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance, self).__init__()

                                                self.yang_name = "dwdm-hour24-optics-time-line-instance"
                                                self.yang_parent_name = "dwdm-hour24-optics-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.cd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self._children_name_map["cd"] = "cd"
                                                self._children_yang_names.add("cd")

                                                self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self._children_name_map["center_wavelength"] = "center-wavelength"
                                                self._children_yang_names.add("center-wavelength")

                                                self.dgd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self._children_name_map["dgd"] = "dgd"
                                                self._children_yang_names.add("dgd")

                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"
                                                self._children_yang_names.add("lbc")

                                                self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self._children_name_map["lbc_pc"] = "lbc-pc"
                                                self._children_yang_names.add("lbc-pc")

                                                self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                                self._children_yang_names.add("low-sig-freq-off")

                                                self.opr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self._children_name_map["opr"] = "opr"
                                                self._children_yang_names.add("opr")

                                                self.opt = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self._children_name_map["opt"] = "opt"
                                                self._children_yang_names.add("opt")

                                                self.osnr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self._children_name_map["osnr"] = "osnr"
                                                self._children_yang_names.add("osnr")

                                                self.pcr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self._children_name_map["pcr"] = "pcr"
                                                self._children_yang_names.add("pcr")

                                                self.pdl = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self._children_name_map["pdl"] = "pdl"
                                                self._children_yang_names.add("pdl")

                                                self.pmd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self._children_name_map["pmd"] = "pmd"
                                                self._children_yang_names.add("pmd")

                                                self.pn = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self._children_name_map["pn"] = "pn"
                                                self._children_yang_names.add("pn")

                                                self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                                self._children_yang_names.add("rx-sig-pow")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance, self).__setattr__(name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LbcPc(Entity):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc, self).__init__()

                                                    self.yang_name = "lbc-pc"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc-pc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Opt(Entity):
                                                """
                                                OPT
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt, self).__init__()

                                                    self.yang_name = "opt"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Opr(Entity):
                                                """
                                                OPR
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr, self).__init__()

                                                    self.yang_name = "opr"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Cd(Entity):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd, self).__init__()

                                                    self.yang_name = "cd"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "cd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Dgd(Entity):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd, self).__init__()

                                                    self.yang_name = "dgd"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dgd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pmd(Entity):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd, self).__init__()

                                                    self.yang_name = "pmd"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pmd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Osnr(Entity):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr, self).__init__()

                                                    self.yang_name = "osnr"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "osnr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class CenterWavelength(Entity):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength, self).__init__()

                                                    self.yang_name = "center-wavelength"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "center-wavelength" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pdl(Entity):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl, self).__init__()

                                                    self.yang_name = "pdl"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pdl" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pcr(Entity):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr, self).__init__()

                                                    self.yang_name = "pcr"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pcr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pn(Entity):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn, self).__init__()

                                                    self.yang_name = "pn"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pn" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class RxSigPow(Entity):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow, self).__init__()

                                                    self.yang_name = "rx-sig-pow"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-sig-pow" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LowSigFreqOff(Entity):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff, self).__init__()

                                                    self.yang_name = "low-sig-freq-off"
                                                    self.yang_parent_name = "dwdm-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "low-sig-freq-off" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.cd is not None and self.cd.has_data()) or
                                                    (self.center_wavelength is not None and self.center_wavelength.has_data()) or
                                                    (self.dgd is not None and self.dgd.has_data()) or
                                                    (self.lbc is not None and self.lbc.has_data()) or
                                                    (self.lbc_pc is not None and self.lbc_pc.has_data()) or
                                                    (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_data()) or
                                                    (self.opr is not None and self.opr.has_data()) or
                                                    (self.opt is not None and self.opt.has_data()) or
                                                    (self.osnr is not None and self.osnr.has_data()) or
                                                    (self.pcr is not None and self.pcr.has_data()) or
                                                    (self.pdl is not None and self.pdl.has_data()) or
                                                    (self.pmd is not None and self.pmd.has_data()) or
                                                    (self.pn is not None and self.pn.has_data()) or
                                                    (self.rx_sig_pow is not None and self.rx_sig_pow.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.cd is not None and self.cd.has_operation()) or
                                                    (self.center_wavelength is not None and self.center_wavelength.has_operation()) or
                                                    (self.dgd is not None and self.dgd.has_operation()) or
                                                    (self.lbc is not None and self.lbc.has_operation()) or
                                                    (self.lbc_pc is not None and self.lbc_pc.has_operation()) or
                                                    (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_operation()) or
                                                    (self.opr is not None and self.opr.has_operation()) or
                                                    (self.opt is not None and self.opt.has_operation()) or
                                                    (self.osnr is not None and self.osnr.has_operation()) or
                                                    (self.pcr is not None and self.pcr.has_operation()) or
                                                    (self.pdl is not None and self.pdl.has_operation()) or
                                                    (self.pmd is not None and self.pmd.has_operation()) or
                                                    (self.pn is not None and self.pn.has_operation()) or
                                                    (self.rx_sig_pow is not None and self.rx_sig_pow.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "dwdm-hour24-optics-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "cd"):
                                                    if (self.cd is None):
                                                        self.cd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Cd()
                                                        self.cd.parent = self
                                                        self._children_name_map["cd"] = "cd"
                                                    return self.cd

                                                if (child_yang_name == "center-wavelength"):
                                                    if (self.center_wavelength is None):
                                                        self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.CenterWavelength()
                                                        self.center_wavelength.parent = self
                                                        self._children_name_map["center_wavelength"] = "center-wavelength"
                                                    return self.center_wavelength

                                                if (child_yang_name == "dgd"):
                                                    if (self.dgd is None):
                                                        self.dgd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Dgd()
                                                        self.dgd.parent = self
                                                        self._children_name_map["dgd"] = "dgd"
                                                    return self.dgd

                                                if (child_yang_name == "lbc"):
                                                    if (self.lbc is None):
                                                        self.lbc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Lbc()
                                                        self.lbc.parent = self
                                                        self._children_name_map["lbc"] = "lbc"
                                                    return self.lbc

                                                if (child_yang_name == "lbc-pc"):
                                                    if (self.lbc_pc is None):
                                                        self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LbcPc()
                                                        self.lbc_pc.parent = self
                                                        self._children_name_map["lbc_pc"] = "lbc-pc"
                                                    return self.lbc_pc

                                                if (child_yang_name == "low-sig-freq-off"):
                                                    if (self.low_sig_freq_off is None):
                                                        self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.LowSigFreqOff()
                                                        self.low_sig_freq_off.parent = self
                                                        self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                                    return self.low_sig_freq_off

                                                if (child_yang_name == "opr"):
                                                    if (self.opr is None):
                                                        self.opr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opr()
                                                        self.opr.parent = self
                                                        self._children_name_map["opr"] = "opr"
                                                    return self.opr

                                                if (child_yang_name == "opt"):
                                                    if (self.opt is None):
                                                        self.opt = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Opt()
                                                        self.opt.parent = self
                                                        self._children_name_map["opt"] = "opt"
                                                    return self.opt

                                                if (child_yang_name == "osnr"):
                                                    if (self.osnr is None):
                                                        self.osnr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Osnr()
                                                        self.osnr.parent = self
                                                        self._children_name_map["osnr"] = "osnr"
                                                    return self.osnr

                                                if (child_yang_name == "pcr"):
                                                    if (self.pcr is None):
                                                        self.pcr = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pcr()
                                                        self.pcr.parent = self
                                                        self._children_name_map["pcr"] = "pcr"
                                                    return self.pcr

                                                if (child_yang_name == "pdl"):
                                                    if (self.pdl is None):
                                                        self.pdl = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pdl()
                                                        self.pdl.parent = self
                                                        self._children_name_map["pdl"] = "pdl"
                                                    return self.pdl

                                                if (child_yang_name == "pmd"):
                                                    if (self.pmd is None):
                                                        self.pmd = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pmd()
                                                        self.pmd.parent = self
                                                        self._children_name_map["pmd"] = "pmd"
                                                    return self.pmd

                                                if (child_yang_name == "pn"):
                                                    if (self.pn is None):
                                                        self.pn = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.Pn()
                                                        self.pn.parent = self
                                                        self._children_name_map["pn"] = "pn"
                                                    return self.pn

                                                if (child_yang_name == "rx-sig-pow"):
                                                    if (self.rx_sig_pow is None):
                                                        self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance.RxSigPow()
                                                        self.rx_sig_pow.parent = self
                                                        self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                                    return self.rx_sig_pow

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cd" or name == "center-wavelength" or name == "dgd" or name == "lbc" or name == "lbc-pc" or name == "low-sig-freq-off" or name == "opr" or name == "opt" or name == "osnr" or name == "pcr" or name == "pdl" or name == "pmd" or name == "pn" or name == "rx-sig-pow" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.dwdm_hour24_optics_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.dwdm_hour24_optics_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dwdm-hour24-optics-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "dwdm-hour24-optics-time-line-instance"):
                                                for c in self.dwdm_hour24_optics_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances.DwdmHour24OpticsTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.dwdm_hour24_optics_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "dwdm-hour24-optics-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.dwdm_hour24_optics_time_line_instances is not None and self.dwdm_hour24_optics_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.dwdm_hour24_optics_time_line_instances is not None and self.dwdm_hour24_optics_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dwdm-hour24-optics-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "dwdm-hour24-optics-time-line-instances"):
                                            if (self.dwdm_hour24_optics_time_line_instances is None):
                                                self.dwdm_hour24_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory.DwdmHour24OpticsTimeLineInstances()
                                                self.dwdm_hour24_optics_time_line_instances.parent = self
                                                self._children_name_map["dwdm_hour24_optics_time_line_instances"] = "dwdm-hour24-optics-time-line-instances"
                                            return self.dwdm_hour24_optics_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "dwdm-hour24-optics-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.dwdm_hour24_optics_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.dwdm_hour24_optics_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dwdm-hour24-optics-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "dwdm-hour24-optics-history"):
                                        for c in self.dwdm_hour24_optics_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories.DwdmHour24OpticsHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.dwdm_hour24_optics_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "dwdm-hour24-optics-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    (self.dwdm_hour24_optics_histories is not None and self.dwdm_hour24_optics_histories.has_data()) or
                                    (self.dwdm_hour24fec_histories is not None and self.dwdm_hour24fec_histories.has_data()) or
                                    (self.dwdm_hour24otn_histories is not None and self.dwdm_hour24otn_histories.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.dwdm_hour24_optics_histories is not None and self.dwdm_hour24_optics_histories.has_operation()) or
                                    (self.dwdm_hour24fec_histories is not None and self.dwdm_hour24fec_histories.has_operation()) or
                                    (self.dwdm_hour24otn_histories is not None and self.dwdm_hour24otn_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dwdm-hour24-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "dwdm-hour24-optics-histories"):
                                    if (self.dwdm_hour24_optics_histories is None):
                                        self.dwdm_hour24_optics_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OpticsHistories()
                                        self.dwdm_hour24_optics_histories.parent = self
                                        self._children_name_map["dwdm_hour24_optics_histories"] = "dwdm-hour24-optics-histories"
                                    return self.dwdm_hour24_optics_histories

                                if (child_yang_name == "dwdm-hour24fec-histories"):
                                    if (self.dwdm_hour24fec_histories is None):
                                        self.dwdm_hour24fec_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24FecHistories()
                                        self.dwdm_hour24fec_histories.parent = self
                                        self._children_name_map["dwdm_hour24fec_histories"] = "dwdm-hour24fec-histories"
                                    return self.dwdm_hour24fec_histories

                                if (child_yang_name == "dwdm-hour24otn-histories"):
                                    if (self.dwdm_hour24otn_histories is None):
                                        self.dwdm_hour24otn_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History.DwdmHour24OtnHistories()
                                        self.dwdm_hour24otn_histories.parent = self
                                        self._children_name_map["dwdm_hour24otn_histories"] = "dwdm-hour24otn-histories"
                                    return self.dwdm_hour24otn_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dwdm-hour24-optics-histories" or name == "dwdm-hour24fec-histories" or name == "dwdm-hour24otn-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.name.is_set or
                                (self.dwdm_hour24_history is not None and self.dwdm_hour24_history.has_data()) or
                                (self.dwdm_minute15_history is not None and self.dwdm_minute15_history.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                (self.dwdm_hour24_history is not None and self.dwdm_hour24_history.has_operation()) or
                                (self.dwdm_minute15_history is not None and self.dwdm_minute15_history.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dwdm-port-history" + "[name='" + self.name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/dwdm-history/dwdm-port-histories/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dwdm-hour24-history"):
                                if (self.dwdm_hour24_history is None):
                                    self.dwdm_hour24_history = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmHour24History()
                                    self.dwdm_hour24_history.parent = self
                                    self._children_name_map["dwdm_hour24_history"] = "dwdm-hour24-history"
                                return self.dwdm_hour24_history

                            if (child_yang_name == "dwdm-minute15-history"):
                                if (self.dwdm_minute15_history is None):
                                    self.dwdm_minute15_history = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory.DwdmMinute15History()
                                    self.dwdm_minute15_history.parent = self
                                    self._children_name_map["dwdm_minute15_history"] = "dwdm-minute15-history"
                                return self.dwdm_minute15_history

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dwdm-hour24-history" or name == "dwdm-minute15-history" or name == "name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.dwdm_port_history:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.dwdm_port_history:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "dwdm-port-histories" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/dwdm-history/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dwdm-port-history"):
                            for c in self.dwdm_port_history:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories.DwdmPortHistory()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.dwdm_port_history.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dwdm-port-history"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.dwdm_port_histories is not None and self.dwdm_port_histories.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.dwdm_port_histories is not None and self.dwdm_port_histories.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "dwdm-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "dwdm-port-histories"):
                        if (self.dwdm_port_histories is None):
                            self.dwdm_port_histories = PerformanceManagementHistory.Global_.Periodic.DwdmHistory.DwdmPortHistories()
                            self.dwdm_port_histories.parent = self
                            self._children_name_map["dwdm_port_histories"] = "dwdm-port-histories"
                        return self.dwdm_port_histories

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "dwdm-port-histories"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class StmHistory(Entity):
                """
                STM controller History performance data
                
                .. attribute:: stm_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`StmPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory, self).__init__()

                    self.yang_name = "stm-history"
                    self.yang_parent_name = "periodic"

                    self.stm_port_histories = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories()
                    self.stm_port_histories.parent = self
                    self._children_name_map["stm_port_histories"] = "stm-port-histories"
                    self._children_yang_names.add("stm-port-histories")


                class StmPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: stm_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`StmPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories, self).__init__()

                        self.yang_name = "stm-port-histories"
                        self.yang_parent_name = "stm-history"

                        self.stm_port_history = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories, self).__setattr__(name, value)


                    class StmPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: stm_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`StmHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History>`
                        
                        .. attribute:: stm_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`StmMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory, self).__init__()

                            self.yang_name = "stm-port-history"
                            self.yang_parent_name = "stm-port-histories"

                            self.name = YLeaf(YType.str, "name")

                            self.stm_hour24_history = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History()
                            self.stm_hour24_history.parent = self
                            self._children_name_map["stm_hour24_history"] = "stm-hour24-history"
                            self._children_yang_names.add("stm-hour24-history")

                            self.stm_minute15_history = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History()
                            self.stm_minute15_history.parent = self
                            self._children_name_map["stm_minute15_history"] = "stm-minute15-history"
                            self._children_yang_names.add("stm-minute15-history")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory, self).__setattr__(name, value)


                        class StmHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: stm_hour24stm_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`StmHour24StmHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History, self).__init__()

                                self.yang_name = "stm-hour24-history"
                                self.yang_parent_name = "stm-port-history"

                                self.stm_hour24stm_histories = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories()
                                self.stm_hour24stm_histories.parent = self
                                self._children_name_map["stm_hour24stm_histories"] = "stm-hour24stm-histories"
                                self._children_yang_names.add("stm-hour24stm-histories")


                            class StmHour24StmHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: stm_hour24stm_history
                                
                                	port 24 hour stm performance data
                                	**type**\: list of    :py:class:`StmHour24StmHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories, self).__init__()

                                    self.yang_name = "stm-hour24stm-histories"
                                    self.yang_parent_name = "stm-hour24-history"

                                    self.stm_hour24stm_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories, self).__setattr__(name, value)


                                class StmHour24StmHistory(Entity):
                                    """
                                    port 24 hour stm performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: stm_hour24stm_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`StmHour24StmTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory, self).__init__()

                                        self.yang_name = "stm-hour24stm-history"
                                        self.yang_parent_name = "stm-hour24stm-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.stm_hour24stm_time_line_instances = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances()
                                        self.stm_hour24stm_time_line_instances.parent = self
                                        self._children_name_map["stm_hour24stm_time_line_instances"] = "stm-hour24stm-time-line-instances"
                                        self._children_yang_names.add("stm-hour24stm-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory, self).__setattr__(name, value)


                                    class StmHour24StmTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: stm_hour24stm_time_line_instance
                                        
                                        	port 15\-minute stm performance data
                                        	**type**\: list of    :py:class:`StmHour24StmTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances, self).__init__()

                                            self.yang_name = "stm-hour24stm-time-line-instances"
                                            self.yang_parent_name = "stm-hour24stm-history"

                                            self.stm_hour24stm_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances, self).__setattr__(name, value)


                                        class StmHour24StmTimeLineInstance(Entity):
                                            """
                                            port 15\-minute stm performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line>`
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance, self).__init__()

                                                self.yang_name = "stm-hour24stm-time-line-instance"
                                                self.yang_parent_name = "stm-hour24stm-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.fe_line = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self._children_name_map["fe_line"] = "fe-line"
                                                self._children_yang_names.add("fe-line")

                                                self.line = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line()
                                                self.line.parent = self
                                                self._children_name_map["line"] = "line"
                                                self._children_yang_names.add("line")

                                                self.section = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section()
                                                self.section.parent = self
                                                self._children_name_map["section"] = "section"
                                                self._children_yang_names.add("section")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance, self).__setattr__(name, value)


                                            class Section(Entity):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_bb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`SectionBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbEs>`
                                                
                                                .. attribute:: section_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`SectionBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbeRs>`
                                                
                                                .. attribute:: section_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:   :py:class:`SectionEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEBs>`
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:   :py:class:`SectionEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEsRs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:   :py:class:`SectionSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSesRs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: section_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:   :py:class:`SectionUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section, self).__init__()

                                                    self.yang_name = "section"
                                                    self.yang_parent_name = "stm-hour24stm-time-line-instance"

                                                    self.section_status = YLeaf(YType.int32, "section-status")

                                                    self.section_bb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbEs()
                                                    self.section_bb_es.parent = self
                                                    self._children_name_map["section_bb_es"] = "section-bb-es"
                                                    self._children_yang_names.add("section-bb-es")

                                                    self.section_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbeRs()
                                                    self.section_bbe_rs.parent = self
                                                    self._children_name_map["section_bbe_rs"] = "section-bbe-rs"
                                                    self._children_yang_names.add("section-bbe-rs")

                                                    self.section_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEBs()
                                                    self.section_e_bs.parent = self
                                                    self._children_name_map["section_e_bs"] = "section-e-bs"
                                                    self._children_yang_names.add("section-e-bs")

                                                    self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self._children_name_map["section_e_ss"] = "section-e-ss"
                                                    self._children_yang_names.add("section-e-ss")

                                                    self.section_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEsRs()
                                                    self.section_es_rs.parent = self
                                                    self._children_name_map["section_es_rs"] = "section-es-rs"
                                                    self._children_yang_names.add("section-es-rs")

                                                    self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self._children_name_map["section_se_ss"] = "section-se-ss"
                                                    self._children_yang_names.add("section-se-ss")

                                                    self.section_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSesRs()
                                                    self.section_ses_rs.parent = self
                                                    self._children_name_map["section_ses_rs"] = "section-ses-rs"
                                                    self._children_yang_names.add("section-ses-rs")

                                                    self.section_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionUaSs()
                                                    self.section_ua_ss.parent = self
                                                    self._children_name_map["section_ua_ss"] = "section-ua-ss"
                                                    self._children_yang_names.add("section-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("section_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section, self).__setattr__(name, value)


                                                class SectionESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionESs, self).__init__()

                                                        self.yang_name = "section-e-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEsRs, self).__init__()

                                                        self.yang_name = "section-es-rs"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEsRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEsRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-es-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionBbEs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbEs, self).__init__()

                                                        self.yang_name = "section-bb-es"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbEs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbEs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-bb-es" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionBbeRs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbeRs, self).__init__()

                                                        self.yang_name = "section-bbe-rs"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbeRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbeRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-bbe-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSeSs, self).__init__()

                                                        self.yang_name = "section-se-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSesRs, self).__init__()

                                                        self.yang_name = "section-ses-rs"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSesRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSesRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-ses-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionUaSs(Entity):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionUaSs, self).__init__()

                                                        self.yang_name = "section-ua-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionEBs(Entity):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEBs, self).__init__()

                                                        self.yang_name = "section-e-bs"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEBs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEBs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-e-bs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.section_status.is_set or
                                                        (self.section_bb_es is not None and self.section_bb_es.has_data()) or
                                                        (self.section_bbe_rs is not None and self.section_bbe_rs.has_data()) or
                                                        (self.section_e_bs is not None and self.section_e_bs.has_data()) or
                                                        (self.section_e_ss is not None and self.section_e_ss.has_data()) or
                                                        (self.section_es_rs is not None and self.section_es_rs.has_data()) or
                                                        (self.section_se_ss is not None and self.section_se_ss.has_data()) or
                                                        (self.section_ses_rs is not None and self.section_ses_rs.has_data()) or
                                                        (self.section_ua_ss is not None and self.section_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.section_status.yfilter != YFilter.not_set or
                                                        (self.section_bb_es is not None and self.section_bb_es.has_operation()) or
                                                        (self.section_bbe_rs is not None and self.section_bbe_rs.has_operation()) or
                                                        (self.section_e_bs is not None and self.section_e_bs.has_operation()) or
                                                        (self.section_e_ss is not None and self.section_e_ss.has_operation()) or
                                                        (self.section_es_rs is not None and self.section_es_rs.has_operation()) or
                                                        (self.section_se_ss is not None and self.section_se_ss.has_operation()) or
                                                        (self.section_ses_rs is not None and self.section_ses_rs.has_operation()) or
                                                        (self.section_ua_ss is not None and self.section_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "section" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.section_status.is_set or self.section_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.section_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "section-bb-es"):
                                                        if (self.section_bb_es is None):
                                                            self.section_bb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbEs()
                                                            self.section_bb_es.parent = self
                                                            self._children_name_map["section_bb_es"] = "section-bb-es"
                                                        return self.section_bb_es

                                                    if (child_yang_name == "section-bbe-rs"):
                                                        if (self.section_bbe_rs is None):
                                                            self.section_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionBbeRs()
                                                            self.section_bbe_rs.parent = self
                                                            self._children_name_map["section_bbe_rs"] = "section-bbe-rs"
                                                        return self.section_bbe_rs

                                                    if (child_yang_name == "section-e-bs"):
                                                        if (self.section_e_bs is None):
                                                            self.section_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEBs()
                                                            self.section_e_bs.parent = self
                                                            self._children_name_map["section_e_bs"] = "section-e-bs"
                                                        return self.section_e_bs

                                                    if (child_yang_name == "section-e-ss"):
                                                        if (self.section_e_ss is None):
                                                            self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionESs()
                                                            self.section_e_ss.parent = self
                                                            self._children_name_map["section_e_ss"] = "section-e-ss"
                                                        return self.section_e_ss

                                                    if (child_yang_name == "section-es-rs"):
                                                        if (self.section_es_rs is None):
                                                            self.section_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionEsRs()
                                                            self.section_es_rs.parent = self
                                                            self._children_name_map["section_es_rs"] = "section-es-rs"
                                                        return self.section_es_rs

                                                    if (child_yang_name == "section-se-ss"):
                                                        if (self.section_se_ss is None):
                                                            self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSeSs()
                                                            self.section_se_ss.parent = self
                                                            self._children_name_map["section_se_ss"] = "section-se-ss"
                                                        return self.section_se_ss

                                                    if (child_yang_name == "section-ses-rs"):
                                                        if (self.section_ses_rs is None):
                                                            self.section_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionSesRs()
                                                            self.section_ses_rs.parent = self
                                                            self._children_name_map["section_ses_rs"] = "section-ses-rs"
                                                        return self.section_ses_rs

                                                    if (child_yang_name == "section-ua-ss"):
                                                        if (self.section_ua_ss is None):
                                                            self.section_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section.SectionUaSs()
                                                            self.section_ua_ss.parent = self
                                                            self._children_name_map["section_ua_ss"] = "section-ua-ss"
                                                        return self.section_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "section-bb-es" or name == "section-bbe-rs" or name == "section-e-bs" or name == "section-e-ss" or name == "section-es-rs" or name == "section-se-ss" or name == "section-ses-rs" or name == "section-ua-ss" or name == "section-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "section-status"):
                                                        self.section_status = value
                                                        self.section_status.value_namespace = name_space
                                                        self.section_status.value_namespace_prefix = name_space_prefix


                                            class Line(Entity):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_bb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`LineBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbEs>`
                                                
                                                .. attribute:: line_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`LineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbeRs>`
                                                
                                                .. attribute:: line_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:   :py:class:`LineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEBs>`
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:   :py:class:`LineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEsRs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:   :py:class:`LineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSesRs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line, self).__init__()

                                                    self.yang_name = "line"
                                                    self.yang_parent_name = "stm-hour24stm-time-line-instance"

                                                    self.line_status = YLeaf(YType.int32, "line-status")

                                                    self.line_bb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbEs()
                                                    self.line_bb_es.parent = self
                                                    self._children_name_map["line_bb_es"] = "line-bb-es"
                                                    self._children_yang_names.add("line-bb-es")

                                                    self.line_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbeRs()
                                                    self.line_bbe_rs.parent = self
                                                    self._children_name_map["line_bbe_rs"] = "line-bbe-rs"
                                                    self._children_yang_names.add("line-bbe-rs")

                                                    self.line_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEBs()
                                                    self.line_e_bs.parent = self
                                                    self._children_name_map["line_e_bs"] = "line-e-bs"
                                                    self._children_yang_names.add("line-e-bs")

                                                    self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self._children_name_map["line_e_ss"] = "line-e-ss"
                                                    self._children_yang_names.add("line-e-ss")

                                                    self.line_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEsRs()
                                                    self.line_es_rs.parent = self
                                                    self._children_name_map["line_es_rs"] = "line-es-rs"
                                                    self._children_yang_names.add("line-es-rs")

                                                    self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self._children_name_map["line_se_ss"] = "line-se-ss"
                                                    self._children_yang_names.add("line-se-ss")

                                                    self.line_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSesRs()
                                                    self.line_ses_rs.parent = self
                                                    self._children_name_map["line_ses_rs"] = "line-ses-rs"
                                                    self._children_yang_names.add("line-ses-rs")

                                                    self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self
                                                    self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                                    self._children_yang_names.add("line-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("line_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line, self).__setattr__(name, value)


                                                class LineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineESs, self).__init__()

                                                        self.yang_name = "line-e-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEsRs, self).__init__()

                                                        self.yang_name = "line-es-rs"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEsRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEsRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-es-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineBbEs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbEs, self).__init__()

                                                        self.yang_name = "line-bb-es"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbEs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbEs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-bb-es" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineBbeRs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbeRs, self).__init__()

                                                        self.yang_name = "line-bbe-rs"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbeRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbeRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-bbe-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSeSs, self).__init__()

                                                        self.yang_name = "line-se-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSesRs, self).__init__()

                                                        self.yang_name = "line-ses-rs"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSesRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSesRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-ses-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineUaSs, self).__init__()

                                                        self.yang_name = "line-ua-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineEBs(Entity):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEBs, self).__init__()

                                                        self.yang_name = "line-e-bs"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEBs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEBs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-e-bs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.line_status.is_set or
                                                        (self.line_bb_es is not None and self.line_bb_es.has_data()) or
                                                        (self.line_bbe_rs is not None and self.line_bbe_rs.has_data()) or
                                                        (self.line_e_bs is not None and self.line_e_bs.has_data()) or
                                                        (self.line_e_ss is not None and self.line_e_ss.has_data()) or
                                                        (self.line_es_rs is not None and self.line_es_rs.has_data()) or
                                                        (self.line_se_ss is not None and self.line_se_ss.has_data()) or
                                                        (self.line_ses_rs is not None and self.line_ses_rs.has_data()) or
                                                        (self.line_ua_ss is not None and self.line_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.line_status.yfilter != YFilter.not_set or
                                                        (self.line_bb_es is not None and self.line_bb_es.has_operation()) or
                                                        (self.line_bbe_rs is not None and self.line_bbe_rs.has_operation()) or
                                                        (self.line_e_bs is not None and self.line_e_bs.has_operation()) or
                                                        (self.line_e_ss is not None and self.line_e_ss.has_operation()) or
                                                        (self.line_es_rs is not None and self.line_es_rs.has_operation()) or
                                                        (self.line_se_ss is not None and self.line_se_ss.has_operation()) or
                                                        (self.line_ses_rs is not None and self.line_ses_rs.has_operation()) or
                                                        (self.line_ua_ss is not None and self.line_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "line" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.line_status.is_set or self.line_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.line_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "line-bb-es"):
                                                        if (self.line_bb_es is None):
                                                            self.line_bb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbEs()
                                                            self.line_bb_es.parent = self
                                                            self._children_name_map["line_bb_es"] = "line-bb-es"
                                                        return self.line_bb_es

                                                    if (child_yang_name == "line-bbe-rs"):
                                                        if (self.line_bbe_rs is None):
                                                            self.line_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineBbeRs()
                                                            self.line_bbe_rs.parent = self
                                                            self._children_name_map["line_bbe_rs"] = "line-bbe-rs"
                                                        return self.line_bbe_rs

                                                    if (child_yang_name == "line-e-bs"):
                                                        if (self.line_e_bs is None):
                                                            self.line_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEBs()
                                                            self.line_e_bs.parent = self
                                                            self._children_name_map["line_e_bs"] = "line-e-bs"
                                                        return self.line_e_bs

                                                    if (child_yang_name == "line-e-ss"):
                                                        if (self.line_e_ss is None):
                                                            self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineESs()
                                                            self.line_e_ss.parent = self
                                                            self._children_name_map["line_e_ss"] = "line-e-ss"
                                                        return self.line_e_ss

                                                    if (child_yang_name == "line-es-rs"):
                                                        if (self.line_es_rs is None):
                                                            self.line_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineEsRs()
                                                            self.line_es_rs.parent = self
                                                            self._children_name_map["line_es_rs"] = "line-es-rs"
                                                        return self.line_es_rs

                                                    if (child_yang_name == "line-se-ss"):
                                                        if (self.line_se_ss is None):
                                                            self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSeSs()
                                                            self.line_se_ss.parent = self
                                                            self._children_name_map["line_se_ss"] = "line-se-ss"
                                                        return self.line_se_ss

                                                    if (child_yang_name == "line-ses-rs"):
                                                        if (self.line_ses_rs is None):
                                                            self.line_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineSesRs()
                                                            self.line_ses_rs.parent = self
                                                            self._children_name_map["line_ses_rs"] = "line-ses-rs"
                                                        return self.line_ses_rs

                                                    if (child_yang_name == "line-ua-ss"):
                                                        if (self.line_ua_ss is None):
                                                            self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line.LineUaSs()
                                                            self.line_ua_ss.parent = self
                                                            self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                                        return self.line_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "line-bb-es" or name == "line-bbe-rs" or name == "line-e-bs" or name == "line-e-ss" or name == "line-es-rs" or name == "line-se-ss" or name == "line-ses-rs" or name == "line-ua-ss" or name == "line-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "line-status"):
                                                        self.line_status = value
                                                        self.line_status.value_namespace = name_space
                                                        self.line_status.value_namespace_prefix = name_space_prefix


                                            class FeLine(Entity):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`FarEndLineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineBbeRs>`
                                                
                                                .. attribute:: far_end_line_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:   :py:class:`FarEndLineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEBs>`
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_ebb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`FarEndLineEbbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEbbEs>`
                                                
                                                .. attribute:: far_end_line_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:   :py:class:`FarEndLineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEsRs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:   :py:class:`FarEndLineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSesRs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine, self).__init__()

                                                    self.yang_name = "fe-line"
                                                    self.yang_parent_name = "stm-hour24stm-time-line-instance"

                                                    self.far_end_line_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineBbeRs()
                                                    self.far_end_line_bbe_rs.parent = self
                                                    self._children_name_map["far_end_line_bbe_rs"] = "far-end-line-bbe-rs"
                                                    self._children_yang_names.add("far-end-line-bbe-rs")

                                                    self.far_end_line_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEBs()
                                                    self.far_end_line_e_bs.parent = self
                                                    self._children_name_map["far_end_line_e_bs"] = "far-end-line-e-bs"
                                                    self._children_yang_names.add("far-end-line-e-bs")

                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                                    self._children_yang_names.add("far-end-line-e-ss")

                                                    self.far_end_line_ebb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEbbEs()
                                                    self.far_end_line_ebb_es.parent = self
                                                    self._children_name_map["far_end_line_ebb_es"] = "far-end-line-ebb-es"
                                                    self._children_yang_names.add("far-end-line-ebb-es")

                                                    self.far_end_line_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEsRs()
                                                    self.far_end_line_es_rs.parent = self
                                                    self._children_name_map["far_end_line_es_rs"] = "far-end-line-es-rs"
                                                    self._children_yang_names.add("far-end-line-es-rs")

                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                                    self._children_yang_names.add("far-end-line-se-ss")

                                                    self.far_end_line_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSesRs()
                                                    self.far_end_line_ses_rs.parent = self
                                                    self._children_name_map["far_end_line_ses_rs"] = "far-end-line-ses-rs"
                                                    self._children_yang_names.add("far-end-line-ses-rs")

                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self
                                                    self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                                    self._children_yang_names.add("far-end-line-ua-ss")


                                                class FarEndLineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineESs, self).__init__()

                                                        self.yang_name = "far-end-line-e-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEsRs, self).__init__()

                                                        self.yang_name = "far-end-line-es-rs"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEsRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEsRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-es-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineEbbEs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEbbEs, self).__init__()

                                                        self.yang_name = "far-end-line-ebb-es"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEbbEs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEbbEs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-ebb-es" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineBbeRs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineBbeRs, self).__init__()

                                                        self.yang_name = "far-end-line-bbe-rs"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineBbeRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineBbeRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-bbe-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSeSs, self).__init__()

                                                        self.yang_name = "far-end-line-se-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSesRs, self).__init__()

                                                        self.yang_name = "far-end-line-ses-rs"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSesRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSesRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-ses-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineUaSs, self).__init__()

                                                        self.yang_name = "far-end-line-ua-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineEBs(Entity):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEBs, self).__init__()

                                                        self.yang_name = "far-end-line-e-bs"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEBs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEBs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-e-bs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        (self.far_end_line_bbe_rs is not None and self.far_end_line_bbe_rs.has_data()) or
                                                        (self.far_end_line_e_bs is not None and self.far_end_line_e_bs.has_data()) or
                                                        (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_data()) or
                                                        (self.far_end_line_ebb_es is not None and self.far_end_line_ebb_es.has_data()) or
                                                        (self.far_end_line_es_rs is not None and self.far_end_line_es_rs.has_data()) or
                                                        (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_data()) or
                                                        (self.far_end_line_ses_rs is not None and self.far_end_line_ses_rs.has_data()) or
                                                        (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.far_end_line_bbe_rs is not None and self.far_end_line_bbe_rs.has_operation()) or
                                                        (self.far_end_line_e_bs is not None and self.far_end_line_e_bs.has_operation()) or
                                                        (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_operation()) or
                                                        (self.far_end_line_ebb_es is not None and self.far_end_line_ebb_es.has_operation()) or
                                                        (self.far_end_line_es_rs is not None and self.far_end_line_es_rs.has_operation()) or
                                                        (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_operation()) or
                                                        (self.far_end_line_ses_rs is not None and self.far_end_line_ses_rs.has_operation()) or
                                                        (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fe-line" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "far-end-line-bbe-rs"):
                                                        if (self.far_end_line_bbe_rs is None):
                                                            self.far_end_line_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineBbeRs()
                                                            self.far_end_line_bbe_rs.parent = self
                                                            self._children_name_map["far_end_line_bbe_rs"] = "far-end-line-bbe-rs"
                                                        return self.far_end_line_bbe_rs

                                                    if (child_yang_name == "far-end-line-e-bs"):
                                                        if (self.far_end_line_e_bs is None):
                                                            self.far_end_line_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEBs()
                                                            self.far_end_line_e_bs.parent = self
                                                            self._children_name_map["far_end_line_e_bs"] = "far-end-line-e-bs"
                                                        return self.far_end_line_e_bs

                                                    if (child_yang_name == "far-end-line-e-ss"):
                                                        if (self.far_end_line_e_ss is None):
                                                            self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineESs()
                                                            self.far_end_line_e_ss.parent = self
                                                            self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                                        return self.far_end_line_e_ss

                                                    if (child_yang_name == "far-end-line-ebb-es"):
                                                        if (self.far_end_line_ebb_es is None):
                                                            self.far_end_line_ebb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEbbEs()
                                                            self.far_end_line_ebb_es.parent = self
                                                            self._children_name_map["far_end_line_ebb_es"] = "far-end-line-ebb-es"
                                                        return self.far_end_line_ebb_es

                                                    if (child_yang_name == "far-end-line-es-rs"):
                                                        if (self.far_end_line_es_rs is None):
                                                            self.far_end_line_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineEsRs()
                                                            self.far_end_line_es_rs.parent = self
                                                            self._children_name_map["far_end_line_es_rs"] = "far-end-line-es-rs"
                                                        return self.far_end_line_es_rs

                                                    if (child_yang_name == "far-end-line-se-ss"):
                                                        if (self.far_end_line_se_ss is None):
                                                            self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSeSs()
                                                            self.far_end_line_se_ss.parent = self
                                                            self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                                        return self.far_end_line_se_ss

                                                    if (child_yang_name == "far-end-line-ses-rs"):
                                                        if (self.far_end_line_ses_rs is None):
                                                            self.far_end_line_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineSesRs()
                                                            self.far_end_line_ses_rs.parent = self
                                                            self._children_name_map["far_end_line_ses_rs"] = "far-end-line-ses-rs"
                                                        return self.far_end_line_ses_rs

                                                    if (child_yang_name == "far-end-line-ua-ss"):
                                                        if (self.far_end_line_ua_ss is None):
                                                            self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine.FarEndLineUaSs()
                                                            self.far_end_line_ua_ss.parent = self
                                                            self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                                        return self.far_end_line_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "far-end-line-bbe-rs" or name == "far-end-line-e-bs" or name == "far-end-line-e-ss" or name == "far-end-line-ebb-es" or name == "far-end-line-es-rs" or name == "far-end-line-se-ss" or name == "far-end-line-ses-rs" or name == "far-end-line-ua-ss"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.fe_line is not None and self.fe_line.has_data()) or
                                                    (self.line is not None and self.line.has_data()) or
                                                    (self.section is not None and self.section.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.fe_line is not None and self.fe_line.has_operation()) or
                                                    (self.line is not None and self.line.has_operation()) or
                                                    (self.section is not None and self.section.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "stm-hour24stm-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "fe-line"):
                                                    if (self.fe_line is None):
                                                        self.fe_line = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.FeLine()
                                                        self.fe_line.parent = self
                                                        self._children_name_map["fe_line"] = "fe-line"
                                                    return self.fe_line

                                                if (child_yang_name == "line"):
                                                    if (self.line is None):
                                                        self.line = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Line()
                                                        self.line.parent = self
                                                        self._children_name_map["line"] = "line"
                                                    return self.line

                                                if (child_yang_name == "section"):
                                                    if (self.section is None):
                                                        self.section = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance.Section()
                                                        self.section.parent = self
                                                        self._children_name_map["section"] = "section"
                                                    return self.section

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "fe-line" or name == "line" or name == "section" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.stm_hour24stm_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.stm_hour24stm_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "stm-hour24stm-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "stm-hour24stm-time-line-instance"):
                                                for c in self.stm_hour24stm_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances.StmHour24StmTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.stm_hour24stm_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "stm-hour24stm-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.stm_hour24stm_time_line_instances is not None and self.stm_hour24stm_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.stm_hour24stm_time_line_instances is not None and self.stm_hour24stm_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "stm-hour24stm-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "stm-hour24stm-time-line-instances"):
                                            if (self.stm_hour24stm_time_line_instances is None):
                                                self.stm_hour24stm_time_line_instances = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory.StmHour24StmTimeLineInstances()
                                                self.stm_hour24stm_time_line_instances.parent = self
                                                self._children_name_map["stm_hour24stm_time_line_instances"] = "stm-hour24stm-time-line-instances"
                                            return self.stm_hour24stm_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "stm-hour24stm-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.stm_hour24stm_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.stm_hour24stm_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "stm-hour24stm-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "stm-hour24stm-history"):
                                        for c in self.stm_hour24stm_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories.StmHour24StmHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.stm_hour24stm_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "stm-hour24stm-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.stm_hour24stm_histories is not None and self.stm_hour24stm_histories.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.stm_hour24stm_histories is not None and self.stm_hour24stm_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "stm-hour24-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "stm-hour24stm-histories"):
                                    if (self.stm_hour24stm_histories is None):
                                        self.stm_hour24stm_histories = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History.StmHour24StmHistories()
                                        self.stm_hour24stm_histories.parent = self
                                        self._children_name_map["stm_hour24stm_histories"] = "stm-hour24stm-histories"
                                    return self.stm_hour24stm_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "stm-hour24stm-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class StmMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: stm_minute15stm_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`StmMinute15StmHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History, self).__init__()

                                self.yang_name = "stm-minute15-history"
                                self.yang_parent_name = "stm-port-history"

                                self.stm_minute15stm_histories = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories()
                                self.stm_minute15stm_histories.parent = self
                                self._children_name_map["stm_minute15stm_histories"] = "stm-minute15stm-histories"
                                self._children_yang_names.add("stm-minute15stm-histories")


                            class StmMinute15StmHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: stm_minute15stm_history
                                
                                	port 15\-minute stm performance data
                                	**type**\: list of    :py:class:`StmMinute15StmHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories, self).__init__()

                                    self.yang_name = "stm-minute15stm-histories"
                                    self.yang_parent_name = "stm-minute15-history"

                                    self.stm_minute15stm_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories, self).__setattr__(name, value)


                                class StmMinute15StmHistory(Entity):
                                    """
                                    port 15\-minute stm performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: stm_minute15stm_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`StmMinute15StmTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory, self).__init__()

                                        self.yang_name = "stm-minute15stm-history"
                                        self.yang_parent_name = "stm-minute15stm-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.stm_minute15stm_time_line_instances = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances()
                                        self.stm_minute15stm_time_line_instances.parent = self
                                        self._children_name_map["stm_minute15stm_time_line_instances"] = "stm-minute15stm-time-line-instances"
                                        self._children_yang_names.add("stm-minute15stm-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory, self).__setattr__(name, value)


                                    class StmMinute15StmTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: stm_minute15stm_time_line_instance
                                        
                                        	port 15\-minute stm performance data
                                        	**type**\: list of    :py:class:`StmMinute15StmTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances, self).__init__()

                                            self.yang_name = "stm-minute15stm-time-line-instances"
                                            self.yang_parent_name = "stm-minute15stm-history"

                                            self.stm_minute15stm_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances, self).__setattr__(name, value)


                                        class StmMinute15StmTimeLineInstance(Entity):
                                            """
                                            port 15\-minute stm performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line>`
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance, self).__init__()

                                                self.yang_name = "stm-minute15stm-time-line-instance"
                                                self.yang_parent_name = "stm-minute15stm-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.fe_line = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self._children_name_map["fe_line"] = "fe-line"
                                                self._children_yang_names.add("fe-line")

                                                self.line = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line()
                                                self.line.parent = self
                                                self._children_name_map["line"] = "line"
                                                self._children_yang_names.add("line")

                                                self.section = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section()
                                                self.section.parent = self
                                                self._children_name_map["section"] = "section"
                                                self._children_yang_names.add("section")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance, self).__setattr__(name, value)


                                            class Section(Entity):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_bb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`SectionBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbEs>`
                                                
                                                .. attribute:: section_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`SectionBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbeRs>`
                                                
                                                .. attribute:: section_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:   :py:class:`SectionEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEBs>`
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:   :py:class:`SectionEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEsRs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:   :py:class:`SectionSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSesRs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: section_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:   :py:class:`SectionUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section, self).__init__()

                                                    self.yang_name = "section"
                                                    self.yang_parent_name = "stm-minute15stm-time-line-instance"

                                                    self.section_status = YLeaf(YType.int32, "section-status")

                                                    self.section_bb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbEs()
                                                    self.section_bb_es.parent = self
                                                    self._children_name_map["section_bb_es"] = "section-bb-es"
                                                    self._children_yang_names.add("section-bb-es")

                                                    self.section_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbeRs()
                                                    self.section_bbe_rs.parent = self
                                                    self._children_name_map["section_bbe_rs"] = "section-bbe-rs"
                                                    self._children_yang_names.add("section-bbe-rs")

                                                    self.section_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEBs()
                                                    self.section_e_bs.parent = self
                                                    self._children_name_map["section_e_bs"] = "section-e-bs"
                                                    self._children_yang_names.add("section-e-bs")

                                                    self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self._children_name_map["section_e_ss"] = "section-e-ss"
                                                    self._children_yang_names.add("section-e-ss")

                                                    self.section_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEsRs()
                                                    self.section_es_rs.parent = self
                                                    self._children_name_map["section_es_rs"] = "section-es-rs"
                                                    self._children_yang_names.add("section-es-rs")

                                                    self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self._children_name_map["section_se_ss"] = "section-se-ss"
                                                    self._children_yang_names.add("section-se-ss")

                                                    self.section_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSesRs()
                                                    self.section_ses_rs.parent = self
                                                    self._children_name_map["section_ses_rs"] = "section-ses-rs"
                                                    self._children_yang_names.add("section-ses-rs")

                                                    self.section_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionUaSs()
                                                    self.section_ua_ss.parent = self
                                                    self._children_name_map["section_ua_ss"] = "section-ua-ss"
                                                    self._children_yang_names.add("section-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("section_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section, self).__setattr__(name, value)


                                                class SectionESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionESs, self).__init__()

                                                        self.yang_name = "section-e-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEsRs, self).__init__()

                                                        self.yang_name = "section-es-rs"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEsRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEsRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-es-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionBbEs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbEs, self).__init__()

                                                        self.yang_name = "section-bb-es"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbEs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbEs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-bb-es" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionBbeRs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbeRs, self).__init__()

                                                        self.yang_name = "section-bbe-rs"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbeRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbeRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-bbe-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSeSs, self).__init__()

                                                        self.yang_name = "section-se-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSesRs, self).__init__()

                                                        self.yang_name = "section-ses-rs"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSesRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSesRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-ses-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionUaSs(Entity):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionUaSs, self).__init__()

                                                        self.yang_name = "section-ua-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionEBs(Entity):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEBs, self).__init__()

                                                        self.yang_name = "section-e-bs"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEBs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEBs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-e-bs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.section_status.is_set or
                                                        (self.section_bb_es is not None and self.section_bb_es.has_data()) or
                                                        (self.section_bbe_rs is not None and self.section_bbe_rs.has_data()) or
                                                        (self.section_e_bs is not None and self.section_e_bs.has_data()) or
                                                        (self.section_e_ss is not None and self.section_e_ss.has_data()) or
                                                        (self.section_es_rs is not None and self.section_es_rs.has_data()) or
                                                        (self.section_se_ss is not None and self.section_se_ss.has_data()) or
                                                        (self.section_ses_rs is not None and self.section_ses_rs.has_data()) or
                                                        (self.section_ua_ss is not None and self.section_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.section_status.yfilter != YFilter.not_set or
                                                        (self.section_bb_es is not None and self.section_bb_es.has_operation()) or
                                                        (self.section_bbe_rs is not None and self.section_bbe_rs.has_operation()) or
                                                        (self.section_e_bs is not None and self.section_e_bs.has_operation()) or
                                                        (self.section_e_ss is not None and self.section_e_ss.has_operation()) or
                                                        (self.section_es_rs is not None and self.section_es_rs.has_operation()) or
                                                        (self.section_se_ss is not None and self.section_se_ss.has_operation()) or
                                                        (self.section_ses_rs is not None and self.section_ses_rs.has_operation()) or
                                                        (self.section_ua_ss is not None and self.section_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "section" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.section_status.is_set or self.section_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.section_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "section-bb-es"):
                                                        if (self.section_bb_es is None):
                                                            self.section_bb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbEs()
                                                            self.section_bb_es.parent = self
                                                            self._children_name_map["section_bb_es"] = "section-bb-es"
                                                        return self.section_bb_es

                                                    if (child_yang_name == "section-bbe-rs"):
                                                        if (self.section_bbe_rs is None):
                                                            self.section_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionBbeRs()
                                                            self.section_bbe_rs.parent = self
                                                            self._children_name_map["section_bbe_rs"] = "section-bbe-rs"
                                                        return self.section_bbe_rs

                                                    if (child_yang_name == "section-e-bs"):
                                                        if (self.section_e_bs is None):
                                                            self.section_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEBs()
                                                            self.section_e_bs.parent = self
                                                            self._children_name_map["section_e_bs"] = "section-e-bs"
                                                        return self.section_e_bs

                                                    if (child_yang_name == "section-e-ss"):
                                                        if (self.section_e_ss is None):
                                                            self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionESs()
                                                            self.section_e_ss.parent = self
                                                            self._children_name_map["section_e_ss"] = "section-e-ss"
                                                        return self.section_e_ss

                                                    if (child_yang_name == "section-es-rs"):
                                                        if (self.section_es_rs is None):
                                                            self.section_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionEsRs()
                                                            self.section_es_rs.parent = self
                                                            self._children_name_map["section_es_rs"] = "section-es-rs"
                                                        return self.section_es_rs

                                                    if (child_yang_name == "section-se-ss"):
                                                        if (self.section_se_ss is None):
                                                            self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSeSs()
                                                            self.section_se_ss.parent = self
                                                            self._children_name_map["section_se_ss"] = "section-se-ss"
                                                        return self.section_se_ss

                                                    if (child_yang_name == "section-ses-rs"):
                                                        if (self.section_ses_rs is None):
                                                            self.section_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionSesRs()
                                                            self.section_ses_rs.parent = self
                                                            self._children_name_map["section_ses_rs"] = "section-ses-rs"
                                                        return self.section_ses_rs

                                                    if (child_yang_name == "section-ua-ss"):
                                                        if (self.section_ua_ss is None):
                                                            self.section_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section.SectionUaSs()
                                                            self.section_ua_ss.parent = self
                                                            self._children_name_map["section_ua_ss"] = "section-ua-ss"
                                                        return self.section_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "section-bb-es" or name == "section-bbe-rs" or name == "section-e-bs" or name == "section-e-ss" or name == "section-es-rs" or name == "section-se-ss" or name == "section-ses-rs" or name == "section-ua-ss" or name == "section-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "section-status"):
                                                        self.section_status = value
                                                        self.section_status.value_namespace = name_space
                                                        self.section_status.value_namespace_prefix = name_space_prefix


                                            class Line(Entity):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_bb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`LineBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbEs>`
                                                
                                                .. attribute:: line_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`LineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbeRs>`
                                                
                                                .. attribute:: line_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:   :py:class:`LineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEBs>`
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:   :py:class:`LineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEsRs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:   :py:class:`LineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSesRs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line, self).__init__()

                                                    self.yang_name = "line"
                                                    self.yang_parent_name = "stm-minute15stm-time-line-instance"

                                                    self.line_status = YLeaf(YType.int32, "line-status")

                                                    self.line_bb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbEs()
                                                    self.line_bb_es.parent = self
                                                    self._children_name_map["line_bb_es"] = "line-bb-es"
                                                    self._children_yang_names.add("line-bb-es")

                                                    self.line_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbeRs()
                                                    self.line_bbe_rs.parent = self
                                                    self._children_name_map["line_bbe_rs"] = "line-bbe-rs"
                                                    self._children_yang_names.add("line-bbe-rs")

                                                    self.line_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEBs()
                                                    self.line_e_bs.parent = self
                                                    self._children_name_map["line_e_bs"] = "line-e-bs"
                                                    self._children_yang_names.add("line-e-bs")

                                                    self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self._children_name_map["line_e_ss"] = "line-e-ss"
                                                    self._children_yang_names.add("line-e-ss")

                                                    self.line_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEsRs()
                                                    self.line_es_rs.parent = self
                                                    self._children_name_map["line_es_rs"] = "line-es-rs"
                                                    self._children_yang_names.add("line-es-rs")

                                                    self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self._children_name_map["line_se_ss"] = "line-se-ss"
                                                    self._children_yang_names.add("line-se-ss")

                                                    self.line_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSesRs()
                                                    self.line_ses_rs.parent = self
                                                    self._children_name_map["line_ses_rs"] = "line-ses-rs"
                                                    self._children_yang_names.add("line-ses-rs")

                                                    self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self
                                                    self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                                    self._children_yang_names.add("line-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("line_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line, self).__setattr__(name, value)


                                                class LineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineESs, self).__init__()

                                                        self.yang_name = "line-e-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEsRs, self).__init__()

                                                        self.yang_name = "line-es-rs"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEsRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEsRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-es-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineBbEs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbEs, self).__init__()

                                                        self.yang_name = "line-bb-es"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbEs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbEs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-bb-es" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineBbeRs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbeRs, self).__init__()

                                                        self.yang_name = "line-bbe-rs"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbeRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbeRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-bbe-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSeSs, self).__init__()

                                                        self.yang_name = "line-se-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSesRs, self).__init__()

                                                        self.yang_name = "line-ses-rs"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSesRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSesRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-ses-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineUaSs, self).__init__()

                                                        self.yang_name = "line-ua-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineEBs(Entity):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEBs, self).__init__()

                                                        self.yang_name = "line-e-bs"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEBs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEBs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-e-bs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.line_status.is_set or
                                                        (self.line_bb_es is not None and self.line_bb_es.has_data()) or
                                                        (self.line_bbe_rs is not None and self.line_bbe_rs.has_data()) or
                                                        (self.line_e_bs is not None and self.line_e_bs.has_data()) or
                                                        (self.line_e_ss is not None and self.line_e_ss.has_data()) or
                                                        (self.line_es_rs is not None and self.line_es_rs.has_data()) or
                                                        (self.line_se_ss is not None and self.line_se_ss.has_data()) or
                                                        (self.line_ses_rs is not None and self.line_ses_rs.has_data()) or
                                                        (self.line_ua_ss is not None and self.line_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.line_status.yfilter != YFilter.not_set or
                                                        (self.line_bb_es is not None and self.line_bb_es.has_operation()) or
                                                        (self.line_bbe_rs is not None and self.line_bbe_rs.has_operation()) or
                                                        (self.line_e_bs is not None and self.line_e_bs.has_operation()) or
                                                        (self.line_e_ss is not None and self.line_e_ss.has_operation()) or
                                                        (self.line_es_rs is not None and self.line_es_rs.has_operation()) or
                                                        (self.line_se_ss is not None and self.line_se_ss.has_operation()) or
                                                        (self.line_ses_rs is not None and self.line_ses_rs.has_operation()) or
                                                        (self.line_ua_ss is not None and self.line_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "line" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.line_status.is_set or self.line_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.line_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "line-bb-es"):
                                                        if (self.line_bb_es is None):
                                                            self.line_bb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbEs()
                                                            self.line_bb_es.parent = self
                                                            self._children_name_map["line_bb_es"] = "line-bb-es"
                                                        return self.line_bb_es

                                                    if (child_yang_name == "line-bbe-rs"):
                                                        if (self.line_bbe_rs is None):
                                                            self.line_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineBbeRs()
                                                            self.line_bbe_rs.parent = self
                                                            self._children_name_map["line_bbe_rs"] = "line-bbe-rs"
                                                        return self.line_bbe_rs

                                                    if (child_yang_name == "line-e-bs"):
                                                        if (self.line_e_bs is None):
                                                            self.line_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEBs()
                                                            self.line_e_bs.parent = self
                                                            self._children_name_map["line_e_bs"] = "line-e-bs"
                                                        return self.line_e_bs

                                                    if (child_yang_name == "line-e-ss"):
                                                        if (self.line_e_ss is None):
                                                            self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineESs()
                                                            self.line_e_ss.parent = self
                                                            self._children_name_map["line_e_ss"] = "line-e-ss"
                                                        return self.line_e_ss

                                                    if (child_yang_name == "line-es-rs"):
                                                        if (self.line_es_rs is None):
                                                            self.line_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineEsRs()
                                                            self.line_es_rs.parent = self
                                                            self._children_name_map["line_es_rs"] = "line-es-rs"
                                                        return self.line_es_rs

                                                    if (child_yang_name == "line-se-ss"):
                                                        if (self.line_se_ss is None):
                                                            self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSeSs()
                                                            self.line_se_ss.parent = self
                                                            self._children_name_map["line_se_ss"] = "line-se-ss"
                                                        return self.line_se_ss

                                                    if (child_yang_name == "line-ses-rs"):
                                                        if (self.line_ses_rs is None):
                                                            self.line_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineSesRs()
                                                            self.line_ses_rs.parent = self
                                                            self._children_name_map["line_ses_rs"] = "line-ses-rs"
                                                        return self.line_ses_rs

                                                    if (child_yang_name == "line-ua-ss"):
                                                        if (self.line_ua_ss is None):
                                                            self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line.LineUaSs()
                                                            self.line_ua_ss.parent = self
                                                            self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                                        return self.line_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "line-bb-es" or name == "line-bbe-rs" or name == "line-e-bs" or name == "line-e-ss" or name == "line-es-rs" or name == "line-se-ss" or name == "line-ses-rs" or name == "line-ua-ss" or name == "line-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "line-status"):
                                                        self.line_status = value
                                                        self.line_status.value_namespace = name_space
                                                        self.line_status.value_namespace_prefix = name_space_prefix


                                            class FeLine(Entity):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_bbe_rs
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`FarEndLineBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineBbeRs>`
                                                
                                                .. attribute:: far_end_line_e_bs
                                                
                                                	The number of Errored Block Second
                                                	**type**\:   :py:class:`FarEndLineEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEBs>`
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_ebb_es
                                                
                                                	The number of Background Block Errors
                                                	**type**\:   :py:class:`FarEndLineEbbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEbbEs>`
                                                
                                                .. attribute:: far_end_line_es_rs
                                                
                                                	The number of Errored Seconds Ratio
                                                	**type**\:   :py:class:`FarEndLineEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEsRs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Second
                                                	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ses_rs
                                                
                                                	The number of Severely Errored Second Ratio
                                                	**type**\:   :py:class:`FarEndLineSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSesRs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Second
                                                	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine, self).__init__()

                                                    self.yang_name = "fe-line"
                                                    self.yang_parent_name = "stm-minute15stm-time-line-instance"

                                                    self.far_end_line_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineBbeRs()
                                                    self.far_end_line_bbe_rs.parent = self
                                                    self._children_name_map["far_end_line_bbe_rs"] = "far-end-line-bbe-rs"
                                                    self._children_yang_names.add("far-end-line-bbe-rs")

                                                    self.far_end_line_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEBs()
                                                    self.far_end_line_e_bs.parent = self
                                                    self._children_name_map["far_end_line_e_bs"] = "far-end-line-e-bs"
                                                    self._children_yang_names.add("far-end-line-e-bs")

                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                                    self._children_yang_names.add("far-end-line-e-ss")

                                                    self.far_end_line_ebb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEbbEs()
                                                    self.far_end_line_ebb_es.parent = self
                                                    self._children_name_map["far_end_line_ebb_es"] = "far-end-line-ebb-es"
                                                    self._children_yang_names.add("far-end-line-ebb-es")

                                                    self.far_end_line_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEsRs()
                                                    self.far_end_line_es_rs.parent = self
                                                    self._children_name_map["far_end_line_es_rs"] = "far-end-line-es-rs"
                                                    self._children_yang_names.add("far-end-line-es-rs")

                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                                    self._children_yang_names.add("far-end-line-se-ss")

                                                    self.far_end_line_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSesRs()
                                                    self.far_end_line_ses_rs.parent = self
                                                    self._children_name_map["far_end_line_ses_rs"] = "far-end-line-ses-rs"
                                                    self._children_yang_names.add("far-end-line-ses-rs")

                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self
                                                    self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                                    self._children_yang_names.add("far-end-line-ua-ss")


                                                class FarEndLineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineESs, self).__init__()

                                                        self.yang_name = "far-end-line-e-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEsRs, self).__init__()

                                                        self.yang_name = "far-end-line-es-rs"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEsRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEsRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-es-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineEbbEs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEbbEs, self).__init__()

                                                        self.yang_name = "far-end-line-ebb-es"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEbbEs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEbbEs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-ebb-es" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineBbeRs(Entity):
                                                    """
                                                    The number of Background Block Errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineBbeRs, self).__init__()

                                                        self.yang_name = "far-end-line-bbe-rs"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineBbeRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineBbeRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-bbe-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSeSs, self).__init__()

                                                        self.yang_name = "far-end-line-se-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Second Ratio
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSesRs, self).__init__()

                                                        self.yang_name = "far-end-line-ses-rs"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSesRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSesRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-ses-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineUaSs, self).__init__()

                                                        self.yang_name = "far-end-line-ua-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineEBs(Entity):
                                                    """
                                                    The number of Errored Block Second
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEBs, self).__init__()

                                                        self.yang_name = "far-end-line-e-bs"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEBs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEBs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-e-bs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        (self.far_end_line_bbe_rs is not None and self.far_end_line_bbe_rs.has_data()) or
                                                        (self.far_end_line_e_bs is not None and self.far_end_line_e_bs.has_data()) or
                                                        (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_data()) or
                                                        (self.far_end_line_ebb_es is not None and self.far_end_line_ebb_es.has_data()) or
                                                        (self.far_end_line_es_rs is not None and self.far_end_line_es_rs.has_data()) or
                                                        (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_data()) or
                                                        (self.far_end_line_ses_rs is not None and self.far_end_line_ses_rs.has_data()) or
                                                        (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.far_end_line_bbe_rs is not None and self.far_end_line_bbe_rs.has_operation()) or
                                                        (self.far_end_line_e_bs is not None and self.far_end_line_e_bs.has_operation()) or
                                                        (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_operation()) or
                                                        (self.far_end_line_ebb_es is not None and self.far_end_line_ebb_es.has_operation()) or
                                                        (self.far_end_line_es_rs is not None and self.far_end_line_es_rs.has_operation()) or
                                                        (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_operation()) or
                                                        (self.far_end_line_ses_rs is not None and self.far_end_line_ses_rs.has_operation()) or
                                                        (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fe-line" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "far-end-line-bbe-rs"):
                                                        if (self.far_end_line_bbe_rs is None):
                                                            self.far_end_line_bbe_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineBbeRs()
                                                            self.far_end_line_bbe_rs.parent = self
                                                            self._children_name_map["far_end_line_bbe_rs"] = "far-end-line-bbe-rs"
                                                        return self.far_end_line_bbe_rs

                                                    if (child_yang_name == "far-end-line-e-bs"):
                                                        if (self.far_end_line_e_bs is None):
                                                            self.far_end_line_e_bs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEBs()
                                                            self.far_end_line_e_bs.parent = self
                                                            self._children_name_map["far_end_line_e_bs"] = "far-end-line-e-bs"
                                                        return self.far_end_line_e_bs

                                                    if (child_yang_name == "far-end-line-e-ss"):
                                                        if (self.far_end_line_e_ss is None):
                                                            self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineESs()
                                                            self.far_end_line_e_ss.parent = self
                                                            self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                                        return self.far_end_line_e_ss

                                                    if (child_yang_name == "far-end-line-ebb-es"):
                                                        if (self.far_end_line_ebb_es is None):
                                                            self.far_end_line_ebb_es = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEbbEs()
                                                            self.far_end_line_ebb_es.parent = self
                                                            self._children_name_map["far_end_line_ebb_es"] = "far-end-line-ebb-es"
                                                        return self.far_end_line_ebb_es

                                                    if (child_yang_name == "far-end-line-es-rs"):
                                                        if (self.far_end_line_es_rs is None):
                                                            self.far_end_line_es_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineEsRs()
                                                            self.far_end_line_es_rs.parent = self
                                                            self._children_name_map["far_end_line_es_rs"] = "far-end-line-es-rs"
                                                        return self.far_end_line_es_rs

                                                    if (child_yang_name == "far-end-line-se-ss"):
                                                        if (self.far_end_line_se_ss is None):
                                                            self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSeSs()
                                                            self.far_end_line_se_ss.parent = self
                                                            self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                                        return self.far_end_line_se_ss

                                                    if (child_yang_name == "far-end-line-ses-rs"):
                                                        if (self.far_end_line_ses_rs is None):
                                                            self.far_end_line_ses_rs = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineSesRs()
                                                            self.far_end_line_ses_rs.parent = self
                                                            self._children_name_map["far_end_line_ses_rs"] = "far-end-line-ses-rs"
                                                        return self.far_end_line_ses_rs

                                                    if (child_yang_name == "far-end-line-ua-ss"):
                                                        if (self.far_end_line_ua_ss is None):
                                                            self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine.FarEndLineUaSs()
                                                            self.far_end_line_ua_ss.parent = self
                                                            self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                                        return self.far_end_line_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "far-end-line-bbe-rs" or name == "far-end-line-e-bs" or name == "far-end-line-e-ss" or name == "far-end-line-ebb-es" or name == "far-end-line-es-rs" or name == "far-end-line-se-ss" or name == "far-end-line-ses-rs" or name == "far-end-line-ua-ss"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.fe_line is not None and self.fe_line.has_data()) or
                                                    (self.line is not None and self.line.has_data()) or
                                                    (self.section is not None and self.section.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.fe_line is not None and self.fe_line.has_operation()) or
                                                    (self.line is not None and self.line.has_operation()) or
                                                    (self.section is not None and self.section.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "stm-minute15stm-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "fe-line"):
                                                    if (self.fe_line is None):
                                                        self.fe_line = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.FeLine()
                                                        self.fe_line.parent = self
                                                        self._children_name_map["fe_line"] = "fe-line"
                                                    return self.fe_line

                                                if (child_yang_name == "line"):
                                                    if (self.line is None):
                                                        self.line = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Line()
                                                        self.line.parent = self
                                                        self._children_name_map["line"] = "line"
                                                    return self.line

                                                if (child_yang_name == "section"):
                                                    if (self.section is None):
                                                        self.section = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance.Section()
                                                        self.section.parent = self
                                                        self._children_name_map["section"] = "section"
                                                    return self.section

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "fe-line" or name == "line" or name == "section" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.stm_minute15stm_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.stm_minute15stm_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "stm-minute15stm-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "stm-minute15stm-time-line-instance"):
                                                for c in self.stm_minute15stm_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances.StmMinute15StmTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.stm_minute15stm_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "stm-minute15stm-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.stm_minute15stm_time_line_instances is not None and self.stm_minute15stm_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.stm_minute15stm_time_line_instances is not None and self.stm_minute15stm_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "stm-minute15stm-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "stm-minute15stm-time-line-instances"):
                                            if (self.stm_minute15stm_time_line_instances is None):
                                                self.stm_minute15stm_time_line_instances = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory.StmMinute15StmTimeLineInstances()
                                                self.stm_minute15stm_time_line_instances.parent = self
                                                self._children_name_map["stm_minute15stm_time_line_instances"] = "stm-minute15stm-time-line-instances"
                                            return self.stm_minute15stm_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "stm-minute15stm-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.stm_minute15stm_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.stm_minute15stm_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "stm-minute15stm-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "stm-minute15stm-history"):
                                        for c in self.stm_minute15stm_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories.StmMinute15StmHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.stm_minute15stm_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "stm-minute15stm-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.stm_minute15stm_histories is not None and self.stm_minute15stm_histories.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.stm_minute15stm_histories is not None and self.stm_minute15stm_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "stm-minute15-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "stm-minute15stm-histories"):
                                    if (self.stm_minute15stm_histories is None):
                                        self.stm_minute15stm_histories = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History.StmMinute15StmHistories()
                                        self.stm_minute15stm_histories.parent = self
                                        self._children_name_map["stm_minute15stm_histories"] = "stm-minute15stm-histories"
                                    return self.stm_minute15stm_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "stm-minute15stm-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.name.is_set or
                                (self.stm_hour24_history is not None and self.stm_hour24_history.has_data()) or
                                (self.stm_minute15_history is not None and self.stm_minute15_history.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                (self.stm_hour24_history is not None and self.stm_hour24_history.has_operation()) or
                                (self.stm_minute15_history is not None and self.stm_minute15_history.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "stm-port-history" + "[name='" + self.name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/stm-history/stm-port-histories/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "stm-hour24-history"):
                                if (self.stm_hour24_history is None):
                                    self.stm_hour24_history = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmHour24History()
                                    self.stm_hour24_history.parent = self
                                    self._children_name_map["stm_hour24_history"] = "stm-hour24-history"
                                return self.stm_hour24_history

                            if (child_yang_name == "stm-minute15-history"):
                                if (self.stm_minute15_history is None):
                                    self.stm_minute15_history = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory.StmMinute15History()
                                    self.stm_minute15_history.parent = self
                                    self._children_name_map["stm_minute15_history"] = "stm-minute15-history"
                                return self.stm_minute15_history

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "stm-hour24-history" or name == "stm-minute15-history" or name == "name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.stm_port_history:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.stm_port_history:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "stm-port-histories" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/stm-history/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "stm-port-history"):
                            for c in self.stm_port_history:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories.StmPortHistory()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.stm_port_history.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "stm-port-history"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.stm_port_histories is not None and self.stm_port_histories.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.stm_port_histories is not None and self.stm_port_histories.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "stm-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "stm-port-histories"):
                        if (self.stm_port_histories is None):
                            self.stm_port_histories = PerformanceManagementHistory.Global_.Periodic.StmHistory.StmPortHistories()
                            self.stm_port_histories.parent = self
                            self._children_name_map["stm_port_histories"] = "stm-port-histories"
                        return self.stm_port_histories

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "stm-port-histories"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class OduHistory(Entity):
                """
                ODU controller History performance data
                
                .. attribute:: odu_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`OduPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory, self).__init__()

                    self.yang_name = "odu-history"
                    self.yang_parent_name = "periodic"

                    self.odu_port_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories()
                    self.odu_port_histories.parent = self
                    self._children_name_map["odu_port_histories"] = "odu-port-histories"
                    self._children_yang_names.add("odu-port-histories")


                class OduPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: odu_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`OduPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories, self).__init__()

                        self.yang_name = "odu-port-histories"
                        self.yang_parent_name = "odu-history"

                        self.odu_port_history = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories, self).__setattr__(name, value)


                    class OduPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: odu_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OduHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History>`
                        
                        .. attribute:: odu_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OduMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory, self).__init__()

                            self.yang_name = "odu-port-history"
                            self.yang_parent_name = "odu-port-histories"

                            self.name = YLeaf(YType.str, "name")

                            self.odu_hour24_history = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History()
                            self.odu_hour24_history.parent = self
                            self._children_name_map["odu_hour24_history"] = "odu-hour24-history"
                            self._children_yang_names.add("odu-hour24-history")

                            self.odu_minute15_history = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History()
                            self.odu_minute15_history.parent = self
                            self._children_name_map["odu_minute15_history"] = "odu-minute15-history"
                            self._children_yang_names.add("odu-minute15-history")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory, self).__setattr__(name, value)


                        class OduHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: odu_hour24gfp_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`OduHour24GfpHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories>`
                            
                            .. attribute:: odu_hour24otn_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`OduHour24OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories>`
                            
                            .. attribute:: odu_hour24prbs_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`OduHour24PrbsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History, self).__init__()

                                self.yang_name = "odu-hour24-history"
                                self.yang_parent_name = "odu-port-history"

                                self.odu_hour24gfp_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories()
                                self.odu_hour24gfp_histories.parent = self
                                self._children_name_map["odu_hour24gfp_histories"] = "odu-hour24gfp-histories"
                                self._children_yang_names.add("odu-hour24gfp-histories")

                                self.odu_hour24otn_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories()
                                self.odu_hour24otn_histories.parent = self
                                self._children_name_map["odu_hour24otn_histories"] = "odu-hour24otn-histories"
                                self._children_yang_names.add("odu-hour24otn-histories")

                                self.odu_hour24prbs_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories()
                                self.odu_hour24prbs_histories.parent = self
                                self._children_name_map["odu_hour24prbs_histories"] = "odu-hour24prbs-histories"
                                self._children_yang_names.add("odu-hour24prbs-histories")


                            class OduHour24GfpHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: odu_hour24gfp_history
                                
                                	port 24 hour otn performance data
                                	**type**\: list of    :py:class:`OduHour24GfpHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories, self).__init__()

                                    self.yang_name = "odu-hour24gfp-histories"
                                    self.yang_parent_name = "odu-hour24-history"

                                    self.odu_hour24gfp_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories, self).__setattr__(name, value)


                                class OduHour24GfpHistory(Entity):
                                    """
                                    port 24 hour otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: odu_hour24gfp_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OduHour24GfpTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory, self).__init__()

                                        self.yang_name = "odu-hour24gfp-history"
                                        self.yang_parent_name = "odu-hour24gfp-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.odu_hour24gfp_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances()
                                        self.odu_hour24gfp_time_line_instances.parent = self
                                        self._children_name_map["odu_hour24gfp_time_line_instances"] = "odu-hour24gfp-time-line-instances"
                                        self._children_yang_names.add("odu-hour24gfp-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory, self).__setattr__(name, value)


                                    class OduHour24GfpTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_hour24gfp_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OduHour24GfpTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances, self).__init__()

                                            self.yang_name = "odu-hour24gfp-time-line-instances"
                                            self.yang_parent_name = "odu-hour24gfp-history"

                                            self.odu_hour24gfp_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances, self).__setattr__(name, value)


                                        class OduHour24GfpTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: rx_bit_err
                                            
                                            	RX BIT ERR
                                            	**type**\:   :py:class:`RxBitErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxBitErr>`
                                            
                                            .. attribute:: rx_crc
                                            
                                            	RX CRC
                                            	**type**\:   :py:class:`RxCrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCrc>`
                                            
                                            .. attribute:: rx_csf
                                            
                                            	RX CSF
                                            	**type**\:   :py:class:`RxCsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCsf>`
                                            
                                            .. attribute:: rx_inv_typ
                                            
                                            	RX INV TYP
                                            	**type**\:   :py:class:`RxInvTyp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxInvTyp>`
                                            
                                            .. attribute:: rx_lfd
                                            
                                            	RX LFD
                                            	**type**\:   :py:class:`RxLfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxLfd>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance, self).__init__()

                                                self.yang_name = "odu-hour24gfp-time-line-instance"
                                                self.yang_parent_name = "odu-hour24gfp-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.rx_bit_err = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxBitErr()
                                                self.rx_bit_err.parent = self
                                                self._children_name_map["rx_bit_err"] = "rx-bit-err"
                                                self._children_yang_names.add("rx-bit-err")

                                                self.rx_crc = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCrc()
                                                self.rx_crc.parent = self
                                                self._children_name_map["rx_crc"] = "rx-crc"
                                                self._children_yang_names.add("rx-crc")

                                                self.rx_csf = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCsf()
                                                self.rx_csf.parent = self
                                                self._children_name_map["rx_csf"] = "rx-csf"
                                                self._children_yang_names.add("rx-csf")

                                                self.rx_inv_typ = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxInvTyp()
                                                self.rx_inv_typ.parent = self
                                                self._children_name_map["rx_inv_typ"] = "rx-inv-typ"
                                                self._children_yang_names.add("rx-inv-typ")

                                                self.rx_lfd = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxLfd()
                                                self.rx_lfd.parent = self
                                                self._children_name_map["rx_lfd"] = "rx-lfd"
                                                self._children_yang_names.add("rx-lfd")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance, self).__setattr__(name, value)


                                            class RxBitErr(Entity):
                                                """
                                                RX BIT ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxBitErr, self).__init__()

                                                    self.yang_name = "rx-bit-err"
                                                    self.yang_parent_name = "odu-hour24gfp-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxBitErr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxBitErr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-bit-err" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class RxInvTyp(Entity):
                                                """
                                                RX INV TYP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxInvTyp, self).__init__()

                                                    self.yang_name = "rx-inv-typ"
                                                    self.yang_parent_name = "odu-hour24gfp-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxInvTyp, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxInvTyp, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-inv-typ" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class RxCrc(Entity):
                                                """
                                                RX CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCrc, self).__init__()

                                                    self.yang_name = "rx-crc"
                                                    self.yang_parent_name = "odu-hour24gfp-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCrc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCrc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-crc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class RxLfd(Entity):
                                                """
                                                RX LFD
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxLfd, self).__init__()

                                                    self.yang_name = "rx-lfd"
                                                    self.yang_parent_name = "odu-hour24gfp-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxLfd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxLfd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-lfd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class RxCsf(Entity):
                                                """
                                                RX CSF
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCsf, self).__init__()

                                                    self.yang_name = "rx-csf"
                                                    self.yang_parent_name = "odu-hour24gfp-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCsf, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCsf, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-csf" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.rx_bit_err is not None and self.rx_bit_err.has_data()) or
                                                    (self.rx_crc is not None and self.rx_crc.has_data()) or
                                                    (self.rx_csf is not None and self.rx_csf.has_data()) or
                                                    (self.rx_inv_typ is not None and self.rx_inv_typ.has_data()) or
                                                    (self.rx_lfd is not None and self.rx_lfd.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.rx_bit_err is not None and self.rx_bit_err.has_operation()) or
                                                    (self.rx_crc is not None and self.rx_crc.has_operation()) or
                                                    (self.rx_csf is not None and self.rx_csf.has_operation()) or
                                                    (self.rx_inv_typ is not None and self.rx_inv_typ.has_operation()) or
                                                    (self.rx_lfd is not None and self.rx_lfd.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "odu-hour24gfp-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "rx-bit-err"):
                                                    if (self.rx_bit_err is None):
                                                        self.rx_bit_err = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxBitErr()
                                                        self.rx_bit_err.parent = self
                                                        self._children_name_map["rx_bit_err"] = "rx-bit-err"
                                                    return self.rx_bit_err

                                                if (child_yang_name == "rx-crc"):
                                                    if (self.rx_crc is None):
                                                        self.rx_crc = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCrc()
                                                        self.rx_crc.parent = self
                                                        self._children_name_map["rx_crc"] = "rx-crc"
                                                    return self.rx_crc

                                                if (child_yang_name == "rx-csf"):
                                                    if (self.rx_csf is None):
                                                        self.rx_csf = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxCsf()
                                                        self.rx_csf.parent = self
                                                        self._children_name_map["rx_csf"] = "rx-csf"
                                                    return self.rx_csf

                                                if (child_yang_name == "rx-inv-typ"):
                                                    if (self.rx_inv_typ is None):
                                                        self.rx_inv_typ = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxInvTyp()
                                                        self.rx_inv_typ.parent = self
                                                        self._children_name_map["rx_inv_typ"] = "rx-inv-typ"
                                                    return self.rx_inv_typ

                                                if (child_yang_name == "rx-lfd"):
                                                    if (self.rx_lfd is None):
                                                        self.rx_lfd = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance.RxLfd()
                                                        self.rx_lfd.parent = self
                                                        self._children_name_map["rx_lfd"] = "rx-lfd"
                                                    return self.rx_lfd

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "rx-bit-err" or name == "rx-crc" or name == "rx-csf" or name == "rx-inv-typ" or name == "rx-lfd" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.odu_hour24gfp_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.odu_hour24gfp_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "odu-hour24gfp-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "odu-hour24gfp-time-line-instance"):
                                                for c in self.odu_hour24gfp_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances.OduHour24GfpTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.odu_hour24gfp_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "odu-hour24gfp-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.odu_hour24gfp_time_line_instances is not None and self.odu_hour24gfp_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.odu_hour24gfp_time_line_instances is not None and self.odu_hour24gfp_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "odu-hour24gfp-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "odu-hour24gfp-time-line-instances"):
                                            if (self.odu_hour24gfp_time_line_instances is None):
                                                self.odu_hour24gfp_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory.OduHour24GfpTimeLineInstances()
                                                self.odu_hour24gfp_time_line_instances.parent = self
                                                self._children_name_map["odu_hour24gfp_time_line_instances"] = "odu-hour24gfp-time-line-instances"
                                            return self.odu_hour24gfp_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "odu-hour24gfp-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.odu_hour24gfp_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.odu_hour24gfp_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "odu-hour24gfp-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "odu-hour24gfp-history"):
                                        for c in self.odu_hour24gfp_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories.OduHour24GfpHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.odu_hour24gfp_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "odu-hour24gfp-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class OduHour24PrbsHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: odu_hour24prbs_history
                                
                                	port 24 hour prbs performance data
                                	**type**\: list of    :py:class:`OduHour24PrbsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories, self).__init__()

                                    self.yang_name = "odu-hour24prbs-histories"
                                    self.yang_parent_name = "odu-hour24-history"

                                    self.odu_hour24prbs_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories, self).__setattr__(name, value)


                                class OduHour24PrbsHistory(Entity):
                                    """
                                    port 24 hour prbs performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: odu_hour24prbs_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OduHour24PrbsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory, self).__init__()

                                        self.yang_name = "odu-hour24prbs-history"
                                        self.yang_parent_name = "odu-hour24prbs-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.odu_hour24prbs_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances()
                                        self.odu_hour24prbs_time_line_instances.parent = self
                                        self._children_name_map["odu_hour24prbs_time_line_instances"] = "odu-hour24prbs-time-line-instances"
                                        self._children_yang_names.add("odu-hour24prbs-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory, self).__setattr__(name, value)


                                    class OduHour24PrbsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_hour24prbs_time_line_instance
                                        
                                        	port 15\-minute prbs performance data
                                        	**type**\: list of    :py:class:`OduHour24PrbsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances, self).__init__()

                                            self.yang_name = "odu-hour24prbs-time-line-instances"
                                            self.yang_parent_name = "odu-hour24prbs-history"

                                            self.odu_hour24prbs_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances, self).__setattr__(name, value)


                                        class OduHour24PrbsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute prbs performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: conf_patt
                                            
                                            	CONFIG PTRN
                                            	**type**\:   :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                            
                                            .. attribute:: ebc
                                            
                                            	EBC
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: found_at_time
                                            
                                            	FOUND AT TS
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: found_count
                                            
                                            	FOUND COUNT
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: lost_at_time
                                            
                                            	LOST AT TS
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: lost_count
                                            
                                            	LOST COUNT
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcv_patt
                                            
                                            	RCVD PTRN
                                            	**type**\:   :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance.RcvPatt>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance, self).__init__()

                                                self.yang_name = "odu-hour24prbs-time-line-instance"
                                                self.yang_parent_name = "odu-hour24prbs-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.conf_patt = YLeaf(YType.enumeration, "conf-patt")

                                                self.ebc = YLeaf(YType.uint64, "ebc")

                                                self.found_at_time = YLeaf(YType.str, "found-at-time")

                                                self.found_count = YLeaf(YType.uint32, "found-count")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.lost_at_time = YLeaf(YType.str, "lost-at-time")

                                                self.lost_count = YLeaf(YType.uint32, "lost-count")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.rcv_patt = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance.RcvPatt()
                                                self.rcv_patt.parent = self
                                                self._children_name_map["rcv_patt"] = "rcv-patt"
                                                self._children_yang_names.add("rcv-patt")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "conf_patt",
                                                                "ebc",
                                                                "found_at_time",
                                                                "found_count",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "lost_at_time",
                                                                "lost_count",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance, self).__setattr__(name, value)


                                            class RcvPatt(Entity):
                                                """
                                                RCVD PTRN
                                                
                                                .. attribute:: rcv_patt
                                                
                                                	RCVD PTRN
                                                	**type**\:   :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance.RcvPatt, self).__init__()

                                                    self.yang_name = "rcv-patt"
                                                    self.yang_parent_name = "odu-hour24prbs-time-line-instance"

                                                    self.rcv_patt = YLeaf(YType.enumeration, "rcv-patt")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("rcv_patt",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance.RcvPatt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance.RcvPatt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.rcv_patt.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.rcv_patt.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rcv-patt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.rcv_patt.is_set or self.rcv_patt.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rcv_patt.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "rcv-patt" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "rcv-patt"):
                                                        self.rcv_patt = value
                                                        self.rcv_patt.value_namespace = name_space
                                                        self.rcv_patt.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.conf_patt.is_set or
                                                    self.ebc.is_set or
                                                    self.found_at_time.is_set or
                                                    self.found_count.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.lost_at_time.is_set or
                                                    self.lost_count.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.rcv_patt is not None and self.rcv_patt.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.conf_patt.yfilter != YFilter.not_set or
                                                    self.ebc.yfilter != YFilter.not_set or
                                                    self.found_at_time.yfilter != YFilter.not_set or
                                                    self.found_count.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.lost_at_time.yfilter != YFilter.not_set or
                                                    self.lost_count.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.rcv_patt is not None and self.rcv_patt.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "odu-hour24prbs-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.conf_patt.is_set or self.conf_patt.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.conf_patt.get_name_leafdata())
                                                if (self.ebc.is_set or self.ebc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ebc.get_name_leafdata())
                                                if (self.found_at_time.is_set or self.found_at_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.found_at_time.get_name_leafdata())
                                                if (self.found_count.is_set or self.found_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.found_count.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.lost_at_time.is_set or self.lost_at_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lost_at_time.get_name_leafdata())
                                                if (self.lost_count.is_set or self.lost_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lost_count.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "rcv-patt"):
                                                    if (self.rcv_patt is None):
                                                        self.rcv_patt = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance.RcvPatt()
                                                        self.rcv_patt.parent = self
                                                        self._children_name_map["rcv_patt"] = "rcv-patt"
                                                    return self.rcv_patt

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "rcv-patt" or name == "number" or name == "conf-patt" or name == "ebc" or name == "found-at-time" or name == "found-count" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "lost-at-time" or name == "lost-count" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "conf-patt"):
                                                    self.conf_patt = value
                                                    self.conf_patt.value_namespace = name_space
                                                    self.conf_patt.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ebc"):
                                                    self.ebc = value
                                                    self.ebc.value_namespace = name_space
                                                    self.ebc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "found-at-time"):
                                                    self.found_at_time = value
                                                    self.found_at_time.value_namespace = name_space
                                                    self.found_at_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "found-count"):
                                                    self.found_count = value
                                                    self.found_count.value_namespace = name_space
                                                    self.found_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lost-at-time"):
                                                    self.lost_at_time = value
                                                    self.lost_at_time.value_namespace = name_space
                                                    self.lost_at_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lost-count"):
                                                    self.lost_count = value
                                                    self.lost_count.value_namespace = name_space
                                                    self.lost_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.odu_hour24prbs_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.odu_hour24prbs_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "odu-hour24prbs-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "odu-hour24prbs-time-line-instance"):
                                                for c in self.odu_hour24prbs_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances.OduHour24PrbsTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.odu_hour24prbs_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "odu-hour24prbs-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.odu_hour24prbs_time_line_instances is not None and self.odu_hour24prbs_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.odu_hour24prbs_time_line_instances is not None and self.odu_hour24prbs_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "odu-hour24prbs-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "odu-hour24prbs-time-line-instances"):
                                            if (self.odu_hour24prbs_time_line_instances is None):
                                                self.odu_hour24prbs_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory.OduHour24PrbsTimeLineInstances()
                                                self.odu_hour24prbs_time_line_instances.parent = self
                                                self._children_name_map["odu_hour24prbs_time_line_instances"] = "odu-hour24prbs-time-line-instances"
                                            return self.odu_hour24prbs_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "odu-hour24prbs-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.odu_hour24prbs_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.odu_hour24prbs_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "odu-hour24prbs-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "odu-hour24prbs-history"):
                                        for c in self.odu_hour24prbs_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories.OduHour24PrbsHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.odu_hour24prbs_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "odu-hour24prbs-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class OduHour24OtnHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: odu_hour24otn_history
                                
                                	port 24 hour otn performance data
                                	**type**\: list of    :py:class:`OduHour24OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories, self).__init__()

                                    self.yang_name = "odu-hour24otn-histories"
                                    self.yang_parent_name = "odu-hour24-history"

                                    self.odu_hour24otn_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories, self).__setattr__(name, value)


                                class OduHour24OtnHistory(Entity):
                                    """
                                    port 24 hour otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: odu_hour24otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OduHour24OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory, self).__init__()

                                        self.yang_name = "odu-hour24otn-history"
                                        self.yang_parent_name = "odu-hour24otn-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.odu_hour24otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances()
                                        self.odu_hour24otn_time_line_instances.parent = self
                                        self._children_name_map["odu_hour24otn_time_line_instances"] = "odu-hour24otn-time-line-instances"
                                        self._children_yang_names.add("odu-hour24otn-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory, self).__setattr__(name, value)


                                    class OduHour24OtnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_hour24otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OduHour24OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances, self).__init__()

                                            self.yang_name = "odu-hour24otn-time-line-instances"
                                            self.yang_parent_name = "odu-hour24otn-history"

                                            self.odu_hour24otn_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances, self).__setattr__(name, value)


                                        class OduHour24OtnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance, self).__init__()

                                                self.yang_name = "odu-hour24otn-time-line-instance"
                                                self.yang_parent_name = "odu-hour24otn-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"
                                                self._children_yang_names.add("bbe-fe")

                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"
                                                self._children_yang_names.add("bbe-ne")

                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"
                                                self._children_yang_names.add("bber-fe")

                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"
                                                self._children_yang_names.add("bber-ne")

                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"
                                                self._children_yang_names.add("es-fe")

                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"
                                                self._children_yang_names.add("es-ne")

                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"
                                                self._children_yang_names.add("esr-fe")

                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"
                                                self._children_yang_names.add("esr-ne")

                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._children_yang_names.add("fc-fe")

                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"
                                                self._children_yang_names.add("fc-ne")

                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"
                                                self._children_yang_names.add("lbc")

                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"
                                                self._children_yang_names.add("ses-fe")

                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"
                                                self._children_yang_names.add("ses-ne")

                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"
                                                self._children_yang_names.add("sesr-fe")

                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"
                                                self._children_yang_names.add("sesr-ne")

                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"
                                                self._children_yang_names.add("uas-fe")

                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"
                                                self._children_yang_names.add("uas-ne")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance, self).__setattr__(name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.Lbc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.Lbc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "odu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_data()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_data()) or
                                                    (self.es_fe is not None and self.es_fe.has_data()) or
                                                    (self.es_ne is not None and self.es_ne.has_data()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_data()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_data()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_data()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_data()) or
                                                    (self.lbc is not None and self.lbc.has_data()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_data()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_data()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_data()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                                    (self.es_fe is not None and self.es_fe.has_operation()) or
                                                    (self.es_ne is not None and self.es_ne.has_operation()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                                    (self.lbc is not None and self.lbc.has_operation()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "odu-hour24otn-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bbe-fe"):
                                                    if (self.bbe_fe is None):
                                                        self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeFe()
                                                        self.bbe_fe.parent = self
                                                        self._children_name_map["bbe_fe"] = "bbe-fe"
                                                    return self.bbe_fe

                                                if (child_yang_name == "bbe-ne"):
                                                    if (self.bbe_ne is None):
                                                        self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BbeNe()
                                                        self.bbe_ne.parent = self
                                                        self._children_name_map["bbe_ne"] = "bbe-ne"
                                                    return self.bbe_ne

                                                if (child_yang_name == "bber-fe"):
                                                    if (self.bber_fe is None):
                                                        self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberFe()
                                                        self.bber_fe.parent = self
                                                        self._children_name_map["bber_fe"] = "bber-fe"
                                                    return self.bber_fe

                                                if (child_yang_name == "bber-ne"):
                                                    if (self.bber_ne is None):
                                                        self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.BberNe()
                                                        self.bber_ne.parent = self
                                                        self._children_name_map["bber_ne"] = "bber-ne"
                                                    return self.bber_ne

                                                if (child_yang_name == "es-fe"):
                                                    if (self.es_fe is None):
                                                        self.es_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsFe()
                                                        self.es_fe.parent = self
                                                        self._children_name_map["es_fe"] = "es-fe"
                                                    return self.es_fe

                                                if (child_yang_name == "es-ne"):
                                                    if (self.es_ne is None):
                                                        self.es_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsNe()
                                                        self.es_ne.parent = self
                                                        self._children_name_map["es_ne"] = "es-ne"
                                                    return self.es_ne

                                                if (child_yang_name == "esr-fe"):
                                                    if (self.esr_fe is None):
                                                        self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrFe()
                                                        self.esr_fe.parent = self
                                                        self._children_name_map["esr_fe"] = "esr-fe"
                                                    return self.esr_fe

                                                if (child_yang_name == "esr-ne"):
                                                    if (self.esr_ne is None):
                                                        self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.EsrNe()
                                                        self.esr_ne.parent = self
                                                        self._children_name_map["esr_ne"] = "esr-ne"
                                                    return self.esr_ne

                                                if (child_yang_name == "fc-fe"):
                                                    if (self.fc_fe is None):
                                                        self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcFe()
                                                        self.fc_fe.parent = self
                                                        self._children_name_map["fc_fe"] = "fc-fe"
                                                    return self.fc_fe

                                                if (child_yang_name == "fc-ne"):
                                                    if (self.fc_ne is None):
                                                        self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.FcNe()
                                                        self.fc_ne.parent = self
                                                        self._children_name_map["fc_ne"] = "fc-ne"
                                                    return self.fc_ne

                                                if (child_yang_name == "lbc"):
                                                    if (self.lbc is None):
                                                        self.lbc = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.Lbc()
                                                        self.lbc.parent = self
                                                        self._children_name_map["lbc"] = "lbc"
                                                    return self.lbc

                                                if (child_yang_name == "ses-fe"):
                                                    if (self.ses_fe is None):
                                                        self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesFe()
                                                        self.ses_fe.parent = self
                                                        self._children_name_map["ses_fe"] = "ses-fe"
                                                    return self.ses_fe

                                                if (child_yang_name == "ses-ne"):
                                                    if (self.ses_ne is None):
                                                        self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesNe()
                                                        self.ses_ne.parent = self
                                                        self._children_name_map["ses_ne"] = "ses-ne"
                                                    return self.ses_ne

                                                if (child_yang_name == "sesr-fe"):
                                                    if (self.sesr_fe is None):
                                                        self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrFe()
                                                        self.sesr_fe.parent = self
                                                        self._children_name_map["sesr_fe"] = "sesr-fe"
                                                    return self.sesr_fe

                                                if (child_yang_name == "sesr-ne"):
                                                    if (self.sesr_ne is None):
                                                        self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.SesrNe()
                                                        self.sesr_ne.parent = self
                                                        self._children_name_map["sesr_ne"] = "sesr-ne"
                                                    return self.sesr_ne

                                                if (child_yang_name == "uas-fe"):
                                                    if (self.uas_fe is None):
                                                        self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasFe()
                                                        self.uas_fe.parent = self
                                                        self._children_name_map["uas_fe"] = "uas-fe"
                                                    return self.uas_fe

                                                if (child_yang_name == "uas-ne"):
                                                    if (self.uas_ne is None):
                                                        self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance.UasNe()
                                                        self.uas_ne.parent = self
                                                        self._children_name_map["uas_ne"] = "uas-ne"
                                                    return self.uas_ne

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.odu_hour24otn_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.odu_hour24otn_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "odu-hour24otn-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "odu-hour24otn-time-line-instance"):
                                                for c in self.odu_hour24otn_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances.OduHour24OtnTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.odu_hour24otn_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "odu-hour24otn-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.odu_hour24otn_time_line_instances is not None and self.odu_hour24otn_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.odu_hour24otn_time_line_instances is not None and self.odu_hour24otn_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "odu-hour24otn-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "odu-hour24otn-time-line-instances"):
                                            if (self.odu_hour24otn_time_line_instances is None):
                                                self.odu_hour24otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory.OduHour24OtnTimeLineInstances()
                                                self.odu_hour24otn_time_line_instances.parent = self
                                                self._children_name_map["odu_hour24otn_time_line_instances"] = "odu-hour24otn-time-line-instances"
                                            return self.odu_hour24otn_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "odu-hour24otn-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.odu_hour24otn_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.odu_hour24otn_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "odu-hour24otn-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "odu-hour24otn-history"):
                                        for c in self.odu_hour24otn_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories.OduHour24OtnHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.odu_hour24otn_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "odu-hour24otn-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    (self.odu_hour24gfp_histories is not None and self.odu_hour24gfp_histories.has_data()) or
                                    (self.odu_hour24otn_histories is not None and self.odu_hour24otn_histories.has_data()) or
                                    (self.odu_hour24prbs_histories is not None and self.odu_hour24prbs_histories.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.odu_hour24gfp_histories is not None and self.odu_hour24gfp_histories.has_operation()) or
                                    (self.odu_hour24otn_histories is not None and self.odu_hour24otn_histories.has_operation()) or
                                    (self.odu_hour24prbs_histories is not None and self.odu_hour24prbs_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "odu-hour24-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "odu-hour24gfp-histories"):
                                    if (self.odu_hour24gfp_histories is None):
                                        self.odu_hour24gfp_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24GfpHistories()
                                        self.odu_hour24gfp_histories.parent = self
                                        self._children_name_map["odu_hour24gfp_histories"] = "odu-hour24gfp-histories"
                                    return self.odu_hour24gfp_histories

                                if (child_yang_name == "odu-hour24otn-histories"):
                                    if (self.odu_hour24otn_histories is None):
                                        self.odu_hour24otn_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24OtnHistories()
                                        self.odu_hour24otn_histories.parent = self
                                        self._children_name_map["odu_hour24otn_histories"] = "odu-hour24otn-histories"
                                    return self.odu_hour24otn_histories

                                if (child_yang_name == "odu-hour24prbs-histories"):
                                    if (self.odu_hour24prbs_histories is None):
                                        self.odu_hour24prbs_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History.OduHour24PrbsHistories()
                                        self.odu_hour24prbs_histories.parent = self
                                        self._children_name_map["odu_hour24prbs_histories"] = "odu-hour24prbs-histories"
                                    return self.odu_hour24prbs_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "odu-hour24gfp-histories" or name == "odu-hour24otn-histories" or name == "odu-hour24prbs-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OduMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: odu_minute15gfp_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OduMinute15GfpHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories>`
                            
                            .. attribute:: odu_minute15otn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OduMinute15OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories>`
                            
                            .. attribute:: odu_minute15prbs_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OduMinute15PrbsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History, self).__init__()

                                self.yang_name = "odu-minute15-history"
                                self.yang_parent_name = "odu-port-history"

                                self.odu_minute15gfp_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories()
                                self.odu_minute15gfp_histories.parent = self
                                self._children_name_map["odu_minute15gfp_histories"] = "odu-minute15gfp-histories"
                                self._children_yang_names.add("odu-minute15gfp-histories")

                                self.odu_minute15otn_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories()
                                self.odu_minute15otn_histories.parent = self
                                self._children_name_map["odu_minute15otn_histories"] = "odu-minute15otn-histories"
                                self._children_yang_names.add("odu-minute15otn-histories")

                                self.odu_minute15prbs_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories()
                                self.odu_minute15prbs_histories.parent = self
                                self._children_name_map["odu_minute15prbs_histories"] = "odu-minute15prbs-histories"
                                self._children_yang_names.add("odu-minute15prbs-histories")


                            class OduMinute15PrbsHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: odu_minute15prbs_history
                                
                                	port 15\-minute prbs performance data
                                	**type**\: list of    :py:class:`OduMinute15PrbsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories, self).__init__()

                                    self.yang_name = "odu-minute15prbs-histories"
                                    self.yang_parent_name = "odu-minute15-history"

                                    self.odu_minute15prbs_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories, self).__setattr__(name, value)


                                class OduMinute15PrbsHistory(Entity):
                                    """
                                    port 15\-minute prbs performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: odu_minute15prbs_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OduMinute15PrbsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory, self).__init__()

                                        self.yang_name = "odu-minute15prbs-history"
                                        self.yang_parent_name = "odu-minute15prbs-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.odu_minute15prbs_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances()
                                        self.odu_minute15prbs_time_line_instances.parent = self
                                        self._children_name_map["odu_minute15prbs_time_line_instances"] = "odu-minute15prbs-time-line-instances"
                                        self._children_yang_names.add("odu-minute15prbs-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory, self).__setattr__(name, value)


                                    class OduMinute15PrbsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_minute15prbs_time_line_instance
                                        
                                        	port 15\-minute prbs performance data
                                        	**type**\: list of    :py:class:`OduMinute15PrbsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances, self).__init__()

                                            self.yang_name = "odu-minute15prbs-time-line-instances"
                                            self.yang_parent_name = "odu-minute15prbs-history"

                                            self.odu_minute15prbs_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances, self).__setattr__(name, value)


                                        class OduMinute15PrbsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute prbs performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: conf_patt
                                            
                                            	CONFIG PTRN
                                            	**type**\:   :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                            
                                            .. attribute:: ebc
                                            
                                            	EBC
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: found_at_time
                                            
                                            	FOUND AT TS
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: found_count
                                            
                                            	FOUND COUNT
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: lost_at_time
                                            
                                            	LOST AT TS
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: lost_count
                                            
                                            	LOST COUNT
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcv_patt
                                            
                                            	RCVD PTRN
                                            	**type**\:   :py:class:`RcvPatt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance.RcvPatt>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance, self).__init__()

                                                self.yang_name = "odu-minute15prbs-time-line-instance"
                                                self.yang_parent_name = "odu-minute15prbs-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.conf_patt = YLeaf(YType.enumeration, "conf-patt")

                                                self.ebc = YLeaf(YType.uint64, "ebc")

                                                self.found_at_time = YLeaf(YType.str, "found-at-time")

                                                self.found_count = YLeaf(YType.uint32, "found-count")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.lost_at_time = YLeaf(YType.str, "lost-at-time")

                                                self.lost_count = YLeaf(YType.uint32, "lost-count")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.rcv_patt = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance.RcvPatt()
                                                self.rcv_patt.parent = self
                                                self._children_name_map["rcv_patt"] = "rcv-patt"
                                                self._children_yang_names.add("rcv-patt")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "conf_patt",
                                                                "ebc",
                                                                "found_at_time",
                                                                "found_count",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "lost_at_time",
                                                                "lost_count",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance, self).__setattr__(name, value)


                                            class RcvPatt(Entity):
                                                """
                                                RCVD PTRN
                                                
                                                .. attribute:: rcv_patt
                                                
                                                	RCVD PTRN
                                                	**type**\:   :py:class:`PmPrbsPatternEt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PmPrbsPatternEt>`
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance.RcvPatt, self).__init__()

                                                    self.yang_name = "rcv-patt"
                                                    self.yang_parent_name = "odu-minute15prbs-time-line-instance"

                                                    self.rcv_patt = YLeaf(YType.enumeration, "rcv-patt")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("rcv_patt",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance.RcvPatt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance.RcvPatt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.rcv_patt.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.rcv_patt.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rcv-patt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.rcv_patt.is_set or self.rcv_patt.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rcv_patt.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "rcv-patt" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "rcv-patt"):
                                                        self.rcv_patt = value
                                                        self.rcv_patt.value_namespace = name_space
                                                        self.rcv_patt.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.conf_patt.is_set or
                                                    self.ebc.is_set or
                                                    self.found_at_time.is_set or
                                                    self.found_count.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.lost_at_time.is_set or
                                                    self.lost_count.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.rcv_patt is not None and self.rcv_patt.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.conf_patt.yfilter != YFilter.not_set or
                                                    self.ebc.yfilter != YFilter.not_set or
                                                    self.found_at_time.yfilter != YFilter.not_set or
                                                    self.found_count.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.lost_at_time.yfilter != YFilter.not_set or
                                                    self.lost_count.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.rcv_patt is not None and self.rcv_patt.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "odu-minute15prbs-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.conf_patt.is_set or self.conf_patt.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.conf_patt.get_name_leafdata())
                                                if (self.ebc.is_set or self.ebc.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ebc.get_name_leafdata())
                                                if (self.found_at_time.is_set or self.found_at_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.found_at_time.get_name_leafdata())
                                                if (self.found_count.is_set or self.found_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.found_count.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.lost_at_time.is_set or self.lost_at_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lost_at_time.get_name_leafdata())
                                                if (self.lost_count.is_set or self.lost_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.lost_count.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "rcv-patt"):
                                                    if (self.rcv_patt is None):
                                                        self.rcv_patt = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance.RcvPatt()
                                                        self.rcv_patt.parent = self
                                                        self._children_name_map["rcv_patt"] = "rcv-patt"
                                                    return self.rcv_patt

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "rcv-patt" or name == "number" or name == "conf-patt" or name == "ebc" or name == "found-at-time" or name == "found-count" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "lost-at-time" or name == "lost-count" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "conf-patt"):
                                                    self.conf_patt = value
                                                    self.conf_patt.value_namespace = name_space
                                                    self.conf_patt.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ebc"):
                                                    self.ebc = value
                                                    self.ebc.value_namespace = name_space
                                                    self.ebc.value_namespace_prefix = name_space_prefix
                                                if(value_path == "found-at-time"):
                                                    self.found_at_time = value
                                                    self.found_at_time.value_namespace = name_space
                                                    self.found_at_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "found-count"):
                                                    self.found_count = value
                                                    self.found_count.value_namespace = name_space
                                                    self.found_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lost-at-time"):
                                                    self.lost_at_time = value
                                                    self.lost_at_time.value_namespace = name_space
                                                    self.lost_at_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "lost-count"):
                                                    self.lost_count = value
                                                    self.lost_count.value_namespace = name_space
                                                    self.lost_count.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.odu_minute15prbs_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.odu_minute15prbs_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "odu-minute15prbs-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "odu-minute15prbs-time-line-instance"):
                                                for c in self.odu_minute15prbs_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances.OduMinute15PrbsTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.odu_minute15prbs_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "odu-minute15prbs-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.odu_minute15prbs_time_line_instances is not None and self.odu_minute15prbs_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.odu_minute15prbs_time_line_instances is not None and self.odu_minute15prbs_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "odu-minute15prbs-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "odu-minute15prbs-time-line-instances"):
                                            if (self.odu_minute15prbs_time_line_instances is None):
                                                self.odu_minute15prbs_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory.OduMinute15PrbsTimeLineInstances()
                                                self.odu_minute15prbs_time_line_instances.parent = self
                                                self._children_name_map["odu_minute15prbs_time_line_instances"] = "odu-minute15prbs-time-line-instances"
                                            return self.odu_minute15prbs_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "odu-minute15prbs-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.odu_minute15prbs_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.odu_minute15prbs_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "odu-minute15prbs-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "odu-minute15prbs-history"):
                                        for c in self.odu_minute15prbs_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories.OduMinute15PrbsHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.odu_minute15prbs_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "odu-minute15prbs-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class OduMinute15GfpHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: odu_minute15gfp_history
                                
                                	port 15\-minute otn performance data
                                	**type**\: list of    :py:class:`OduMinute15GfpHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories, self).__init__()

                                    self.yang_name = "odu-minute15gfp-histories"
                                    self.yang_parent_name = "odu-minute15-history"

                                    self.odu_minute15gfp_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories, self).__setattr__(name, value)


                                class OduMinute15GfpHistory(Entity):
                                    """
                                    port 15\-minute otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: odu_minute15gfp_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OduMinute15GfpTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory, self).__init__()

                                        self.yang_name = "odu-minute15gfp-history"
                                        self.yang_parent_name = "odu-minute15gfp-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.odu_minute15gfp_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances()
                                        self.odu_minute15gfp_time_line_instances.parent = self
                                        self._children_name_map["odu_minute15gfp_time_line_instances"] = "odu-minute15gfp-time-line-instances"
                                        self._children_yang_names.add("odu-minute15gfp-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory, self).__setattr__(name, value)


                                    class OduMinute15GfpTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_minute15gfp_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OduMinute15GfpTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances, self).__init__()

                                            self.yang_name = "odu-minute15gfp-time-line-instances"
                                            self.yang_parent_name = "odu-minute15gfp-history"

                                            self.odu_minute15gfp_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances, self).__setattr__(name, value)


                                        class OduMinute15GfpTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: rx_bit_err
                                            
                                            	RX BIT ERR
                                            	**type**\:   :py:class:`RxBitErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxBitErr>`
                                            
                                            .. attribute:: rx_crc
                                            
                                            	RX CRC
                                            	**type**\:   :py:class:`RxCrc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCrc>`
                                            
                                            .. attribute:: rx_csf
                                            
                                            	RX CSF
                                            	**type**\:   :py:class:`RxCsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCsf>`
                                            
                                            .. attribute:: rx_inv_typ
                                            
                                            	RX INV TYP
                                            	**type**\:   :py:class:`RxInvTyp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxInvTyp>`
                                            
                                            .. attribute:: rx_lfd
                                            
                                            	RX LFD
                                            	**type**\:   :py:class:`RxLfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxLfd>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance, self).__init__()

                                                self.yang_name = "odu-minute15gfp-time-line-instance"
                                                self.yang_parent_name = "odu-minute15gfp-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.rx_bit_err = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxBitErr()
                                                self.rx_bit_err.parent = self
                                                self._children_name_map["rx_bit_err"] = "rx-bit-err"
                                                self._children_yang_names.add("rx-bit-err")

                                                self.rx_crc = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCrc()
                                                self.rx_crc.parent = self
                                                self._children_name_map["rx_crc"] = "rx-crc"
                                                self._children_yang_names.add("rx-crc")

                                                self.rx_csf = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCsf()
                                                self.rx_csf.parent = self
                                                self._children_name_map["rx_csf"] = "rx-csf"
                                                self._children_yang_names.add("rx-csf")

                                                self.rx_inv_typ = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxInvTyp()
                                                self.rx_inv_typ.parent = self
                                                self._children_name_map["rx_inv_typ"] = "rx-inv-typ"
                                                self._children_yang_names.add("rx-inv-typ")

                                                self.rx_lfd = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxLfd()
                                                self.rx_lfd.parent = self
                                                self._children_name_map["rx_lfd"] = "rx-lfd"
                                                self._children_yang_names.add("rx-lfd")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance, self).__setattr__(name, value)


                                            class RxBitErr(Entity):
                                                """
                                                RX BIT ERR
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxBitErr, self).__init__()

                                                    self.yang_name = "rx-bit-err"
                                                    self.yang_parent_name = "odu-minute15gfp-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxBitErr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxBitErr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-bit-err" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class RxInvTyp(Entity):
                                                """
                                                RX INV TYP
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxInvTyp, self).__init__()

                                                    self.yang_name = "rx-inv-typ"
                                                    self.yang_parent_name = "odu-minute15gfp-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxInvTyp, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxInvTyp, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-inv-typ" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class RxCrc(Entity):
                                                """
                                                RX CRC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCrc, self).__init__()

                                                    self.yang_name = "rx-crc"
                                                    self.yang_parent_name = "odu-minute15gfp-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCrc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCrc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-crc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class RxLfd(Entity):
                                                """
                                                RX LFD
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxLfd, self).__init__()

                                                    self.yang_name = "rx-lfd"
                                                    self.yang_parent_name = "odu-minute15gfp-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxLfd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxLfd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-lfd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class RxCsf(Entity):
                                                """
                                                RX CSF
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCsf, self).__init__()

                                                    self.yang_name = "rx-csf"
                                                    self.yang_parent_name = "odu-minute15gfp-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCsf, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCsf, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-csf" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.rx_bit_err is not None and self.rx_bit_err.has_data()) or
                                                    (self.rx_crc is not None and self.rx_crc.has_data()) or
                                                    (self.rx_csf is not None and self.rx_csf.has_data()) or
                                                    (self.rx_inv_typ is not None and self.rx_inv_typ.has_data()) or
                                                    (self.rx_lfd is not None and self.rx_lfd.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.rx_bit_err is not None and self.rx_bit_err.has_operation()) or
                                                    (self.rx_crc is not None and self.rx_crc.has_operation()) or
                                                    (self.rx_csf is not None and self.rx_csf.has_operation()) or
                                                    (self.rx_inv_typ is not None and self.rx_inv_typ.has_operation()) or
                                                    (self.rx_lfd is not None and self.rx_lfd.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "odu-minute15gfp-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "rx-bit-err"):
                                                    if (self.rx_bit_err is None):
                                                        self.rx_bit_err = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxBitErr()
                                                        self.rx_bit_err.parent = self
                                                        self._children_name_map["rx_bit_err"] = "rx-bit-err"
                                                    return self.rx_bit_err

                                                if (child_yang_name == "rx-crc"):
                                                    if (self.rx_crc is None):
                                                        self.rx_crc = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCrc()
                                                        self.rx_crc.parent = self
                                                        self._children_name_map["rx_crc"] = "rx-crc"
                                                    return self.rx_crc

                                                if (child_yang_name == "rx-csf"):
                                                    if (self.rx_csf is None):
                                                        self.rx_csf = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxCsf()
                                                        self.rx_csf.parent = self
                                                        self._children_name_map["rx_csf"] = "rx-csf"
                                                    return self.rx_csf

                                                if (child_yang_name == "rx-inv-typ"):
                                                    if (self.rx_inv_typ is None):
                                                        self.rx_inv_typ = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxInvTyp()
                                                        self.rx_inv_typ.parent = self
                                                        self._children_name_map["rx_inv_typ"] = "rx-inv-typ"
                                                    return self.rx_inv_typ

                                                if (child_yang_name == "rx-lfd"):
                                                    if (self.rx_lfd is None):
                                                        self.rx_lfd = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance.RxLfd()
                                                        self.rx_lfd.parent = self
                                                        self._children_name_map["rx_lfd"] = "rx-lfd"
                                                    return self.rx_lfd

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "rx-bit-err" or name == "rx-crc" or name == "rx-csf" or name == "rx-inv-typ" or name == "rx-lfd" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.odu_minute15gfp_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.odu_minute15gfp_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "odu-minute15gfp-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "odu-minute15gfp-time-line-instance"):
                                                for c in self.odu_minute15gfp_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances.OduMinute15GfpTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.odu_minute15gfp_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "odu-minute15gfp-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.odu_minute15gfp_time_line_instances is not None and self.odu_minute15gfp_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.odu_minute15gfp_time_line_instances is not None and self.odu_minute15gfp_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "odu-minute15gfp-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "odu-minute15gfp-time-line-instances"):
                                            if (self.odu_minute15gfp_time_line_instances is None):
                                                self.odu_minute15gfp_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory.OduMinute15GfpTimeLineInstances()
                                                self.odu_minute15gfp_time_line_instances.parent = self
                                                self._children_name_map["odu_minute15gfp_time_line_instances"] = "odu-minute15gfp-time-line-instances"
                                            return self.odu_minute15gfp_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "odu-minute15gfp-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.odu_minute15gfp_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.odu_minute15gfp_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "odu-minute15gfp-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "odu-minute15gfp-history"):
                                        for c in self.odu_minute15gfp_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories.OduMinute15GfpHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.odu_minute15gfp_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "odu-minute15gfp-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class OduMinute15OtnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: odu_minute15otn_history
                                
                                	port 15\-minute otn performance data
                                	**type**\: list of    :py:class:`OduMinute15OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories, self).__init__()

                                    self.yang_name = "odu-minute15otn-histories"
                                    self.yang_parent_name = "odu-minute15-history"

                                    self.odu_minute15otn_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories, self).__setattr__(name, value)


                                class OduMinute15OtnHistory(Entity):
                                    """
                                    port 15\-minute otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: odu_minute15otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OduMinute15OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory, self).__init__()

                                        self.yang_name = "odu-minute15otn-history"
                                        self.yang_parent_name = "odu-minute15otn-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.odu_minute15otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances()
                                        self.odu_minute15otn_time_line_instances.parent = self
                                        self._children_name_map["odu_minute15otn_time_line_instances"] = "odu-minute15otn-time-line-instances"
                                        self._children_yang_names.add("odu-minute15otn-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory, self).__setattr__(name, value)


                                    class OduMinute15OtnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: odu_minute15otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OduMinute15OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances, self).__init__()

                                            self.yang_name = "odu-minute15otn-time-line-instances"
                                            self.yang_parent_name = "odu-minute15otn-history"

                                            self.odu_minute15otn_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances, self).__setattr__(name, value)


                                        class OduMinute15OtnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance, self).__init__()

                                                self.yang_name = "odu-minute15otn-time-line-instance"
                                                self.yang_parent_name = "odu-minute15otn-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"
                                                self._children_yang_names.add("bbe-fe")

                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"
                                                self._children_yang_names.add("bbe-ne")

                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"
                                                self._children_yang_names.add("bber-fe")

                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"
                                                self._children_yang_names.add("bber-ne")

                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"
                                                self._children_yang_names.add("es-fe")

                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"
                                                self._children_yang_names.add("es-ne")

                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"
                                                self._children_yang_names.add("esr-fe")

                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"
                                                self._children_yang_names.add("esr-ne")

                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._children_yang_names.add("fc-fe")

                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"
                                                self._children_yang_names.add("fc-ne")

                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"
                                                self._children_yang_names.add("lbc")

                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"
                                                self._children_yang_names.add("ses-fe")

                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"
                                                self._children_yang_names.add("ses-ne")

                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"
                                                self._children_yang_names.add("sesr-fe")

                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"
                                                self._children_yang_names.add("sesr-ne")

                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"
                                                self._children_yang_names.add("uas-fe")

                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"
                                                self._children_yang_names.add("uas-ne")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance, self).__setattr__(name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.Lbc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.Lbc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "odu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_data()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_data()) or
                                                    (self.es_fe is not None and self.es_fe.has_data()) or
                                                    (self.es_ne is not None and self.es_ne.has_data()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_data()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_data()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_data()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_data()) or
                                                    (self.lbc is not None and self.lbc.has_data()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_data()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_data()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_data()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                                    (self.es_fe is not None and self.es_fe.has_operation()) or
                                                    (self.es_ne is not None and self.es_ne.has_operation()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                                    (self.lbc is not None and self.lbc.has_operation()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "odu-minute15otn-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bbe-fe"):
                                                    if (self.bbe_fe is None):
                                                        self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeFe()
                                                        self.bbe_fe.parent = self
                                                        self._children_name_map["bbe_fe"] = "bbe-fe"
                                                    return self.bbe_fe

                                                if (child_yang_name == "bbe-ne"):
                                                    if (self.bbe_ne is None):
                                                        self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BbeNe()
                                                        self.bbe_ne.parent = self
                                                        self._children_name_map["bbe_ne"] = "bbe-ne"
                                                    return self.bbe_ne

                                                if (child_yang_name == "bber-fe"):
                                                    if (self.bber_fe is None):
                                                        self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberFe()
                                                        self.bber_fe.parent = self
                                                        self._children_name_map["bber_fe"] = "bber-fe"
                                                    return self.bber_fe

                                                if (child_yang_name == "bber-ne"):
                                                    if (self.bber_ne is None):
                                                        self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.BberNe()
                                                        self.bber_ne.parent = self
                                                        self._children_name_map["bber_ne"] = "bber-ne"
                                                    return self.bber_ne

                                                if (child_yang_name == "es-fe"):
                                                    if (self.es_fe is None):
                                                        self.es_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsFe()
                                                        self.es_fe.parent = self
                                                        self._children_name_map["es_fe"] = "es-fe"
                                                    return self.es_fe

                                                if (child_yang_name == "es-ne"):
                                                    if (self.es_ne is None):
                                                        self.es_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsNe()
                                                        self.es_ne.parent = self
                                                        self._children_name_map["es_ne"] = "es-ne"
                                                    return self.es_ne

                                                if (child_yang_name == "esr-fe"):
                                                    if (self.esr_fe is None):
                                                        self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrFe()
                                                        self.esr_fe.parent = self
                                                        self._children_name_map["esr_fe"] = "esr-fe"
                                                    return self.esr_fe

                                                if (child_yang_name == "esr-ne"):
                                                    if (self.esr_ne is None):
                                                        self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.EsrNe()
                                                        self.esr_ne.parent = self
                                                        self._children_name_map["esr_ne"] = "esr-ne"
                                                    return self.esr_ne

                                                if (child_yang_name == "fc-fe"):
                                                    if (self.fc_fe is None):
                                                        self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcFe()
                                                        self.fc_fe.parent = self
                                                        self._children_name_map["fc_fe"] = "fc-fe"
                                                    return self.fc_fe

                                                if (child_yang_name == "fc-ne"):
                                                    if (self.fc_ne is None):
                                                        self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.FcNe()
                                                        self.fc_ne.parent = self
                                                        self._children_name_map["fc_ne"] = "fc-ne"
                                                    return self.fc_ne

                                                if (child_yang_name == "lbc"):
                                                    if (self.lbc is None):
                                                        self.lbc = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.Lbc()
                                                        self.lbc.parent = self
                                                        self._children_name_map["lbc"] = "lbc"
                                                    return self.lbc

                                                if (child_yang_name == "ses-fe"):
                                                    if (self.ses_fe is None):
                                                        self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesFe()
                                                        self.ses_fe.parent = self
                                                        self._children_name_map["ses_fe"] = "ses-fe"
                                                    return self.ses_fe

                                                if (child_yang_name == "ses-ne"):
                                                    if (self.ses_ne is None):
                                                        self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesNe()
                                                        self.ses_ne.parent = self
                                                        self._children_name_map["ses_ne"] = "ses-ne"
                                                    return self.ses_ne

                                                if (child_yang_name == "sesr-fe"):
                                                    if (self.sesr_fe is None):
                                                        self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrFe()
                                                        self.sesr_fe.parent = self
                                                        self._children_name_map["sesr_fe"] = "sesr-fe"
                                                    return self.sesr_fe

                                                if (child_yang_name == "sesr-ne"):
                                                    if (self.sesr_ne is None):
                                                        self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.SesrNe()
                                                        self.sesr_ne.parent = self
                                                        self._children_name_map["sesr_ne"] = "sesr-ne"
                                                    return self.sesr_ne

                                                if (child_yang_name == "uas-fe"):
                                                    if (self.uas_fe is None):
                                                        self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasFe()
                                                        self.uas_fe.parent = self
                                                        self._children_name_map["uas_fe"] = "uas-fe"
                                                    return self.uas_fe

                                                if (child_yang_name == "uas-ne"):
                                                    if (self.uas_ne is None):
                                                        self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance.UasNe()
                                                        self.uas_ne.parent = self
                                                        self._children_name_map["uas_ne"] = "uas-ne"
                                                    return self.uas_ne

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.odu_minute15otn_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.odu_minute15otn_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "odu-minute15otn-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "odu-minute15otn-time-line-instance"):
                                                for c in self.odu_minute15otn_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances.OduMinute15OtnTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.odu_minute15otn_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "odu-minute15otn-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.odu_minute15otn_time_line_instances is not None and self.odu_minute15otn_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.odu_minute15otn_time_line_instances is not None and self.odu_minute15otn_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "odu-minute15otn-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "odu-minute15otn-time-line-instances"):
                                            if (self.odu_minute15otn_time_line_instances is None):
                                                self.odu_minute15otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory.OduMinute15OtnTimeLineInstances()
                                                self.odu_minute15otn_time_line_instances.parent = self
                                                self._children_name_map["odu_minute15otn_time_line_instances"] = "odu-minute15otn-time-line-instances"
                                            return self.odu_minute15otn_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "odu-minute15otn-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.odu_minute15otn_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.odu_minute15otn_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "odu-minute15otn-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "odu-minute15otn-history"):
                                        for c in self.odu_minute15otn_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories.OduMinute15OtnHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.odu_minute15otn_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "odu-minute15otn-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    (self.odu_minute15gfp_histories is not None and self.odu_minute15gfp_histories.has_data()) or
                                    (self.odu_minute15otn_histories is not None and self.odu_minute15otn_histories.has_data()) or
                                    (self.odu_minute15prbs_histories is not None and self.odu_minute15prbs_histories.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.odu_minute15gfp_histories is not None and self.odu_minute15gfp_histories.has_operation()) or
                                    (self.odu_minute15otn_histories is not None and self.odu_minute15otn_histories.has_operation()) or
                                    (self.odu_minute15prbs_histories is not None and self.odu_minute15prbs_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "odu-minute15-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "odu-minute15gfp-histories"):
                                    if (self.odu_minute15gfp_histories is None):
                                        self.odu_minute15gfp_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15GfpHistories()
                                        self.odu_minute15gfp_histories.parent = self
                                        self._children_name_map["odu_minute15gfp_histories"] = "odu-minute15gfp-histories"
                                    return self.odu_minute15gfp_histories

                                if (child_yang_name == "odu-minute15otn-histories"):
                                    if (self.odu_minute15otn_histories is None):
                                        self.odu_minute15otn_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15OtnHistories()
                                        self.odu_minute15otn_histories.parent = self
                                        self._children_name_map["odu_minute15otn_histories"] = "odu-minute15otn-histories"
                                    return self.odu_minute15otn_histories

                                if (child_yang_name == "odu-minute15prbs-histories"):
                                    if (self.odu_minute15prbs_histories is None):
                                        self.odu_minute15prbs_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History.OduMinute15PrbsHistories()
                                        self.odu_minute15prbs_histories.parent = self
                                        self._children_name_map["odu_minute15prbs_histories"] = "odu-minute15prbs-histories"
                                    return self.odu_minute15prbs_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "odu-minute15gfp-histories" or name == "odu-minute15otn-histories" or name == "odu-minute15prbs-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.name.is_set or
                                (self.odu_hour24_history is not None and self.odu_hour24_history.has_data()) or
                                (self.odu_minute15_history is not None and self.odu_minute15_history.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                (self.odu_hour24_history is not None and self.odu_hour24_history.has_operation()) or
                                (self.odu_minute15_history is not None and self.odu_minute15_history.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "odu-port-history" + "[name='" + self.name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/odu-history/odu-port-histories/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "odu-hour24-history"):
                                if (self.odu_hour24_history is None):
                                    self.odu_hour24_history = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduHour24History()
                                    self.odu_hour24_history.parent = self
                                    self._children_name_map["odu_hour24_history"] = "odu-hour24-history"
                                return self.odu_hour24_history

                            if (child_yang_name == "odu-minute15-history"):
                                if (self.odu_minute15_history is None):
                                    self.odu_minute15_history = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory.OduMinute15History()
                                    self.odu_minute15_history.parent = self
                                    self._children_name_map["odu_minute15_history"] = "odu-minute15-history"
                                return self.odu_minute15_history

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "odu-hour24-history" or name == "odu-minute15-history" or name == "name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.odu_port_history:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.odu_port_history:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "odu-port-histories" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/odu-history/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "odu-port-history"):
                            for c in self.odu_port_history:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories.OduPortHistory()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.odu_port_history.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "odu-port-history"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.odu_port_histories is not None and self.odu_port_histories.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.odu_port_histories is not None and self.odu_port_histories.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "odu-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "odu-port-histories"):
                        if (self.odu_port_histories is None):
                            self.odu_port_histories = PerformanceManagementHistory.Global_.Periodic.OduHistory.OduPortHistories()
                            self.odu_port_histories.parent = self
                            self._children_name_map["odu_port_histories"] = "odu-port-histories"
                        return self.odu_port_histories

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "odu-port-histories"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class OtuHistory(Entity):
                """
                OTU controller History performance data
                
                .. attribute:: otu_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`OtuPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory, self).__init__()

                    self.yang_name = "otu-history"
                    self.yang_parent_name = "periodic"

                    self.otu_port_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories()
                    self.otu_port_histories.parent = self
                    self._children_name_map["otu_port_histories"] = "otu-port-histories"
                    self._children_yang_names.add("otu-port-histories")


                class OtuPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: otu_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`OtuPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories, self).__init__()

                        self.yang_name = "otu-port-histories"
                        self.yang_parent_name = "otu-history"

                        self.otu_port_history = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories, self).__setattr__(name, value)


                    class OtuPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: otu_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History>`
                        
                        .. attribute:: otu_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History>`
                        
                        .. attribute:: otu_second30_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OtuSecond30History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory, self).__init__()

                            self.yang_name = "otu-port-history"
                            self.yang_parent_name = "otu-port-histories"

                            self.name = YLeaf(YType.str, "name")

                            self.otu_hour24_history = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History()
                            self.otu_hour24_history.parent = self
                            self._children_name_map["otu_hour24_history"] = "otu-hour24-history"
                            self._children_yang_names.add("otu-hour24-history")

                            self.otu_minute15_history = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History()
                            self.otu_minute15_history.parent = self
                            self._children_name_map["otu_minute15_history"] = "otu-minute15-history"
                            self._children_yang_names.add("otu-minute15-history")

                            self.otu_second30_history = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History()
                            self.otu_second30_history.parent = self
                            self._children_name_map["otu_second30_history"] = "otu-second30-history"
                            self._children_yang_names.add("otu-second30-history")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory, self).__setattr__(name, value)


                        class OtuSecond30History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_second30fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OtuSecond30FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories>`
                            
                            .. attribute:: otu_second30otn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OtuSecond30OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History, self).__init__()

                                self.yang_name = "otu-second30-history"
                                self.yang_parent_name = "otu-port-history"

                                self.otu_second30fec_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories()
                                self.otu_second30fec_histories.parent = self
                                self._children_name_map["otu_second30fec_histories"] = "otu-second30fec-histories"
                                self._children_yang_names.add("otu-second30fec-histories")

                                self.otu_second30otn_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories()
                                self.otu_second30otn_histories.parent = self
                                self._children_name_map["otu_second30otn_histories"] = "otu-second30otn-histories"
                                self._children_yang_names.add("otu-second30otn-histories")


                            class OtuSecond30FecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: otu_second30fec_history
                                
                                	port 30\-second fec performance data
                                	**type**\: list of    :py:class:`OtuSecond30FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories, self).__init__()

                                    self.yang_name = "otu-second30fec-histories"
                                    self.yang_parent_name = "otu-second30-history"

                                    self.otu_second30fec_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories, self).__setattr__(name, value)


                                class OtuSecond30FecHistory(Entity):
                                    """
                                    port 30\-second fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: otu_second30fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OtuSecond30FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory, self).__init__()

                                        self.yang_name = "otu-second30fec-history"
                                        self.yang_parent_name = "otu-second30fec-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.otu_second30fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances()
                                        self.otu_second30fec_time_line_instances.parent = self
                                        self._children_name_map["otu_second30fec_time_line_instances"] = "otu-second30fec-time-line-instances"
                                        self._children_yang_names.add("otu-second30fec-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory, self).__setattr__(name, value)


                                    class OtuSecond30FecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_second30fec_time_line_instance
                                        
                                        	port 30\-second fec performance data
                                        	**type**\: list of    :py:class:`OtuSecond30FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-second30fec-time-line-instances"
                                            self.yang_parent_name = "otu-second30fec-history"

                                            self.otu_second30fec_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances, self).__setattr__(name, value)


                                        class OtuSecond30FecTimeLineInstance(Entity):
                                            """
                                            port 30\-second fec performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-second30fec-time-line-instance"
                                                self.yang_parent_name = "otu-second30fec-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"
                                                self._children_yang_names.add("ec-bits")

                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                self._children_yang_names.add("post-fec-ber")

                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                self._children_yang_names.add("pre-fec-ber")

                                                self.q = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"
                                                self._children_yang_names.add("q")

                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._children_yang_names.add("qmargin")

                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"
                                                self._children_yang_names.add("uc-words")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance, self).__setattr__(name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "otu-second30fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.EcBits, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.EcBits, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ec-bits" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "otu-second30fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.UcWords, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.UcWords, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uc-words" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "otu-second30fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pre-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "otu-second30fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "post-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "otu-second30fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Q, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Q, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "q" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "otu-second30fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Qmargin, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Qmargin, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "qmargin" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_data()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                                    (self.q is not None and self.q.has_data()) or
                                                    (self.qmargin is not None and self.qmargin.has_data()) or
                                                    (self.uc_words is not None and self.uc_words.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                                    (self.q is not None and self.q.has_operation()) or
                                                    (self.qmargin is not None and self.qmargin.has_operation()) or
                                                    (self.uc_words is not None and self.uc_words.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "otu-second30fec-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ec-bits"):
                                                    if (self.ec_bits is None):
                                                        self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.EcBits()
                                                        self.ec_bits.parent = self
                                                        self._children_name_map["ec_bits"] = "ec-bits"
                                                    return self.ec_bits

                                                if (child_yang_name == "post-fec-ber"):
                                                    if (self.post_fec_ber is None):
                                                        self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PostFecBer()
                                                        self.post_fec_ber.parent = self
                                                        self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                    return self.post_fec_ber

                                                if (child_yang_name == "pre-fec-ber"):
                                                    if (self.pre_fec_ber is None):
                                                        self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.PreFecBer()
                                                        self.pre_fec_ber.parent = self
                                                        self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                    return self.pre_fec_ber

                                                if (child_yang_name == "q"):
                                                    if (self.q is None):
                                                        self.q = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Q()
                                                        self.q.parent = self
                                                        self._children_name_map["q"] = "q"
                                                    return self.q

                                                if (child_yang_name == "qmargin"):
                                                    if (self.qmargin is None):
                                                        self.qmargin = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.Qmargin()
                                                        self.qmargin.parent = self
                                                        self._children_name_map["qmargin"] = "qmargin"
                                                    return self.qmargin

                                                if (child_yang_name == "uc-words"):
                                                    if (self.uc_words is None):
                                                        self.uc_words = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance.UcWords()
                                                        self.uc_words.parent = self
                                                        self._children_name_map["uc_words"] = "uc-words"
                                                    return self.uc_words

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.otu_second30fec_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.otu_second30fec_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "otu-second30fec-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "otu-second30fec-time-line-instance"):
                                                for c in self.otu_second30fec_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances.OtuSecond30FecTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.otu_second30fec_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "otu-second30fec-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.otu_second30fec_time_line_instances is not None and self.otu_second30fec_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.otu_second30fec_time_line_instances is not None and self.otu_second30fec_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "otu-second30fec-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "otu-second30fec-time-line-instances"):
                                            if (self.otu_second30fec_time_line_instances is None):
                                                self.otu_second30fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory.OtuSecond30FecTimeLineInstances()
                                                self.otu_second30fec_time_line_instances.parent = self
                                                self._children_name_map["otu_second30fec_time_line_instances"] = "otu-second30fec-time-line-instances"
                                            return self.otu_second30fec_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "otu-second30fec-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.otu_second30fec_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.otu_second30fec_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "otu-second30fec-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "otu-second30fec-history"):
                                        for c in self.otu_second30fec_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories.OtuSecond30FecHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.otu_second30fec_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "otu-second30fec-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class OtuSecond30OtnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: otu_second30otn_history
                                
                                	port 30\-second otn performance data
                                	**type**\: list of    :py:class:`OtuSecond30OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories, self).__init__()

                                    self.yang_name = "otu-second30otn-histories"
                                    self.yang_parent_name = "otu-second30-history"

                                    self.otu_second30otn_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories, self).__setattr__(name, value)


                                class OtuSecond30OtnHistory(Entity):
                                    """
                                    port 30\-second otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: otu_second30otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OtuSecond30OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory, self).__init__()

                                        self.yang_name = "otu-second30otn-history"
                                        self.yang_parent_name = "otu-second30otn-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.otu_second30otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances()
                                        self.otu_second30otn_time_line_instances.parent = self
                                        self._children_name_map["otu_second30otn_time_line_instances"] = "otu-second30otn-time-line-instances"
                                        self._children_yang_names.add("otu-second30otn-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory, self).__setattr__(name, value)


                                    class OtuSecond30OtnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_second30otn_time_line_instance
                                        
                                        	port 30\-second otn performance data
                                        	**type**\: list of    :py:class:`OtuSecond30OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-second30otn-time-line-instances"
                                            self.yang_parent_name = "otu-second30otn-history"

                                            self.otu_second30otn_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances, self).__setattr__(name, value)


                                        class OtuSecond30OtnTimeLineInstance(Entity):
                                            """
                                            port 30\-second otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-second30otn-time-line-instance"
                                                self.yang_parent_name = "otu-second30otn-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"
                                                self._children_yang_names.add("bbe-fe")

                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"
                                                self._children_yang_names.add("bbe-ne")

                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"
                                                self._children_yang_names.add("bber-fe")

                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"
                                                self._children_yang_names.add("bber-ne")

                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"
                                                self._children_yang_names.add("es-fe")

                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"
                                                self._children_yang_names.add("es-ne")

                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"
                                                self._children_yang_names.add("esr-fe")

                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"
                                                self._children_yang_names.add("esr-ne")

                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._children_yang_names.add("fc-fe")

                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"
                                                self._children_yang_names.add("fc-ne")

                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"
                                                self._children_yang_names.add("lbc")

                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"
                                                self._children_yang_names.add("ses-fe")

                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"
                                                self._children_yang_names.add("ses-ne")

                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"
                                                self._children_yang_names.add("sesr-fe")

                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"
                                                self._children_yang_names.add("sesr-ne")

                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"
                                                self._children_yang_names.add("uas-fe")

                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"
                                                self._children_yang_names.add("uas-ne")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance, self).__setattr__(name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.Lbc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.Lbc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "otu-second30otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_data()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_data()) or
                                                    (self.es_fe is not None and self.es_fe.has_data()) or
                                                    (self.es_ne is not None and self.es_ne.has_data()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_data()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_data()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_data()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_data()) or
                                                    (self.lbc is not None and self.lbc.has_data()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_data()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_data()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_data()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                                    (self.es_fe is not None and self.es_fe.has_operation()) or
                                                    (self.es_ne is not None and self.es_ne.has_operation()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                                    (self.lbc is not None and self.lbc.has_operation()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "otu-second30otn-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bbe-fe"):
                                                    if (self.bbe_fe is None):
                                                        self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeFe()
                                                        self.bbe_fe.parent = self
                                                        self._children_name_map["bbe_fe"] = "bbe-fe"
                                                    return self.bbe_fe

                                                if (child_yang_name == "bbe-ne"):
                                                    if (self.bbe_ne is None):
                                                        self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BbeNe()
                                                        self.bbe_ne.parent = self
                                                        self._children_name_map["bbe_ne"] = "bbe-ne"
                                                    return self.bbe_ne

                                                if (child_yang_name == "bber-fe"):
                                                    if (self.bber_fe is None):
                                                        self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberFe()
                                                        self.bber_fe.parent = self
                                                        self._children_name_map["bber_fe"] = "bber-fe"
                                                    return self.bber_fe

                                                if (child_yang_name == "bber-ne"):
                                                    if (self.bber_ne is None):
                                                        self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.BberNe()
                                                        self.bber_ne.parent = self
                                                        self._children_name_map["bber_ne"] = "bber-ne"
                                                    return self.bber_ne

                                                if (child_yang_name == "es-fe"):
                                                    if (self.es_fe is None):
                                                        self.es_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsFe()
                                                        self.es_fe.parent = self
                                                        self._children_name_map["es_fe"] = "es-fe"
                                                    return self.es_fe

                                                if (child_yang_name == "es-ne"):
                                                    if (self.es_ne is None):
                                                        self.es_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsNe()
                                                        self.es_ne.parent = self
                                                        self._children_name_map["es_ne"] = "es-ne"
                                                    return self.es_ne

                                                if (child_yang_name == "esr-fe"):
                                                    if (self.esr_fe is None):
                                                        self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrFe()
                                                        self.esr_fe.parent = self
                                                        self._children_name_map["esr_fe"] = "esr-fe"
                                                    return self.esr_fe

                                                if (child_yang_name == "esr-ne"):
                                                    if (self.esr_ne is None):
                                                        self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.EsrNe()
                                                        self.esr_ne.parent = self
                                                        self._children_name_map["esr_ne"] = "esr-ne"
                                                    return self.esr_ne

                                                if (child_yang_name == "fc-fe"):
                                                    if (self.fc_fe is None):
                                                        self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcFe()
                                                        self.fc_fe.parent = self
                                                        self._children_name_map["fc_fe"] = "fc-fe"
                                                    return self.fc_fe

                                                if (child_yang_name == "fc-ne"):
                                                    if (self.fc_ne is None):
                                                        self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.FcNe()
                                                        self.fc_ne.parent = self
                                                        self._children_name_map["fc_ne"] = "fc-ne"
                                                    return self.fc_ne

                                                if (child_yang_name == "lbc"):
                                                    if (self.lbc is None):
                                                        self.lbc = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.Lbc()
                                                        self.lbc.parent = self
                                                        self._children_name_map["lbc"] = "lbc"
                                                    return self.lbc

                                                if (child_yang_name == "ses-fe"):
                                                    if (self.ses_fe is None):
                                                        self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesFe()
                                                        self.ses_fe.parent = self
                                                        self._children_name_map["ses_fe"] = "ses-fe"
                                                    return self.ses_fe

                                                if (child_yang_name == "ses-ne"):
                                                    if (self.ses_ne is None):
                                                        self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesNe()
                                                        self.ses_ne.parent = self
                                                        self._children_name_map["ses_ne"] = "ses-ne"
                                                    return self.ses_ne

                                                if (child_yang_name == "sesr-fe"):
                                                    if (self.sesr_fe is None):
                                                        self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrFe()
                                                        self.sesr_fe.parent = self
                                                        self._children_name_map["sesr_fe"] = "sesr-fe"
                                                    return self.sesr_fe

                                                if (child_yang_name == "sesr-ne"):
                                                    if (self.sesr_ne is None):
                                                        self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.SesrNe()
                                                        self.sesr_ne.parent = self
                                                        self._children_name_map["sesr_ne"] = "sesr-ne"
                                                    return self.sesr_ne

                                                if (child_yang_name == "uas-fe"):
                                                    if (self.uas_fe is None):
                                                        self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasFe()
                                                        self.uas_fe.parent = self
                                                        self._children_name_map["uas_fe"] = "uas-fe"
                                                    return self.uas_fe

                                                if (child_yang_name == "uas-ne"):
                                                    if (self.uas_ne is None):
                                                        self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance.UasNe()
                                                        self.uas_ne.parent = self
                                                        self._children_name_map["uas_ne"] = "uas-ne"
                                                    return self.uas_ne

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.otu_second30otn_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.otu_second30otn_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "otu-second30otn-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "otu-second30otn-time-line-instance"):
                                                for c in self.otu_second30otn_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances.OtuSecond30OtnTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.otu_second30otn_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "otu-second30otn-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.otu_second30otn_time_line_instances is not None and self.otu_second30otn_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.otu_second30otn_time_line_instances is not None and self.otu_second30otn_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "otu-second30otn-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "otu-second30otn-time-line-instances"):
                                            if (self.otu_second30otn_time_line_instances is None):
                                                self.otu_second30otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory.OtuSecond30OtnTimeLineInstances()
                                                self.otu_second30otn_time_line_instances.parent = self
                                                self._children_name_map["otu_second30otn_time_line_instances"] = "otu-second30otn-time-line-instances"
                                            return self.otu_second30otn_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "otu-second30otn-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.otu_second30otn_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.otu_second30otn_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "otu-second30otn-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "otu-second30otn-history"):
                                        for c in self.otu_second30otn_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories.OtuSecond30OtnHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.otu_second30otn_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "otu-second30otn-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    (self.otu_second30fec_histories is not None and self.otu_second30fec_histories.has_data()) or
                                    (self.otu_second30otn_histories is not None and self.otu_second30otn_histories.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.otu_second30fec_histories is not None and self.otu_second30fec_histories.has_operation()) or
                                    (self.otu_second30otn_histories is not None and self.otu_second30otn_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "otu-second30-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "otu-second30fec-histories"):
                                    if (self.otu_second30fec_histories is None):
                                        self.otu_second30fec_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30FecHistories()
                                        self.otu_second30fec_histories.parent = self
                                        self._children_name_map["otu_second30fec_histories"] = "otu-second30fec-histories"
                                    return self.otu_second30fec_histories

                                if (child_yang_name == "otu-second30otn-histories"):
                                    if (self.otu_second30otn_histories is None):
                                        self.otu_second30otn_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History.OtuSecond30OtnHistories()
                                        self.otu_second30otn_histories.parent = self
                                        self._children_name_map["otu_second30otn_histories"] = "otu-second30otn-histories"
                                    return self.otu_second30otn_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otu-second30fec-histories" or name == "otu-second30otn-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OtuMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_minute15fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OtuMinute15FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories>`
                            
                            .. attribute:: otu_minute15otn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OtuMinute15OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History, self).__init__()

                                self.yang_name = "otu-minute15-history"
                                self.yang_parent_name = "otu-port-history"

                                self.otu_minute15fec_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories()
                                self.otu_minute15fec_histories.parent = self
                                self._children_name_map["otu_minute15fec_histories"] = "otu-minute15fec-histories"
                                self._children_yang_names.add("otu-minute15fec-histories")

                                self.otu_minute15otn_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories()
                                self.otu_minute15otn_histories.parent = self
                                self._children_name_map["otu_minute15otn_histories"] = "otu-minute15otn-histories"
                                self._children_yang_names.add("otu-minute15otn-histories")


                            class OtuMinute15FecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: otu_minute15fec_history
                                
                                	port 15\-minute fec performance data
                                	**type**\: list of    :py:class:`OtuMinute15FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories, self).__init__()

                                    self.yang_name = "otu-minute15fec-histories"
                                    self.yang_parent_name = "otu-minute15-history"

                                    self.otu_minute15fec_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories, self).__setattr__(name, value)


                                class OtuMinute15FecHistory(Entity):
                                    """
                                    port 15\-minute fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: otu_minute15fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OtuMinute15FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory, self).__init__()

                                        self.yang_name = "otu-minute15fec-history"
                                        self.yang_parent_name = "otu-minute15fec-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.otu_minute15fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances()
                                        self.otu_minute15fec_time_line_instances.parent = self
                                        self._children_name_map["otu_minute15fec_time_line_instances"] = "otu-minute15fec-time-line-instances"
                                        self._children_yang_names.add("otu-minute15fec-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory, self).__setattr__(name, value)


                                    class OtuMinute15FecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_minute15fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of    :py:class:`OtuMinute15FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-minute15fec-time-line-instances"
                                            self.yang_parent_name = "otu-minute15fec-history"

                                            self.otu_minute15fec_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances, self).__setattr__(name, value)


                                        class OtuMinute15FecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-minute15fec-time-line-instance"
                                                self.yang_parent_name = "otu-minute15fec-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"
                                                self._children_yang_names.add("ec-bits")

                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                self._children_yang_names.add("post-fec-ber")

                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                self._children_yang_names.add("pre-fec-ber")

                                                self.q = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"
                                                self._children_yang_names.add("q")

                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._children_yang_names.add("qmargin")

                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"
                                                self._children_yang_names.add("uc-words")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance, self).__setattr__(name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "otu-minute15fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.EcBits, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.EcBits, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ec-bits" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "otu-minute15fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.UcWords, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.UcWords, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uc-words" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "otu-minute15fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pre-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "otu-minute15fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "post-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "otu-minute15fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Q, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Q, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "q" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "otu-minute15fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Qmargin, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Qmargin, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "qmargin" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_data()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                                    (self.q is not None and self.q.has_data()) or
                                                    (self.qmargin is not None and self.qmargin.has_data()) or
                                                    (self.uc_words is not None and self.uc_words.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                                    (self.q is not None and self.q.has_operation()) or
                                                    (self.qmargin is not None and self.qmargin.has_operation()) or
                                                    (self.uc_words is not None and self.uc_words.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "otu-minute15fec-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ec-bits"):
                                                    if (self.ec_bits is None):
                                                        self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.EcBits()
                                                        self.ec_bits.parent = self
                                                        self._children_name_map["ec_bits"] = "ec-bits"
                                                    return self.ec_bits

                                                if (child_yang_name == "post-fec-ber"):
                                                    if (self.post_fec_ber is None):
                                                        self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PostFecBer()
                                                        self.post_fec_ber.parent = self
                                                        self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                    return self.post_fec_ber

                                                if (child_yang_name == "pre-fec-ber"):
                                                    if (self.pre_fec_ber is None):
                                                        self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.PreFecBer()
                                                        self.pre_fec_ber.parent = self
                                                        self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                    return self.pre_fec_ber

                                                if (child_yang_name == "q"):
                                                    if (self.q is None):
                                                        self.q = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Q()
                                                        self.q.parent = self
                                                        self._children_name_map["q"] = "q"
                                                    return self.q

                                                if (child_yang_name == "qmargin"):
                                                    if (self.qmargin is None):
                                                        self.qmargin = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.Qmargin()
                                                        self.qmargin.parent = self
                                                        self._children_name_map["qmargin"] = "qmargin"
                                                    return self.qmargin

                                                if (child_yang_name == "uc-words"):
                                                    if (self.uc_words is None):
                                                        self.uc_words = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance.UcWords()
                                                        self.uc_words.parent = self
                                                        self._children_name_map["uc_words"] = "uc-words"
                                                    return self.uc_words

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.otu_minute15fec_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.otu_minute15fec_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "otu-minute15fec-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "otu-minute15fec-time-line-instance"):
                                                for c in self.otu_minute15fec_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances.OtuMinute15FecTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.otu_minute15fec_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "otu-minute15fec-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.otu_minute15fec_time_line_instances is not None and self.otu_minute15fec_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.otu_minute15fec_time_line_instances is not None and self.otu_minute15fec_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "otu-minute15fec-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "otu-minute15fec-time-line-instances"):
                                            if (self.otu_minute15fec_time_line_instances is None):
                                                self.otu_minute15fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory.OtuMinute15FecTimeLineInstances()
                                                self.otu_minute15fec_time_line_instances.parent = self
                                                self._children_name_map["otu_minute15fec_time_line_instances"] = "otu-minute15fec-time-line-instances"
                                            return self.otu_minute15fec_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "otu-minute15fec-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.otu_minute15fec_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.otu_minute15fec_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "otu-minute15fec-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "otu-minute15fec-history"):
                                        for c in self.otu_minute15fec_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories.OtuMinute15FecHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.otu_minute15fec_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "otu-minute15fec-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class OtuMinute15OtnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: otu_minute15otn_history
                                
                                	port 15\-minute otn performance data
                                	**type**\: list of    :py:class:`OtuMinute15OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories, self).__init__()

                                    self.yang_name = "otu-minute15otn-histories"
                                    self.yang_parent_name = "otu-minute15-history"

                                    self.otu_minute15otn_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories, self).__setattr__(name, value)


                                class OtuMinute15OtnHistory(Entity):
                                    """
                                    port 15\-minute otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: otu_minute15otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OtuMinute15OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory, self).__init__()

                                        self.yang_name = "otu-minute15otn-history"
                                        self.yang_parent_name = "otu-minute15otn-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.otu_minute15otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances()
                                        self.otu_minute15otn_time_line_instances.parent = self
                                        self._children_name_map["otu_minute15otn_time_line_instances"] = "otu-minute15otn-time-line-instances"
                                        self._children_yang_names.add("otu-minute15otn-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory, self).__setattr__(name, value)


                                    class OtuMinute15OtnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_minute15otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OtuMinute15OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-minute15otn-time-line-instances"
                                            self.yang_parent_name = "otu-minute15otn-history"

                                            self.otu_minute15otn_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances, self).__setattr__(name, value)


                                        class OtuMinute15OtnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-minute15otn-time-line-instance"
                                                self.yang_parent_name = "otu-minute15otn-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"
                                                self._children_yang_names.add("bbe-fe")

                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"
                                                self._children_yang_names.add("bbe-ne")

                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"
                                                self._children_yang_names.add("bber-fe")

                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"
                                                self._children_yang_names.add("bber-ne")

                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"
                                                self._children_yang_names.add("es-fe")

                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"
                                                self._children_yang_names.add("es-ne")

                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"
                                                self._children_yang_names.add("esr-fe")

                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"
                                                self._children_yang_names.add("esr-ne")

                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._children_yang_names.add("fc-fe")

                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"
                                                self._children_yang_names.add("fc-ne")

                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"
                                                self._children_yang_names.add("lbc")

                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"
                                                self._children_yang_names.add("ses-fe")

                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"
                                                self._children_yang_names.add("ses-ne")

                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"
                                                self._children_yang_names.add("sesr-fe")

                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"
                                                self._children_yang_names.add("sesr-ne")

                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"
                                                self._children_yang_names.add("uas-fe")

                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"
                                                self._children_yang_names.add("uas-ne")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance, self).__setattr__(name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.Lbc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.Lbc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "otu-minute15otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_data()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_data()) or
                                                    (self.es_fe is not None and self.es_fe.has_data()) or
                                                    (self.es_ne is not None and self.es_ne.has_data()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_data()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_data()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_data()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_data()) or
                                                    (self.lbc is not None and self.lbc.has_data()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_data()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_data()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_data()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                                    (self.es_fe is not None and self.es_fe.has_operation()) or
                                                    (self.es_ne is not None and self.es_ne.has_operation()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                                    (self.lbc is not None and self.lbc.has_operation()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "otu-minute15otn-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bbe-fe"):
                                                    if (self.bbe_fe is None):
                                                        self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeFe()
                                                        self.bbe_fe.parent = self
                                                        self._children_name_map["bbe_fe"] = "bbe-fe"
                                                    return self.bbe_fe

                                                if (child_yang_name == "bbe-ne"):
                                                    if (self.bbe_ne is None):
                                                        self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BbeNe()
                                                        self.bbe_ne.parent = self
                                                        self._children_name_map["bbe_ne"] = "bbe-ne"
                                                    return self.bbe_ne

                                                if (child_yang_name == "bber-fe"):
                                                    if (self.bber_fe is None):
                                                        self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberFe()
                                                        self.bber_fe.parent = self
                                                        self._children_name_map["bber_fe"] = "bber-fe"
                                                    return self.bber_fe

                                                if (child_yang_name == "bber-ne"):
                                                    if (self.bber_ne is None):
                                                        self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.BberNe()
                                                        self.bber_ne.parent = self
                                                        self._children_name_map["bber_ne"] = "bber-ne"
                                                    return self.bber_ne

                                                if (child_yang_name == "es-fe"):
                                                    if (self.es_fe is None):
                                                        self.es_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsFe()
                                                        self.es_fe.parent = self
                                                        self._children_name_map["es_fe"] = "es-fe"
                                                    return self.es_fe

                                                if (child_yang_name == "es-ne"):
                                                    if (self.es_ne is None):
                                                        self.es_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsNe()
                                                        self.es_ne.parent = self
                                                        self._children_name_map["es_ne"] = "es-ne"
                                                    return self.es_ne

                                                if (child_yang_name == "esr-fe"):
                                                    if (self.esr_fe is None):
                                                        self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrFe()
                                                        self.esr_fe.parent = self
                                                        self._children_name_map["esr_fe"] = "esr-fe"
                                                    return self.esr_fe

                                                if (child_yang_name == "esr-ne"):
                                                    if (self.esr_ne is None):
                                                        self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.EsrNe()
                                                        self.esr_ne.parent = self
                                                        self._children_name_map["esr_ne"] = "esr-ne"
                                                    return self.esr_ne

                                                if (child_yang_name == "fc-fe"):
                                                    if (self.fc_fe is None):
                                                        self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcFe()
                                                        self.fc_fe.parent = self
                                                        self._children_name_map["fc_fe"] = "fc-fe"
                                                    return self.fc_fe

                                                if (child_yang_name == "fc-ne"):
                                                    if (self.fc_ne is None):
                                                        self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.FcNe()
                                                        self.fc_ne.parent = self
                                                        self._children_name_map["fc_ne"] = "fc-ne"
                                                    return self.fc_ne

                                                if (child_yang_name == "lbc"):
                                                    if (self.lbc is None):
                                                        self.lbc = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.Lbc()
                                                        self.lbc.parent = self
                                                        self._children_name_map["lbc"] = "lbc"
                                                    return self.lbc

                                                if (child_yang_name == "ses-fe"):
                                                    if (self.ses_fe is None):
                                                        self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesFe()
                                                        self.ses_fe.parent = self
                                                        self._children_name_map["ses_fe"] = "ses-fe"
                                                    return self.ses_fe

                                                if (child_yang_name == "ses-ne"):
                                                    if (self.ses_ne is None):
                                                        self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesNe()
                                                        self.ses_ne.parent = self
                                                        self._children_name_map["ses_ne"] = "ses-ne"
                                                    return self.ses_ne

                                                if (child_yang_name == "sesr-fe"):
                                                    if (self.sesr_fe is None):
                                                        self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrFe()
                                                        self.sesr_fe.parent = self
                                                        self._children_name_map["sesr_fe"] = "sesr-fe"
                                                    return self.sesr_fe

                                                if (child_yang_name == "sesr-ne"):
                                                    if (self.sesr_ne is None):
                                                        self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.SesrNe()
                                                        self.sesr_ne.parent = self
                                                        self._children_name_map["sesr_ne"] = "sesr-ne"
                                                    return self.sesr_ne

                                                if (child_yang_name == "uas-fe"):
                                                    if (self.uas_fe is None):
                                                        self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasFe()
                                                        self.uas_fe.parent = self
                                                        self._children_name_map["uas_fe"] = "uas-fe"
                                                    return self.uas_fe

                                                if (child_yang_name == "uas-ne"):
                                                    if (self.uas_ne is None):
                                                        self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance.UasNe()
                                                        self.uas_ne.parent = self
                                                        self._children_name_map["uas_ne"] = "uas-ne"
                                                    return self.uas_ne

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.otu_minute15otn_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.otu_minute15otn_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "otu-minute15otn-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "otu-minute15otn-time-line-instance"):
                                                for c in self.otu_minute15otn_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances.OtuMinute15OtnTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.otu_minute15otn_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "otu-minute15otn-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.otu_minute15otn_time_line_instances is not None and self.otu_minute15otn_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.otu_minute15otn_time_line_instances is not None and self.otu_minute15otn_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "otu-minute15otn-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "otu-minute15otn-time-line-instances"):
                                            if (self.otu_minute15otn_time_line_instances is None):
                                                self.otu_minute15otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory.OtuMinute15OtnTimeLineInstances()
                                                self.otu_minute15otn_time_line_instances.parent = self
                                                self._children_name_map["otu_minute15otn_time_line_instances"] = "otu-minute15otn-time-line-instances"
                                            return self.otu_minute15otn_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "otu-minute15otn-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.otu_minute15otn_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.otu_minute15otn_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "otu-minute15otn-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "otu-minute15otn-history"):
                                        for c in self.otu_minute15otn_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories.OtuMinute15OtnHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.otu_minute15otn_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "otu-minute15otn-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    (self.otu_minute15fec_histories is not None and self.otu_minute15fec_histories.has_data()) or
                                    (self.otu_minute15otn_histories is not None and self.otu_minute15otn_histories.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.otu_minute15fec_histories is not None and self.otu_minute15fec_histories.has_operation()) or
                                    (self.otu_minute15otn_histories is not None and self.otu_minute15otn_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "otu-minute15-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "otu-minute15fec-histories"):
                                    if (self.otu_minute15fec_histories is None):
                                        self.otu_minute15fec_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15FecHistories()
                                        self.otu_minute15fec_histories.parent = self
                                        self._children_name_map["otu_minute15fec_histories"] = "otu-minute15fec-histories"
                                    return self.otu_minute15fec_histories

                                if (child_yang_name == "otu-minute15otn-histories"):
                                    if (self.otu_minute15otn_histories is None):
                                        self.otu_minute15otn_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History.OtuMinute15OtnHistories()
                                        self.otu_minute15otn_histories.parent = self
                                        self._children_name_map["otu_minute15otn_histories"] = "otu-minute15otn-histories"
                                    return self.otu_minute15otn_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otu-minute15fec-histories" or name == "otu-minute15otn-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OtuHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: otu_hour24fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OtuHour24FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories>`
                            
                            .. attribute:: otu_hour24otn_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`OtuHour24OtnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History, self).__init__()

                                self.yang_name = "otu-hour24-history"
                                self.yang_parent_name = "otu-port-history"

                                self.otu_hour24fec_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories()
                                self.otu_hour24fec_histories.parent = self
                                self._children_name_map["otu_hour24fec_histories"] = "otu-hour24fec-histories"
                                self._children_yang_names.add("otu-hour24fec-histories")

                                self.otu_hour24otn_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories()
                                self.otu_hour24otn_histories.parent = self
                                self._children_name_map["otu_hour24otn_histories"] = "otu-hour24otn-histories"
                                self._children_yang_names.add("otu-hour24otn-histories")


                            class OtuHour24OtnHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: otu_hour24otn_history
                                
                                	port 24 hour otn performance data
                                	**type**\: list of    :py:class:`OtuHour24OtnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories, self).__init__()

                                    self.yang_name = "otu-hour24otn-histories"
                                    self.yang_parent_name = "otu-hour24-history"

                                    self.otu_hour24otn_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories, self).__setattr__(name, value)


                                class OtuHour24OtnHistory(Entity):
                                    """
                                    port 24 hour otn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: otu_hour24otn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OtuHour24OtnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory, self).__init__()

                                        self.yang_name = "otu-hour24otn-history"
                                        self.yang_parent_name = "otu-hour24otn-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.otu_hour24otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances()
                                        self.otu_hour24otn_time_line_instances.parent = self
                                        self._children_name_map["otu_hour24otn_time_line_instances"] = "otu-hour24otn-time-line-instances"
                                        self._children_yang_names.add("otu-hour24otn-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory, self).__setattr__(name, value)


                                    class OtuHour24OtnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_hour24otn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OtuHour24OtnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-hour24otn-time-line-instances"
                                            self.yang_parent_name = "otu-hour24otn-history"

                                            self.otu_hour24otn_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances, self).__setattr__(name, value)


                                        class OtuHour24OtnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: bbe_fe
                                            
                                            	BBE SM FE
                                            	**type**\:   :py:class:`BbeFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeFe>`
                                            
                                            .. attribute:: bbe_ne
                                            
                                            	BBE SM NE
                                            	**type**\:   :py:class:`BbeNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeNe>`
                                            
                                            .. attribute:: bber_fe
                                            
                                            	BBER SM FE
                                            	**type**\:   :py:class:`BberFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberFe>`
                                            
                                            .. attribute:: bber_ne
                                            
                                            	BBER SM NE
                                            	**type**\:   :py:class:`BberNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberNe>`
                                            
                                            .. attribute:: es_fe
                                            
                                            	ES SM FE
                                            	**type**\:   :py:class:`EsFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsFe>`
                                            
                                            .. attribute:: es_ne
                                            
                                            	ES SM NE
                                            	**type**\:   :py:class:`EsNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsNe>`
                                            
                                            .. attribute:: esr_fe
                                            
                                            	ESR PM FE
                                            	**type**\:   :py:class:`EsrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrFe>`
                                            
                                            .. attribute:: esr_ne
                                            
                                            	ESR PM NE
                                            	**type**\:   :py:class:`EsrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrNe>`
                                            
                                            .. attribute:: fc_fe
                                            
                                            	FC SM FE
                                            	**type**\:   :py:class:`FcFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcFe>`
                                            
                                            .. attribute:: fc_ne
                                            
                                            	FC SM NE
                                            	**type**\:   :py:class:`FcNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcNe>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: ses_fe
                                            
                                            	SES SM FE
                                            	**type**\:   :py:class:`SesFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesFe>`
                                            
                                            .. attribute:: ses_ne
                                            
                                            	SES SM NE
                                            	**type**\:   :py:class:`SesNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesNe>`
                                            
                                            .. attribute:: sesr_fe
                                            
                                            	SESR SM FE
                                            	**type**\:   :py:class:`SesrFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrFe>`
                                            
                                            .. attribute:: sesr_ne
                                            
                                            	SESR SM NE
                                            	**type**\:   :py:class:`SesrNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrNe>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uas_fe
                                            
                                            	UAS SM FE
                                            	**type**\:   :py:class:`UasFe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasFe>`
                                            
                                            .. attribute:: uas_ne
                                            
                                            	UAS SM NE
                                            	**type**\:   :py:class:`UasNe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasNe>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-hour24otn-time-line-instance"
                                                self.yang_parent_name = "otu-hour24otn-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeFe()
                                                self.bbe_fe.parent = self
                                                self._children_name_map["bbe_fe"] = "bbe-fe"
                                                self._children_yang_names.add("bbe-fe")

                                                self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeNe()
                                                self.bbe_ne.parent = self
                                                self._children_name_map["bbe_ne"] = "bbe-ne"
                                                self._children_yang_names.add("bbe-ne")

                                                self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberFe()
                                                self.bber_fe.parent = self
                                                self._children_name_map["bber_fe"] = "bber-fe"
                                                self._children_yang_names.add("bber-fe")

                                                self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberNe()
                                                self.bber_ne.parent = self
                                                self._children_name_map["bber_ne"] = "bber-ne"
                                                self._children_yang_names.add("bber-ne")

                                                self.es_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsFe()
                                                self.es_fe.parent = self
                                                self._children_name_map["es_fe"] = "es-fe"
                                                self._children_yang_names.add("es-fe")

                                                self.es_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsNe()
                                                self.es_ne.parent = self
                                                self._children_name_map["es_ne"] = "es-ne"
                                                self._children_yang_names.add("es-ne")

                                                self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrFe()
                                                self.esr_fe.parent = self
                                                self._children_name_map["esr_fe"] = "esr-fe"
                                                self._children_yang_names.add("esr-fe")

                                                self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrNe()
                                                self.esr_ne.parent = self
                                                self._children_name_map["esr_ne"] = "esr-ne"
                                                self._children_yang_names.add("esr-ne")

                                                self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcFe()
                                                self.fc_fe.parent = self
                                                self._children_name_map["fc_fe"] = "fc-fe"
                                                self._children_yang_names.add("fc-fe")

                                                self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcNe()
                                                self.fc_ne.parent = self
                                                self._children_name_map["fc_ne"] = "fc-ne"
                                                self._children_yang_names.add("fc-ne")

                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"
                                                self._children_yang_names.add("lbc")

                                                self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesFe()
                                                self.ses_fe.parent = self
                                                self._children_name_map["ses_fe"] = "ses-fe"
                                                self._children_yang_names.add("ses-fe")

                                                self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesNe()
                                                self.ses_ne.parent = self
                                                self._children_name_map["ses_ne"] = "ses-ne"
                                                self._children_yang_names.add("ses-ne")

                                                self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrFe()
                                                self.sesr_fe.parent = self
                                                self._children_name_map["sesr_fe"] = "sesr-fe"
                                                self._children_yang_names.add("sesr-fe")

                                                self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrNe()
                                                self.sesr_ne.parent = self
                                                self._children_name_map["sesr_ne"] = "sesr-ne"
                                                self._children_yang_names.add("sesr-ne")

                                                self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasFe()
                                                self.uas_fe.parent = self
                                                self._children_name_map["uas_fe"] = "uas-fe"
                                                self._children_yang_names.add("uas-fe")

                                                self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasNe()
                                                self.uas_ne.parent = self
                                                self._children_name_map["uas_ne"] = "uas-ne"
                                                self._children_yang_names.add("uas-ne")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance, self).__setattr__(name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.Lbc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.Lbc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsNe(Entity):
                                                """
                                                ES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsNe, self).__init__()

                                                    self.yang_name = "es-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrNe(Entity):
                                                """
                                                ESR PM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrNe, self).__init__()

                                                    self.yang_name = "esr-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesNe(Entity):
                                                """
                                                SES SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesNe, self).__init__()

                                                    self.yang_name = "ses-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrNe(Entity):
                                                """
                                                SESR SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrNe, self).__init__()

                                                    self.yang_name = "sesr-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasNe(Entity):
                                                """
                                                UAS SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasNe, self).__init__()

                                                    self.yang_name = "uas-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeNe(Entity):
                                                """
                                                BBE SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeNe, self).__init__()

                                                    self.yang_name = "bbe-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberNe(Entity):
                                                """
                                                BBER SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberNe, self).__init__()

                                                    self.yang_name = "bber-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcNe(Entity):
                                                """
                                                FC SM NE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcNe, self).__init__()

                                                    self.yang_name = "fc-ne"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcNe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcNe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-ne" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsFe(Entity):
                                                """
                                                ES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsFe, self).__init__()

                                                    self.yang_name = "es-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "es-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class EsrFe(Entity):
                                                """
                                                ESR PM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrFe, self).__init__()

                                                    self.yang_name = "esr-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "esr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesFe(Entity):
                                                """
                                                SES SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesFe, self).__init__()

                                                    self.yang_name = "ses-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ses-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class SesrFe(Entity):
                                                """
                                                SESR SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrFe, self).__init__()

                                                    self.yang_name = "sesr-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "sesr-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class UasFe(Entity):
                                                """
                                                UAS SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasFe, self).__init__()

                                                    self.yang_name = "uas-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uas-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BbeFe(Entity):
                                                """
                                                BBE SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeFe, self).__init__()

                                                    self.yang_name = "bbe-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bbe-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class BberFe(Entity):
                                                """
                                                BBER SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  str
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberFe, self).__init__()

                                                    self.yang_name = "bber-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.str, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.str, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "bber-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix


                                            class FcFe(Entity):
                                                """
                                                FC SM FE
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcFe, self).__init__()

                                                    self.yang_name = "fc-fe"
                                                    self.yang_parent_name = "otu-hour24otn-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcFe, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcFe, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fc-fe" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_data()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_data()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_data()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_data()) or
                                                    (self.es_fe is not None and self.es_fe.has_data()) or
                                                    (self.es_ne is not None and self.es_ne.has_data()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_data()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_data()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_data()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_data()) or
                                                    (self.lbc is not None and self.lbc.has_data()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_data()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_data()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_data()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_data()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_data()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.bbe_fe is not None and self.bbe_fe.has_operation()) or
                                                    (self.bbe_ne is not None and self.bbe_ne.has_operation()) or
                                                    (self.bber_fe is not None and self.bber_fe.has_operation()) or
                                                    (self.bber_ne is not None and self.bber_ne.has_operation()) or
                                                    (self.es_fe is not None and self.es_fe.has_operation()) or
                                                    (self.es_ne is not None and self.es_ne.has_operation()) or
                                                    (self.esr_fe is not None and self.esr_fe.has_operation()) or
                                                    (self.esr_ne is not None and self.esr_ne.has_operation()) or
                                                    (self.fc_fe is not None and self.fc_fe.has_operation()) or
                                                    (self.fc_ne is not None and self.fc_ne.has_operation()) or
                                                    (self.lbc is not None and self.lbc.has_operation()) or
                                                    (self.ses_fe is not None and self.ses_fe.has_operation()) or
                                                    (self.ses_ne is not None and self.ses_ne.has_operation()) or
                                                    (self.sesr_fe is not None and self.sesr_fe.has_operation()) or
                                                    (self.sesr_ne is not None and self.sesr_ne.has_operation()) or
                                                    (self.uas_fe is not None and self.uas_fe.has_operation()) or
                                                    (self.uas_ne is not None and self.uas_ne.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "otu-hour24otn-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "bbe-fe"):
                                                    if (self.bbe_fe is None):
                                                        self.bbe_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeFe()
                                                        self.bbe_fe.parent = self
                                                        self._children_name_map["bbe_fe"] = "bbe-fe"
                                                    return self.bbe_fe

                                                if (child_yang_name == "bbe-ne"):
                                                    if (self.bbe_ne is None):
                                                        self.bbe_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BbeNe()
                                                        self.bbe_ne.parent = self
                                                        self._children_name_map["bbe_ne"] = "bbe-ne"
                                                    return self.bbe_ne

                                                if (child_yang_name == "bber-fe"):
                                                    if (self.bber_fe is None):
                                                        self.bber_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberFe()
                                                        self.bber_fe.parent = self
                                                        self._children_name_map["bber_fe"] = "bber-fe"
                                                    return self.bber_fe

                                                if (child_yang_name == "bber-ne"):
                                                    if (self.bber_ne is None):
                                                        self.bber_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.BberNe()
                                                        self.bber_ne.parent = self
                                                        self._children_name_map["bber_ne"] = "bber-ne"
                                                    return self.bber_ne

                                                if (child_yang_name == "es-fe"):
                                                    if (self.es_fe is None):
                                                        self.es_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsFe()
                                                        self.es_fe.parent = self
                                                        self._children_name_map["es_fe"] = "es-fe"
                                                    return self.es_fe

                                                if (child_yang_name == "es-ne"):
                                                    if (self.es_ne is None):
                                                        self.es_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsNe()
                                                        self.es_ne.parent = self
                                                        self._children_name_map["es_ne"] = "es-ne"
                                                    return self.es_ne

                                                if (child_yang_name == "esr-fe"):
                                                    if (self.esr_fe is None):
                                                        self.esr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrFe()
                                                        self.esr_fe.parent = self
                                                        self._children_name_map["esr_fe"] = "esr-fe"
                                                    return self.esr_fe

                                                if (child_yang_name == "esr-ne"):
                                                    if (self.esr_ne is None):
                                                        self.esr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.EsrNe()
                                                        self.esr_ne.parent = self
                                                        self._children_name_map["esr_ne"] = "esr-ne"
                                                    return self.esr_ne

                                                if (child_yang_name == "fc-fe"):
                                                    if (self.fc_fe is None):
                                                        self.fc_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcFe()
                                                        self.fc_fe.parent = self
                                                        self._children_name_map["fc_fe"] = "fc-fe"
                                                    return self.fc_fe

                                                if (child_yang_name == "fc-ne"):
                                                    if (self.fc_ne is None):
                                                        self.fc_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.FcNe()
                                                        self.fc_ne.parent = self
                                                        self._children_name_map["fc_ne"] = "fc-ne"
                                                    return self.fc_ne

                                                if (child_yang_name == "lbc"):
                                                    if (self.lbc is None):
                                                        self.lbc = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.Lbc()
                                                        self.lbc.parent = self
                                                        self._children_name_map["lbc"] = "lbc"
                                                    return self.lbc

                                                if (child_yang_name == "ses-fe"):
                                                    if (self.ses_fe is None):
                                                        self.ses_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesFe()
                                                        self.ses_fe.parent = self
                                                        self._children_name_map["ses_fe"] = "ses-fe"
                                                    return self.ses_fe

                                                if (child_yang_name == "ses-ne"):
                                                    if (self.ses_ne is None):
                                                        self.ses_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesNe()
                                                        self.ses_ne.parent = self
                                                        self._children_name_map["ses_ne"] = "ses-ne"
                                                    return self.ses_ne

                                                if (child_yang_name == "sesr-fe"):
                                                    if (self.sesr_fe is None):
                                                        self.sesr_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrFe()
                                                        self.sesr_fe.parent = self
                                                        self._children_name_map["sesr_fe"] = "sesr-fe"
                                                    return self.sesr_fe

                                                if (child_yang_name == "sesr-ne"):
                                                    if (self.sesr_ne is None):
                                                        self.sesr_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.SesrNe()
                                                        self.sesr_ne.parent = self
                                                        self._children_name_map["sesr_ne"] = "sesr-ne"
                                                    return self.sesr_ne

                                                if (child_yang_name == "uas-fe"):
                                                    if (self.uas_fe is None):
                                                        self.uas_fe = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasFe()
                                                        self.uas_fe.parent = self
                                                        self._children_name_map["uas_fe"] = "uas-fe"
                                                    return self.uas_fe

                                                if (child_yang_name == "uas-ne"):
                                                    if (self.uas_ne is None):
                                                        self.uas_ne = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance.UasNe()
                                                        self.uas_ne.parent = self
                                                        self._children_name_map["uas_ne"] = "uas-ne"
                                                    return self.uas_ne

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "bbe-fe" or name == "bbe-ne" or name == "bber-fe" or name == "bber-ne" or name == "es-fe" or name == "es-ne" or name == "esr-fe" or name == "esr-ne" or name == "fc-fe" or name == "fc-ne" or name == "lbc" or name == "ses-fe" or name == "ses-ne" or name == "sesr-fe" or name == "sesr-ne" or name == "uas-fe" or name == "uas-ne" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.otu_hour24otn_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.otu_hour24otn_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "otu-hour24otn-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "otu-hour24otn-time-line-instance"):
                                                for c in self.otu_hour24otn_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances.OtuHour24OtnTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.otu_hour24otn_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "otu-hour24otn-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.otu_hour24otn_time_line_instances is not None and self.otu_hour24otn_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.otu_hour24otn_time_line_instances is not None and self.otu_hour24otn_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "otu-hour24otn-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "otu-hour24otn-time-line-instances"):
                                            if (self.otu_hour24otn_time_line_instances is None):
                                                self.otu_hour24otn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory.OtuHour24OtnTimeLineInstances()
                                                self.otu_hour24otn_time_line_instances.parent = self
                                                self._children_name_map["otu_hour24otn_time_line_instances"] = "otu-hour24otn-time-line-instances"
                                            return self.otu_hour24otn_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "otu-hour24otn-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.otu_hour24otn_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.otu_hour24otn_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "otu-hour24otn-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "otu-hour24otn-history"):
                                        for c in self.otu_hour24otn_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories.OtuHour24OtnHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.otu_hour24otn_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "otu-hour24otn-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class OtuHour24FecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: otu_hour24fec_history
                                
                                	port 24 hour fec performance data
                                	**type**\: list of    :py:class:`OtuHour24FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories, self).__init__()

                                    self.yang_name = "otu-hour24fec-histories"
                                    self.yang_parent_name = "otu-hour24-history"

                                    self.otu_hour24fec_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories, self).__setattr__(name, value)


                                class OtuHour24FecHistory(Entity):
                                    """
                                    port 24 hour fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: otu_hour24fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OtuHour24FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory, self).__init__()

                                        self.yang_name = "otu-hour24fec-history"
                                        self.yang_parent_name = "otu-hour24fec-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.otu_hour24fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances()
                                        self.otu_hour24fec_time_line_instances.parent = self
                                        self._children_name_map["otu_hour24fec_time_line_instances"] = "otu-hour24fec-time-line-instances"
                                        self._children_yang_names.add("otu-hour24fec-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory, self).__setattr__(name, value)


                                    class OtuHour24FecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: otu_hour24fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of    :py:class:`OtuHour24FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances, self).__init__()

                                            self.yang_name = "otu-hour24fec-time-line-instances"
                                            self.yang_parent_name = "otu-hour24fec-history"

                                            self.otu_hour24fec_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances, self).__setattr__(name, value)


                                        class OtuHour24FecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance, self).__init__()

                                                self.yang_name = "otu-hour24fec-time-line-instance"
                                                self.yang_parent_name = "otu-hour24fec-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"
                                                self._children_yang_names.add("ec-bits")

                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                self._children_yang_names.add("post-fec-ber")

                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                self._children_yang_names.add("pre-fec-ber")

                                                self.q = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"
                                                self._children_yang_names.add("q")

                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._children_yang_names.add("qmargin")

                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"
                                                self._children_yang_names.add("uc-words")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance, self).__setattr__(name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "otu-hour24fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.EcBits, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.EcBits, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ec-bits" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "otu-hour24fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.UcWords, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.UcWords, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uc-words" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "otu-hour24fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pre-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "otu-hour24fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "post-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "otu-hour24fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Q, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Q, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "q" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "otu-hour24fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Qmargin, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Qmargin, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "qmargin" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_data()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                                    (self.q is not None and self.q.has_data()) or
                                                    (self.qmargin is not None and self.qmargin.has_data()) or
                                                    (self.uc_words is not None and self.uc_words.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                                    (self.q is not None and self.q.has_operation()) or
                                                    (self.qmargin is not None and self.qmargin.has_operation()) or
                                                    (self.uc_words is not None and self.uc_words.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "otu-hour24fec-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ec-bits"):
                                                    if (self.ec_bits is None):
                                                        self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.EcBits()
                                                        self.ec_bits.parent = self
                                                        self._children_name_map["ec_bits"] = "ec-bits"
                                                    return self.ec_bits

                                                if (child_yang_name == "post-fec-ber"):
                                                    if (self.post_fec_ber is None):
                                                        self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PostFecBer()
                                                        self.post_fec_ber.parent = self
                                                        self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                    return self.post_fec_ber

                                                if (child_yang_name == "pre-fec-ber"):
                                                    if (self.pre_fec_ber is None):
                                                        self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.PreFecBer()
                                                        self.pre_fec_ber.parent = self
                                                        self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                    return self.pre_fec_ber

                                                if (child_yang_name == "q"):
                                                    if (self.q is None):
                                                        self.q = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Q()
                                                        self.q.parent = self
                                                        self._children_name_map["q"] = "q"
                                                    return self.q

                                                if (child_yang_name == "qmargin"):
                                                    if (self.qmargin is None):
                                                        self.qmargin = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.Qmargin()
                                                        self.qmargin.parent = self
                                                        self._children_name_map["qmargin"] = "qmargin"
                                                    return self.qmargin

                                                if (child_yang_name == "uc-words"):
                                                    if (self.uc_words is None):
                                                        self.uc_words = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance.UcWords()
                                                        self.uc_words.parent = self
                                                        self._children_name_map["uc_words"] = "uc-words"
                                                    return self.uc_words

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.otu_hour24fec_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.otu_hour24fec_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "otu-hour24fec-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "otu-hour24fec-time-line-instance"):
                                                for c in self.otu_hour24fec_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances.OtuHour24FecTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.otu_hour24fec_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "otu-hour24fec-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.otu_hour24fec_time_line_instances is not None and self.otu_hour24fec_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.otu_hour24fec_time_line_instances is not None and self.otu_hour24fec_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "otu-hour24fec-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "otu-hour24fec-time-line-instances"):
                                            if (self.otu_hour24fec_time_line_instances is None):
                                                self.otu_hour24fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory.OtuHour24FecTimeLineInstances()
                                                self.otu_hour24fec_time_line_instances.parent = self
                                                self._children_name_map["otu_hour24fec_time_line_instances"] = "otu-hour24fec-time-line-instances"
                                            return self.otu_hour24fec_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "otu-hour24fec-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.otu_hour24fec_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.otu_hour24fec_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "otu-hour24fec-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "otu-hour24fec-history"):
                                        for c in self.otu_hour24fec_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories.OtuHour24FecHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.otu_hour24fec_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "otu-hour24fec-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    (self.otu_hour24fec_histories is not None and self.otu_hour24fec_histories.has_data()) or
                                    (self.otu_hour24otn_histories is not None and self.otu_hour24otn_histories.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.otu_hour24fec_histories is not None and self.otu_hour24fec_histories.has_operation()) or
                                    (self.otu_hour24otn_histories is not None and self.otu_hour24otn_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "otu-hour24-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "otu-hour24fec-histories"):
                                    if (self.otu_hour24fec_histories is None):
                                        self.otu_hour24fec_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24FecHistories()
                                        self.otu_hour24fec_histories.parent = self
                                        self._children_name_map["otu_hour24fec_histories"] = "otu-hour24fec-histories"
                                    return self.otu_hour24fec_histories

                                if (child_yang_name == "otu-hour24otn-histories"):
                                    if (self.otu_hour24otn_histories is None):
                                        self.otu_hour24otn_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History.OtuHour24OtnHistories()
                                        self.otu_hour24otn_histories.parent = self
                                        self._children_name_map["otu_hour24otn_histories"] = "otu-hour24otn-histories"
                                    return self.otu_hour24otn_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "otu-hour24fec-histories" or name == "otu-hour24otn-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.name.is_set or
                                (self.otu_hour24_history is not None and self.otu_hour24_history.has_data()) or
                                (self.otu_minute15_history is not None and self.otu_minute15_history.has_data()) or
                                (self.otu_second30_history is not None and self.otu_second30_history.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                (self.otu_hour24_history is not None and self.otu_hour24_history.has_operation()) or
                                (self.otu_minute15_history is not None and self.otu_minute15_history.has_operation()) or
                                (self.otu_second30_history is not None and self.otu_second30_history.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "otu-port-history" + "[name='" + self.name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/otu-history/otu-port-histories/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "otu-hour24-history"):
                                if (self.otu_hour24_history is None):
                                    self.otu_hour24_history = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuHour24History()
                                    self.otu_hour24_history.parent = self
                                    self._children_name_map["otu_hour24_history"] = "otu-hour24-history"
                                return self.otu_hour24_history

                            if (child_yang_name == "otu-minute15-history"):
                                if (self.otu_minute15_history is None):
                                    self.otu_minute15_history = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuMinute15History()
                                    self.otu_minute15_history.parent = self
                                    self._children_name_map["otu_minute15_history"] = "otu-minute15-history"
                                return self.otu_minute15_history

                            if (child_yang_name == "otu-second30-history"):
                                if (self.otu_second30_history is None):
                                    self.otu_second30_history = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory.OtuSecond30History()
                                    self.otu_second30_history.parent = self
                                    self._children_name_map["otu_second30_history"] = "otu-second30-history"
                                return self.otu_second30_history

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "otu-hour24-history" or name == "otu-minute15-history" or name == "otu-second30-history" or name == "name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.otu_port_history:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.otu_port_history:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "otu-port-histories" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/otu-history/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "otu-port-history"):
                            for c in self.otu_port_history:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories.OtuPortHistory()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.otu_port_history.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "otu-port-history"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.otu_port_histories is not None and self.otu_port_histories.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.otu_port_histories is not None and self.otu_port_histories.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "otu-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "otu-port-histories"):
                        if (self.otu_port_histories is None):
                            self.otu_port_histories = PerformanceManagementHistory.Global_.Periodic.OtuHistory.OtuPortHistories()
                            self.otu_port_histories.parent = self
                            self._children_name_map["otu_port_histories"] = "otu-port-histories"
                        return self.otu_port_histories

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "otu-port-histories"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class HoVcHistory(Entity):
                """
                HO\_VC controller History performance data
                
                .. attribute:: ho_vc_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`HoVcPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory, self).__init__()

                    self.yang_name = "ho-vc-history"
                    self.yang_parent_name = "periodic"

                    self.ho_vc_port_histories = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories()
                    self.ho_vc_port_histories.parent = self
                    self._children_name_map["ho_vc_port_histories"] = "ho-vc-port-histories"
                    self._children_yang_names.add("ho-vc-port-histories")


                class HoVcPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: ho_vc_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`HoVcPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories, self).__init__()

                        self.yang_name = "ho-vc-port-histories"
                        self.yang_parent_name = "ho-vc-history"

                        self.ho_vc_port_history = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories, self).__setattr__(name, value)


                    class HoVcPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: ho_vc_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`HoVcHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History>`
                        
                        .. attribute:: ho_vc_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`HoVcMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory, self).__init__()

                            self.yang_name = "ho-vc-port-history"
                            self.yang_parent_name = "ho-vc-port-histories"

                            self.name = YLeaf(YType.str, "name")

                            self.ho_vc_hour24_history = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History()
                            self.ho_vc_hour24_history.parent = self
                            self._children_name_map["ho_vc_hour24_history"] = "ho-vc-hour24-history"
                            self._children_yang_names.add("ho-vc-hour24-history")

                            self.ho_vc_minute15_history = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History()
                            self.ho_vc_minute15_history.parent = self
                            self._children_name_map["ho_vc_minute15_history"] = "ho-vc-minute15-history"
                            self._children_yang_names.add("ho-vc-minute15-history")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory, self).__setattr__(name, value)


                        class HoVcMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: ho_vc_minute15_path_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`HoVcMinute15PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History, self).__init__()

                                self.yang_name = "ho-vc-minute15-history"
                                self.yang_parent_name = "ho-vc-port-history"

                                self.ho_vc_minute15_path_histories = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories()
                                self.ho_vc_minute15_path_histories.parent = self
                                self._children_name_map["ho_vc_minute15_path_histories"] = "ho-vc-minute15-path-histories"
                                self._children_yang_names.add("ho-vc-minute15-path-histories")


                            class HoVcMinute15PathHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: ho_vc_minute15_path_history
                                
                                	port 15\-minute Path performance data
                                	**type**\: list of    :py:class:`HoVcMinute15PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories, self).__init__()

                                    self.yang_name = "ho-vc-minute15-path-histories"
                                    self.yang_parent_name = "ho-vc-minute15-history"

                                    self.ho_vc_minute15_path_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories, self).__setattr__(name, value)


                                class HoVcMinute15PathHistory(Entity):
                                    """
                                    port 15\-minute Path performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ho_vc_minute15_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`HoVcMinute15PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory, self).__init__()

                                        self.yang_name = "ho-vc-minute15-path-history"
                                        self.yang_parent_name = "ho-vc-minute15-path-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.ho_vc_minute15_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances()
                                        self.ho_vc_minute15_path_time_line_instances.parent = self
                                        self._children_name_map["ho_vc_minute15_path_time_line_instances"] = "ho-vc-minute15-path-time-line-instances"
                                        self._children_yang_names.add("ho-vc-minute15-path-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory, self).__setattr__(name, value)


                                    class HoVcMinute15PathTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: ho_vc_minute15_path_time_line_instance
                                        
                                        	port 15\-minute ho\_vc performance data
                                        	**type**\: list of    :py:class:`HoVcMinute15PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances, self).__init__()

                                            self.yang_name = "ho-vc-minute15-path-time-line-instances"
                                            self.yang_parent_name = "ho-vc-minute15-path-history"

                                            self.ho_vc_minute15_path_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances, self).__setattr__(name, value)


                                        class HoVcMinute15PathTimeLineInstance(Entity):
                                            """
                                            port 15\-minute ho\_vc performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance, self).__init__()

                                                self.yang_name = "ho-vc-minute15-path-time-line-instance"
                                                self.yang_parent_name = "ho-vc-minute15-path-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.fe_path = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self._children_name_map["fe_path"] = "fe-path"
                                                self._children_yang_names.add("fe-path")

                                                self.path = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self._children_name_map["path"] = "path"
                                                self._children_yang_names.add("path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance, self).__setattr__(name, value)


                                            class Path(Entity):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_bb_es
                                                
                                                	The number of background block errors
                                                	**type**\:   :py:class:`PathBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs>`
                                                
                                                .. attribute:: path_bbe_rs
                                                
                                                	The number of background block errors
                                                	**type**\:   :py:class:`PathBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs>`
                                                
                                                .. attribute:: path_e_bs
                                                
                                                	The number of Errored blocks
                                                	**type**\:   :py:class:`PathEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs>`
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_es_rs
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_ses_rs
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path, self).__init__()

                                                    self.yang_name = "path"
                                                    self.yang_parent_name = "ho-vc-minute15-path-time-line-instance"

                                                    self.path_status = YLeaf(YType.int32, "path-status")

                                                    self.path_bb_es = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs()
                                                    self.path_bb_es.parent = self
                                                    self._children_name_map["path_bb_es"] = "path-bb-es"
                                                    self._children_yang_names.add("path-bb-es")

                                                    self.path_bbe_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs()
                                                    self.path_bbe_rs.parent = self
                                                    self._children_name_map["path_bbe_rs"] = "path-bbe-rs"
                                                    self._children_yang_names.add("path-bbe-rs")

                                                    self.path_e_bs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs()
                                                    self.path_e_bs.parent = self
                                                    self._children_name_map["path_e_bs"] = "path-e-bs"
                                                    self._children_yang_names.add("path-e-bs")

                                                    self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self._children_name_map["path_e_ss"] = "path-e-ss"
                                                    self._children_yang_names.add("path-e-ss")

                                                    self.path_es_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs()
                                                    self.path_es_rs.parent = self
                                                    self._children_name_map["path_es_rs"] = "path-es-rs"
                                                    self._children_yang_names.add("path-es-rs")

                                                    self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self._children_name_map["path_se_ss"] = "path-se-ss"
                                                    self._children_yang_names.add("path-se-ss")

                                                    self.path_ses_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs()
                                                    self.path_ses_rs.parent = self
                                                    self._children_name_map["path_ses_rs"] = "path-ses-rs"
                                                    self._children_yang_names.add("path-ses-rs")

                                                    self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                    self._children_yang_names.add("path-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("path_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path, self).__setattr__(name, value)


                                                class PathESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs, self).__init__()

                                                        self.yang_name = "path-e-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs, self).__init__()

                                                        self.yang_name = "path-es-rs"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-es-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs, self).__init__()

                                                        self.yang_name = "path-se-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs, self).__init__()

                                                        self.yang_name = "path-ses-rs"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-ses-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathEBs(Entity):
                                                    """
                                                    The number of Errored blocks
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs, self).__init__()

                                                        self.yang_name = "path-e-bs"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-e-bs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs, self).__init__()

                                                        self.yang_name = "path-ua-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathBbEs(Entity):
                                                    """
                                                    The number of background block errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs, self).__init__()

                                                        self.yang_name = "path-bb-es"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-bb-es" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathBbeRs(Entity):
                                                    """
                                                    The number of background block errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs, self).__init__()

                                                        self.yang_name = "path-bbe-rs"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-bbe-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.path_status.is_set or
                                                        (self.path_bb_es is not None and self.path_bb_es.has_data()) or
                                                        (self.path_bbe_rs is not None and self.path_bbe_rs.has_data()) or
                                                        (self.path_e_bs is not None and self.path_e_bs.has_data()) or
                                                        (self.path_e_ss is not None and self.path_e_ss.has_data()) or
                                                        (self.path_es_rs is not None and self.path_es_rs.has_data()) or
                                                        (self.path_se_ss is not None and self.path_se_ss.has_data()) or
                                                        (self.path_ses_rs is not None and self.path_ses_rs.has_data()) or
                                                        (self.path_ua_ss is not None and self.path_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.path_status.yfilter != YFilter.not_set or
                                                        (self.path_bb_es is not None and self.path_bb_es.has_operation()) or
                                                        (self.path_bbe_rs is not None and self.path_bbe_rs.has_operation()) or
                                                        (self.path_e_bs is not None and self.path_e_bs.has_operation()) or
                                                        (self.path_e_ss is not None and self.path_e_ss.has_operation()) or
                                                        (self.path_es_rs is not None and self.path_es_rs.has_operation()) or
                                                        (self.path_se_ss is not None and self.path_se_ss.has_operation()) or
                                                        (self.path_ses_rs is not None and self.path_ses_rs.has_operation()) or
                                                        (self.path_ua_ss is not None and self.path_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.path_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "path-bb-es"):
                                                        if (self.path_bb_es is None):
                                                            self.path_bb_es = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbEs()
                                                            self.path_bb_es.parent = self
                                                            self._children_name_map["path_bb_es"] = "path-bb-es"
                                                        return self.path_bb_es

                                                    if (child_yang_name == "path-bbe-rs"):
                                                        if (self.path_bbe_rs is None):
                                                            self.path_bbe_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathBbeRs()
                                                            self.path_bbe_rs.parent = self
                                                            self._children_name_map["path_bbe_rs"] = "path-bbe-rs"
                                                        return self.path_bbe_rs

                                                    if (child_yang_name == "path-e-bs"):
                                                        if (self.path_e_bs is None):
                                                            self.path_e_bs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEBs()
                                                            self.path_e_bs.parent = self
                                                            self._children_name_map["path_e_bs"] = "path-e-bs"
                                                        return self.path_e_bs

                                                    if (child_yang_name == "path-e-ss"):
                                                        if (self.path_e_ss is None):
                                                            self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathESs()
                                                            self.path_e_ss.parent = self
                                                            self._children_name_map["path_e_ss"] = "path-e-ss"
                                                        return self.path_e_ss

                                                    if (child_yang_name == "path-es-rs"):
                                                        if (self.path_es_rs is None):
                                                            self.path_es_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathEsRs()
                                                            self.path_es_rs.parent = self
                                                            self._children_name_map["path_es_rs"] = "path-es-rs"
                                                        return self.path_es_rs

                                                    if (child_yang_name == "path-se-ss"):
                                                        if (self.path_se_ss is None):
                                                            self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSeSs()
                                                            self.path_se_ss.parent = self
                                                            self._children_name_map["path_se_ss"] = "path-se-ss"
                                                        return self.path_se_ss

                                                    if (child_yang_name == "path-ses-rs"):
                                                        if (self.path_ses_rs is None):
                                                            self.path_ses_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathSesRs()
                                                            self.path_ses_rs.parent = self
                                                            self._children_name_map["path_ses_rs"] = "path-ses-rs"
                                                        return self.path_ses_rs

                                                    if (child_yang_name == "path-ua-ss"):
                                                        if (self.path_ua_ss is None):
                                                            self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path.PathUaSs()
                                                            self.path_ua_ss.parent = self
                                                            self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                        return self.path_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "path-bb-es" or name == "path-bbe-rs" or name == "path-e-bs" or name == "path-e-ss" or name == "path-es-rs" or name == "path-se-ss" or name == "path-ses-rs" or name == "path-ua-ss" or name == "path-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "path-status"):
                                                        self.path_status = value
                                                        self.path_status.value_namespace = name_space
                                                        self.path_status.value_namespace_prefix = name_space_prefix


                                            class FePath(Entity):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath, self).__init__()

                                                    self.yang_name = "fe-path"
                                                    self.yang_parent_name = "ho-vc-minute15-path-time-line-instance"

                                                    self.far_end_path_c_vs = YLeaf(YType.uint32, "far-end-path-c-vs")

                                                    self.far_end_path_e_ss = YLeaf(YType.uint32, "far-end-path-e-ss")

                                                    self.far_end_path_se_ss = YLeaf(YType.uint32, "far-end-path-se-ss")

                                                    self.far_end_path_ua_ss = YLeaf(YType.uint32, "far-end-path-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("far_end_path_c_vs",
                                                                    "far_end_path_e_ss",
                                                                    "far_end_path_se_ss",
                                                                    "far_end_path_ua_ss") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.far_end_path_c_vs.is_set or
                                                        self.far_end_path_e_ss.is_set or
                                                        self.far_end_path_se_ss.is_set or
                                                        self.far_end_path_ua_ss.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.far_end_path_c_vs.yfilter != YFilter.not_set or
                                                        self.far_end_path_e_ss.yfilter != YFilter.not_set or
                                                        self.far_end_path_se_ss.yfilter != YFilter.not_set or
                                                        self.far_end_path_ua_ss.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fe-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.far_end_path_c_vs.is_set or self.far_end_path_c_vs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_c_vs.get_name_leafdata())
                                                    if (self.far_end_path_e_ss.is_set or self.far_end_path_e_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_e_ss.get_name_leafdata())
                                                    if (self.far_end_path_se_ss.is_set or self.far_end_path_se_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_se_ss.get_name_leafdata())
                                                    if (self.far_end_path_ua_ss.is_set or self.far_end_path_ua_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_ua_ss.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "far-end-path-c-vs" or name == "far-end-path-e-ss" or name == "far-end-path-se-ss" or name == "far-end-path-ua-ss"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "far-end-path-c-vs"):
                                                        self.far_end_path_c_vs = value
                                                        self.far_end_path_c_vs.value_namespace = name_space
                                                        self.far_end_path_c_vs.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-e-ss"):
                                                        self.far_end_path_e_ss = value
                                                        self.far_end_path_e_ss.value_namespace = name_space
                                                        self.far_end_path_e_ss.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-se-ss"):
                                                        self.far_end_path_se_ss = value
                                                        self.far_end_path_se_ss.value_namespace = name_space
                                                        self.far_end_path_se_ss.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-ua-ss"):
                                                        self.far_end_path_ua_ss = value
                                                        self.far_end_path_ua_ss.value_namespace = name_space
                                                        self.far_end_path_ua_ss.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.fe_path is not None and self.fe_path.has_data()) or
                                                    (self.path is not None and self.path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.fe_path is not None and self.fe_path.has_operation()) or
                                                    (self.path is not None and self.path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ho-vc-minute15-path-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "fe-path"):
                                                    if (self.fe_path is None):
                                                        self.fe_path = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.FePath()
                                                        self.fe_path.parent = self
                                                        self._children_name_map["fe_path"] = "fe-path"
                                                    return self.fe_path

                                                if (child_yang_name == "path"):
                                                    if (self.path is None):
                                                        self.path = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance.Path()
                                                        self.path.parent = self
                                                        self._children_name_map["path"] = "path"
                                                    return self.path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "fe-path" or name == "path" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.ho_vc_minute15_path_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.ho_vc_minute15_path_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ho-vc-minute15-path-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "ho-vc-minute15-path-time-line-instance"):
                                                for c in self.ho_vc_minute15_path_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances.HoVcMinute15PathTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ho_vc_minute15_path_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ho-vc-minute15-path-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.ho_vc_minute15_path_time_line_instances is not None and self.ho_vc_minute15_path_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.ho_vc_minute15_path_time_line_instances is not None and self.ho_vc_minute15_path_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ho-vc-minute15-path-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "ho-vc-minute15-path-time-line-instances"):
                                            if (self.ho_vc_minute15_path_time_line_instances is None):
                                                self.ho_vc_minute15_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory.HoVcMinute15PathTimeLineInstances()
                                                self.ho_vc_minute15_path_time_line_instances.parent = self
                                                self._children_name_map["ho_vc_minute15_path_time_line_instances"] = "ho-vc-minute15-path-time-line-instances"
                                            return self.ho_vc_minute15_path_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ho-vc-minute15-path-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.ho_vc_minute15_path_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.ho_vc_minute15_path_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ho-vc-minute15-path-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ho-vc-minute15-path-history"):
                                        for c in self.ho_vc_minute15_path_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories.HoVcMinute15PathHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.ho_vc_minute15_path_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ho-vc-minute15-path-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.ho_vc_minute15_path_histories is not None and self.ho_vc_minute15_path_histories.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.ho_vc_minute15_path_histories is not None and self.ho_vc_minute15_path_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ho-vc-minute15-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ho-vc-minute15-path-histories"):
                                    if (self.ho_vc_minute15_path_histories is None):
                                        self.ho_vc_minute15_path_histories = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History.HoVcMinute15PathHistories()
                                        self.ho_vc_minute15_path_histories.parent = self
                                        self._children_name_map["ho_vc_minute15_path_histories"] = "ho-vc-minute15-path-histories"
                                    return self.ho_vc_minute15_path_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ho-vc-minute15-path-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class HoVcHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: ho_vc_hour24_path_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`HoVcHour24PathHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History, self).__init__()

                                self.yang_name = "ho-vc-hour24-history"
                                self.yang_parent_name = "ho-vc-port-history"

                                self.ho_vc_hour24_path_histories = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories()
                                self.ho_vc_hour24_path_histories.parent = self
                                self._children_name_map["ho_vc_hour24_path_histories"] = "ho-vc-hour24-path-histories"
                                self._children_yang_names.add("ho-vc-hour24-path-histories")


                            class HoVcHour24PathHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: ho_vc_hour24_path_history
                                
                                	port 24 hour Path performance data
                                	**type**\: list of    :py:class:`HoVcHour24PathHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories, self).__init__()

                                    self.yang_name = "ho-vc-hour24-path-histories"
                                    self.yang_parent_name = "ho-vc-hour24-history"

                                    self.ho_vc_hour24_path_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories, self).__setattr__(name, value)


                                class HoVcHour24PathHistory(Entity):
                                    """
                                    port 24 hour Path performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ho_vc_hour24_path_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`HoVcHour24PathTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory, self).__init__()

                                        self.yang_name = "ho-vc-hour24-path-history"
                                        self.yang_parent_name = "ho-vc-hour24-path-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.ho_vc_hour24_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances()
                                        self.ho_vc_hour24_path_time_line_instances.parent = self
                                        self._children_name_map["ho_vc_hour24_path_time_line_instances"] = "ho-vc-hour24-path-time-line-instances"
                                        self._children_yang_names.add("ho-vc-hour24-path-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory, self).__setattr__(name, value)


                                    class HoVcHour24PathTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: ho_vc_hour24_path_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`HoVcHour24PathTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances, self).__init__()

                                            self.yang_name = "ho-vc-hour24-path-time-line-instances"
                                            self.yang_parent_name = "ho-vc-hour24-path-history"

                                            self.ho_vc_hour24_path_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances, self).__setattr__(name, value)


                                        class HoVcHour24PathTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_path
                                            
                                            	Far End PATH
                                            	**type**\:   :py:class:`FePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: path
                                            
                                            	PATH
                                            	**type**\:   :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance, self).__init__()

                                                self.yang_name = "ho-vc-hour24-path-time-line-instance"
                                                self.yang_parent_name = "ho-vc-hour24-path-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.fe_path = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath()
                                                self.fe_path.parent = self
                                                self._children_name_map["fe_path"] = "fe-path"
                                                self._children_yang_names.add("fe-path")

                                                self.path = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path()
                                                self.path.parent = self
                                                self._children_name_map["path"] = "path"
                                                self._children_yang_names.add("path")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance, self).__setattr__(name, value)


                                            class Path(Entity):
                                                """
                                                PATH
                                                
                                                .. attribute:: path_bb_es
                                                
                                                	The number of background block errors
                                                	**type**\:   :py:class:`PathBbEs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs>`
                                                
                                                .. attribute:: path_bbe_rs
                                                
                                                	The number of background block errors
                                                	**type**\:   :py:class:`PathBbeRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs>`
                                                
                                                .. attribute:: path_e_bs
                                                
                                                	The number of Errored blocks
                                                	**type**\:   :py:class:`PathEBs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs>`
                                                
                                                .. attribute:: path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs>`
                                                
                                                .. attribute:: path_es_rs
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`PathEsRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs>`
                                                
                                                .. attribute:: path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs>`
                                                
                                                .. attribute:: path_ses_rs
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`PathSesRs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs>`
                                                
                                                .. attribute:: path_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`PathUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path, self).__init__()

                                                    self.yang_name = "path"
                                                    self.yang_parent_name = "ho-vc-hour24-path-time-line-instance"

                                                    self.path_status = YLeaf(YType.int32, "path-status")

                                                    self.path_bb_es = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs()
                                                    self.path_bb_es.parent = self
                                                    self._children_name_map["path_bb_es"] = "path-bb-es"
                                                    self._children_yang_names.add("path-bb-es")

                                                    self.path_bbe_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs()
                                                    self.path_bbe_rs.parent = self
                                                    self._children_name_map["path_bbe_rs"] = "path-bbe-rs"
                                                    self._children_yang_names.add("path-bbe-rs")

                                                    self.path_e_bs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs()
                                                    self.path_e_bs.parent = self
                                                    self._children_name_map["path_e_bs"] = "path-e-bs"
                                                    self._children_yang_names.add("path-e-bs")

                                                    self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs()
                                                    self.path_e_ss.parent = self
                                                    self._children_name_map["path_e_ss"] = "path-e-ss"
                                                    self._children_yang_names.add("path-e-ss")

                                                    self.path_es_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs()
                                                    self.path_es_rs.parent = self
                                                    self._children_name_map["path_es_rs"] = "path-es-rs"
                                                    self._children_yang_names.add("path-es-rs")

                                                    self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs()
                                                    self.path_se_ss.parent = self
                                                    self._children_name_map["path_se_ss"] = "path-se-ss"
                                                    self._children_yang_names.add("path-se-ss")

                                                    self.path_ses_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs()
                                                    self.path_ses_rs.parent = self
                                                    self._children_name_map["path_ses_rs"] = "path-ses-rs"
                                                    self._children_yang_names.add("path-ses-rs")

                                                    self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs()
                                                    self.path_ua_ss.parent = self
                                                    self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                    self._children_yang_names.add("path-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("path_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path, self).__setattr__(name, value)


                                                class PathESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs, self).__init__()

                                                        self.yang_name = "path-e-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathEsRs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs, self).__init__()

                                                        self.yang_name = "path-es-rs"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-es-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs, self).__init__()

                                                        self.yang_name = "path-se-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathSesRs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs, self).__init__()

                                                        self.yang_name = "path-ses-rs"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-ses-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathEBs(Entity):
                                                    """
                                                    The number of Errored blocks
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs, self).__init__()

                                                        self.yang_name = "path-e-bs"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-e-bs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs, self).__init__()

                                                        self.yang_name = "path-ua-ss"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathBbEs(Entity):
                                                    """
                                                    The number of background block errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs, self).__init__()

                                                        self.yang_name = "path-bb-es"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-bb-es" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class PathBbeRs(Entity):
                                                    """
                                                    The number of background block errors
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..8
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs, self).__init__()

                                                        self.yang_name = "path-bbe-rs"
                                                        self.yang_parent_name = "path"

                                                        self.data = YLeaf(YType.str, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.str, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "path-bbe-rs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.path_status.is_set or
                                                        (self.path_bb_es is not None and self.path_bb_es.has_data()) or
                                                        (self.path_bbe_rs is not None and self.path_bbe_rs.has_data()) or
                                                        (self.path_e_bs is not None and self.path_e_bs.has_data()) or
                                                        (self.path_e_ss is not None and self.path_e_ss.has_data()) or
                                                        (self.path_es_rs is not None and self.path_es_rs.has_data()) or
                                                        (self.path_se_ss is not None and self.path_se_ss.has_data()) or
                                                        (self.path_ses_rs is not None and self.path_ses_rs.has_data()) or
                                                        (self.path_ua_ss is not None and self.path_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.path_status.yfilter != YFilter.not_set or
                                                        (self.path_bb_es is not None and self.path_bb_es.has_operation()) or
                                                        (self.path_bbe_rs is not None and self.path_bbe_rs.has_operation()) or
                                                        (self.path_e_bs is not None and self.path_e_bs.has_operation()) or
                                                        (self.path_e_ss is not None and self.path_e_ss.has_operation()) or
                                                        (self.path_es_rs is not None and self.path_es_rs.has_operation()) or
                                                        (self.path_se_ss is not None and self.path_se_ss.has_operation()) or
                                                        (self.path_ses_rs is not None and self.path_ses_rs.has_operation()) or
                                                        (self.path_ua_ss is not None and self.path_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.path_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "path-bb-es"):
                                                        if (self.path_bb_es is None):
                                                            self.path_bb_es = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbEs()
                                                            self.path_bb_es.parent = self
                                                            self._children_name_map["path_bb_es"] = "path-bb-es"
                                                        return self.path_bb_es

                                                    if (child_yang_name == "path-bbe-rs"):
                                                        if (self.path_bbe_rs is None):
                                                            self.path_bbe_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathBbeRs()
                                                            self.path_bbe_rs.parent = self
                                                            self._children_name_map["path_bbe_rs"] = "path-bbe-rs"
                                                        return self.path_bbe_rs

                                                    if (child_yang_name == "path-e-bs"):
                                                        if (self.path_e_bs is None):
                                                            self.path_e_bs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEBs()
                                                            self.path_e_bs.parent = self
                                                            self._children_name_map["path_e_bs"] = "path-e-bs"
                                                        return self.path_e_bs

                                                    if (child_yang_name == "path-e-ss"):
                                                        if (self.path_e_ss is None):
                                                            self.path_e_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathESs()
                                                            self.path_e_ss.parent = self
                                                            self._children_name_map["path_e_ss"] = "path-e-ss"
                                                        return self.path_e_ss

                                                    if (child_yang_name == "path-es-rs"):
                                                        if (self.path_es_rs is None):
                                                            self.path_es_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathEsRs()
                                                            self.path_es_rs.parent = self
                                                            self._children_name_map["path_es_rs"] = "path-es-rs"
                                                        return self.path_es_rs

                                                    if (child_yang_name == "path-se-ss"):
                                                        if (self.path_se_ss is None):
                                                            self.path_se_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSeSs()
                                                            self.path_se_ss.parent = self
                                                            self._children_name_map["path_se_ss"] = "path-se-ss"
                                                        return self.path_se_ss

                                                    if (child_yang_name == "path-ses-rs"):
                                                        if (self.path_ses_rs is None):
                                                            self.path_ses_rs = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathSesRs()
                                                            self.path_ses_rs.parent = self
                                                            self._children_name_map["path_ses_rs"] = "path-ses-rs"
                                                        return self.path_ses_rs

                                                    if (child_yang_name == "path-ua-ss"):
                                                        if (self.path_ua_ss is None):
                                                            self.path_ua_ss = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path.PathUaSs()
                                                            self.path_ua_ss.parent = self
                                                            self._children_name_map["path_ua_ss"] = "path-ua-ss"
                                                        return self.path_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "path-bb-es" or name == "path-bbe-rs" or name == "path-e-bs" or name == "path-e-ss" or name == "path-es-rs" or name == "path-se-ss" or name == "path-ses-rs" or name == "path-ua-ss" or name == "path-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "path-status"):
                                                        self.path_status = value
                                                        self.path_status.value_namespace = name_space
                                                        self.path_status.value_namespace_prefix = name_space_prefix


                                            class FePath(Entity):
                                                """
                                                Far End PATH
                                                
                                                .. attribute:: far_end_path_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: far_end_path_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: far_end_path_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath, self).__init__()

                                                    self.yang_name = "fe-path"
                                                    self.yang_parent_name = "ho-vc-hour24-path-time-line-instance"

                                                    self.far_end_path_c_vs = YLeaf(YType.uint32, "far-end-path-c-vs")

                                                    self.far_end_path_e_ss = YLeaf(YType.uint32, "far-end-path-e-ss")

                                                    self.far_end_path_se_ss = YLeaf(YType.uint32, "far-end-path-se-ss")

                                                    self.far_end_path_ua_ss = YLeaf(YType.uint32, "far-end-path-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("far_end_path_c_vs",
                                                                    "far_end_path_e_ss",
                                                                    "far_end_path_se_ss",
                                                                    "far_end_path_ua_ss") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.far_end_path_c_vs.is_set or
                                                        self.far_end_path_e_ss.is_set or
                                                        self.far_end_path_se_ss.is_set or
                                                        self.far_end_path_ua_ss.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.far_end_path_c_vs.yfilter != YFilter.not_set or
                                                        self.far_end_path_e_ss.yfilter != YFilter.not_set or
                                                        self.far_end_path_se_ss.yfilter != YFilter.not_set or
                                                        self.far_end_path_ua_ss.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fe-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.far_end_path_c_vs.is_set or self.far_end_path_c_vs.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_c_vs.get_name_leafdata())
                                                    if (self.far_end_path_e_ss.is_set or self.far_end_path_e_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_e_ss.get_name_leafdata())
                                                    if (self.far_end_path_se_ss.is_set or self.far_end_path_se_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_se_ss.get_name_leafdata())
                                                    if (self.far_end_path_ua_ss.is_set or self.far_end_path_ua_ss.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.far_end_path_ua_ss.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "far-end-path-c-vs" or name == "far-end-path-e-ss" or name == "far-end-path-se-ss" or name == "far-end-path-ua-ss"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "far-end-path-c-vs"):
                                                        self.far_end_path_c_vs = value
                                                        self.far_end_path_c_vs.value_namespace = name_space
                                                        self.far_end_path_c_vs.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-e-ss"):
                                                        self.far_end_path_e_ss = value
                                                        self.far_end_path_e_ss.value_namespace = name_space
                                                        self.far_end_path_e_ss.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-se-ss"):
                                                        self.far_end_path_se_ss = value
                                                        self.far_end_path_se_ss.value_namespace = name_space
                                                        self.far_end_path_se_ss.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "far-end-path-ua-ss"):
                                                        self.far_end_path_ua_ss = value
                                                        self.far_end_path_ua_ss.value_namespace = name_space
                                                        self.far_end_path_ua_ss.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.fe_path is not None and self.fe_path.has_data()) or
                                                    (self.path is not None and self.path.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.fe_path is not None and self.fe_path.has_operation()) or
                                                    (self.path is not None and self.path.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ho-vc-hour24-path-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "fe-path"):
                                                    if (self.fe_path is None):
                                                        self.fe_path = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.FePath()
                                                        self.fe_path.parent = self
                                                        self._children_name_map["fe_path"] = "fe-path"
                                                    return self.fe_path

                                                if (child_yang_name == "path"):
                                                    if (self.path is None):
                                                        self.path = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance.Path()
                                                        self.path.parent = self
                                                        self._children_name_map["path"] = "path"
                                                    return self.path

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "fe-path" or name == "path" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.ho_vc_hour24_path_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.ho_vc_hour24_path_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ho-vc-hour24-path-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "ho-vc-hour24-path-time-line-instance"):
                                                for c in self.ho_vc_hour24_path_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances.HoVcHour24PathTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ho_vc_hour24_path_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ho-vc-hour24-path-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.ho_vc_hour24_path_time_line_instances is not None and self.ho_vc_hour24_path_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.ho_vc_hour24_path_time_line_instances is not None and self.ho_vc_hour24_path_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ho-vc-hour24-path-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "ho-vc-hour24-path-time-line-instances"):
                                            if (self.ho_vc_hour24_path_time_line_instances is None):
                                                self.ho_vc_hour24_path_time_line_instances = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory.HoVcHour24PathTimeLineInstances()
                                                self.ho_vc_hour24_path_time_line_instances.parent = self
                                                self._children_name_map["ho_vc_hour24_path_time_line_instances"] = "ho-vc-hour24-path-time-line-instances"
                                            return self.ho_vc_hour24_path_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ho-vc-hour24-path-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.ho_vc_hour24_path_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.ho_vc_hour24_path_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ho-vc-hour24-path-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ho-vc-hour24-path-history"):
                                        for c in self.ho_vc_hour24_path_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories.HoVcHour24PathHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.ho_vc_hour24_path_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ho-vc-hour24-path-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.ho_vc_hour24_path_histories is not None and self.ho_vc_hour24_path_histories.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.ho_vc_hour24_path_histories is not None and self.ho_vc_hour24_path_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ho-vc-hour24-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ho-vc-hour24-path-histories"):
                                    if (self.ho_vc_hour24_path_histories is None):
                                        self.ho_vc_hour24_path_histories = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History.HoVcHour24PathHistories()
                                        self.ho_vc_hour24_path_histories.parent = self
                                        self._children_name_map["ho_vc_hour24_path_histories"] = "ho-vc-hour24-path-histories"
                                    return self.ho_vc_hour24_path_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ho-vc-hour24-path-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.name.is_set or
                                (self.ho_vc_hour24_history is not None and self.ho_vc_hour24_history.has_data()) or
                                (self.ho_vc_minute15_history is not None and self.ho_vc_minute15_history.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                (self.ho_vc_hour24_history is not None and self.ho_vc_hour24_history.has_operation()) or
                                (self.ho_vc_minute15_history is not None and self.ho_vc_minute15_history.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ho-vc-port-history" + "[name='" + self.name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/ho-vc-history/ho-vc-port-histories/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ho-vc-hour24-history"):
                                if (self.ho_vc_hour24_history is None):
                                    self.ho_vc_hour24_history = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcHour24History()
                                    self.ho_vc_hour24_history.parent = self
                                    self._children_name_map["ho_vc_hour24_history"] = "ho-vc-hour24-history"
                                return self.ho_vc_hour24_history

                            if (child_yang_name == "ho-vc-minute15-history"):
                                if (self.ho_vc_minute15_history is None):
                                    self.ho_vc_minute15_history = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory.HoVcMinute15History()
                                    self.ho_vc_minute15_history.parent = self
                                    self._children_name_map["ho_vc_minute15_history"] = "ho-vc-minute15-history"
                                return self.ho_vc_minute15_history

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ho-vc-hour24-history" or name == "ho-vc-minute15-history" or name == "name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ho_vc_port_history:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ho_vc_port_history:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ho-vc-port-histories" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/ho-vc-history/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ho-vc-port-history"):
                            for c in self.ho_vc_port_history:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories.HoVcPortHistory()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ho_vc_port_history.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ho-vc-port-history"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.ho_vc_port_histories is not None and self.ho_vc_port_histories.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.ho_vc_port_histories is not None and self.ho_vc_port_histories.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ho-vc-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ho-vc-port-histories"):
                        if (self.ho_vc_port_histories is None):
                            self.ho_vc_port_histories = PerformanceManagementHistory.Global_.Periodic.HoVcHistory.HoVcPortHistories()
                            self.ho_vc_port_histories.parent = self
                            self._children_name_map["ho_vc_port_histories"] = "ho-vc-port-histories"
                        return self.ho_vc_port_histories

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ho-vc-port-histories"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class OpticsHistory(Entity):
                """
                OPTICS controller History performance data
                
                .. attribute:: optics_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`OpticsPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory, self).__init__()

                    self.yang_name = "optics-history"
                    self.yang_parent_name = "periodic"

                    self.optics_port_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories()
                    self.optics_port_histories.parent = self
                    self._children_name_map["optics_port_histories"] = "optics-port-histories"
                    self._children_yang_names.add("optics-port-histories")


                class OpticsPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: optics_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`OpticsPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories, self).__init__()

                        self.yang_name = "optics-port-histories"
                        self.yang_parent_name = "optics-history"

                        self.optics_port_history = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories, self).__setattr__(name, value)


                    class OpticsPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: optics_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History>`
                        
                        .. attribute:: optics_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History>`
                        
                        .. attribute:: optics_second30_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OpticsSecond30History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory, self).__init__()

                            self.yang_name = "optics-port-history"
                            self.yang_parent_name = "optics-port-histories"

                            self.name = YLeaf(YType.str, "name")

                            self.optics_hour24_history = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History()
                            self.optics_hour24_history.parent = self
                            self._children_name_map["optics_hour24_history"] = "optics-hour24-history"
                            self._children_yang_names.add("optics-hour24-history")

                            self.optics_minute15_history = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History()
                            self.optics_minute15_history.parent = self
                            self._children_name_map["optics_minute15_history"] = "optics-minute15-history"
                            self._children_yang_names.add("optics-minute15-history")

                            self.optics_second30_history = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History()
                            self.optics_second30_history.parent = self
                            self._children_name_map["optics_second30_history"] = "optics-second30-history"
                            self._children_yang_names.add("optics-second30-history")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory, self).__setattr__(name, value)


                        class OpticsHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_hour24_optics_histories
                            
                            	port 24 hour performance data
                            	**type**\:   :py:class:`OpticsHour24OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories>`
                            
                            .. attribute:: optics_hour24fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OpticsHour24FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History, self).__init__()

                                self.yang_name = "optics-hour24-history"
                                self.yang_parent_name = "optics-port-history"

                                self.optics_hour24_optics_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories()
                                self.optics_hour24_optics_histories.parent = self
                                self._children_name_map["optics_hour24_optics_histories"] = "optics-hour24-optics-histories"
                                self._children_yang_names.add("optics-hour24-optics-histories")

                                self.optics_hour24fec_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories()
                                self.optics_hour24fec_histories.parent = self
                                self._children_name_map["optics_hour24fec_histories"] = "optics-hour24fec-histories"
                                self._children_yang_names.add("optics-hour24fec-histories")


                            class OpticsHour24OpticsHistories(Entity):
                                """
                                port 24 hour performance data
                                
                                .. attribute:: optics_hour24_optics_history
                                
                                	port 24 hour optics performance data
                                	**type**\: list of    :py:class:`OpticsHour24OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories, self).__init__()

                                    self.yang_name = "optics-hour24-optics-histories"
                                    self.yang_parent_name = "optics-hour24-history"

                                    self.optics_hour24_optics_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories, self).__setattr__(name, value)


                                class OpticsHour24OpticsHistory(Entity):
                                    """
                                    port 24 hour optics performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: optics_hour24_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OpticsHour24OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory, self).__init__()

                                        self.yang_name = "optics-hour24-optics-history"
                                        self.yang_parent_name = "optics-hour24-optics-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.optics_hour24_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances()
                                        self.optics_hour24_optics_time_line_instances.parent = self
                                        self._children_name_map["optics_hour24_optics_time_line_instances"] = "optics-hour24-optics-time-line-instances"
                                        self._children_yang_names.add("optics-hour24-optics-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory, self).__setattr__(name, value)


                                    class OpticsHour24OpticsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_hour24_optics_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OpticsHour24OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances, self).__init__()

                                            self.yang_name = "optics-hour24-optics-time-line-instances"
                                            self.yang_parent_name = "optics-hour24-optics-history"

                                            self.optics_hour24_optics_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances, self).__setattr__(name, value)


                                        class OpticsHour24OpticsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance, self).__init__()

                                                self.yang_name = "optics-hour24-optics-time-line-instance"
                                                self.yang_parent_name = "optics-hour24-optics-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.cd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self._children_name_map["cd"] = "cd"
                                                self._children_yang_names.add("cd")

                                                self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self._children_name_map["center_wavelength"] = "center-wavelength"
                                                self._children_yang_names.add("center-wavelength")

                                                self.dgd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self._children_name_map["dgd"] = "dgd"
                                                self._children_yang_names.add("dgd")

                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"
                                                self._children_yang_names.add("lbc")

                                                self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self._children_name_map["lbc_pc"] = "lbc-pc"
                                                self._children_yang_names.add("lbc-pc")

                                                self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                                self._children_yang_names.add("low-sig-freq-off")

                                                self.opr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self._children_name_map["opr"] = "opr"
                                                self._children_yang_names.add("opr")

                                                self.opt = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self._children_name_map["opt"] = "opt"
                                                self._children_yang_names.add("opt")

                                                self.osnr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self._children_name_map["osnr"] = "osnr"
                                                self._children_yang_names.add("osnr")

                                                self.pcr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self._children_name_map["pcr"] = "pcr"
                                                self._children_yang_names.add("pcr")

                                                self.pdl = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self._children_name_map["pdl"] = "pdl"
                                                self._children_yang_names.add("pdl")

                                                self.pmd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self._children_name_map["pmd"] = "pmd"
                                                self._children_yang_names.add("pmd")

                                                self.pn = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self._children_name_map["pn"] = "pn"
                                                self._children_yang_names.add("pn")

                                                self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                                self._children_yang_names.add("rx-sig-pow")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance, self).__setattr__(name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LbcPc(Entity):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc, self).__init__()

                                                    self.yang_name = "lbc-pc"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc-pc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Opt(Entity):
                                                """
                                                OPT
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt, self).__init__()

                                                    self.yang_name = "opt"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Opr(Entity):
                                                """
                                                OPR
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr, self).__init__()

                                                    self.yang_name = "opr"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Cd(Entity):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd, self).__init__()

                                                    self.yang_name = "cd"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "cd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Dgd(Entity):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd, self).__init__()

                                                    self.yang_name = "dgd"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dgd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pmd(Entity):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd, self).__init__()

                                                    self.yang_name = "pmd"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pmd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Osnr(Entity):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr, self).__init__()

                                                    self.yang_name = "osnr"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "osnr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class CenterWavelength(Entity):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength, self).__init__()

                                                    self.yang_name = "center-wavelength"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "center-wavelength" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pdl(Entity):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl, self).__init__()

                                                    self.yang_name = "pdl"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pdl" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pcr(Entity):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr, self).__init__()

                                                    self.yang_name = "pcr"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pcr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pn(Entity):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn, self).__init__()

                                                    self.yang_name = "pn"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pn" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class RxSigPow(Entity):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow, self).__init__()

                                                    self.yang_name = "rx-sig-pow"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-sig-pow" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LowSigFreqOff(Entity):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff, self).__init__()

                                                    self.yang_name = "low-sig-freq-off"
                                                    self.yang_parent_name = "optics-hour24-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "low-sig-freq-off" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.cd is not None and self.cd.has_data()) or
                                                    (self.center_wavelength is not None and self.center_wavelength.has_data()) or
                                                    (self.dgd is not None and self.dgd.has_data()) or
                                                    (self.lbc is not None and self.lbc.has_data()) or
                                                    (self.lbc_pc is not None and self.lbc_pc.has_data()) or
                                                    (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_data()) or
                                                    (self.opr is not None and self.opr.has_data()) or
                                                    (self.opt is not None and self.opt.has_data()) or
                                                    (self.osnr is not None and self.osnr.has_data()) or
                                                    (self.pcr is not None and self.pcr.has_data()) or
                                                    (self.pdl is not None and self.pdl.has_data()) or
                                                    (self.pmd is not None and self.pmd.has_data()) or
                                                    (self.pn is not None and self.pn.has_data()) or
                                                    (self.rx_sig_pow is not None and self.rx_sig_pow.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.cd is not None and self.cd.has_operation()) or
                                                    (self.center_wavelength is not None and self.center_wavelength.has_operation()) or
                                                    (self.dgd is not None and self.dgd.has_operation()) or
                                                    (self.lbc is not None and self.lbc.has_operation()) or
                                                    (self.lbc_pc is not None and self.lbc_pc.has_operation()) or
                                                    (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_operation()) or
                                                    (self.opr is not None and self.opr.has_operation()) or
                                                    (self.opt is not None and self.opt.has_operation()) or
                                                    (self.osnr is not None and self.osnr.has_operation()) or
                                                    (self.pcr is not None and self.pcr.has_operation()) or
                                                    (self.pdl is not None and self.pdl.has_operation()) or
                                                    (self.pmd is not None and self.pmd.has_operation()) or
                                                    (self.pn is not None and self.pn.has_operation()) or
                                                    (self.rx_sig_pow is not None and self.rx_sig_pow.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "optics-hour24-optics-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "cd"):
                                                    if (self.cd is None):
                                                        self.cd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Cd()
                                                        self.cd.parent = self
                                                        self._children_name_map["cd"] = "cd"
                                                    return self.cd

                                                if (child_yang_name == "center-wavelength"):
                                                    if (self.center_wavelength is None):
                                                        self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.CenterWavelength()
                                                        self.center_wavelength.parent = self
                                                        self._children_name_map["center_wavelength"] = "center-wavelength"
                                                    return self.center_wavelength

                                                if (child_yang_name == "dgd"):
                                                    if (self.dgd is None):
                                                        self.dgd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Dgd()
                                                        self.dgd.parent = self
                                                        self._children_name_map["dgd"] = "dgd"
                                                    return self.dgd

                                                if (child_yang_name == "lbc"):
                                                    if (self.lbc is None):
                                                        self.lbc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Lbc()
                                                        self.lbc.parent = self
                                                        self._children_name_map["lbc"] = "lbc"
                                                    return self.lbc

                                                if (child_yang_name == "lbc-pc"):
                                                    if (self.lbc_pc is None):
                                                        self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LbcPc()
                                                        self.lbc_pc.parent = self
                                                        self._children_name_map["lbc_pc"] = "lbc-pc"
                                                    return self.lbc_pc

                                                if (child_yang_name == "low-sig-freq-off"):
                                                    if (self.low_sig_freq_off is None):
                                                        self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.LowSigFreqOff()
                                                        self.low_sig_freq_off.parent = self
                                                        self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                                    return self.low_sig_freq_off

                                                if (child_yang_name == "opr"):
                                                    if (self.opr is None):
                                                        self.opr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opr()
                                                        self.opr.parent = self
                                                        self._children_name_map["opr"] = "opr"
                                                    return self.opr

                                                if (child_yang_name == "opt"):
                                                    if (self.opt is None):
                                                        self.opt = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Opt()
                                                        self.opt.parent = self
                                                        self._children_name_map["opt"] = "opt"
                                                    return self.opt

                                                if (child_yang_name == "osnr"):
                                                    if (self.osnr is None):
                                                        self.osnr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Osnr()
                                                        self.osnr.parent = self
                                                        self._children_name_map["osnr"] = "osnr"
                                                    return self.osnr

                                                if (child_yang_name == "pcr"):
                                                    if (self.pcr is None):
                                                        self.pcr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pcr()
                                                        self.pcr.parent = self
                                                        self._children_name_map["pcr"] = "pcr"
                                                    return self.pcr

                                                if (child_yang_name == "pdl"):
                                                    if (self.pdl is None):
                                                        self.pdl = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pdl()
                                                        self.pdl.parent = self
                                                        self._children_name_map["pdl"] = "pdl"
                                                    return self.pdl

                                                if (child_yang_name == "pmd"):
                                                    if (self.pmd is None):
                                                        self.pmd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pmd()
                                                        self.pmd.parent = self
                                                        self._children_name_map["pmd"] = "pmd"
                                                    return self.pmd

                                                if (child_yang_name == "pn"):
                                                    if (self.pn is None):
                                                        self.pn = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.Pn()
                                                        self.pn.parent = self
                                                        self._children_name_map["pn"] = "pn"
                                                    return self.pn

                                                if (child_yang_name == "rx-sig-pow"):
                                                    if (self.rx_sig_pow is None):
                                                        self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance.RxSigPow()
                                                        self.rx_sig_pow.parent = self
                                                        self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                                    return self.rx_sig_pow

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cd" or name == "center-wavelength" or name == "dgd" or name == "lbc" or name == "lbc-pc" or name == "low-sig-freq-off" or name == "opr" or name == "opt" or name == "osnr" or name == "pcr" or name == "pdl" or name == "pmd" or name == "pn" or name == "rx-sig-pow" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.optics_hour24_optics_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.optics_hour24_optics_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "optics-hour24-optics-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "optics-hour24-optics-time-line-instance"):
                                                for c in self.optics_hour24_optics_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances.OpticsHour24OpticsTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.optics_hour24_optics_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "optics-hour24-optics-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.optics_hour24_optics_time_line_instances is not None and self.optics_hour24_optics_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.optics_hour24_optics_time_line_instances is not None and self.optics_hour24_optics_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "optics-hour24-optics-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "optics-hour24-optics-time-line-instances"):
                                            if (self.optics_hour24_optics_time_line_instances is None):
                                                self.optics_hour24_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory.OpticsHour24OpticsTimeLineInstances()
                                                self.optics_hour24_optics_time_line_instances.parent = self
                                                self._children_name_map["optics_hour24_optics_time_line_instances"] = "optics-hour24-optics-time-line-instances"
                                            return self.optics_hour24_optics_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "optics-hour24-optics-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.optics_hour24_optics_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.optics_hour24_optics_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "optics-hour24-optics-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "optics-hour24-optics-history"):
                                        for c in self.optics_hour24_optics_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories.OpticsHour24OpticsHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.optics_hour24_optics_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "optics-hour24-optics-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class OpticsHour24FecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: optics_hour24fec_history
                                
                                	port 24 hour fec performance data
                                	**type**\: list of    :py:class:`OpticsHour24FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories, self).__init__()

                                    self.yang_name = "optics-hour24fec-histories"
                                    self.yang_parent_name = "optics-hour24-history"

                                    self.optics_hour24fec_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories, self).__setattr__(name, value)


                                class OpticsHour24FecHistory(Entity):
                                    """
                                    port 24 hour fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: optics_hour24fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OpticsHour24FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory, self).__init__()

                                        self.yang_name = "optics-hour24fec-history"
                                        self.yang_parent_name = "optics-hour24fec-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.optics_hour24fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances()
                                        self.optics_hour24fec_time_line_instances.parent = self
                                        self._children_name_map["optics_hour24fec_time_line_instances"] = "optics-hour24fec-time-line-instances"
                                        self._children_yang_names.add("optics-hour24fec-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory, self).__setattr__(name, value)


                                    class OpticsHour24FecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_hour24fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of    :py:class:`OpticsHour24FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances, self).__init__()

                                            self.yang_name = "optics-hour24fec-time-line-instances"
                                            self.yang_parent_name = "optics-hour24fec-history"

                                            self.optics_hour24fec_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances, self).__setattr__(name, value)


                                        class OpticsHour24FecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance, self).__init__()

                                                self.yang_name = "optics-hour24fec-time-line-instance"
                                                self.yang_parent_name = "optics-hour24fec-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"
                                                self._children_yang_names.add("ec-bits")

                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                self._children_yang_names.add("post-fec-ber")

                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                self._children_yang_names.add("pre-fec-ber")

                                                self.q = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"
                                                self._children_yang_names.add("q")

                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._children_yang_names.add("qmargin")

                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"
                                                self._children_yang_names.add("uc-words")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance, self).__setattr__(name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "optics-hour24fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.EcBits, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.EcBits, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ec-bits" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "optics-hour24fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.UcWords, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.UcWords, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uc-words" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "optics-hour24fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pre-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "optics-hour24fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "post-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "optics-hour24fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Q, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Q, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "q" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "optics-hour24fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Qmargin, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Qmargin, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "qmargin" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_data()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                                    (self.q is not None and self.q.has_data()) or
                                                    (self.qmargin is not None and self.qmargin.has_data()) or
                                                    (self.uc_words is not None and self.uc_words.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                                    (self.q is not None and self.q.has_operation()) or
                                                    (self.qmargin is not None and self.qmargin.has_operation()) or
                                                    (self.uc_words is not None and self.uc_words.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "optics-hour24fec-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ec-bits"):
                                                    if (self.ec_bits is None):
                                                        self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.EcBits()
                                                        self.ec_bits.parent = self
                                                        self._children_name_map["ec_bits"] = "ec-bits"
                                                    return self.ec_bits

                                                if (child_yang_name == "post-fec-ber"):
                                                    if (self.post_fec_ber is None):
                                                        self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PostFecBer()
                                                        self.post_fec_ber.parent = self
                                                        self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                    return self.post_fec_ber

                                                if (child_yang_name == "pre-fec-ber"):
                                                    if (self.pre_fec_ber is None):
                                                        self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.PreFecBer()
                                                        self.pre_fec_ber.parent = self
                                                        self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                    return self.pre_fec_ber

                                                if (child_yang_name == "q"):
                                                    if (self.q is None):
                                                        self.q = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Q()
                                                        self.q.parent = self
                                                        self._children_name_map["q"] = "q"
                                                    return self.q

                                                if (child_yang_name == "qmargin"):
                                                    if (self.qmargin is None):
                                                        self.qmargin = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.Qmargin()
                                                        self.qmargin.parent = self
                                                        self._children_name_map["qmargin"] = "qmargin"
                                                    return self.qmargin

                                                if (child_yang_name == "uc-words"):
                                                    if (self.uc_words is None):
                                                        self.uc_words = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance.UcWords()
                                                        self.uc_words.parent = self
                                                        self._children_name_map["uc_words"] = "uc-words"
                                                    return self.uc_words

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.optics_hour24fec_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.optics_hour24fec_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "optics-hour24fec-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "optics-hour24fec-time-line-instance"):
                                                for c in self.optics_hour24fec_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances.OpticsHour24FecTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.optics_hour24fec_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "optics-hour24fec-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.optics_hour24fec_time_line_instances is not None and self.optics_hour24fec_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.optics_hour24fec_time_line_instances is not None and self.optics_hour24fec_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "optics-hour24fec-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "optics-hour24fec-time-line-instances"):
                                            if (self.optics_hour24fec_time_line_instances is None):
                                                self.optics_hour24fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory.OpticsHour24FecTimeLineInstances()
                                                self.optics_hour24fec_time_line_instances.parent = self
                                                self._children_name_map["optics_hour24fec_time_line_instances"] = "optics-hour24fec-time-line-instances"
                                            return self.optics_hour24fec_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "optics-hour24fec-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.optics_hour24fec_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.optics_hour24fec_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "optics-hour24fec-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "optics-hour24fec-history"):
                                        for c in self.optics_hour24fec_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories.OpticsHour24FecHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.optics_hour24fec_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "optics-hour24fec-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    (self.optics_hour24_optics_histories is not None and self.optics_hour24_optics_histories.has_data()) or
                                    (self.optics_hour24fec_histories is not None and self.optics_hour24fec_histories.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.optics_hour24_optics_histories is not None and self.optics_hour24_optics_histories.has_operation()) or
                                    (self.optics_hour24fec_histories is not None and self.optics_hour24fec_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "optics-hour24-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "optics-hour24-optics-histories"):
                                    if (self.optics_hour24_optics_histories is None):
                                        self.optics_hour24_optics_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24OpticsHistories()
                                        self.optics_hour24_optics_histories.parent = self
                                        self._children_name_map["optics_hour24_optics_histories"] = "optics-hour24-optics-histories"
                                    return self.optics_hour24_optics_histories

                                if (child_yang_name == "optics-hour24fec-histories"):
                                    if (self.optics_hour24fec_histories is None):
                                        self.optics_hour24fec_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History.OpticsHour24FecHistories()
                                        self.optics_hour24fec_histories.parent = self
                                        self._children_name_map["optics_hour24fec_histories"] = "optics-hour24fec-histories"
                                    return self.optics_hour24fec_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-hour24-optics-histories" or name == "optics-hour24fec-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OpticsSecond30History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_second30_optics_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OpticsSecond30OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories>`
                            
                            .. attribute:: optics_second30fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OpticsSecond30FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History, self).__init__()

                                self.yang_name = "optics-second30-history"
                                self.yang_parent_name = "optics-port-history"

                                self.optics_second30_optics_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories()
                                self.optics_second30_optics_histories.parent = self
                                self._children_name_map["optics_second30_optics_histories"] = "optics-second30-optics-histories"
                                self._children_yang_names.add("optics-second30-optics-histories")

                                self.optics_second30fec_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories()
                                self.optics_second30fec_histories.parent = self
                                self._children_name_map["optics_second30fec_histories"] = "optics-second30fec-histories"
                                self._children_yang_names.add("optics-second30fec-histories")


                            class OpticsSecond30OpticsHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: optics_second30_optics_history
                                
                                	port 30\-second optics performance data
                                	**type**\: list of    :py:class:`OpticsSecond30OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories, self).__init__()

                                    self.yang_name = "optics-second30-optics-histories"
                                    self.yang_parent_name = "optics-second30-history"

                                    self.optics_second30_optics_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories, self).__setattr__(name, value)


                                class OpticsSecond30OpticsHistory(Entity):
                                    """
                                    port 30\-second optics performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: optics_second30_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OpticsSecond30OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory, self).__init__()

                                        self.yang_name = "optics-second30-optics-history"
                                        self.yang_parent_name = "optics-second30-optics-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.optics_second30_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances()
                                        self.optics_second30_optics_time_line_instances.parent = self
                                        self._children_name_map["optics_second30_optics_time_line_instances"] = "optics-second30-optics-time-line-instances"
                                        self._children_yang_names.add("optics-second30-optics-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory, self).__setattr__(name, value)


                                    class OpticsSecond30OpticsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_second30_optics_time_line_instance
                                        
                                        	port 30 second otn performance data
                                        	**type**\: list of    :py:class:`OpticsSecond30OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances, self).__init__()

                                            self.yang_name = "optics-second30-optics-time-line-instances"
                                            self.yang_parent_name = "optics-second30-optics-history"

                                            self.optics_second30_optics_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances, self).__setattr__(name, value)


                                        class OpticsSecond30OpticsTimeLineInstance(Entity):
                                            """
                                            port 30 second otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance, self).__init__()

                                                self.yang_name = "optics-second30-optics-time-line-instance"
                                                self.yang_parent_name = "optics-second30-optics-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.cd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self._children_name_map["cd"] = "cd"
                                                self._children_yang_names.add("cd")

                                                self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self._children_name_map["center_wavelength"] = "center-wavelength"
                                                self._children_yang_names.add("center-wavelength")

                                                self.dgd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self._children_name_map["dgd"] = "dgd"
                                                self._children_yang_names.add("dgd")

                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"
                                                self._children_yang_names.add("lbc")

                                                self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self._children_name_map["lbc_pc"] = "lbc-pc"
                                                self._children_yang_names.add("lbc-pc")

                                                self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                                self._children_yang_names.add("low-sig-freq-off")

                                                self.opr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self._children_name_map["opr"] = "opr"
                                                self._children_yang_names.add("opr")

                                                self.opt = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self._children_name_map["opt"] = "opt"
                                                self._children_yang_names.add("opt")

                                                self.osnr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self._children_name_map["osnr"] = "osnr"
                                                self._children_yang_names.add("osnr")

                                                self.pcr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self._children_name_map["pcr"] = "pcr"
                                                self._children_yang_names.add("pcr")

                                                self.pdl = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self._children_name_map["pdl"] = "pdl"
                                                self._children_yang_names.add("pdl")

                                                self.pmd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self._children_name_map["pmd"] = "pmd"
                                                self._children_yang_names.add("pmd")

                                                self.pn = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self._children_name_map["pn"] = "pn"
                                                self._children_yang_names.add("pn")

                                                self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                                self._children_yang_names.add("rx-sig-pow")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance, self).__setattr__(name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LbcPc(Entity):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc, self).__init__()

                                                    self.yang_name = "lbc-pc"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc-pc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Opt(Entity):
                                                """
                                                OPT
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt, self).__init__()

                                                    self.yang_name = "opt"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Opr(Entity):
                                                """
                                                OPR
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr, self).__init__()

                                                    self.yang_name = "opr"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Cd(Entity):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd, self).__init__()

                                                    self.yang_name = "cd"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "cd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Dgd(Entity):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd, self).__init__()

                                                    self.yang_name = "dgd"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dgd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pmd(Entity):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd, self).__init__()

                                                    self.yang_name = "pmd"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pmd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Osnr(Entity):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr, self).__init__()

                                                    self.yang_name = "osnr"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "osnr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class CenterWavelength(Entity):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength, self).__init__()

                                                    self.yang_name = "center-wavelength"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "center-wavelength" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pdl(Entity):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl, self).__init__()

                                                    self.yang_name = "pdl"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pdl" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pcr(Entity):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr, self).__init__()

                                                    self.yang_name = "pcr"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pcr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pn(Entity):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn, self).__init__()

                                                    self.yang_name = "pn"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pn" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class RxSigPow(Entity):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow, self).__init__()

                                                    self.yang_name = "rx-sig-pow"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-sig-pow" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LowSigFreqOff(Entity):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff, self).__init__()

                                                    self.yang_name = "low-sig-freq-off"
                                                    self.yang_parent_name = "optics-second30-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "low-sig-freq-off" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.cd is not None and self.cd.has_data()) or
                                                    (self.center_wavelength is not None and self.center_wavelength.has_data()) or
                                                    (self.dgd is not None and self.dgd.has_data()) or
                                                    (self.lbc is not None and self.lbc.has_data()) or
                                                    (self.lbc_pc is not None and self.lbc_pc.has_data()) or
                                                    (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_data()) or
                                                    (self.opr is not None and self.opr.has_data()) or
                                                    (self.opt is not None and self.opt.has_data()) or
                                                    (self.osnr is not None and self.osnr.has_data()) or
                                                    (self.pcr is not None and self.pcr.has_data()) or
                                                    (self.pdl is not None and self.pdl.has_data()) or
                                                    (self.pmd is not None and self.pmd.has_data()) or
                                                    (self.pn is not None and self.pn.has_data()) or
                                                    (self.rx_sig_pow is not None and self.rx_sig_pow.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.cd is not None and self.cd.has_operation()) or
                                                    (self.center_wavelength is not None and self.center_wavelength.has_operation()) or
                                                    (self.dgd is not None and self.dgd.has_operation()) or
                                                    (self.lbc is not None and self.lbc.has_operation()) or
                                                    (self.lbc_pc is not None and self.lbc_pc.has_operation()) or
                                                    (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_operation()) or
                                                    (self.opr is not None and self.opr.has_operation()) or
                                                    (self.opt is not None and self.opt.has_operation()) or
                                                    (self.osnr is not None and self.osnr.has_operation()) or
                                                    (self.pcr is not None and self.pcr.has_operation()) or
                                                    (self.pdl is not None and self.pdl.has_operation()) or
                                                    (self.pmd is not None and self.pmd.has_operation()) or
                                                    (self.pn is not None and self.pn.has_operation()) or
                                                    (self.rx_sig_pow is not None and self.rx_sig_pow.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "optics-second30-optics-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "cd"):
                                                    if (self.cd is None):
                                                        self.cd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Cd()
                                                        self.cd.parent = self
                                                        self._children_name_map["cd"] = "cd"
                                                    return self.cd

                                                if (child_yang_name == "center-wavelength"):
                                                    if (self.center_wavelength is None):
                                                        self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.CenterWavelength()
                                                        self.center_wavelength.parent = self
                                                        self._children_name_map["center_wavelength"] = "center-wavelength"
                                                    return self.center_wavelength

                                                if (child_yang_name == "dgd"):
                                                    if (self.dgd is None):
                                                        self.dgd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Dgd()
                                                        self.dgd.parent = self
                                                        self._children_name_map["dgd"] = "dgd"
                                                    return self.dgd

                                                if (child_yang_name == "lbc"):
                                                    if (self.lbc is None):
                                                        self.lbc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Lbc()
                                                        self.lbc.parent = self
                                                        self._children_name_map["lbc"] = "lbc"
                                                    return self.lbc

                                                if (child_yang_name == "lbc-pc"):
                                                    if (self.lbc_pc is None):
                                                        self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LbcPc()
                                                        self.lbc_pc.parent = self
                                                        self._children_name_map["lbc_pc"] = "lbc-pc"
                                                    return self.lbc_pc

                                                if (child_yang_name == "low-sig-freq-off"):
                                                    if (self.low_sig_freq_off is None):
                                                        self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.LowSigFreqOff()
                                                        self.low_sig_freq_off.parent = self
                                                        self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                                    return self.low_sig_freq_off

                                                if (child_yang_name == "opr"):
                                                    if (self.opr is None):
                                                        self.opr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opr()
                                                        self.opr.parent = self
                                                        self._children_name_map["opr"] = "opr"
                                                    return self.opr

                                                if (child_yang_name == "opt"):
                                                    if (self.opt is None):
                                                        self.opt = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Opt()
                                                        self.opt.parent = self
                                                        self._children_name_map["opt"] = "opt"
                                                    return self.opt

                                                if (child_yang_name == "osnr"):
                                                    if (self.osnr is None):
                                                        self.osnr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Osnr()
                                                        self.osnr.parent = self
                                                        self._children_name_map["osnr"] = "osnr"
                                                    return self.osnr

                                                if (child_yang_name == "pcr"):
                                                    if (self.pcr is None):
                                                        self.pcr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pcr()
                                                        self.pcr.parent = self
                                                        self._children_name_map["pcr"] = "pcr"
                                                    return self.pcr

                                                if (child_yang_name == "pdl"):
                                                    if (self.pdl is None):
                                                        self.pdl = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pdl()
                                                        self.pdl.parent = self
                                                        self._children_name_map["pdl"] = "pdl"
                                                    return self.pdl

                                                if (child_yang_name == "pmd"):
                                                    if (self.pmd is None):
                                                        self.pmd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pmd()
                                                        self.pmd.parent = self
                                                        self._children_name_map["pmd"] = "pmd"
                                                    return self.pmd

                                                if (child_yang_name == "pn"):
                                                    if (self.pn is None):
                                                        self.pn = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.Pn()
                                                        self.pn.parent = self
                                                        self._children_name_map["pn"] = "pn"
                                                    return self.pn

                                                if (child_yang_name == "rx-sig-pow"):
                                                    if (self.rx_sig_pow is None):
                                                        self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance.RxSigPow()
                                                        self.rx_sig_pow.parent = self
                                                        self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                                    return self.rx_sig_pow

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cd" or name == "center-wavelength" or name == "dgd" or name == "lbc" or name == "lbc-pc" or name == "low-sig-freq-off" or name == "opr" or name == "opt" or name == "osnr" or name == "pcr" or name == "pdl" or name == "pmd" or name == "pn" or name == "rx-sig-pow" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.optics_second30_optics_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.optics_second30_optics_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "optics-second30-optics-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "optics-second30-optics-time-line-instance"):
                                                for c in self.optics_second30_optics_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances.OpticsSecond30OpticsTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.optics_second30_optics_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "optics-second30-optics-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.optics_second30_optics_time_line_instances is not None and self.optics_second30_optics_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.optics_second30_optics_time_line_instances is not None and self.optics_second30_optics_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "optics-second30-optics-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "optics-second30-optics-time-line-instances"):
                                            if (self.optics_second30_optics_time_line_instances is None):
                                                self.optics_second30_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory.OpticsSecond30OpticsTimeLineInstances()
                                                self.optics_second30_optics_time_line_instances.parent = self
                                                self._children_name_map["optics_second30_optics_time_line_instances"] = "optics-second30-optics-time-line-instances"
                                            return self.optics_second30_optics_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "optics-second30-optics-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.optics_second30_optics_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.optics_second30_optics_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "optics-second30-optics-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "optics-second30-optics-history"):
                                        for c in self.optics_second30_optics_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories.OpticsSecond30OpticsHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.optics_second30_optics_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "optics-second30-optics-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class OpticsSecond30FecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: optics_second30fec_history
                                
                                	port 30\-second fec performance data
                                	**type**\: list of    :py:class:`OpticsSecond30FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories, self).__init__()

                                    self.yang_name = "optics-second30fec-histories"
                                    self.yang_parent_name = "optics-second30-history"

                                    self.optics_second30fec_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories, self).__setattr__(name, value)


                                class OpticsSecond30FecHistory(Entity):
                                    """
                                    port 30\-second fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: optics_second30fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OpticsSecond30FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory, self).__init__()

                                        self.yang_name = "optics-second30fec-history"
                                        self.yang_parent_name = "optics-second30fec-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.optics_second30fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances()
                                        self.optics_second30fec_time_line_instances.parent = self
                                        self._children_name_map["optics_second30fec_time_line_instances"] = "optics-second30fec-time-line-instances"
                                        self._children_yang_names.add("optics-second30fec-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory, self).__setattr__(name, value)


                                    class OpticsSecond30FecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_second30fec_time_line_instance
                                        
                                        	port sec\-30 fec performance data
                                        	**type**\: list of    :py:class:`OpticsSecond30FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances, self).__init__()

                                            self.yang_name = "optics-second30fec-time-line-instances"
                                            self.yang_parent_name = "optics-second30fec-history"

                                            self.optics_second30fec_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances, self).__setattr__(name, value)


                                        class OpticsSecond30FecTimeLineInstance(Entity):
                                            """
                                            port sec\-30 fec performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance, self).__init__()

                                                self.yang_name = "optics-second30fec-time-line-instance"
                                                self.yang_parent_name = "optics-second30fec-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"
                                                self._children_yang_names.add("ec-bits")

                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                self._children_yang_names.add("post-fec-ber")

                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                self._children_yang_names.add("pre-fec-ber")

                                                self.q = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"
                                                self._children_yang_names.add("q")

                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._children_yang_names.add("qmargin")

                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"
                                                self._children_yang_names.add("uc-words")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance, self).__setattr__(name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "optics-second30fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.EcBits, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.EcBits, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ec-bits" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "optics-second30fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.UcWords, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.UcWords, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uc-words" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "optics-second30fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pre-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "optics-second30fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "post-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "optics-second30fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Q, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Q, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "q" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "optics-second30fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Qmargin, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Qmargin, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "qmargin" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_data()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                                    (self.q is not None and self.q.has_data()) or
                                                    (self.qmargin is not None and self.qmargin.has_data()) or
                                                    (self.uc_words is not None and self.uc_words.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                                    (self.q is not None and self.q.has_operation()) or
                                                    (self.qmargin is not None and self.qmargin.has_operation()) or
                                                    (self.uc_words is not None and self.uc_words.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "optics-second30fec-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ec-bits"):
                                                    if (self.ec_bits is None):
                                                        self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.EcBits()
                                                        self.ec_bits.parent = self
                                                        self._children_name_map["ec_bits"] = "ec-bits"
                                                    return self.ec_bits

                                                if (child_yang_name == "post-fec-ber"):
                                                    if (self.post_fec_ber is None):
                                                        self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PostFecBer()
                                                        self.post_fec_ber.parent = self
                                                        self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                    return self.post_fec_ber

                                                if (child_yang_name == "pre-fec-ber"):
                                                    if (self.pre_fec_ber is None):
                                                        self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.PreFecBer()
                                                        self.pre_fec_ber.parent = self
                                                        self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                    return self.pre_fec_ber

                                                if (child_yang_name == "q"):
                                                    if (self.q is None):
                                                        self.q = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Q()
                                                        self.q.parent = self
                                                        self._children_name_map["q"] = "q"
                                                    return self.q

                                                if (child_yang_name == "qmargin"):
                                                    if (self.qmargin is None):
                                                        self.qmargin = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.Qmargin()
                                                        self.qmargin.parent = self
                                                        self._children_name_map["qmargin"] = "qmargin"
                                                    return self.qmargin

                                                if (child_yang_name == "uc-words"):
                                                    if (self.uc_words is None):
                                                        self.uc_words = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance.UcWords()
                                                        self.uc_words.parent = self
                                                        self._children_name_map["uc_words"] = "uc-words"
                                                    return self.uc_words

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.optics_second30fec_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.optics_second30fec_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "optics-second30fec-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "optics-second30fec-time-line-instance"):
                                                for c in self.optics_second30fec_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances.OpticsSecond30FecTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.optics_second30fec_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "optics-second30fec-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.optics_second30fec_time_line_instances is not None and self.optics_second30fec_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.optics_second30fec_time_line_instances is not None and self.optics_second30fec_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "optics-second30fec-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "optics-second30fec-time-line-instances"):
                                            if (self.optics_second30fec_time_line_instances is None):
                                                self.optics_second30fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory.OpticsSecond30FecTimeLineInstances()
                                                self.optics_second30fec_time_line_instances.parent = self
                                                self._children_name_map["optics_second30fec_time_line_instances"] = "optics-second30fec-time-line-instances"
                                            return self.optics_second30fec_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "optics-second30fec-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.optics_second30fec_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.optics_second30fec_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "optics-second30fec-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "optics-second30fec-history"):
                                        for c in self.optics_second30fec_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories.OpticsSecond30FecHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.optics_second30fec_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "optics-second30fec-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    (self.optics_second30_optics_histories is not None and self.optics_second30_optics_histories.has_data()) or
                                    (self.optics_second30fec_histories is not None and self.optics_second30fec_histories.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.optics_second30_optics_histories is not None and self.optics_second30_optics_histories.has_operation()) or
                                    (self.optics_second30fec_histories is not None and self.optics_second30fec_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "optics-second30-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "optics-second30-optics-histories"):
                                    if (self.optics_second30_optics_histories is None):
                                        self.optics_second30_optics_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30OpticsHistories()
                                        self.optics_second30_optics_histories.parent = self
                                        self._children_name_map["optics_second30_optics_histories"] = "optics-second30-optics-histories"
                                    return self.optics_second30_optics_histories

                                if (child_yang_name == "optics-second30fec-histories"):
                                    if (self.optics_second30fec_histories is None):
                                        self.optics_second30fec_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History.OpticsSecond30FecHistories()
                                        self.optics_second30fec_histories.parent = self
                                        self._children_name_map["optics_second30fec_histories"] = "optics-second30fec-histories"
                                    return self.optics_second30fec_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-second30-optics-histories" or name == "optics-second30fec-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OpticsMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: optics_minute15_optics_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OpticsMinute15OpticsHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories>`
                            
                            .. attribute:: optics_minute15fec_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OpticsMinute15FecHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History, self).__init__()

                                self.yang_name = "optics-minute15-history"
                                self.yang_parent_name = "optics-port-history"

                                self.optics_minute15_optics_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories()
                                self.optics_minute15_optics_histories.parent = self
                                self._children_name_map["optics_minute15_optics_histories"] = "optics-minute15-optics-histories"
                                self._children_yang_names.add("optics-minute15-optics-histories")

                                self.optics_minute15fec_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories()
                                self.optics_minute15fec_histories.parent = self
                                self._children_name_map["optics_minute15fec_histories"] = "optics-minute15fec-histories"
                                self._children_yang_names.add("optics-minute15fec-histories")


                            class OpticsMinute15OpticsHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: optics_minute15_optics_history
                                
                                	port 15\-minute optics performance data
                                	**type**\: list of    :py:class:`OpticsMinute15OpticsHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories, self).__init__()

                                    self.yang_name = "optics-minute15-optics-histories"
                                    self.yang_parent_name = "optics-minute15-history"

                                    self.optics_minute15_optics_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories, self).__setattr__(name, value)


                                class OpticsMinute15OpticsHistory(Entity):
                                    """
                                    port 15\-minute optics performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: optics_minute15_optics_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OpticsMinute15OpticsTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory, self).__init__()

                                        self.yang_name = "optics-minute15-optics-history"
                                        self.yang_parent_name = "optics-minute15-optics-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.optics_minute15_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances()
                                        self.optics_minute15_optics_time_line_instances.parent = self
                                        self._children_name_map["optics_minute15_optics_time_line_instances"] = "optics-minute15-optics-time-line-instances"
                                        self._children_yang_names.add("optics-minute15-optics-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory, self).__setattr__(name, value)


                                    class OpticsMinute15OpticsTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_minute15_optics_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OpticsMinute15OpticsTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances, self).__init__()

                                            self.yang_name = "optics-minute15-optics-time-line-instances"
                                            self.yang_parent_name = "optics-minute15-optics-history"

                                            self.optics_minute15_optics_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances, self).__setattr__(name, value)


                                        class OpticsMinute15OpticsTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: cd
                                            
                                            	Chromatic Dispersion
                                            	**type**\:   :py:class:`Cd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd>`
                                            
                                            .. attribute:: center_wavelength
                                            
                                            	Center Wavelength/Frequency
                                            	**type**\:   :py:class:`CenterWavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength>`
                                            
                                            .. attribute:: dgd
                                            
                                            	Differential group Delay
                                            	**type**\:   :py:class:`Dgd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: lbc
                                            
                                            	LBC
                                            	**type**\:   :py:class:`Lbc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc>`
                                            
                                            .. attribute:: lbc_pc
                                            
                                            	LBC in percentage
                                            	**type**\:   :py:class:`LbcPc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc>`
                                            
                                            .. attribute:: low_sig_freq_off
                                            
                                            	low freq sig off
                                            	**type**\:   :py:class:`LowSigFreqOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff>`
                                            
                                            .. attribute:: opr
                                            
                                            	OPR
                                            	**type**\:   :py:class:`Opr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr>`
                                            
                                            .. attribute:: opt
                                            
                                            	OPT
                                            	**type**\:   :py:class:`Opt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt>`
                                            
                                            .. attribute:: osnr
                                            
                                            	Optical Signal to Noise Ratio
                                            	**type**\:   :py:class:`Osnr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr>`
                                            
                                            .. attribute:: pcr
                                            
                                            	Polarization Change Rate
                                            	**type**\:   :py:class:`Pcr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr>`
                                            
                                            .. attribute:: pdl
                                            
                                            	Polarization Dependent Loss
                                            	**type**\:   :py:class:`Pdl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl>`
                                            
                                            .. attribute:: pmd
                                            
                                            	Polarization Mode Dispersion
                                            	**type**\:   :py:class:`Pmd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd>`
                                            
                                            .. attribute:: pn
                                            
                                            	Phase Noise
                                            	**type**\:   :py:class:`Pn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn>`
                                            
                                            .. attribute:: rx_sig_pow
                                            
                                            	Rx signal power
                                            	**type**\:   :py:class:`RxSigPow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance, self).__init__()

                                                self.yang_name = "optics-minute15-optics-time-line-instance"
                                                self.yang_parent_name = "optics-minute15-optics-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.cd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd()
                                                self.cd.parent = self
                                                self._children_name_map["cd"] = "cd"
                                                self._children_yang_names.add("cd")

                                                self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength()
                                                self.center_wavelength.parent = self
                                                self._children_name_map["center_wavelength"] = "center-wavelength"
                                                self._children_yang_names.add("center-wavelength")

                                                self.dgd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd()
                                                self.dgd.parent = self
                                                self._children_name_map["dgd"] = "dgd"
                                                self._children_yang_names.add("dgd")

                                                self.lbc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc()
                                                self.lbc.parent = self
                                                self._children_name_map["lbc"] = "lbc"
                                                self._children_yang_names.add("lbc")

                                                self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc()
                                                self.lbc_pc.parent = self
                                                self._children_name_map["lbc_pc"] = "lbc-pc"
                                                self._children_yang_names.add("lbc-pc")

                                                self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff()
                                                self.low_sig_freq_off.parent = self
                                                self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                                self._children_yang_names.add("low-sig-freq-off")

                                                self.opr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr()
                                                self.opr.parent = self
                                                self._children_name_map["opr"] = "opr"
                                                self._children_yang_names.add("opr")

                                                self.opt = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt()
                                                self.opt.parent = self
                                                self._children_name_map["opt"] = "opt"
                                                self._children_yang_names.add("opt")

                                                self.osnr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr()
                                                self.osnr.parent = self
                                                self._children_name_map["osnr"] = "osnr"
                                                self._children_yang_names.add("osnr")

                                                self.pcr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr()
                                                self.pcr.parent = self
                                                self._children_name_map["pcr"] = "pcr"
                                                self._children_yang_names.add("pcr")

                                                self.pdl = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl()
                                                self.pdl.parent = self
                                                self._children_name_map["pdl"] = "pdl"
                                                self._children_yang_names.add("pdl")

                                                self.pmd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd()
                                                self.pmd.parent = self
                                                self._children_name_map["pmd"] = "pmd"
                                                self._children_yang_names.add("pmd")

                                                self.pn = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn()
                                                self.pn.parent = self
                                                self._children_name_map["pn"] = "pn"
                                                self._children_yang_names.add("pn")

                                                self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow()
                                                self.rx_sig_pow.parent = self
                                                self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                                self._children_yang_names.add("rx-sig-pow")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance, self).__setattr__(name, value)


                                            class Lbc(Entity):
                                                """
                                                LBC
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc, self).__init__()

                                                    self.yang_name = "lbc"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LbcPc(Entity):
                                                """
                                                LBC in percentage
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc, self).__init__()

                                                    self.yang_name = "lbc-pc"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "lbc-pc" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Opt(Entity):
                                                """
                                                OPT
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt, self).__init__()

                                                    self.yang_name = "opt"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opt" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Opr(Entity):
                                                """
                                                OPR
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr, self).__init__()

                                                    self.yang_name = "opr"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "opr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Cd(Entity):
                                                """
                                                Chromatic Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd, self).__init__()

                                                    self.yang_name = "cd"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "cd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Dgd(Entity):
                                                """
                                                Differential group Delay
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd, self).__init__()

                                                    self.yang_name = "dgd"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "dgd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pmd(Entity):
                                                """
                                                Polarization Mode Dispersion
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd, self).__init__()

                                                    self.yang_name = "pmd"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pmd" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Osnr(Entity):
                                                """
                                                Optical Signal to Noise Ratio
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr, self).__init__()

                                                    self.yang_name = "osnr"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "osnr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class CenterWavelength(Entity):
                                                """
                                                Center Wavelength/Frequency
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength, self).__init__()

                                                    self.yang_name = "center-wavelength"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "center-wavelength" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pdl(Entity):
                                                """
                                                Polarization Dependent Loss
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl, self).__init__()

                                                    self.yang_name = "pdl"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pdl" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pcr(Entity):
                                                """
                                                Polarization Change Rate
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr, self).__init__()

                                                    self.yang_name = "pcr"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pcr" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Pn(Entity):
                                                """
                                                Phase Noise
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn, self).__init__()

                                                    self.yang_name = "pn"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pn" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class RxSigPow(Entity):
                                                """
                                                Rx signal power
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow, self).__init__()

                                                    self.yang_name = "rx-sig-pow"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "rx-sig-pow" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class LowSigFreqOff(Entity):
                                                """
                                                low freq sig off
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA on max
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff, self).__init__()

                                                    self.yang_name = "low-sig-freq-off"
                                                    self.yang_parent_name = "optics-minute15-optics-time-line-instance"

                                                    self.average = YLeaf(YType.int32, "average")

                                                    self.maximum = YLeaf(YType.int32, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.int32, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.int32, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.int32, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "low-sig-freq-off" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.cd is not None and self.cd.has_data()) or
                                                    (self.center_wavelength is not None and self.center_wavelength.has_data()) or
                                                    (self.dgd is not None and self.dgd.has_data()) or
                                                    (self.lbc is not None and self.lbc.has_data()) or
                                                    (self.lbc_pc is not None and self.lbc_pc.has_data()) or
                                                    (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_data()) or
                                                    (self.opr is not None and self.opr.has_data()) or
                                                    (self.opt is not None and self.opt.has_data()) or
                                                    (self.osnr is not None and self.osnr.has_data()) or
                                                    (self.pcr is not None and self.pcr.has_data()) or
                                                    (self.pdl is not None and self.pdl.has_data()) or
                                                    (self.pmd is not None and self.pmd.has_data()) or
                                                    (self.pn is not None and self.pn.has_data()) or
                                                    (self.rx_sig_pow is not None and self.rx_sig_pow.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.cd is not None and self.cd.has_operation()) or
                                                    (self.center_wavelength is not None and self.center_wavelength.has_operation()) or
                                                    (self.dgd is not None and self.dgd.has_operation()) or
                                                    (self.lbc is not None and self.lbc.has_operation()) or
                                                    (self.lbc_pc is not None and self.lbc_pc.has_operation()) or
                                                    (self.low_sig_freq_off is not None and self.low_sig_freq_off.has_operation()) or
                                                    (self.opr is not None and self.opr.has_operation()) or
                                                    (self.opt is not None and self.opt.has_operation()) or
                                                    (self.osnr is not None and self.osnr.has_operation()) or
                                                    (self.pcr is not None and self.pcr.has_operation()) or
                                                    (self.pdl is not None and self.pdl.has_operation()) or
                                                    (self.pmd is not None and self.pmd.has_operation()) or
                                                    (self.pn is not None and self.pn.has_operation()) or
                                                    (self.rx_sig_pow is not None and self.rx_sig_pow.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "optics-minute15-optics-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "cd"):
                                                    if (self.cd is None):
                                                        self.cd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Cd()
                                                        self.cd.parent = self
                                                        self._children_name_map["cd"] = "cd"
                                                    return self.cd

                                                if (child_yang_name == "center-wavelength"):
                                                    if (self.center_wavelength is None):
                                                        self.center_wavelength = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.CenterWavelength()
                                                        self.center_wavelength.parent = self
                                                        self._children_name_map["center_wavelength"] = "center-wavelength"
                                                    return self.center_wavelength

                                                if (child_yang_name == "dgd"):
                                                    if (self.dgd is None):
                                                        self.dgd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Dgd()
                                                        self.dgd.parent = self
                                                        self._children_name_map["dgd"] = "dgd"
                                                    return self.dgd

                                                if (child_yang_name == "lbc"):
                                                    if (self.lbc is None):
                                                        self.lbc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Lbc()
                                                        self.lbc.parent = self
                                                        self._children_name_map["lbc"] = "lbc"
                                                    return self.lbc

                                                if (child_yang_name == "lbc-pc"):
                                                    if (self.lbc_pc is None):
                                                        self.lbc_pc = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LbcPc()
                                                        self.lbc_pc.parent = self
                                                        self._children_name_map["lbc_pc"] = "lbc-pc"
                                                    return self.lbc_pc

                                                if (child_yang_name == "low-sig-freq-off"):
                                                    if (self.low_sig_freq_off is None):
                                                        self.low_sig_freq_off = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.LowSigFreqOff()
                                                        self.low_sig_freq_off.parent = self
                                                        self._children_name_map["low_sig_freq_off"] = "low-sig-freq-off"
                                                    return self.low_sig_freq_off

                                                if (child_yang_name == "opr"):
                                                    if (self.opr is None):
                                                        self.opr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opr()
                                                        self.opr.parent = self
                                                        self._children_name_map["opr"] = "opr"
                                                    return self.opr

                                                if (child_yang_name == "opt"):
                                                    if (self.opt is None):
                                                        self.opt = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Opt()
                                                        self.opt.parent = self
                                                        self._children_name_map["opt"] = "opt"
                                                    return self.opt

                                                if (child_yang_name == "osnr"):
                                                    if (self.osnr is None):
                                                        self.osnr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Osnr()
                                                        self.osnr.parent = self
                                                        self._children_name_map["osnr"] = "osnr"
                                                    return self.osnr

                                                if (child_yang_name == "pcr"):
                                                    if (self.pcr is None):
                                                        self.pcr = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pcr()
                                                        self.pcr.parent = self
                                                        self._children_name_map["pcr"] = "pcr"
                                                    return self.pcr

                                                if (child_yang_name == "pdl"):
                                                    if (self.pdl is None):
                                                        self.pdl = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pdl()
                                                        self.pdl.parent = self
                                                        self._children_name_map["pdl"] = "pdl"
                                                    return self.pdl

                                                if (child_yang_name == "pmd"):
                                                    if (self.pmd is None):
                                                        self.pmd = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pmd()
                                                        self.pmd.parent = self
                                                        self._children_name_map["pmd"] = "pmd"
                                                    return self.pmd

                                                if (child_yang_name == "pn"):
                                                    if (self.pn is None):
                                                        self.pn = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.Pn()
                                                        self.pn.parent = self
                                                        self._children_name_map["pn"] = "pn"
                                                    return self.pn

                                                if (child_yang_name == "rx-sig-pow"):
                                                    if (self.rx_sig_pow is None):
                                                        self.rx_sig_pow = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance.RxSigPow()
                                                        self.rx_sig_pow.parent = self
                                                        self._children_name_map["rx_sig_pow"] = "rx-sig-pow"
                                                    return self.rx_sig_pow

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cd" or name == "center-wavelength" or name == "dgd" or name == "lbc" or name == "lbc-pc" or name == "low-sig-freq-off" or name == "opr" or name == "opt" or name == "osnr" or name == "pcr" or name == "pdl" or name == "pmd" or name == "pn" or name == "rx-sig-pow" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.optics_minute15_optics_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.optics_minute15_optics_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "optics-minute15-optics-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "optics-minute15-optics-time-line-instance"):
                                                for c in self.optics_minute15_optics_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances.OpticsMinute15OpticsTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.optics_minute15_optics_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "optics-minute15-optics-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.optics_minute15_optics_time_line_instances is not None and self.optics_minute15_optics_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.optics_minute15_optics_time_line_instances is not None and self.optics_minute15_optics_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "optics-minute15-optics-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "optics-minute15-optics-time-line-instances"):
                                            if (self.optics_minute15_optics_time_line_instances is None):
                                                self.optics_minute15_optics_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory.OpticsMinute15OpticsTimeLineInstances()
                                                self.optics_minute15_optics_time_line_instances.parent = self
                                                self._children_name_map["optics_minute15_optics_time_line_instances"] = "optics-minute15-optics-time-line-instances"
                                            return self.optics_minute15_optics_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "optics-minute15-optics-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.optics_minute15_optics_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.optics_minute15_optics_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "optics-minute15-optics-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "optics-minute15-optics-history"):
                                        for c in self.optics_minute15_optics_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories.OpticsMinute15OpticsHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.optics_minute15_optics_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "optics-minute15-optics-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class OpticsMinute15FecHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: optics_minute15fec_history
                                
                                	port 15\-minute fec performance data
                                	**type**\: list of    :py:class:`OpticsMinute15FecHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories, self).__init__()

                                    self.yang_name = "optics-minute15fec-histories"
                                    self.yang_parent_name = "optics-minute15-history"

                                    self.optics_minute15fec_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories, self).__setattr__(name, value)


                                class OpticsMinute15FecHistory(Entity):
                                    """
                                    port 15\-minute fec performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: optics_minute15fec_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OpticsMinute15FecTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory, self).__init__()

                                        self.yang_name = "optics-minute15fec-history"
                                        self.yang_parent_name = "optics-minute15fec-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.optics_minute15fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances()
                                        self.optics_minute15fec_time_line_instances.parent = self
                                        self._children_name_map["optics_minute15fec_time_line_instances"] = "optics-minute15fec-time-line-instances"
                                        self._children_yang_names.add("optics-minute15fec-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory, self).__setattr__(name, value)


                                    class OpticsMinute15FecTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: optics_minute15fec_time_line_instance
                                        
                                        	port 15\-minute fec performance data
                                        	**type**\: list of    :py:class:`OpticsMinute15FecTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances, self).__init__()

                                            self.yang_name = "optics-minute15fec-time-line-instances"
                                            self.yang_parent_name = "optics-minute15fec-history"

                                            self.optics_minute15fec_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances, self).__setattr__(name, value)


                                        class OpticsMinute15FecTimeLineInstance(Entity):
                                            """
                                            port 15\-minute fec performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ec_bits
                                            
                                            	EC BITS
                                            	**type**\:   :py:class:`EcBits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.EcBits>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear30_sec_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            .. attribute:: post_fec_ber
                                            
                                            	Post FEC BER
                                            	**type**\:   :py:class:`PostFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PostFecBer>`
                                            
                                            .. attribute:: pre_fec_ber
                                            
                                            	Pre FEC BER
                                            	**type**\:   :py:class:`PreFecBer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PreFecBer>`
                                            
                                            .. attribute:: q
                                            
                                            	Q
                                            	**type**\:   :py:class:`Q <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Q>`
                                            
                                            .. attribute:: qmargin
                                            
                                            	Q Margin
                                            	**type**\:   :py:class:`Qmargin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Qmargin>`
                                            
                                            .. attribute:: sec30_support
                                            
                                            	30 sec support
                                            	**type**\:  bool
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            .. attribute:: uc_words
                                            
                                            	UC WORDS
                                            	**type**\:   :py:class:`UcWords <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.UcWords>`
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance, self).__init__()

                                                self.yang_name = "optics-minute15fec-time-line-instance"
                                                self.yang_parent_name = "optics-minute15fec-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear30_sec_time = YLeaf(YType.str, "last-clear30-sec-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.sec30_support = YLeaf(YType.boolean, "sec30-support")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.EcBits()
                                                self.ec_bits.parent = self
                                                self._children_name_map["ec_bits"] = "ec-bits"
                                                self._children_yang_names.add("ec-bits")

                                                self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PostFecBer()
                                                self.post_fec_ber.parent = self
                                                self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                self._children_yang_names.add("post-fec-ber")

                                                self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PreFecBer()
                                                self.pre_fec_ber.parent = self
                                                self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                self._children_yang_names.add("pre-fec-ber")

                                                self.q = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Q()
                                                self.q.parent = self
                                                self._children_name_map["q"] = "q"
                                                self._children_yang_names.add("q")

                                                self.qmargin = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Qmargin()
                                                self.qmargin.parent = self
                                                self._children_name_map["qmargin"] = "qmargin"
                                                self._children_yang_names.add("qmargin")

                                                self.uc_words = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.UcWords()
                                                self.uc_words.parent = self
                                                self._children_name_map["uc_words"] = "uc-words"
                                                self._children_yang_names.add("uc-words")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear30_sec_time",
                                                                "last_clear_time",
                                                                "sec30_support",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance, self).__setattr__(name, value)


                                            class EcBits(Entity):
                                                """
                                                EC BITS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.EcBits, self).__init__()

                                                    self.yang_name = "ec-bits"
                                                    self.yang_parent_name = "optics-minute15fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.EcBits, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.EcBits, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ec-bits" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class UcWords(Entity):
                                                """
                                                UC WORDS
                                                
                                                .. attribute:: data
                                                
                                                	the number in the interval
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: threshold
                                                
                                                	the threshold users set
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.UcWords, self).__init__()

                                                    self.yang_name = "uc-words"
                                                    self.yang_parent_name = "optics-minute15fec-time-line-instance"

                                                    self.data = YLeaf(YType.uint64, "data")

                                                    self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                    self.threshold = YLeaf(YType.uint64, "threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("data",
                                                                    "tca_report",
                                                                    "threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.UcWords, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.UcWords, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.data.is_set or
                                                        self.tca_report.is_set or
                                                        self.threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.data.yfilter != YFilter.not_set or
                                                        self.tca_report.yfilter != YFilter.not_set or
                                                        self.threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uc-words" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.data.get_name_leafdata())
                                                    if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "data" or name == "tca-report" or name == "threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "data"):
                                                        self.data = value
                                                        self.data.value_namespace = name_space
                                                        self.data.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tca-report"):
                                                        self.tca_report = value
                                                        self.tca_report.value_namespace = name_space
                                                        self.tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "threshold"):
                                                        self.threshold = value
                                                        self.threshold.value_namespace = name_space
                                                        self.threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PreFecBer(Entity):
                                                """
                                                Pre FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PreFecBer, self).__init__()

                                                    self.yang_name = "pre-fec-ber"
                                                    self.yang_parent_name = "optics-minute15fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PreFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "pre-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class PostFecBer(Entity):
                                                """
                                                Post FEC BER
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PostFecBer, self).__init__()

                                                    self.yang_name = "post-fec-ber"
                                                    self.yang_parent_name = "optics-minute15fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PostFecBer, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "post-fec-ber" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Q(Entity):
                                                """
                                                Q
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Q, self).__init__()

                                                    self.yang_name = "q"
                                                    self.yang_parent_name = "optics-minute15fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Q, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Q, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "q" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix


                                            class Qmargin(Entity):
                                                """
                                                Q Margin
                                                
                                                .. attribute:: average
                                                
                                                	average
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum
                                                
                                                	maximum
                                                	**type**\:  str
                                                
                                                .. attribute:: maximum_tca_report
                                                
                                                	enable/disable to report TCA
                                                	**type**\:  bool
                                                
                                                .. attribute:: maximum_threshold
                                                
                                                	maximum threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum
                                                
                                                	minimum
                                                	**type**\:  str
                                                
                                                .. attribute:: minimum_tca_report
                                                
                                                	enable/disable to report TCA on min
                                                	**type**\:  bool
                                                
                                                .. attribute:: minimum_threshold
                                                
                                                	minimun threshold
                                                	**type**\:  str
                                                
                                                .. attribute:: valid
                                                
                                                	valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Qmargin, self).__init__()

                                                    self.yang_name = "qmargin"
                                                    self.yang_parent_name = "optics-minute15fec-time-line-instance"

                                                    self.average = YLeaf(YType.str, "average")

                                                    self.maximum = YLeaf(YType.str, "maximum")

                                                    self.maximum_tca_report = YLeaf(YType.boolean, "maximum-tca-report")

                                                    self.maximum_threshold = YLeaf(YType.str, "maximum-threshold")

                                                    self.minimum = YLeaf(YType.str, "minimum")

                                                    self.minimum_tca_report = YLeaf(YType.boolean, "minimum-tca-report")

                                                    self.minimum_threshold = YLeaf(YType.str, "minimum-threshold")

                                                    self.valid = YLeaf(YType.boolean, "valid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("average",
                                                                    "maximum",
                                                                    "maximum_tca_report",
                                                                    "maximum_threshold",
                                                                    "minimum",
                                                                    "minimum_tca_report",
                                                                    "minimum_threshold",
                                                                    "valid") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Qmargin, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Qmargin, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.average.is_set or
                                                        self.maximum.is_set or
                                                        self.maximum_tca_report.is_set or
                                                        self.maximum_threshold.is_set or
                                                        self.minimum.is_set or
                                                        self.minimum_tca_report.is_set or
                                                        self.minimum_threshold.is_set or
                                                        self.valid.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.average.yfilter != YFilter.not_set or
                                                        self.maximum.yfilter != YFilter.not_set or
                                                        self.maximum_tca_report.yfilter != YFilter.not_set or
                                                        self.maximum_threshold.yfilter != YFilter.not_set or
                                                        self.minimum.yfilter != YFilter.not_set or
                                                        self.minimum_tca_report.yfilter != YFilter.not_set or
                                                        self.minimum_threshold.yfilter != YFilter.not_set or
                                                        self.valid.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "qmargin" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.average.is_set or self.average.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.average.get_name_leafdata())
                                                    if (self.maximum.is_set or self.maximum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum.get_name_leafdata())
                                                    if (self.maximum_tca_report.is_set or self.maximum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_tca_report.get_name_leafdata())
                                                    if (self.maximum_threshold.is_set or self.maximum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_threshold.get_name_leafdata())
                                                    if (self.minimum.is_set or self.minimum.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum.get_name_leafdata())
                                                    if (self.minimum_tca_report.is_set or self.minimum_tca_report.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_tca_report.get_name_leafdata())
                                                    if (self.minimum_threshold.is_set or self.minimum_threshold.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.minimum_threshold.get_name_leafdata())
                                                    if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.valid.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "average" or name == "maximum" or name == "maximum-tca-report" or name == "maximum-threshold" or name == "minimum" or name == "minimum-tca-report" or name == "minimum-threshold" or name == "valid"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "average"):
                                                        self.average = value
                                                        self.average.value_namespace = name_space
                                                        self.average.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum"):
                                                        self.maximum = value
                                                        self.maximum.value_namespace = name_space
                                                        self.maximum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-tca-report"):
                                                        self.maximum_tca_report = value
                                                        self.maximum_tca_report.value_namespace = name_space
                                                        self.maximum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "maximum-threshold"):
                                                        self.maximum_threshold = value
                                                        self.maximum_threshold.value_namespace = name_space
                                                        self.maximum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum"):
                                                        self.minimum = value
                                                        self.minimum.value_namespace = name_space
                                                        self.minimum.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-tca-report"):
                                                        self.minimum_tca_report = value
                                                        self.minimum_tca_report.value_namespace = name_space
                                                        self.minimum_tca_report.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "minimum-threshold"):
                                                        self.minimum_threshold = value
                                                        self.minimum_threshold.value_namespace = name_space
                                                        self.minimum_threshold.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "valid"):
                                                        self.valid = value
                                                        self.valid.value_namespace = name_space
                                                        self.valid.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear30_sec_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.sec30_support.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_data()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_data()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_data()) or
                                                    (self.q is not None and self.q.has_data()) or
                                                    (self.qmargin is not None and self.qmargin.has_data()) or
                                                    (self.uc_words is not None and self.uc_words.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear30_sec_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.sec30_support.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.ec_bits is not None and self.ec_bits.has_operation()) or
                                                    (self.post_fec_ber is not None and self.post_fec_ber.has_operation()) or
                                                    (self.pre_fec_ber is not None and self.pre_fec_ber.has_operation()) or
                                                    (self.q is not None and self.q.has_operation()) or
                                                    (self.qmargin is not None and self.qmargin.has_operation()) or
                                                    (self.uc_words is not None and self.uc_words.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "optics-minute15fec-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear30_sec_time.is_set or self.last_clear30_sec_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear30_sec_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.sec30_support.is_set or self.sec30_support.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.sec30_support.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ec-bits"):
                                                    if (self.ec_bits is None):
                                                        self.ec_bits = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.EcBits()
                                                        self.ec_bits.parent = self
                                                        self._children_name_map["ec_bits"] = "ec-bits"
                                                    return self.ec_bits

                                                if (child_yang_name == "post-fec-ber"):
                                                    if (self.post_fec_ber is None):
                                                        self.post_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PostFecBer()
                                                        self.post_fec_ber.parent = self
                                                        self._children_name_map["post_fec_ber"] = "post-fec-ber"
                                                    return self.post_fec_ber

                                                if (child_yang_name == "pre-fec-ber"):
                                                    if (self.pre_fec_ber is None):
                                                        self.pre_fec_ber = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.PreFecBer()
                                                        self.pre_fec_ber.parent = self
                                                        self._children_name_map["pre_fec_ber"] = "pre-fec-ber"
                                                    return self.pre_fec_ber

                                                if (child_yang_name == "q"):
                                                    if (self.q is None):
                                                        self.q = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Q()
                                                        self.q.parent = self
                                                        self._children_name_map["q"] = "q"
                                                    return self.q

                                                if (child_yang_name == "qmargin"):
                                                    if (self.qmargin is None):
                                                        self.qmargin = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.Qmargin()
                                                        self.qmargin.parent = self
                                                        self._children_name_map["qmargin"] = "qmargin"
                                                    return self.qmargin

                                                if (child_yang_name == "uc-words"):
                                                    if (self.uc_words is None):
                                                        self.uc_words = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance.UcWords()
                                                        self.uc_words.parent = self
                                                        self._children_name_map["uc_words"] = "uc-words"
                                                    return self.uc_words

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ec-bits" or name == "post-fec-ber" or name == "pre-fec-ber" or name == "q" or name == "qmargin" or name == "uc-words" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear30-sec-time" or name == "last-clear-time" or name == "sec30-support" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear30-sec-time"):
                                                    self.last_clear30_sec_time = value
                                                    self.last_clear30_sec_time.value_namespace = name_space
                                                    self.last_clear30_sec_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "sec30-support"):
                                                    self.sec30_support = value
                                                    self.sec30_support.value_namespace = name_space
                                                    self.sec30_support.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.optics_minute15fec_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.optics_minute15fec_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "optics-minute15fec-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "optics-minute15fec-time-line-instance"):
                                                for c in self.optics_minute15fec_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances.OpticsMinute15FecTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.optics_minute15fec_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "optics-minute15fec-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.optics_minute15fec_time_line_instances is not None and self.optics_minute15fec_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.optics_minute15fec_time_line_instances is not None and self.optics_minute15fec_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "optics-minute15fec-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "optics-minute15fec-time-line-instances"):
                                            if (self.optics_minute15fec_time_line_instances is None):
                                                self.optics_minute15fec_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory.OpticsMinute15FecTimeLineInstances()
                                                self.optics_minute15fec_time_line_instances.parent = self
                                                self._children_name_map["optics_minute15fec_time_line_instances"] = "optics-minute15fec-time-line-instances"
                                            return self.optics_minute15fec_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "optics-minute15fec-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.optics_minute15fec_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.optics_minute15fec_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "optics-minute15fec-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "optics-minute15fec-history"):
                                        for c in self.optics_minute15fec_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories.OpticsMinute15FecHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.optics_minute15fec_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "optics-minute15fec-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    (self.optics_minute15_optics_histories is not None and self.optics_minute15_optics_histories.has_data()) or
                                    (self.optics_minute15fec_histories is not None and self.optics_minute15fec_histories.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.optics_minute15_optics_histories is not None and self.optics_minute15_optics_histories.has_operation()) or
                                    (self.optics_minute15fec_histories is not None and self.optics_minute15fec_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "optics-minute15-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "optics-minute15-optics-histories"):
                                    if (self.optics_minute15_optics_histories is None):
                                        self.optics_minute15_optics_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15OpticsHistories()
                                        self.optics_minute15_optics_histories.parent = self
                                        self._children_name_map["optics_minute15_optics_histories"] = "optics-minute15-optics-histories"
                                    return self.optics_minute15_optics_histories

                                if (child_yang_name == "optics-minute15fec-histories"):
                                    if (self.optics_minute15fec_histories is None):
                                        self.optics_minute15fec_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History.OpticsMinute15FecHistories()
                                        self.optics_minute15fec_histories.parent = self
                                        self._children_name_map["optics_minute15fec_histories"] = "optics-minute15fec-histories"
                                    return self.optics_minute15fec_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "optics-minute15-optics-histories" or name == "optics-minute15fec-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.name.is_set or
                                (self.optics_hour24_history is not None and self.optics_hour24_history.has_data()) or
                                (self.optics_minute15_history is not None and self.optics_minute15_history.has_data()) or
                                (self.optics_second30_history is not None and self.optics_second30_history.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                (self.optics_hour24_history is not None and self.optics_hour24_history.has_operation()) or
                                (self.optics_minute15_history is not None and self.optics_minute15_history.has_operation()) or
                                (self.optics_second30_history is not None and self.optics_second30_history.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "optics-port-history" + "[name='" + self.name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/optics-history/optics-port-histories/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "optics-hour24-history"):
                                if (self.optics_hour24_history is None):
                                    self.optics_hour24_history = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsHour24History()
                                    self.optics_hour24_history.parent = self
                                    self._children_name_map["optics_hour24_history"] = "optics-hour24-history"
                                return self.optics_hour24_history

                            if (child_yang_name == "optics-minute15-history"):
                                if (self.optics_minute15_history is None):
                                    self.optics_minute15_history = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsMinute15History()
                                    self.optics_minute15_history.parent = self
                                    self._children_name_map["optics_minute15_history"] = "optics-minute15-history"
                                return self.optics_minute15_history

                            if (child_yang_name == "optics-second30-history"):
                                if (self.optics_second30_history is None):
                                    self.optics_second30_history = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory.OpticsSecond30History()
                                    self.optics_second30_history.parent = self
                                    self._children_name_map["optics_second30_history"] = "optics-second30-history"
                                return self.optics_second30_history

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "optics-hour24-history" or name == "optics-minute15-history" or name == "optics-second30-history" or name == "name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.optics_port_history:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.optics_port_history:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "optics-port-histories" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/optics-history/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "optics-port-history"):
                            for c in self.optics_port_history:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories.OpticsPortHistory()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.optics_port_history.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "optics-port-history"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.optics_port_histories is not None and self.optics_port_histories.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.optics_port_histories is not None and self.optics_port_histories.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "optics-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "optics-port-histories"):
                        if (self.optics_port_histories is None):
                            self.optics_port_histories = PerformanceManagementHistory.Global_.Periodic.OpticsHistory.OpticsPortHistories()
                            self.optics_port_histories.parent = self
                            self._children_name_map["optics_port_histories"] = "optics-port-histories"
                        return self.optics_port_histories

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "optics-port-histories"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class OcHistory(Entity):
                """
                OC controller History performance data
                
                .. attribute:: oc_port_histories
                
                	Port performance data
                	**type**\:   :py:class:`OcPortHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories>`
                
                

                """

                _prefix = 'pmengine-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory, self).__init__()

                    self.yang_name = "oc-history"
                    self.yang_parent_name = "periodic"

                    self.oc_port_histories = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories()
                    self.oc_port_histories.parent = self
                    self._children_name_map["oc_port_histories"] = "oc-port-histories"
                    self._children_yang_names.add("oc-port-histories")


                class OcPortHistories(Entity):
                    """
                    Port performance data
                    
                    .. attribute:: oc_port_history
                    
                    	Port performance data
                    	**type**\: list of    :py:class:`OcPortHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory>`
                    
                    

                    """

                    _prefix = 'pmengine-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories, self).__init__()

                        self.yang_name = "oc-port-histories"
                        self.yang_parent_name = "oc-history"

                        self.oc_port_history = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories, self).__setattr__(name, value)


                    class OcPortHistory(Entity):
                        """
                        Port performance data
                        
                        .. attribute:: name  <key>
                        
                        	Port name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: oc_hour24_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OcHour24History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History>`
                        
                        .. attribute:: oc_minute15_history
                        
                        	port current performance data
                        	**type**\:   :py:class:`OcMinute15History <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History>`
                        
                        

                        """

                        _prefix = 'pmengine-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory, self).__init__()

                            self.yang_name = "oc-port-history"
                            self.yang_parent_name = "oc-port-histories"

                            self.name = YLeaf(YType.str, "name")

                            self.oc_hour24_history = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History()
                            self.oc_hour24_history.parent = self
                            self._children_name_map["oc_hour24_history"] = "oc-hour24-history"
                            self._children_yang_names.add("oc-hour24-history")

                            self.oc_minute15_history = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History()
                            self.oc_minute15_history.parent = self
                            self._children_name_map["oc_minute15_history"] = "oc-minute15-history"
                            self._children_yang_names.add("oc-minute15-history")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory, self).__setattr__(name, value)


                        class OcHour24History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: oc_hour24ocn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OcHour24OcnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History, self).__init__()

                                self.yang_name = "oc-hour24-history"
                                self.yang_parent_name = "oc-port-history"

                                self.oc_hour24ocn_histories = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories()
                                self.oc_hour24ocn_histories.parent = self
                                self._children_name_map["oc_hour24ocn_histories"] = "oc-hour24ocn-histories"
                                self._children_yang_names.add("oc-hour24ocn-histories")


                            class OcHour24OcnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: oc_hour24ocn_history
                                
                                	port 24 hour ocn performance data
                                	**type**\: list of    :py:class:`OcHour24OcnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories, self).__init__()

                                    self.yang_name = "oc-hour24ocn-histories"
                                    self.yang_parent_name = "oc-hour24-history"

                                    self.oc_hour24ocn_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories, self).__setattr__(name, value)


                                class OcHour24OcnHistory(Entity):
                                    """
                                    port 24 hour ocn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: oc_hour24ocn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OcHour24OcnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory, self).__init__()

                                        self.yang_name = "oc-hour24ocn-history"
                                        self.yang_parent_name = "oc-hour24ocn-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.oc_hour24ocn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances()
                                        self.oc_hour24ocn_time_line_instances.parent = self
                                        self._children_name_map["oc_hour24ocn_time_line_instances"] = "oc-hour24ocn-time-line-instances"
                                        self._children_yang_names.add("oc-hour24ocn-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory, self).__setattr__(name, value)


                                    class OcHour24OcnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: oc_hour24ocn_time_line_instance
                                        
                                        	port 15\-minute otn performance data
                                        	**type**\: list of    :py:class:`OcHour24OcnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances, self).__init__()

                                            self.yang_name = "oc-hour24ocn-time-line-instances"
                                            self.yang_parent_name = "oc-hour24ocn-history"

                                            self.oc_hour24ocn_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances, self).__setattr__(name, value)


                                        class OcHour24OcnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute otn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line>`
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance, self).__init__()

                                                self.yang_name = "oc-hour24ocn-time-line-instance"
                                                self.yang_parent_name = "oc-hour24ocn-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.fe_line = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self._children_name_map["fe_line"] = "fe-line"
                                                self._children_yang_names.add("fe-line")

                                                self.line = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line()
                                                self.line.parent = self
                                                self._children_name_map["line"] = "line"
                                                self._children_yang_names.add("line")

                                                self.section = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section()
                                                self.section.parent = self
                                                self._children_name_map["section"] = "section"
                                                self._children_yang_names.add("section")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance, self).__setattr__(name, value)


                                            class Section(Entity):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionCVs>`
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_sef_ss
                                                
                                                	The number of Severely Errored Framing Seconds
                                                	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSefSs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section, self).__init__()

                                                    self.yang_name = "section"
                                                    self.yang_parent_name = "oc-hour24ocn-time-line-instance"

                                                    self.section_status = YLeaf(YType.int32, "section-status")

                                                    self.section_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionCVs()
                                                    self.section_c_vs.parent = self
                                                    self._children_name_map["section_c_vs"] = "section-c-vs"
                                                    self._children_yang_names.add("section-c-vs")

                                                    self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self._children_name_map["section_e_ss"] = "section-e-ss"
                                                    self._children_yang_names.add("section-e-ss")

                                                    self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self._children_name_map["section_se_ss"] = "section-se-ss"
                                                    self._children_yang_names.add("section-se-ss")

                                                    self.section_sef_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSefSs()
                                                    self.section_sef_ss.parent = self
                                                    self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                                    self._children_yang_names.add("section-sef-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("section_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section, self).__setattr__(name, value)


                                                class SectionESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionESs, self).__init__()

                                                        self.yang_name = "section-e-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSeSs, self).__init__()

                                                        self.yang_name = "section-se-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionSefSs(Entity):
                                                    """
                                                    The number of Severely Errored Framing Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSefSs, self).__init__()

                                                        self.yang_name = "section-sef-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSefSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSefSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-sef-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionCVs, self).__init__()

                                                        self.yang_name = "section-c-vs"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.section_status.is_set or
                                                        (self.section_c_vs is not None and self.section_c_vs.has_data()) or
                                                        (self.section_e_ss is not None and self.section_e_ss.has_data()) or
                                                        (self.section_se_ss is not None and self.section_se_ss.has_data()) or
                                                        (self.section_sef_ss is not None and self.section_sef_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.section_status.yfilter != YFilter.not_set or
                                                        (self.section_c_vs is not None and self.section_c_vs.has_operation()) or
                                                        (self.section_e_ss is not None and self.section_e_ss.has_operation()) or
                                                        (self.section_se_ss is not None and self.section_se_ss.has_operation()) or
                                                        (self.section_sef_ss is not None and self.section_sef_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "section" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.section_status.is_set or self.section_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.section_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "section-c-vs"):
                                                        if (self.section_c_vs is None):
                                                            self.section_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionCVs()
                                                            self.section_c_vs.parent = self
                                                            self._children_name_map["section_c_vs"] = "section-c-vs"
                                                        return self.section_c_vs

                                                    if (child_yang_name == "section-e-ss"):
                                                        if (self.section_e_ss is None):
                                                            self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionESs()
                                                            self.section_e_ss.parent = self
                                                            self._children_name_map["section_e_ss"] = "section-e-ss"
                                                        return self.section_e_ss

                                                    if (child_yang_name == "section-se-ss"):
                                                        if (self.section_se_ss is None):
                                                            self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSeSs()
                                                            self.section_se_ss.parent = self
                                                            self._children_name_map["section_se_ss"] = "section-se-ss"
                                                        return self.section_se_ss

                                                    if (child_yang_name == "section-sef-ss"):
                                                        if (self.section_sef_ss is None):
                                                            self.section_sef_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section.SectionSefSs()
                                                            self.section_sef_ss.parent = self
                                                            self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                                        return self.section_sef_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "section-c-vs" or name == "section-e-ss" or name == "section-se-ss" or name == "section-sef-ss" or name == "section-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "section-status"):
                                                        self.section_status = value
                                                        self.section_status.value_namespace = name_space
                                                        self.section_status.value_namespace_prefix = name_space_prefix


                                            class Line(Entity):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineCVs>`
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineFcLs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line, self).__init__()

                                                    self.yang_name = "line"
                                                    self.yang_parent_name = "oc-hour24ocn-time-line-instance"

                                                    self.line_status = YLeaf(YType.int32, "line-status")

                                                    self.line_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineCVs()
                                                    self.line_c_vs.parent = self
                                                    self._children_name_map["line_c_vs"] = "line-c-vs"
                                                    self._children_yang_names.add("line-c-vs")

                                                    self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self._children_name_map["line_e_ss"] = "line-e-ss"
                                                    self._children_yang_names.add("line-e-ss")

                                                    self.line_fc_ls = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineFcLs()
                                                    self.line_fc_ls.parent = self
                                                    self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                                    self._children_yang_names.add("line-fc-ls")

                                                    self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self._children_name_map["line_se_ss"] = "line-se-ss"
                                                    self._children_yang_names.add("line-se-ss")

                                                    self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self
                                                    self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                                    self._children_yang_names.add("line-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("line_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line, self).__setattr__(name, value)


                                                class LineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineESs, self).__init__()

                                                        self.yang_name = "line-e-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineSeSs, self).__init__()

                                                        self.yang_name = "line-se-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineCVs, self).__init__()

                                                        self.yang_name = "line-c-vs"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineUaSs, self).__init__()

                                                        self.yang_name = "line-ua-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineFcLs, self).__init__()

                                                        self.yang_name = "line-fc-ls"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineFcLs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineFcLs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-fc-ls" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.line_status.is_set or
                                                        (self.line_c_vs is not None and self.line_c_vs.has_data()) or
                                                        (self.line_e_ss is not None and self.line_e_ss.has_data()) or
                                                        (self.line_fc_ls is not None and self.line_fc_ls.has_data()) or
                                                        (self.line_se_ss is not None and self.line_se_ss.has_data()) or
                                                        (self.line_ua_ss is not None and self.line_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.line_status.yfilter != YFilter.not_set or
                                                        (self.line_c_vs is not None and self.line_c_vs.has_operation()) or
                                                        (self.line_e_ss is not None and self.line_e_ss.has_operation()) or
                                                        (self.line_fc_ls is not None and self.line_fc_ls.has_operation()) or
                                                        (self.line_se_ss is not None and self.line_se_ss.has_operation()) or
                                                        (self.line_ua_ss is not None and self.line_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "line" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.line_status.is_set or self.line_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.line_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "line-c-vs"):
                                                        if (self.line_c_vs is None):
                                                            self.line_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineCVs()
                                                            self.line_c_vs.parent = self
                                                            self._children_name_map["line_c_vs"] = "line-c-vs"
                                                        return self.line_c_vs

                                                    if (child_yang_name == "line-e-ss"):
                                                        if (self.line_e_ss is None):
                                                            self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineESs()
                                                            self.line_e_ss.parent = self
                                                            self._children_name_map["line_e_ss"] = "line-e-ss"
                                                        return self.line_e_ss

                                                    if (child_yang_name == "line-fc-ls"):
                                                        if (self.line_fc_ls is None):
                                                            self.line_fc_ls = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineFcLs()
                                                            self.line_fc_ls.parent = self
                                                            self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                                        return self.line_fc_ls

                                                    if (child_yang_name == "line-se-ss"):
                                                        if (self.line_se_ss is None):
                                                            self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineSeSs()
                                                            self.line_se_ss.parent = self
                                                            self._children_name_map["line_se_ss"] = "line-se-ss"
                                                        return self.line_se_ss

                                                    if (child_yang_name == "line-ua-ss"):
                                                        if (self.line_ua_ss is None):
                                                            self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line.LineUaSs()
                                                            self.line_ua_ss.parent = self
                                                            self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                                        return self.line_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "line-c-vs" or name == "line-e-ss" or name == "line-fc-ls" or name == "line-se-ss" or name == "line-ua-ss" or name == "line-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "line-status"):
                                                        self.line_status = value
                                                        self.line_status.value_namespace = name_space
                                                        self.line_status.value_namespace_prefix = name_space_prefix


                                            class FeLine(Entity):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineCVs>`
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine, self).__init__()

                                                    self.yang_name = "fe-line"
                                                    self.yang_parent_name = "oc-hour24ocn-time-line-instance"

                                                    self.far_end_line_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineCVs()
                                                    self.far_end_line_c_vs.parent = self
                                                    self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                                    self._children_yang_names.add("far-end-line-c-vs")

                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                                    self._children_yang_names.add("far-end-line-e-ss")

                                                    self.far_end_line_fc_ls = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                    self.far_end_line_fc_ls.parent = self
                                                    self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                                    self._children_yang_names.add("far-end-line-fc-ls")

                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                                    self._children_yang_names.add("far-end-line-se-ss")

                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self
                                                    self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                                    self._children_yang_names.add("far-end-line-ua-ss")


                                                class FarEndLineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineESs, self).__init__()

                                                        self.yang_name = "far-end-line-e-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs, self).__init__()

                                                        self.yang_name = "far-end-line-se-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineCVs, self).__init__()

                                                        self.yang_name = "far-end-line-c-vs"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs, self).__init__()

                                                        self.yang_name = "far-end-line-ua-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs, self).__init__()

                                                        self.yang_name = "far-end-line-fc-ls"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-fc-ls" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_data()) or
                                                        (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_data()) or
                                                        (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_data()) or
                                                        (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_data()) or
                                                        (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_operation()) or
                                                        (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_operation()) or
                                                        (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_operation()) or
                                                        (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_operation()) or
                                                        (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fe-line" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "far-end-line-c-vs"):
                                                        if (self.far_end_line_c_vs is None):
                                                            self.far_end_line_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineCVs()
                                                            self.far_end_line_c_vs.parent = self
                                                            self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                                        return self.far_end_line_c_vs

                                                    if (child_yang_name == "far-end-line-e-ss"):
                                                        if (self.far_end_line_e_ss is None):
                                                            self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineESs()
                                                            self.far_end_line_e_ss.parent = self
                                                            self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                                        return self.far_end_line_e_ss

                                                    if (child_yang_name == "far-end-line-fc-ls"):
                                                        if (self.far_end_line_fc_ls is None):
                                                            self.far_end_line_fc_ls = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                            self.far_end_line_fc_ls.parent = self
                                                            self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                                        return self.far_end_line_fc_ls

                                                    if (child_yang_name == "far-end-line-se-ss"):
                                                        if (self.far_end_line_se_ss is None):
                                                            self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                            self.far_end_line_se_ss.parent = self
                                                            self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                                        return self.far_end_line_se_ss

                                                    if (child_yang_name == "far-end-line-ua-ss"):
                                                        if (self.far_end_line_ua_ss is None):
                                                            self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                            self.far_end_line_ua_ss.parent = self
                                                            self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                                        return self.far_end_line_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "far-end-line-c-vs" or name == "far-end-line-e-ss" or name == "far-end-line-fc-ls" or name == "far-end-line-se-ss" or name == "far-end-line-ua-ss"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.fe_line is not None and self.fe_line.has_data()) or
                                                    (self.line is not None and self.line.has_data()) or
                                                    (self.section is not None and self.section.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.fe_line is not None and self.fe_line.has_operation()) or
                                                    (self.line is not None and self.line.has_operation()) or
                                                    (self.section is not None and self.section.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "oc-hour24ocn-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "fe-line"):
                                                    if (self.fe_line is None):
                                                        self.fe_line = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.FeLine()
                                                        self.fe_line.parent = self
                                                        self._children_name_map["fe_line"] = "fe-line"
                                                    return self.fe_line

                                                if (child_yang_name == "line"):
                                                    if (self.line is None):
                                                        self.line = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Line()
                                                        self.line.parent = self
                                                        self._children_name_map["line"] = "line"
                                                    return self.line

                                                if (child_yang_name == "section"):
                                                    if (self.section is None):
                                                        self.section = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance.Section()
                                                        self.section.parent = self
                                                        self._children_name_map["section"] = "section"
                                                    return self.section

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "fe-line" or name == "line" or name == "section" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.oc_hour24ocn_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.oc_hour24ocn_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "oc-hour24ocn-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "oc-hour24ocn-time-line-instance"):
                                                for c in self.oc_hour24ocn_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances.OcHour24OcnTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.oc_hour24ocn_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "oc-hour24ocn-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.oc_hour24ocn_time_line_instances is not None and self.oc_hour24ocn_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.oc_hour24ocn_time_line_instances is not None and self.oc_hour24ocn_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "oc-hour24ocn-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "oc-hour24ocn-time-line-instances"):
                                            if (self.oc_hour24ocn_time_line_instances is None):
                                                self.oc_hour24ocn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory.OcHour24OcnTimeLineInstances()
                                                self.oc_hour24ocn_time_line_instances.parent = self
                                                self._children_name_map["oc_hour24ocn_time_line_instances"] = "oc-hour24ocn-time-line-instances"
                                            return self.oc_hour24ocn_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "oc-hour24ocn-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.oc_hour24ocn_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.oc_hour24ocn_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "oc-hour24ocn-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "oc-hour24ocn-history"):
                                        for c in self.oc_hour24ocn_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories.OcHour24OcnHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.oc_hour24ocn_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "oc-hour24ocn-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.oc_hour24ocn_histories is not None and self.oc_hour24ocn_histories.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.oc_hour24ocn_histories is not None and self.oc_hour24ocn_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "oc-hour24-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "oc-hour24ocn-histories"):
                                    if (self.oc_hour24ocn_histories is None):
                                        self.oc_hour24ocn_histories = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History.OcHour24OcnHistories()
                                        self.oc_hour24ocn_histories.parent = self
                                        self._children_name_map["oc_hour24ocn_histories"] = "oc-hour24ocn-histories"
                                    return self.oc_hour24ocn_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "oc-hour24ocn-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class OcMinute15History(Entity):
                            """
                            port current performance data
                            
                            .. attribute:: oc_minute15ocn_histories
                            
                            	port current performance data
                            	**type**\:   :py:class:`OcMinute15OcnHistories <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories>`
                            
                            

                            """

                            _prefix = 'pmengine-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History, self).__init__()

                                self.yang_name = "oc-minute15-history"
                                self.yang_parent_name = "oc-port-history"

                                self.oc_minute15ocn_histories = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories()
                                self.oc_minute15ocn_histories.parent = self
                                self._children_name_map["oc_minute15ocn_histories"] = "oc-minute15ocn-histories"
                                self._children_yang_names.add("oc-minute15ocn-histories")


                            class OcMinute15OcnHistories(Entity):
                                """
                                port current performance data
                                
                                .. attribute:: oc_minute15ocn_history
                                
                                	port 15\-minute ocn performance data
                                	**type**\: list of    :py:class:`OcMinute15OcnHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory>`
                                
                                

                                """

                                _prefix = 'pmengine-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories, self).__init__()

                                    self.yang_name = "oc-minute15ocn-histories"
                                    self.yang_parent_name = "oc-minute15-history"

                                    self.oc_minute15ocn_history = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories, self).__setattr__(name, value)


                                class OcMinute15OcnHistory(Entity):
                                    """
                                    port 15\-minute ocn performance data
                                    
                                    .. attribute:: number  <key>
                                    
                                    	channel number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: oc_minute15ocn_time_line_instances
                                    
                                    	port current performance data
                                    	**type**\:   :py:class:`OcMinute15OcnTimeLineInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances>`
                                    
                                    

                                    """

                                    _prefix = 'pmengine-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory, self).__init__()

                                        self.yang_name = "oc-minute15ocn-history"
                                        self.yang_parent_name = "oc-minute15ocn-histories"

                                        self.number = YLeaf(YType.int32, "number")

                                        self.oc_minute15ocn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances()
                                        self.oc_minute15ocn_time_line_instances.parent = self
                                        self._children_name_map["oc_minute15ocn_time_line_instances"] = "oc-minute15ocn-time-line-instances"
                                        self._children_yang_names.add("oc-minute15ocn-time-line-instances")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("number") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory, self).__setattr__(name, value)


                                    class OcMinute15OcnTimeLineInstances(Entity):
                                        """
                                        port current performance data
                                        
                                        .. attribute:: oc_minute15ocn_time_line_instance
                                        
                                        	port 15\-minute ocn performance data
                                        	**type**\: list of    :py:class:`OcMinute15OcnTimeLineInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance>`
                                        
                                        

                                        """

                                        _prefix = 'pmengine-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances, self).__init__()

                                            self.yang_name = "oc-minute15ocn-time-line-instances"
                                            self.yang_parent_name = "oc-minute15ocn-history"

                                            self.oc_minute15ocn_time_line_instance = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances, self).__setattr__(name, value)


                                        class OcMinute15OcnTimeLineInstance(Entity):
                                            """
                                            port 15\-minute ocn performance data
                                            
                                            .. attribute:: number  <key>
                                            
                                            	History Index number
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: fe_line
                                            
                                            	FarEnd LINE
                                            	**type**\:   :py:class:`FeLine <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine>`
                                            
                                            .. attribute:: index
                                            
                                            	index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_clear15_min_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear24_hr_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: last_clear_time
                                            
                                            	last clear time
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: line
                                            
                                            	LINE
                                            	**type**\:   :py:class:`Line <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line>`
                                            
                                            .. attribute:: section
                                            
                                            	SECTION
                                            	**type**\:   :py:class:`Section <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section>`
                                            
                                            .. attribute:: timestamp
                                            
                                            	timestamp
                                            	**type**\:  str
                                            
                                            	**length:** 0..64
                                            
                                            .. attribute:: valid
                                            
                                            	valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'pmengine-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance, self).__init__()

                                                self.yang_name = "oc-minute15ocn-time-line-instance"
                                                self.yang_parent_name = "oc-minute15ocn-time-line-instances"

                                                self.number = YLeaf(YType.int32, "number")

                                                self.index = YLeaf(YType.uint32, "index")

                                                self.last_clear15_min_time = YLeaf(YType.str, "last-clear15-min-time")

                                                self.last_clear24_hr_time = YLeaf(YType.str, "last-clear24-hr-time")

                                                self.last_clear_time = YLeaf(YType.str, "last-clear-time")

                                                self.timestamp = YLeaf(YType.str, "timestamp")

                                                self.valid = YLeaf(YType.boolean, "valid")

                                                self.fe_line = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine()
                                                self.fe_line.parent = self
                                                self._children_name_map["fe_line"] = "fe-line"
                                                self._children_yang_names.add("fe-line")

                                                self.line = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line()
                                                self.line.parent = self
                                                self._children_name_map["line"] = "line"
                                                self._children_yang_names.add("line")

                                                self.section = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section()
                                                self.section.parent = self
                                                self._children_name_map["section"] = "section"
                                                self._children_yang_names.add("section")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("number",
                                                                "index",
                                                                "last_clear15_min_time",
                                                                "last_clear24_hr_time",
                                                                "last_clear_time",
                                                                "timestamp",
                                                                "valid") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance, self).__setattr__(name, value)


                                            class Section(Entity):
                                                """
                                                SECTION
                                                
                                                .. attribute:: section_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`SectionCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionCVs>`
                                                
                                                .. attribute:: section_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`SectionESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionESs>`
                                                
                                                .. attribute:: section_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`SectionSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSeSs>`
                                                
                                                .. attribute:: section_sef_ss
                                                
                                                	The number of Severely Errored Framing Seconds
                                                	**type**\:   :py:class:`SectionSefSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSefSs>`
                                                
                                                .. attribute:: section_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section, self).__init__()

                                                    self.yang_name = "section"
                                                    self.yang_parent_name = "oc-minute15ocn-time-line-instance"

                                                    self.section_status = YLeaf(YType.int32, "section-status")

                                                    self.section_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionCVs()
                                                    self.section_c_vs.parent = self
                                                    self._children_name_map["section_c_vs"] = "section-c-vs"
                                                    self._children_yang_names.add("section-c-vs")

                                                    self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionESs()
                                                    self.section_e_ss.parent = self
                                                    self._children_name_map["section_e_ss"] = "section-e-ss"
                                                    self._children_yang_names.add("section-e-ss")

                                                    self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSeSs()
                                                    self.section_se_ss.parent = self
                                                    self._children_name_map["section_se_ss"] = "section-se-ss"
                                                    self._children_yang_names.add("section-se-ss")

                                                    self.section_sef_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSefSs()
                                                    self.section_sef_ss.parent = self
                                                    self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                                    self._children_yang_names.add("section-sef-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("section_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section, self).__setattr__(name, value)


                                                class SectionESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionESs, self).__init__()

                                                        self.yang_name = "section-e-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSeSs, self).__init__()

                                                        self.yang_name = "section-se-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionSefSs(Entity):
                                                    """
                                                    The number of Severely Errored Framing Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSefSs, self).__init__()

                                                        self.yang_name = "section-sef-ss"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSefSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSefSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-sef-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class SectionCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionCVs, self).__init__()

                                                        self.yang_name = "section-c-vs"
                                                        self.yang_parent_name = "section"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "section-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.section_status.is_set or
                                                        (self.section_c_vs is not None and self.section_c_vs.has_data()) or
                                                        (self.section_e_ss is not None and self.section_e_ss.has_data()) or
                                                        (self.section_se_ss is not None and self.section_se_ss.has_data()) or
                                                        (self.section_sef_ss is not None and self.section_sef_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.section_status.yfilter != YFilter.not_set or
                                                        (self.section_c_vs is not None and self.section_c_vs.has_operation()) or
                                                        (self.section_e_ss is not None and self.section_e_ss.has_operation()) or
                                                        (self.section_se_ss is not None and self.section_se_ss.has_operation()) or
                                                        (self.section_sef_ss is not None and self.section_sef_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "section" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.section_status.is_set or self.section_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.section_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "section-c-vs"):
                                                        if (self.section_c_vs is None):
                                                            self.section_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionCVs()
                                                            self.section_c_vs.parent = self
                                                            self._children_name_map["section_c_vs"] = "section-c-vs"
                                                        return self.section_c_vs

                                                    if (child_yang_name == "section-e-ss"):
                                                        if (self.section_e_ss is None):
                                                            self.section_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionESs()
                                                            self.section_e_ss.parent = self
                                                            self._children_name_map["section_e_ss"] = "section-e-ss"
                                                        return self.section_e_ss

                                                    if (child_yang_name == "section-se-ss"):
                                                        if (self.section_se_ss is None):
                                                            self.section_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSeSs()
                                                            self.section_se_ss.parent = self
                                                            self._children_name_map["section_se_ss"] = "section-se-ss"
                                                        return self.section_se_ss

                                                    if (child_yang_name == "section-sef-ss"):
                                                        if (self.section_sef_ss is None):
                                                            self.section_sef_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section.SectionSefSs()
                                                            self.section_sef_ss.parent = self
                                                            self._children_name_map["section_sef_ss"] = "section-sef-ss"
                                                        return self.section_sef_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "section-c-vs" or name == "section-e-ss" or name == "section-se-ss" or name == "section-sef-ss" or name == "section-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "section-status"):
                                                        self.section_status = value
                                                        self.section_status.value_namespace = name_space
                                                        self.section_status.value_namespace_prefix = name_space_prefix


                                            class Line(Entity):
                                                """
                                                LINE
                                                
                                                .. attribute:: line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`LineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineCVs>`
                                                
                                                .. attribute:: line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`LineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineESs>`
                                                
                                                .. attribute:: line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`LineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineFcLs>`
                                                
                                                .. attribute:: line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`LineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineSeSs>`
                                                
                                                .. attribute:: line_status
                                                
                                                	 status of the interface
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`LineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line, self).__init__()

                                                    self.yang_name = "line"
                                                    self.yang_parent_name = "oc-minute15ocn-time-line-instance"

                                                    self.line_status = YLeaf(YType.int32, "line-status")

                                                    self.line_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineCVs()
                                                    self.line_c_vs.parent = self
                                                    self._children_name_map["line_c_vs"] = "line-c-vs"
                                                    self._children_yang_names.add("line-c-vs")

                                                    self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineESs()
                                                    self.line_e_ss.parent = self
                                                    self._children_name_map["line_e_ss"] = "line-e-ss"
                                                    self._children_yang_names.add("line-e-ss")

                                                    self.line_fc_ls = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineFcLs()
                                                    self.line_fc_ls.parent = self
                                                    self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                                    self._children_yang_names.add("line-fc-ls")

                                                    self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineSeSs()
                                                    self.line_se_ss.parent = self
                                                    self._children_name_map["line_se_ss"] = "line-se-ss"
                                                    self._children_yang_names.add("line-se-ss")

                                                    self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineUaSs()
                                                    self.line_ua_ss.parent = self
                                                    self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                                    self._children_yang_names.add("line-ua-ss")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("line_status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line, self).__setattr__(name, value)


                                                class LineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineESs, self).__init__()

                                                        self.yang_name = "line-e-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineSeSs, self).__init__()

                                                        self.yang_name = "line-se-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineCVs, self).__init__()

                                                        self.yang_name = "line-c-vs"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineUaSs, self).__init__()

                                                        self.yang_name = "line-ua-ss"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class LineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineFcLs, self).__init__()

                                                        self.yang_name = "line-fc-ls"
                                                        self.yang_parent_name = "line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineFcLs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineFcLs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "line-fc-ls" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.line_status.is_set or
                                                        (self.line_c_vs is not None and self.line_c_vs.has_data()) or
                                                        (self.line_e_ss is not None and self.line_e_ss.has_data()) or
                                                        (self.line_fc_ls is not None and self.line_fc_ls.has_data()) or
                                                        (self.line_se_ss is not None and self.line_se_ss.has_data()) or
                                                        (self.line_ua_ss is not None and self.line_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.line_status.yfilter != YFilter.not_set or
                                                        (self.line_c_vs is not None and self.line_c_vs.has_operation()) or
                                                        (self.line_e_ss is not None and self.line_e_ss.has_operation()) or
                                                        (self.line_fc_ls is not None and self.line_fc_ls.has_operation()) or
                                                        (self.line_se_ss is not None and self.line_se_ss.has_operation()) or
                                                        (self.line_ua_ss is not None and self.line_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "line" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.line_status.is_set or self.line_status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.line_status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "line-c-vs"):
                                                        if (self.line_c_vs is None):
                                                            self.line_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineCVs()
                                                            self.line_c_vs.parent = self
                                                            self._children_name_map["line_c_vs"] = "line-c-vs"
                                                        return self.line_c_vs

                                                    if (child_yang_name == "line-e-ss"):
                                                        if (self.line_e_ss is None):
                                                            self.line_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineESs()
                                                            self.line_e_ss.parent = self
                                                            self._children_name_map["line_e_ss"] = "line-e-ss"
                                                        return self.line_e_ss

                                                    if (child_yang_name == "line-fc-ls"):
                                                        if (self.line_fc_ls is None):
                                                            self.line_fc_ls = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineFcLs()
                                                            self.line_fc_ls.parent = self
                                                            self._children_name_map["line_fc_ls"] = "line-fc-ls"
                                                        return self.line_fc_ls

                                                    if (child_yang_name == "line-se-ss"):
                                                        if (self.line_se_ss is None):
                                                            self.line_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineSeSs()
                                                            self.line_se_ss.parent = self
                                                            self._children_name_map["line_se_ss"] = "line-se-ss"
                                                        return self.line_se_ss

                                                    if (child_yang_name == "line-ua-ss"):
                                                        if (self.line_ua_ss is None):
                                                            self.line_ua_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line.LineUaSs()
                                                            self.line_ua_ss.parent = self
                                                            self._children_name_map["line_ua_ss"] = "line-ua-ss"
                                                        return self.line_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "line-c-vs" or name == "line-e-ss" or name == "line-fc-ls" or name == "line-se-ss" or name == "line-ua-ss" or name == "line-status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "line-status"):
                                                        self.line_status = value
                                                        self.line_status.value_namespace = name_space
                                                        self.line_status.value_namespace_prefix = name_space_prefix


                                            class FeLine(Entity):
                                                """
                                                FarEnd LINE
                                                
                                                .. attribute:: far_end_line_c_vs
                                                
                                                	The number of Coding Violations
                                                	**type**\:   :py:class:`FarEndLineCVs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs>`
                                                
                                                .. attribute:: far_end_line_e_ss
                                                
                                                	The number of Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineESs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineESs>`
                                                
                                                .. attribute:: far_end_line_fc_ls
                                                
                                                	The number of Failure counts Seconds
                                                	**type**\:   :py:class:`FarEndLineFcLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs>`
                                                
                                                .. attribute:: far_end_line_se_ss
                                                
                                                	The number of Severely Errored Seconds
                                                	**type**\:   :py:class:`FarEndLineSeSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs>`
                                                
                                                .. attribute:: far_end_line_ua_ss
                                                
                                                	The number of Unavailable Seconds
                                                	**type**\:   :py:class:`FarEndLineUaSs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_oper.PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs>`
                                                
                                                

                                                """

                                                _prefix = 'pmengine-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine, self).__init__()

                                                    self.yang_name = "fe-line"
                                                    self.yang_parent_name = "oc-minute15ocn-time-line-instance"

                                                    self.far_end_line_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs()
                                                    self.far_end_line_c_vs.parent = self
                                                    self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                                    self._children_yang_names.add("far-end-line-c-vs")

                                                    self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineESs()
                                                    self.far_end_line_e_ss.parent = self
                                                    self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                                    self._children_yang_names.add("far-end-line-e-ss")

                                                    self.far_end_line_fc_ls = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                    self.far_end_line_fc_ls.parent = self
                                                    self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                                    self._children_yang_names.add("far-end-line-fc-ls")

                                                    self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                    self.far_end_line_se_ss.parent = self
                                                    self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                                    self._children_yang_names.add("far-end-line-se-ss")

                                                    self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                    self.far_end_line_ua_ss.parent = self
                                                    self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                                    self._children_yang_names.add("far-end-line-ua-ss")


                                                class FarEndLineESs(Entity):
                                                    """
                                                    The number of Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineESs, self).__init__()

                                                        self.yang_name = "far-end-line-e-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineESs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineESs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-e-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineSeSs(Entity):
                                                    """
                                                    The number of Severely Errored Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs, self).__init__()

                                                        self.yang_name = "far-end-line-se-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-se-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineCVs(Entity):
                                                    """
                                                    The number of Coding Violations
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs, self).__init__()

                                                        self.yang_name = "far-end-line-c-vs"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-c-vs" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineUaSs(Entity):
                                                    """
                                                    The number of Unavailable Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs, self).__init__()

                                                        self.yang_name = "far-end-line-ua-ss"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-ua-ss" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix


                                                class FarEndLineFcLs(Entity):
                                                    """
                                                    The number of Failure counts Seconds
                                                    
                                                    .. attribute:: data
                                                    
                                                    	the number in the interval
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tca_report
                                                    
                                                    	enable/disable to report TCA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: threshold
                                                    
                                                    	the threshold users set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'pmengine-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs, self).__init__()

                                                        self.yang_name = "far-end-line-fc-ls"
                                                        self.yang_parent_name = "fe-line"

                                                        self.data = YLeaf(YType.uint32, "data")

                                                        self.tca_report = YLeaf(YType.boolean, "tca-report")

                                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("data",
                                                                        "tca_report",
                                                                        "threshold") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.data.is_set or
                                                            self.tca_report.is_set or
                                                            self.threshold.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.data.yfilter != YFilter.not_set or
                                                            self.tca_report.yfilter != YFilter.not_set or
                                                            self.threshold.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "far-end-line-fc-ls" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.data.is_set or self.data.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.data.get_name_leafdata())
                                                        if (self.tca_report.is_set or self.tca_report.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tca_report.get_name_leafdata())
                                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "data" or name == "tca-report" or name == "threshold"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "data"):
                                                            self.data = value
                                                            self.data.value_namespace = name_space
                                                            self.data.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tca-report"):
                                                            self.tca_report = value
                                                            self.tca_report.value_namespace = name_space
                                                            self.tca_report.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "threshold"):
                                                            self.threshold = value
                                                            self.threshold.value_namespace = name_space
                                                            self.threshold.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_data()) or
                                                        (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_data()) or
                                                        (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_data()) or
                                                        (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_data()) or
                                                        (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.far_end_line_c_vs is not None and self.far_end_line_c_vs.has_operation()) or
                                                        (self.far_end_line_e_ss is not None and self.far_end_line_e_ss.has_operation()) or
                                                        (self.far_end_line_fc_ls is not None and self.far_end_line_fc_ls.has_operation()) or
                                                        (self.far_end_line_se_ss is not None and self.far_end_line_se_ss.has_operation()) or
                                                        (self.far_end_line_ua_ss is not None and self.far_end_line_ua_ss.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "fe-line" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "far-end-line-c-vs"):
                                                        if (self.far_end_line_c_vs is None):
                                                            self.far_end_line_c_vs = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineCVs()
                                                            self.far_end_line_c_vs.parent = self
                                                            self._children_name_map["far_end_line_c_vs"] = "far-end-line-c-vs"
                                                        return self.far_end_line_c_vs

                                                    if (child_yang_name == "far-end-line-e-ss"):
                                                        if (self.far_end_line_e_ss is None):
                                                            self.far_end_line_e_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineESs()
                                                            self.far_end_line_e_ss.parent = self
                                                            self._children_name_map["far_end_line_e_ss"] = "far-end-line-e-ss"
                                                        return self.far_end_line_e_ss

                                                    if (child_yang_name == "far-end-line-fc-ls"):
                                                        if (self.far_end_line_fc_ls is None):
                                                            self.far_end_line_fc_ls = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineFcLs()
                                                            self.far_end_line_fc_ls.parent = self
                                                            self._children_name_map["far_end_line_fc_ls"] = "far-end-line-fc-ls"
                                                        return self.far_end_line_fc_ls

                                                    if (child_yang_name == "far-end-line-se-ss"):
                                                        if (self.far_end_line_se_ss is None):
                                                            self.far_end_line_se_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineSeSs()
                                                            self.far_end_line_se_ss.parent = self
                                                            self._children_name_map["far_end_line_se_ss"] = "far-end-line-se-ss"
                                                        return self.far_end_line_se_ss

                                                    if (child_yang_name == "far-end-line-ua-ss"):
                                                        if (self.far_end_line_ua_ss is None):
                                                            self.far_end_line_ua_ss = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine.FarEndLineUaSs()
                                                            self.far_end_line_ua_ss.parent = self
                                                            self._children_name_map["far_end_line_ua_ss"] = "far-end-line-ua-ss"
                                                        return self.far_end_line_ua_ss

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "far-end-line-c-vs" or name == "far-end-line-e-ss" or name == "far-end-line-fc-ls" or name == "far-end-line-se-ss" or name == "far-end-line-ua-ss"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.number.is_set or
                                                    self.index.is_set or
                                                    self.last_clear15_min_time.is_set or
                                                    self.last_clear24_hr_time.is_set or
                                                    self.last_clear_time.is_set or
                                                    self.timestamp.is_set or
                                                    self.valid.is_set or
                                                    (self.fe_line is not None and self.fe_line.has_data()) or
                                                    (self.line is not None and self.line.has_data()) or
                                                    (self.section is not None and self.section.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.number.yfilter != YFilter.not_set or
                                                    self.index.yfilter != YFilter.not_set or
                                                    self.last_clear15_min_time.yfilter != YFilter.not_set or
                                                    self.last_clear24_hr_time.yfilter != YFilter.not_set or
                                                    self.last_clear_time.yfilter != YFilter.not_set or
                                                    self.timestamp.yfilter != YFilter.not_set or
                                                    self.valid.yfilter != YFilter.not_set or
                                                    (self.fe_line is not None and self.fe_line.has_operation()) or
                                                    (self.line is not None and self.line.has_operation()) or
                                                    (self.section is not None and self.section.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "oc-minute15ocn-time-line-instance" + "[number='" + self.number.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.number.get_name_leafdata())
                                                if (self.index.is_set or self.index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.index.get_name_leafdata())
                                                if (self.last_clear15_min_time.is_set or self.last_clear15_min_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear15_min_time.get_name_leafdata())
                                                if (self.last_clear24_hr_time.is_set or self.last_clear24_hr_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear24_hr_time.get_name_leafdata())
                                                if (self.last_clear_time.is_set or self.last_clear_time.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.last_clear_time.get_name_leafdata())
                                                if (self.timestamp.is_set or self.timestamp.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.timestamp.get_name_leafdata())
                                                if (self.valid.is_set or self.valid.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.valid.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "fe-line"):
                                                    if (self.fe_line is None):
                                                        self.fe_line = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.FeLine()
                                                        self.fe_line.parent = self
                                                        self._children_name_map["fe_line"] = "fe-line"
                                                    return self.fe_line

                                                if (child_yang_name == "line"):
                                                    if (self.line is None):
                                                        self.line = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Line()
                                                        self.line.parent = self
                                                        self._children_name_map["line"] = "line"
                                                    return self.line

                                                if (child_yang_name == "section"):
                                                    if (self.section is None):
                                                        self.section = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance.Section()
                                                        self.section.parent = self
                                                        self._children_name_map["section"] = "section"
                                                    return self.section

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "fe-line" or name == "line" or name == "section" or name == "number" or name == "index" or name == "last-clear15-min-time" or name == "last-clear24-hr-time" or name == "last-clear-time" or name == "timestamp" or name == "valid"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "number"):
                                                    self.number = value
                                                    self.number.value_namespace = name_space
                                                    self.number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "index"):
                                                    self.index = value
                                                    self.index.value_namespace = name_space
                                                    self.index.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear15-min-time"):
                                                    self.last_clear15_min_time = value
                                                    self.last_clear15_min_time.value_namespace = name_space
                                                    self.last_clear15_min_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear24-hr-time"):
                                                    self.last_clear24_hr_time = value
                                                    self.last_clear24_hr_time.value_namespace = name_space
                                                    self.last_clear24_hr_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "last-clear-time"):
                                                    self.last_clear_time = value
                                                    self.last_clear_time.value_namespace = name_space
                                                    self.last_clear_time.value_namespace_prefix = name_space_prefix
                                                if(value_path == "timestamp"):
                                                    self.timestamp = value
                                                    self.timestamp.value_namespace = name_space
                                                    self.timestamp.value_namespace_prefix = name_space_prefix
                                                if(value_path == "valid"):
                                                    self.valid = value
                                                    self.valid.value_namespace = name_space
                                                    self.valid.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.oc_minute15ocn_time_line_instance:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.oc_minute15ocn_time_line_instance:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "oc-minute15ocn-time-line-instances" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "oc-minute15ocn-time-line-instance"):
                                                for c in self.oc_minute15ocn_time_line_instance:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances.OcMinute15OcnTimeLineInstance()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.oc_minute15ocn_time_line_instance.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "oc-minute15ocn-time-line-instance"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.number.is_set or
                                            (self.oc_minute15ocn_time_line_instances is not None and self.oc_minute15ocn_time_line_instances.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.number.yfilter != YFilter.not_set or
                                            (self.oc_minute15ocn_time_line_instances is not None and self.oc_minute15ocn_time_line_instances.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "oc-minute15ocn-history" + "[number='" + self.number.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.number.is_set or self.number.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.number.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "oc-minute15ocn-time-line-instances"):
                                            if (self.oc_minute15ocn_time_line_instances is None):
                                                self.oc_minute15ocn_time_line_instances = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory.OcMinute15OcnTimeLineInstances()
                                                self.oc_minute15ocn_time_line_instances.parent = self
                                                self._children_name_map["oc_minute15ocn_time_line_instances"] = "oc-minute15ocn-time-line-instances"
                                            return self.oc_minute15ocn_time_line_instances

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "oc-minute15ocn-time-line-instances" or name == "number"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "number"):
                                            self.number = value
                                            self.number.value_namespace = name_space
                                            self.number.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.oc_minute15ocn_history:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.oc_minute15ocn_history:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "oc-minute15ocn-histories" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "oc-minute15ocn-history"):
                                        for c in self.oc_minute15ocn_history:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories.OcMinute15OcnHistory()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.oc_minute15ocn_history.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "oc-minute15ocn-history"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.oc_minute15ocn_histories is not None and self.oc_minute15ocn_histories.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.oc_minute15ocn_histories is not None and self.oc_minute15ocn_histories.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "oc-minute15-history" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "oc-minute15ocn-histories"):
                                    if (self.oc_minute15ocn_histories is None):
                                        self.oc_minute15ocn_histories = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History.OcMinute15OcnHistories()
                                        self.oc_minute15ocn_histories.parent = self
                                        self._children_name_map["oc_minute15ocn_histories"] = "oc-minute15ocn-histories"
                                    return self.oc_minute15ocn_histories

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "oc-minute15ocn-histories"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.name.is_set or
                                (self.oc_hour24_history is not None and self.oc_hour24_history.has_data()) or
                                (self.oc_minute15_history is not None and self.oc_minute15_history.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.name.yfilter != YFilter.not_set or
                                (self.oc_hour24_history is not None and self.oc_hour24_history.has_operation()) or
                                (self.oc_minute15_history is not None and self.oc_minute15_history.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "oc-port-history" + "[name='" + self.name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/oc-history/oc-port-histories/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.name.is_set or self.name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "oc-hour24-history"):
                                if (self.oc_hour24_history is None):
                                    self.oc_hour24_history = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcHour24History()
                                    self.oc_hour24_history.parent = self
                                    self._children_name_map["oc_hour24_history"] = "oc-hour24-history"
                                return self.oc_hour24_history

                            if (child_yang_name == "oc-minute15-history"):
                                if (self.oc_minute15_history is None):
                                    self.oc_minute15_history = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory.OcMinute15History()
                                    self.oc_minute15_history.parent = self
                                    self._children_name_map["oc_minute15_history"] = "oc-minute15-history"
                                return self.oc_minute15_history

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "oc-hour24-history" or name == "oc-minute15-history" or name == "name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "name"):
                                self.name = value
                                self.name.value_namespace = name_space
                                self.name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.oc_port_history:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.oc_port_history:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "oc-port-histories" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/oc-history/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "oc-port-history"):
                            for c in self.oc_port_history:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories.OcPortHistory()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.oc_port_history.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "oc-port-history"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.oc_port_histories is not None and self.oc_port_histories.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.oc_port_histories is not None and self.oc_port_histories.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "oc-history" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/periodic/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "oc-port-histories"):
                        if (self.oc_port_histories is None):
                            self.oc_port_histories = PerformanceManagementHistory.Global_.Periodic.OcHistory.OcPortHistories()
                            self.oc_port_histories.parent = self
                            self._children_name_map["oc_port_histories"] = "oc-port-histories"
                        return self.oc_port_histories

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "oc-port-histories"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.dwdm_history is not None and self.dwdm_history.has_data()) or
                    (self.ethernet_history is not None and self.ethernet_history.has_data()) or
                    (self.ho_vc_history is not None and self.ho_vc_history.has_data()) or
                    (self.oc_history is not None and self.oc_history.has_data()) or
                    (self.odu_history is not None and self.odu_history.has_data()) or
                    (self.optics_history is not None and self.optics_history.has_data()) or
                    (self.otu_history is not None and self.otu_history.has_data()) or
                    (self.sonet_history is not None and self.sonet_history.has_data()) or
                    (self.stm_history is not None and self.stm_history.has_data()) or
                    (self.sts_history is not None and self.sts_history.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.dwdm_history is not None and self.dwdm_history.has_operation()) or
                    (self.ethernet_history is not None and self.ethernet_history.has_operation()) or
                    (self.ho_vc_history is not None and self.ho_vc_history.has_operation()) or
                    (self.oc_history is not None and self.oc_history.has_operation()) or
                    (self.odu_history is not None and self.odu_history.has_operation()) or
                    (self.optics_history is not None and self.optics_history.has_operation()) or
                    (self.otu_history is not None and self.otu_history.has_operation()) or
                    (self.sonet_history is not None and self.sonet_history.has_operation()) or
                    (self.stm_history is not None and self.stm_history.has_operation()) or
                    (self.sts_history is not None and self.sts_history.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "periodic" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/global/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "dwdm-history"):
                    if (self.dwdm_history is None):
                        self.dwdm_history = PerformanceManagementHistory.Global_.Periodic.DwdmHistory()
                        self.dwdm_history.parent = self
                        self._children_name_map["dwdm_history"] = "dwdm-history"
                    return self.dwdm_history

                if (child_yang_name == "ethernet-history"):
                    if (self.ethernet_history is None):
                        self.ethernet_history = PerformanceManagementHistory.Global_.Periodic.EthernetHistory()
                        self.ethernet_history.parent = self
                        self._children_name_map["ethernet_history"] = "ethernet-history"
                    return self.ethernet_history

                if (child_yang_name == "ho-vc-history"):
                    if (self.ho_vc_history is None):
                        self.ho_vc_history = PerformanceManagementHistory.Global_.Periodic.HoVcHistory()
                        self.ho_vc_history.parent = self
                        self._children_name_map["ho_vc_history"] = "ho-vc-history"
                    return self.ho_vc_history

                if (child_yang_name == "oc-history"):
                    if (self.oc_history is None):
                        self.oc_history = PerformanceManagementHistory.Global_.Periodic.OcHistory()
                        self.oc_history.parent = self
                        self._children_name_map["oc_history"] = "oc-history"
                    return self.oc_history

                if (child_yang_name == "odu-history"):
                    if (self.odu_history is None):
                        self.odu_history = PerformanceManagementHistory.Global_.Periodic.OduHistory()
                        self.odu_history.parent = self
                        self._children_name_map["odu_history"] = "odu-history"
                    return self.odu_history

                if (child_yang_name == "optics-history"):
                    if (self.optics_history is None):
                        self.optics_history = PerformanceManagementHistory.Global_.Periodic.OpticsHistory()
                        self.optics_history.parent = self
                        self._children_name_map["optics_history"] = "optics-history"
                    return self.optics_history

                if (child_yang_name == "otu-history"):
                    if (self.otu_history is None):
                        self.otu_history = PerformanceManagementHistory.Global_.Periodic.OtuHistory()
                        self.otu_history.parent = self
                        self._children_name_map["otu_history"] = "otu-history"
                    return self.otu_history

                if (child_yang_name == "sonet-history"):
                    if (self.sonet_history is None):
                        self.sonet_history = PerformanceManagementHistory.Global_.Periodic.SonetHistory()
                        self.sonet_history.parent = self
                        self._children_name_map["sonet_history"] = "sonet-history"
                    return self.sonet_history

                if (child_yang_name == "stm-history"):
                    if (self.stm_history is None):
                        self.stm_history = PerformanceManagementHistory.Global_.Periodic.StmHistory()
                        self.stm_history.parent = self
                        self._children_name_map["stm_history"] = "stm-history"
                    return self.stm_history

                if (child_yang_name == "sts-history"):
                    if (self.sts_history is None):
                        self.sts_history = PerformanceManagementHistory.Global_.Periodic.StsHistory()
                        self.sts_history.parent = self
                        self._children_name_map["sts_history"] = "sts-history"
                    return self.sts_history

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "dwdm-history" or name == "ethernet-history" or name == "ho-vc-history" or name == "oc-history" or name == "odu-history" or name == "optics-history" or name == "otu-history" or name == "sonet-history" or name == "stm-history" or name == "sts-history"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (self.periodic is not None and self.periodic.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.periodic is not None and self.periodic.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "global" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "periodic"):
                if (self.periodic is None):
                    self.periodic = PerformanceManagementHistory.Global_.Periodic()
                    self.periodic.parent = self
                    self._children_name_map["periodic"] = "periodic"
                return self.periodic

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "periodic"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (self.global_ is not None and self.global_.has_data())

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.global_ is not None and self.global_.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-pmengine-oper:performance-management-history" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "global"):
            if (self.global_ is None):
                self.global_ = PerformanceManagementHistory.Global_()
                self.global_.parent = self
                self._children_name_map["global_"] = "global"
            return self.global_

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "global"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = PerformanceManagementHistory()
        return self._top_entity

